@@ -50,30 +50,18 @@ extern gchar *CYA_FLT_TYPE[];
 extern gchar *CYA_FLT_STATUS[];
 
 
+static void register_panel_export_csv(GtkWidget *widget, gpointer user_data);
+static void register_panel_edit_multiple(GtkWidget *widget, Transaction *txn, gint column_id, gpointer user_data);
+static void register_panel_make_assignment(GtkWidget *widget, gpointer user_data);
+static void register_panel_make_archive(GtkWidget *widget, gpointer user_data);
 static void register_panel_collect_filtered_txn(GtkWidget *view, gboolean emptysearch);
 static void register_panel_listview_populate(GtkWidget *view);
+static void register_panel_add_after_propagate(struct register_panel_data *data, Transaction *add_txn);
+static void register_panel_add_single_transaction(GtkWindow *window, Transaction *txn);
 static void register_panel_action(GtkWidget *widget, gpointer user_data);
+static void register_panel_selection(GtkTreeSelection *treeselection, gpointer user_data);
 static void register_panel_update(GtkWidget *widget, gpointer user_data);
 
-static void register_panel_export_csv(GtkWidget *widget, gpointer user_data);
-
-static void register_panel_make_archive(GtkWidget *widget, gpointer user_data);
-static void register_panel_make_assignment(GtkWidget *widget, gpointer user_data);
-
-static void status_selected_foreach_func (GtkTreeModel	*model, GtkTreePath	 *path, GtkTreeIter	 *iter, gpointer userdata);
-
-static void register_panel_edit_multiple(GtkWidget *widget, Transaction *txn, gint column_id, gpointer user_data);
-
-static void register_panel_selection(GtkTreeSelection *treeselection, gpointer user_data);
-static void register_panel_onRowActivated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *col, gpointer userdata);
-
-static void txn_list_add_by_value(GtkTreeView *treeview, Transaction *ope);
-
-static void register_panel_add_single_transaction(GtkWindow *window, Transaction *txn);
-
-static void register_panel_add_after_propagate(struct register_panel_data *data, Transaction *add_txn);
-
-static gint txn_list_get_count_reconciled(GtkTreeView *treeview);
 
 /* account action functions -------------------- */
 
@@ -141,6 +129,7 @@ struct register_panel_data *data = user_data;
 	register_panel_action(data->window, GINT_TO_POINTER(ACTION_ACCOUNT_DELETE));
 }
 
+
 static void register_panel_action_find(GtkMenuItem *menuitem, gpointer     user_data)
 {
 struct register_panel_data *data = user_data;
@@ -536,7 +525,7 @@ gboolean lockrecon;
 	if(data->showall)
 		return;
 
-	DB( g_print("action assign\n") );
+	DB( g_print("\n[register] assign\n") );
 
 	lockrecon = gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled));
 
@@ -571,7 +560,7 @@ static void register_panel_action_close(GtkMenuItem *menuitem, gpointer     user
 {
 struct register_panel_data *data = user_data;
 
-	DB( g_print("action close\n") );
+	DB( g_print("\n[register] close\n") );
 
 	DB( g_print("window %p\n", data->window) );
 
@@ -605,8 +594,6 @@ gboolean hassplit, hasstatus;
 	if( ui_dialog_export_csv(GTK_WINDOW(data->window), &filepath, &hassplit, &hasstatus, data->showall) == GTK_RESPONSE_ACCEPT )
 	{
 		DB( g_printf(" filename is '%s'\n", filepath) );
-		DB( g_printf(" detail split %d\n", detailsplit) );
-		DB( g_printf(" status column '%d'\n", statcol) );
 
 		io = g_io_channel_new_file(filepath, "w", NULL);
 		if(io != NULL)
@@ -901,13 +888,7 @@ struct register_panel_data *data;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 	
-	DB( g_print(" changes is %d\n", state) );
-	
-	gtk_image_set_from_icon_name(GTK_IMAGE(data->IM_lockreconciled), state == TRUE ? ICONNAME_CHANGES_PREVENT : ICONNAME_CHANGES_ALLOW, GTK_ICON_SIZE_BUTTON);
-
-	//5.6 add lockreconciled icon
-	list_txn_set_lockreconciled(GTK_TREE_VIEW(data->LV_ope), state);
-	gtk_widget_queue_draw (data->LV_ope);
+	DB( g_print(" state=%d switch=%d\n", state, gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled)) ) );
 
 	register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE));
 
@@ -931,8 +912,9 @@ gint range;
 
 	data->filter->nbdaysfuture = 0;
 
-	if(range != FLT_RANGE_OTHER)
-	{
+	//in 5.6 no longer custom open the filter
+	//if(range != FLT_RANGE_OTHER)
+	//{
 		filter_preset_daterange_set(data->filter, range, (data->showall == FALSE) ? data->acc->key : 0);
 		// add eventual x days into future display
 		if( future && (PREFS->date_future_nbdays > 0) )
@@ -940,7 +922,7 @@ gint range;
 		
 		register_panel_collect_filtered_txn(data->LV_ope, FALSE);
 		register_panel_listview_populate(data->LV_ope);
-	}
+	/*}
 	else
 	{
 		if(ui_flt_manage_dialog_new(GTK_WINDOW(data->window), data->filter, data->showall, TRUE) != GTK_RESPONSE_REJECT)
@@ -949,7 +931,7 @@ gint range;
 			register_panel_listview_populate(data->LV_ope);
 			register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE+FLG_REG_BALANCE));
 		}
-	}
+	}*/
 }
 
 
@@ -1065,7 +1047,7 @@ gushort lpos = 1;
 	if(data->showall)
 		return;
 
-	DB( g_print("\n[account %d] balance refresh\n", data->acc != NULL ? (gint)data->acc->key : -1) );
+	DB( g_print("\n[register] balance refresh kacc=%d\n", data->acc != NULL ? (gint)data->acc->key : -1) );
 
 	balance = data->acc->initial;
 
@@ -1214,13 +1196,13 @@ guint i, qs_flag;
 	// ref model to keep it
 	//g_object_ref(model);
 	//gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_ope), NULL);
-	gtk_list_store_clear (GTK_LIST_STORE(model));
+	gtk_tree_store_clear (GTK_TREE_STORE(model));
 
 
 	// perf: if you leave the sort, insert is damned slow
-	gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE(GTK_LIST_STORE(model)), &sort_column_id, &order);
+	gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE(GTK_TREE_STORE(model)), &sort_column_id, &order);
 	
-	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(GTK_LIST_STORE(model)), GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID, PREFS->lst_ope_sort_order);
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(GTK_TREE_STORE(model)), GTK_TREE_SORTABLE_UNSORTED_SORT_COLUMN_ID, PREFS->lst_ope_sort_order);
 
 	hastext = (gtk_entry_get_text_length (GTK_ENTRY(data->ST_search)) >= 2) ? TRUE : FALSE;
 	needle = (gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_search));
@@ -1249,7 +1231,7 @@ guint i, qs_flag;
 		{
 			//gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 	 		//gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-	 		gtk_list_store_insert_with_values(GTK_LIST_STORE(model), &iter, -1,
+	 		gtk_tree_store_insert_with_values(GTK_TREE_STORE(model), &iter, NULL, -1,
 				MODEL_TXN_POINTER, txn,
 				-1);
 
@@ -1266,7 +1248,7 @@ guint i, qs_flag;
 	//g_object_unref(model);
 
 	// push back the sort id
-	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(GTK_LIST_STORE(model)), sort_column_id, order);
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(GTK_TREE_STORE(model)), sort_column_id, order);
 
 	/* update info range text */
 	{
@@ -1282,7 +1264,7 @@ guint i, qs_flag;
 
 }
 
-static gint txn_list_get_count_reconciled(GtkTreeView *treeview)
+static gint list_txn_get_count_reconciled(GtkTreeView *treeview)
 {
 GtkTreeModel *model;
 GList *lselection, *list;
@@ -1313,7 +1295,7 @@ gint count = 0;
 }
 
 
-static void txn_list_add_by_value(GtkTreeView *treeview, Transaction *ope)
+static void list_txn_add_by_value(GtkTreeView *treeview, Transaction *ope)
 {
 GtkTreeModel *model;
 GtkTreeIter  iter;
@@ -1326,8 +1308,8 @@ GtkTreeIter  iter;
 	DB( g_print("\n[transaction] add_treeview\n") );
 
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
-	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-	gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+	gtk_tree_store_append (GTK_TREE_STORE(model), &iter, NULL);
+	gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
 		MODEL_TXN_POINTER, ope,
 		-1);
 
@@ -1344,7 +1326,7 @@ GtkTreeIter  iter;
 
 
 /* used to remove a intxfer child from a treeview */
-static void txn_list_remove_by_value(GtkTreeModel *model, Transaction *txn)
+static void list_txn_remove_by_value(GtkTreeModel *model, Transaction *txn)
 {
 GtkTreeIter iter;
 gboolean valid;
@@ -1365,7 +1347,7 @@ gboolean valid;
 
 		if( txn == tmp )
 		{
-			gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
+			gtk_tree_store_remove(GTK_TREE_STORE(model), &iter);
 			break;
 		}
 		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
@@ -1374,7 +1356,7 @@ gboolean valid;
 
 
 // this func to some toggle
-static void status_selected_foreach_func (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer userdata)
+static void list_txn_status_selected_foreach_func (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer userdata)
 {
 gint targetstatus = GPOINTER_TO_INT(userdata);
 Transaction *txn;
@@ -1443,7 +1425,7 @@ static void register_panel_add_after_propagate(struct register_panel_data *data,
 
 	if((data->showall == TRUE) || ( (data->acc != NULL) && (add_txn->kacc == data->acc->key) ) )
 	{
-		txn_list_add_by_value(GTK_TREE_VIEW(data->LV_ope), add_txn);
+		list_txn_add_by_value(GTK_TREE_VIEW(data->LV_ope), add_txn);
 		//#1716181 also add to the ptr_array (quickfilter)
 		g_ptr_array_add(data->gpatxn, (gpointer)add_txn);
 
@@ -1467,7 +1449,7 @@ static void register_panel_add_after_propagate(struct register_panel_data *data,
 }
 
 
-static void remove_active_transaction(GtkTreeView *treeview)
+static void lst_txn_remove_active_transaction(GtkTreeView *treeview)
 {
 GtkTreeModel *model;
 GList *list;
@@ -1480,7 +1462,7 @@ GList *list;
 	GtkTreeIter iter;
 
 		gtk_tree_model_get_iter(model, &iter, list->data);
-		gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
+		gtk_tree_store_remove(GTK_TREE_STORE(model), &iter);
 	}
 
 	g_list_foreach(list, (GFunc)gtk_tree_path_free, NULL);
@@ -1501,7 +1483,7 @@ struct register_panel_data *data;
 	
 	data = g_object_get_data(G_OBJECT(window), "inst_data");
 
-	txn_list_add_by_value(GTK_TREE_VIEW(data->LV_ope), txn);
+	list_txn_add_by_value(GTK_TREE_VIEW(data->LV_ope), txn);
 }
 
 
@@ -1634,7 +1616,7 @@ gboolean result;
 					{
 					GtkWindow *accwin = account_window(new_txn->kacc);
 						
-						remove_active_transaction(GTK_TREE_VIEW(data->LV_ope));
+						lst_txn_remove_active_transaction(GTK_TREE_VIEW(data->LV_ope));
 						//#1667501 update target account window if open
 						if(accwin)
 						{
@@ -1710,7 +1692,7 @@ gboolean result;
 						g_ptr_array_remove(data->gpatxn, (gpointer)rem_txn);
 
 						// 1) remove visible current and potential xfer
-						gtk_list_store_remove(GTK_LIST_STORE(model), &iter);
+						gtk_tree_store_remove(GTK_TREE_STORE(model), &iter);
 
 						//manage target open window as well
 						if((rem_txn->flags & OF_INTXFER))
@@ -1720,7 +1702,7 @@ gboolean result;
 							{
 								if( data->showall )
 								{
-									txn_list_remove_by_value(model, child);
+									list_txn_remove_by_value(model, child);
 									//#1716181 also remove from the ptr_array (quickfilter)				
 									g_ptr_array_remove(data->gpatxn, (gpointer)child);
 									data->total--;
@@ -1755,7 +1737,7 @@ gboolean result;
 		GtkTreeSelection *selection;
 		gint count, result;
 			
-			count = txn_list_get_count_reconciled(GTK_TREE_VIEW(data->LV_ope));
+			count = list_txn_get_count_reconciled(GTK_TREE_VIEW(data->LV_ope));
 
 			if(count > 0 )
 			{
@@ -1774,7 +1756,7 @@ gboolean result;
 			if( result == GTK_RESPONSE_OK )
 			{
 				selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope));
-				gtk_tree_selection_selected_foreach(selection, (GtkTreeSelectionForeachFunc)status_selected_foreach_func, 
+				gtk_tree_selection_selected_foreach(selection, (GtkTreeSelectionForeachFunc)list_txn_status_selected_foreach_func, 
 					GINT_TO_POINTER(TXN_STATUS_NONE));
 
 				DB( g_print(" - none\n") );
@@ -1795,7 +1777,7 @@ gboolean result;
 			GtkTreeSelection *selection;
 			
 			selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope));
-			gtk_tree_selection_selected_foreach(selection, (GtkTreeSelectionForeachFunc)status_selected_foreach_func, 
+			gtk_tree_selection_selected_foreach(selection, (GtkTreeSelectionForeachFunc)list_txn_status_selected_foreach_func, 
 				GINT_TO_POINTER(TXN_STATUS_CLEARED));
 
 			DB( g_print(" - clear\n") );
@@ -1814,7 +1796,7 @@ gboolean result;
 		GtkTreeSelection *selection;
 		gint count, result;
 			
-			count = txn_list_get_count_reconciled(GTK_TREE_VIEW(data->LV_ope));
+			count = list_txn_get_count_reconciled(GTK_TREE_VIEW(data->LV_ope));
 
 			if(count > 0 )
 			{
@@ -1833,7 +1815,7 @@ gboolean result;
 			if( result == GTK_RESPONSE_OK )
 			{
 				selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope));
-				gtk_tree_selection_selected_foreach(selection, (GtkTreeSelectionForeachFunc)status_selected_foreach_func, 
+				gtk_tree_selection_selected_foreach(selection, (GtkTreeSelectionForeachFunc)list_txn_status_selected_foreach_func, 
 					GINT_TO_POINTER(TXN_STATUS_RECONCILED));
 
 				DB( g_print(" - reconcile\n") );
@@ -1859,7 +1841,7 @@ gboolean result;
 				register_panel_update(data->LV_ope, GINT_TO_POINTER(FLG_REG_SENSITIVE+FLG_REG_BALANCE));
 
 				g_signal_handler_block(data->CY_range, data->handler_id[HID_RANGE]);
-				hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_OTHER);
+				hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_MISC_CUSTOM);
 				g_signal_handler_unblock(data->CY_range, data->handler_id[HID_RANGE]);
 			}
 
@@ -1929,13 +1911,13 @@ static void register_panel_update(GtkWidget *widget, gpointer user_data)
 struct register_panel_data *data;
 GtkTreeSelection *selection;
 gint flags = GPOINTER_TO_INT(user_data);
-gboolean visible;
+gboolean lockrecon, visible;
 gint count = 0;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 	//data = INST_DATA(widget);
 
-	DB( g_print("\n[account %d] update\n", data->acc != NULL ? (gint)data->acc->key : -1) );
+	DB( g_print("\n[register] update kacc=%d\n", data->acc != NULL ? (gint)data->acc->key : -1) );
 
 	
 	GLOBALS->minor = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_minor));
@@ -1943,14 +1925,16 @@ gint count = 0;
 	/* set window title */
 	if(flags & FLG_REG_TITLE)
 	{
-		DB( g_print(" - FLG_REG_TITLE\n") );
+		DB( g_print(" FLG_REG_TITLE\n") );
 
 	}
 
 	/* update toolbar & list */
 	if(flags & FLG_REG_VISUAL)
 	{
-		DB( g_print(" - FLG_REG_VISUAL\n") );
+	//gboolean visible;
+		
+		DB( g_print(" FLG_REG_VISUAL\n") );
 
 		if(PREFS->toolbar_style == 0)
 			gtk_toolbar_unset_style(GTK_TOOLBAR(data->TB_bar));
@@ -1964,7 +1948,7 @@ gint count = 0;
 	/* update balances */
 	if(flags & FLG_REG_BALANCE)
 	{
-		DB( g_print(" - FLG_REG_BALANCE\n") );
+		DB( g_print(" FLG_REG_BALANCE\n") );
 
 		if(data->showall == FALSE)
 		{
@@ -2008,13 +1992,13 @@ gint count = 0;
 	/* update disabled things */
 	if(flags & FLG_REG_SENSITIVE)
 	{
-	gboolean lockreconciled, sensitive, psensitive, nsensitive;
+	gboolean sensitive, psensitive, nsensitive;
 	GtkTreeModel *model;
 	gint sort_column_id;
 	GtkSortType order;
 	Transaction *ope;
 
-		DB( g_print(" - FLG_REG_SENSITIVE\n") );
+		DB( g_print(" FLG_REG_SENSITIVE\n") );
 
 		selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_ope));
 		count = gtk_tree_selection_count_selected_rows(selection);
@@ -2034,15 +2018,15 @@ gint count = 0;
 		hb_widget_visible(data->MI_chkintxfer, visible);
 		//#1873248 Auto. assignments faulty visible on 'All transactions' window
 		hb_widget_visible(data->MI_autoassign, visible);
-		
+
 		//1909749 lock/unlock reconciled
-		lockreconciled = !gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled));
+		lockrecon = gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled));
 		if( ope != NULL )
 		{
 			if( (ope->status != TXN_STATUS_RECONCILED) )
-				lockreconciled = TRUE;
+				lockrecon = FALSE;
 
-			DB( g_print(" - lockreconciled = %d (%d %d)\n", lockreconciled, ope->status != TXN_STATUS_RECONCILED, gtk_switch_get_state (GTK_SWITCH(data->SW_lockreconciled)) ) );
+			DB( g_print(" - lockrecon = %d (%d %d)\n", lockrecon, ope->status != TXN_STATUS_RECONCILED, gtk_switch_get_state (GTK_SWITCH(data->SW_lockreconciled)) ) );
 		}
 
 
@@ -2061,10 +2045,10 @@ gint count = 0;
 		sensitive = (count != 1 ) ? FALSE : TRUE;
 		gtk_widget_set_sensitive(data->MI_herit, sensitive);
 		gtk_widget_set_sensitive(data->MI_popherit, sensitive);
-		gtk_widget_set_sensitive(data->MI_edit, lockreconciled ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->MI_popedit, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->MI_edit, lockrecon ? FALSE : sensitive);
+		gtk_widget_set_sensitive(data->MI_popedit, lockrecon ? FALSE : sensitive);
 		gtk_widget_set_sensitive(data->BT_herit, sensitive);
-		gtk_widget_set_sensitive(data->BT_edit, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->BT_edit, lockrecon ? FALSE : sensitive);
 		gtk_widget_set_sensitive(data->MI_popcopyamount, sensitive);
 
 		//txn have split
@@ -2074,7 +2058,7 @@ gint count = 0;
 		// single: disable multiedit
 		sensitive = (count <= 1 ) ? FALSE : TRUE;
 		//1909749 lock/unlock reconciled
-		if( (txn_list_get_count_reconciled(GTK_TREE_VIEW(data->LV_ope)) > 0) && (gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled)) == TRUE) )
+		if( (list_txn_get_count_reconciled(GTK_TREE_VIEW(data->LV_ope)) > 0) && (gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled)) == TRUE) )
 			sensitive = FALSE;
 		gtk_widget_set_sensitive(data->MI_multiedit   , sensitive);
 		gtk_widget_set_sensitive(data->MI_popmultiedit, sensitive);
@@ -2083,17 +2067,17 @@ gint count = 0;
 		// no selection: disable reconcile, delete
 		sensitive = (count > 0 ) ? TRUE : FALSE;
 		gtk_widget_set_sensitive(data->MI_copy, sensitive);
-		gtk_widget_set_sensitive(data->ME_menustatus, lockreconciled ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->ME_popmenustatus, lockreconciled ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->MI_delete, lockreconciled ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->MI_popdelete, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->ME_menustatus, lockrecon ? FALSE : sensitive);
+		gtk_widget_set_sensitive(data->ME_popmenustatus, lockrecon ? FALSE : sensitive);
+		gtk_widget_set_sensitive(data->MI_delete, lockrecon ? FALSE : sensitive);
+		gtk_widget_set_sensitive(data->MI_popdelete, lockrecon ? FALSE : sensitive);
 		gtk_widget_set_sensitive(data->MI_assign, sensitive);
 		gtk_widget_set_sensitive(data->MI_popassign, sensitive);
 		gtk_widget_set_sensitive(data->MI_template, sensitive);
 		gtk_widget_set_sensitive(data->MI_poptemplate, sensitive);
-		gtk_widget_set_sensitive(data->BT_delete, lockreconciled ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->BT_clear, lockreconciled ? sensitive : FALSE);
-		gtk_widget_set_sensitive(data->BT_reconcile, lockreconciled ? sensitive : FALSE);
+		gtk_widget_set_sensitive(data->BT_delete, lockrecon ? FALSE : sensitive);
+		gtk_widget_set_sensitive(data->BT_clear, lockrecon ? FALSE : sensitive);
+		gtk_widget_set_sensitive(data->BT_reconcile, lockrecon ? FALSE : sensitive);
 		gtk_widget_set_sensitive(data->BT_template, sensitive);
 
 		//edit menu
@@ -2117,7 +2101,7 @@ gint count = 0;
 
 			visible = TRUE;
 			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_ope));
-			gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE(GTK_LIST_STORE(model)), &sort_column_id, &order);
+			gtk_tree_sortable_get_sort_column_id (GTK_TREE_SORTABLE(GTK_TREE_STORE(model)), &sort_column_id, &order);
 			if( (data->showall == TRUE) || (sort_column_id != LST_DSPOPE_DATE) )
 				visible = FALSE;
 
@@ -2234,12 +2218,15 @@ gint count = 0;
 	gtk_label_set_markup(GTK_LABEL(data->TX_selection), msg);
 	g_free (msg);
 
-	//update lock/unlock 
-	visible = gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled));
+	//5.6 update lock/unlock
+	lockrecon = gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled));
+	DB( g_print(" lockrecon=%d\n", lockrecon) );
+
+	list_txn_set_lockreconciled(GTK_TREE_VIEW(data->LV_ope), lockrecon);
+	gtk_image_set_from_icon_name(GTK_IMAGE(data->IM_lockreconciled), lockrecon == TRUE ? ICONNAME_CHANGES_PREVENT : ICONNAME_CHANGES_ALLOW, GTK_ICON_SIZE_BUTTON);
 	gtk_widget_set_tooltip_text (data->SW_lockreconciled, 
-		visible == TRUE ? _("Locked. Click to unlock") : _("Unlocked. Click to lock"));
-	
-	//gtk_label_set_label(GTK_LABEL(data->LB_lockreconciled), visible == TRUE ? _("Reconciled changes is permitted") : _("Change of reconciled is locked"));
+		lockrecon == TRUE ? _("Locked. Click to unlock") : _("Unlocked. Click to lock"));
+	gtk_widget_queue_draw (data->LV_ope);
 
 }
 
@@ -2251,7 +2238,7 @@ GtkTreeModel *model;
 GtkTreeIter iter;
 gint col_id, count;
 Transaction *ope;
-gboolean lockreconciled;
+gboolean lockrecon;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(treeview), GTK_TYPE_WINDOW)), "inst_data");
 
@@ -2272,11 +2259,11 @@ gboolean lockreconciled;
 	if( count == 1)
 	{
 		//1909749 lock/unlock reconciled	
-		lockreconciled = FALSE;
+		lockrecon = FALSE;
 		if( (ope->status == TXN_STATUS_RECONCILED) && (gtk_switch_get_active (GTK_SWITCH(data->SW_lockreconciled)) == TRUE) )
-			lockreconciled = TRUE;
+			lockrecon = TRUE;
 
-		if( lockreconciled == FALSE )
+		if( lockrecon == FALSE )
 		{
 			register_panel_action(GTK_WIDGET(treeview), GINT_TO_POINTER(ACTION_ACCOUNT_EDIT));
 		}
@@ -2468,13 +2455,22 @@ struct register_panel_data *data = user_data;
 
 static gint listview_context_cb (GtkWidget *widget, GdkEventButton *event, GtkWidget *menu)
 {
+struct register_panel_data *data;
 
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	//#1993088 register closed account popmenu should be disabled
+	if( data->acc != NULL )
+	{
+		if( data->acc->flags & AF_CLOSED )
+			goto end;
+	}
 	
 	if (event->type == GDK_BUTTON_PRESS && event->button == 3)
 	{
 
 		// check we are not in the header but in bin window
-		 if (event->window == gtk_tree_view_get_bin_window (GTK_TREE_VIEW (widget)))
+		if (event->window == gtk_tree_view_get_bin_window (GTK_TREE_VIEW (widget)))
 		{
 			#if( (GTK_MAJOR_VERSION == 3) && (GTK_MINOR_VERSION >= 22) )
 				gtk_menu_popup_at_pointer(GTK_MENU(menu), (GdkEvent *)event);
@@ -2488,7 +2484,8 @@ static gint listview_context_cb (GtkWidget *widget, GdkEventButton *event, GtkWi
 
 		// On indique à l'appelant que l'on n'a pas géré cet événement.
 	}
-		return FALSE;
+end:
+	return FALSE;
 }
 
 
@@ -2841,9 +2838,8 @@ gint row;
 	gtk_grid_attach (GTK_GRID(table), data->CY_status, row, 0, 1, 1);
 
 	row++;
-	//widget = gtk_button_new_with_mnemonic (_("Reset _filters"));
-	widget = gtk_button_new_with_mnemonic (_("_Reset"));
-	data->BT_reset = widget;
+	widget = make_image_button(ICONNAME_HB_FILTER, _("Open the list filter"));
+	data->BT_filter = widget;
 	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
 
 	row++;
@@ -2852,8 +2848,9 @@ gint row;
 	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
 
 	row++;
-	widget = make_image_button(ICONNAME_HB_FILTER, _("Open the list filter"));
-	data->BT_filter = widget;
+	//widget = gtk_button_new_with_mnemonic (_("Reset _filters"));
+	widget = gtk_button_new_with_mnemonic (_("_Reset"));
+	data->BT_reset = widget;
 	gtk_grid_attach (GTK_GRID(table), widget, row, 0, 1, 1);
 
 	row++;
