@@ -1110,10 +1110,17 @@ gint r;
 			hbfile_file_hasrevert(GLOBALS->xhb_filepath);
 			
 			if(PREFS->appendscheduled)
+			{
+				DB( g_print(" - auto: post all pending\n") );
 				scheduled_post_all_pending();
+			}
 
 			if(PREFS->do_update_currency)
+			{
+				DB( g_print(" - auto: update currency\n") );
+				//TODO: currency_needs_online
 				ui_cur_manage_dialog_update_currencies(GTK_WINDOW(GLOBALS->mainwindow));
+			}
 
 			homebank_lastopenedfiles_save();
 
@@ -1122,6 +1129,7 @@ gint r;
 			account_transaction_sort();
 
 			//TODO: delete this after computing done at xml read
+			DB( g_print(" - compute balance\n") );
 			account_compute_balances();
 
 			ui_mainwindow_recent_add(data, GLOBALS->xhb_filepath);
@@ -1153,6 +1161,8 @@ gint r;
 
 		}
 
+		DB( g_print(" - start update window\n") );
+
 		ui_hub_account_populate(GLOBALS->mainwindow, NULL);
 		ui_hub_scheduled_populate(GLOBALS->mainwindow, NULL);
 		ui_hub_spending_populate(GLOBALS->mainwindow, NULL);
@@ -1862,6 +1872,7 @@ GtkAccelGroup *accel_group = NULL;
 
 	menu = hbtk_menubar_add_menu(menubar, _("_Manage"), &data->ME_menuman);
 
+		data->MI_manwal = hbtk_menu_add_menuitem(menu, _("Wallet..."));
 		data->MI_manacc = hbtk_menu_add_menuitem(menu, _("Acc_ounts..."));
 		data->MI_manpay = hbtk_menu_add_menuitem(menu, _("_Payees..."));
 		data->MI_mancat = hbtk_menu_add_menuitem(menu, _("Categories..."));
@@ -2161,6 +2172,7 @@ GtkWidget *window;
 	g_signal_connect (data->MI_showbotlist , "toggled", G_CALLBACK (ui_mainwindow_action_toggle_upcoming), (gpointer)data);
 	g_signal_connect (data->MI_eurominor , "toggled", G_CALLBACK (ui_mainwindow_action_toggle_minor), (gpointer)data);
 
+	g_signal_connect (data->MI_manwal , "activate", G_CALLBACK (ui_mainwindow_action_properties), (gpointer)data);
 	g_signal_connect (data->MI_manacc , "activate", G_CALLBACK (ui_mainwindow_action_defaccount), (gpointer)data);
 	g_signal_connect (data->MI_manpay , "activate", G_CALLBACK (ui_mainwindow_action_defpayee), (gpointer)data);
 	g_signal_connect (data->MI_mancat , "activate", G_CALLBACK (ui_mainwindow_action_defcategory), (gpointer)data);
