@@ -79,6 +79,16 @@ enum
 };
 
 
+//
+enum
+{
+	HB_LIST_QUICK_SELECT_UNSET,
+	HB_LIST_QUICK_SELECT_ALL,
+	HB_LIST_QUICK_SELECT_NONE,
+	HB_LIST_QUICK_SELECT_INVERT
+};
+
+
 /*
 ** list pixbuf (account/transaction)
 *//*
@@ -105,10 +115,6 @@ enum
 };*/
 
 
-
-
-
-
-
-
 #endif
+
+
