@@ -457,12 +457,21 @@ gint i;
 
 	// collect other width, add margins
 	context->header_zh = (th / PANGO_SCALE) + CHART_SPACING;
-	context->cat_col_w = title_w + CHART_SPACING;
-
 	//chart->title_y = chart->t;
 	context->subtitle_y = context->t + context->title_zh;
 	context->header_y = context->subtitle_y + context->subtitle_zh;
 
+	//old pre 5.6	
+	//context->cat_col_w = title_w + CHART_SPACING;
+	double rem_w = context->w - context->bud_col_w - context->res_col_w - context->rel_col_w - (double)(CHART_SPACING*4);
+	if( (title_w + CHART_SPACING) <= (rem_w/3) )
+	{
+		context->cat_col_w   = title_w + CHART_SPACING;
+	}
+	else
+	{
+		context->cat_col_w = 	(rem_w/3);
+	}
 
 	context->graph_width  = context->w - context->cat_col_w - context->bud_col_w - context->res_col_w - context->rel_col_w - (double)(CHART_SPACING*4);
 	context->graph_height = context->h - context->title_zh - context->subtitle_zh - context->header_zh;
@@ -693,6 +702,7 @@ int tw, th;
 	//pango_font_description_set_size(chart->pfd, CHART_FONT_SIZE_NORMAL * PANGO_SCALE);
 	ui_chart_progress_set_font_size(chart, layout, CHART_FONT_SIZE_NORMAL);
 	pango_layout_set_font_description (layout, chart->pfd);
+	pango_layout_set_ellipsize(layout, PANGO_ELLIPSIZE_END);
 
 	for(i=0; i<context->visible ;i++)
 	{
@@ -725,7 +735,9 @@ int tw, th;
 			cairo_user_set_rgbacol (cr, &global_colors[THTEXT], 0.78);
 		else
 			cairo_user_set_rgbacol (cr, &global_colors[BLACK], 0.78);
-		cairo_move_to(cr, context->l + context->cat_col_w - (tw / PANGO_SCALE) - CHART_SPACING, ytext);
+		//cairo_move_to(cr, context->l + context->cat_col_w - (tw / PANGO_SCALE) - CHART_SPACING, ytext);
+		cairo_move_to(cr, context->l, ytext);
+		pango_layout_set_width(layout, context->cat_col_w * PANGO_SCALE);
 		pango_cairo_show_layout (cr, layout);
 
 		// bar background
