@@ -350,14 +350,24 @@ int tw, th;
 
 			if( chart->show_xval == TRUE )
 			{
-			ChartItem *item = &g_array_index(chart->items, ChartItem, i);
-
+				valstr = "";
+				
 				//TODO: we miss a vertical line here
-
-				valstr = item->label;
-
-				if( chart->type == CHART_TYPE_STACK || chart->type == CHART_TYPE_STACK100 )
-					valstr = chart->collabel[i];	
+				switch(chart->type)
+				{
+					case CHART_TYPE_COL:
+					case CHART_TYPE_LINE:
+					case CHART_TYPE_PIE:
+						{
+							ChartItem *item = &g_array_index(chart->items, ChartItem, i);
+							valstr = item->label;
+						}
+						break;
+					case CHART_TYPE_STACK:
+					case CHART_TYPE_STACK100:			
+						valstr = chart->collabel[i];	
+						break;
+				}
 
 				DBG( g_print(" x: %2d '%s'", i, valstr) );
 
@@ -871,7 +881,7 @@ gint rowid, colid;
 	tmpmax = 0.0;
 
 	DB( g_print(" colsum: ") );
-	for(colid=0;colid<=nbcols;colid++)
+	for(colid=0;colid<nbcols;colid++)
 	{
 		tmpmax = MAX(tmpmax, ABS(chart->colsum[colid]));
 		DB( g_print("%.2f|", chart->colsum[colid]) );
@@ -1661,7 +1671,7 @@ gint i;
 static void chart_recompute(GtkChart *chart)
 {
 HbtkDrawContext *drawctx = &chart->context;
-GdkWindow *gdkwindow;
+//GdkWindow *gdkwindow;
 cairo_surface_t *surf = NULL;
 cairo_t *cr;
 GtkAllocation allocation;
@@ -1675,6 +1685,8 @@ GtkAllocation allocation;
 
 	gtk_widget_get_allocation(chart->drawarea, &allocation);
 
+	/*
+	//removed deprecated call to gdk_cairo_create
 	gdkwindow = gtk_widget_get_window(chart->drawarea);
 	if(!gdkwindow)
 	{
@@ -1683,7 +1695,10 @@ GtkAllocation allocation;
 	}
 	else
 		cr = gdk_cairo_create (gdkwindow);
+	*/
 
+	cr = cairo_create (chart->surface);
+	
 	drawctx->l = CHART_MARGIN;
 	drawctx->t = CHART_MARGIN;
 	drawctx->w = allocation.width - (CHART_MARGIN*2);
@@ -2210,7 +2225,7 @@ gboolean retval = FALSE;
 		gint colid = chart->colhover;	
 		GtkTreeIter iter;
 		DataRow *dr;
-		gdouble value, rate;
+		gdouble value, rate = 0.0;
 
 			if( colid > -1 )
 			{
@@ -2224,13 +2239,15 @@ gboolean retval = FALSE;
 				value = da_datarow_get_cell_sum (dr, colid);
 				strval = chart_print_double(chart, chart->buffer1, value);
 				
-				if( chart->type == CHART_TYPE_STACK )
-					buffer = g_strdup_printf("%s\n%s\n%s", chart->collabel[colid], item->label, strval);
-				else
-				{
-					rate = (value * 100) / chart->colsum[colid];
+				//#1996223 always show rate
+				//if( chart->type == CHART_TYPE_STACK )
+				//	buffer = g_strdup_printf("%s\n%s\n%s", chart->collabel[colid], item->label, strval);
+				//else
+				//{
+					if( chart->colsum[colid] > 0 )
+						rate = (value * 100) / chart->colsum[colid];
 					buffer = g_strdup_printf("%s\n%s\n%s\n%.2f%%", chart->collabel[colid], item->label, strval, rate);
-				}
+				//}
 			}
 		}
 
