@@ -51,6 +51,9 @@ da_acc_free(Account *item)
 		g_free(item->bankname);
 		g_free(item->notes);
 		
+		g_free(item->xferexpname);
+		g_free(item->xferincname);
+
 		g_queue_free (item->txn_queue);
 		
 		g_free(item);
@@ -143,6 +146,20 @@ da_acc_delete(guint32 key)
 }
 
 
+static void
+da_cat_build_xfername(Account *item)
+{
+
+	g_free(item->xferexpname);
+	g_free(item->xferincname);
+	
+	item->xferexpname = g_strdup_printf("> %s", item->name);
+	item->xferincname = g_strdup_printf("< %s", item->name);
+
+	DB( g_print("- updated %d:'%s' xferexpname='%s' xferincname='%s'\n", item->key, item->name, item->xferexpname, item->xferincname) );
+}
+
+
 //#1889659: ensure name != null/empty
 static gboolean
 da_acc_ensure_name(Account *item)
@@ -172,6 +189,7 @@ da_acc_rename(Account *item, gchar *newname)
 
 	//#1889659: ensure name != null/empty
 	da_acc_ensure_name(item);
+	da_cat_build_xfername(item);
 
 }
 
@@ -196,6 +214,7 @@ guint32 *new_key;
 	
 	//#1889659: ensure name != null/empty
 	da_acc_ensure_name(item);
+	da_cat_build_xfername(item);
 
 	g_hash_table_insert(GLOBALS->h_acc, new_key, item);
 
@@ -290,6 +309,27 @@ da_acc_get(guint32 key)
 }
 
 
+static gint da_acc_glist_compare_pos_func(Account *a, Account *b) { return ((gint)a->pos - b->pos); }
+
+guint32
+da_acc_get_first_key(void)
+{
+GList *lacc, *list;
+
+guint32 retval = 0;
+
+	list = g_hash_table_get_values(GLOBALS->h_acc);
+	lacc = list = g_list_sort(list, (GCompareFunc)da_acc_glist_compare_pos_func);
+	if( list != NULL )
+	{
+	Account *accitem = list->data;
+		retval = accitem->key;
+	}
+	g_list_free(lacc);
+	return retval;
+}
+
+
 void da_acc_consistency(Account *item)
 {
 	g_strstrip(item->name);
