@@ -202,6 +202,42 @@ Archive *retval = NULL;
 	return retval;
 }
 
+//#1968249 build a non empty label, when memo/payee/category are empty
+void da_archive_get_display_label(GString *tpltitle, Archive *item)
+{
+	g_string_truncate(tpltitle, 0);
+	if(item->memo != NULL)
+	{
+		g_string_append(tpltitle, item->memo);
+	}
+	else
+	{
+		g_string_append(tpltitle, _("(no memo)") );
+		if(item->kpay > 0)
+		{
+		Payee *pay = da_pay_get(item->kpay);
+
+			if(pay != NULL)
+			{
+				g_string_append_c(tpltitle, ' ');
+				g_string_append(tpltitle, pay->name);
+			}
+		}
+
+		if(item->kcat > 0)
+		{
+		Category *cat = da_cat_get(item->kcat);
+
+			if(cat != NULL)
+			{
+				g_string_append(tpltitle, " / ");
+				g_string_append(tpltitle, cat->fullname);
+			}
+		}
+
+	}
+}
+
 
 void da_archive_consistency(Archive *item)
 {
@@ -330,6 +366,8 @@ Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn, gboole
 	//fill it
 	arc->amount		= txn->amount;
 	arc->kacc		= txn->kacc;
+	//#1673260
+	arc->xferamount = txn->xferamount;
 	arc->kxferacc	= txn->kxferacc;
 	arc->paymode	= txn->paymode;
 	arc->flags		= txn->flags;
@@ -365,6 +403,22 @@ Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn, gboole
 }
 
 
+/* = = = = = = = = = = = = = = = = = = = = */
+
+
+static void _sched_nextdate_weekend_adjust(GDate *tmpdate)
+{
+GDateWeekday wday;
+
+	wday = g_date_get_weekday(tmpdate);
+	if( wday == G_DATE_SATURDAY )
+		g_date_add_days (tmpdate, 2);
+	else
+	if( wday == G_DATE_SUNDAY )
+		g_date_add_days (tmpdate, 1);
+}
+
+
 static guint32 _sched_date_get_next_post(GDate *tmpdate, Archive *arc, guint32 nextdate)
 {
 guint32 nextpostdate = nextdate;
@@ -393,6 +447,11 @@ guint32 nextpostdate = nextdate;
 
 	//DB( g_print("out: %2d-%2d-%4d\n", g_date_get_day(tmpdate), g_date_get_month (tmpdate), g_date_get_year(tmpdate) ) );
 
+	//#1906953 add ignore weekend
+	if( arc->weekend == ARC_WEEKEND_SKIP )
+	{
+		_sched_nextdate_weekend_adjust(tmpdate);
+	}
 
 	/* get the final post date and free */
 	nextpostdate = g_date_get_julian(tmpdate);
@@ -401,6 +460,20 @@ guint32 nextpostdate = nextdate;
 }
 
 
+//#1906953 add ignore weekend
+void scheduled_nextdate_weekend_adjust(Archive *arc)
+{
+	if( arc->weekend == ARC_WEEKEND_SKIP )
+	{
+	GDate *tmpdate = g_date_new_julian(arc->nextdate);
+
+		_sched_nextdate_weekend_adjust(tmpdate);
+		arc->nextdate = g_date_get_julian(tmpdate);
+		g_date_free(tmpdate);
+	}
+}
+
+
 gboolean scheduled_is_postable(Archive *arc)
 {
 gdouble value;
@@ -422,10 +495,10 @@ gint shift;
 
 	DB( g_print("\n[scheduled] get_postdate\n") );
 
-
 	finalpostdate = postdate;
 	
 	tmpdate = g_date_new_julian(finalpostdate);
+
 	/* manage weekend exception */
 	if( arc->weekend > 0 )
 	{
@@ -532,8 +605,6 @@ gushort lastday;
 
 	DB( g_print("\n[scheduled] date_advance\n") );
 
-	DB( g_print(" arc: '%s'\n", arc->memo ) );
-
 	post_date = g_date_new();
 	g_date_set_julian(post_date, arc->nextdate);
 	// saved the current day number
@@ -541,7 +612,7 @@ gushort lastday;
 
 	arc->nextdate = _sched_date_get_next_post(post_date, arc, arc->nextdate);
 
-	DB( g_print(" raw next post date: %2d-%2d-%4d\n", g_date_get_day(post_date), g_date_get_month (post_date), g_date_get_year(post_date) ) );
+	DB( g_print(" raw next post date: %02d-%02d-%4d\n", g_date_get_day(post_date), g_date_get_month (post_date), g_date_get_year(post_date) ) );
 
 	//for day > 28 we might have a gap to compensate later
 	if( (arc->unit==AUTO_UNIT_MONTH) || (arc->unit==AUTO_UNIT_YEAR) )
@@ -565,7 +636,6 @@ gushort lastday;
 			arc->daygap = 0;
 	}
 
-
 	//#1556289
 	/* check limit, update and maybe break */
 	if(arc->flags & OF_LIMIT)
@@ -630,42 +700,51 @@ guint16 month, year;
 /*
  *  return the maximum date a scheduled txn can be posted to
  */
-guint32 scheduled_date_get_post_max(void)
+guint32 scheduled_date_get_post_max(guint32 start, gint auto_smode, gint auto_nbdays, gint auto_weekday, gint nbmonth)
 {
-guint nbdays;
+guint nbdays = 0;
 GDate *today, *maxdate;
+gdouble nxtmonth;
+guint8 daysinmonth;
 
-	DB( g_print("\n[scheduled] date_get_post_max\n") );
-
-	//add until xx of the each month (excluded)
-	if(GLOBALS->auto_smode == 0)	
+	switch( auto_smode)
 	{
-		DB( g_print(" - max is %d of next month\n", GLOBALS->auto_weekday) );
-		
-		today = g_date_new_julian(GLOBALS->today);
+		//add until xx of the yy month (excluded)
+		//if(auto_smode == 0)
+		case ARC_POSTMODE_PAYOUT:
+		{
+			today = g_date_new_julian(start);
+			daysinmonth = g_date_get_days_in_month(g_date_get_month(today), g_date_get_year(today));
+			maxdate = g_date_new_julian(start + (daysinmonth - auto_weekday));
+			
+			nxtmonth = ceil((gdouble)g_date_get_month(maxdate)/(gdouble)nbmonth)*(gdouble)nbmonth;
+			DB( g_print("nxtmonth: %f =  ceil( %d / %d) / %d\n", nxtmonth, g_date_get_month(today), month, month) );
+			g_date_set_day(maxdate, auto_weekday);
+			g_date_set_month(maxdate, nxtmonth);
 
-		//we compute user xx weekday of next month
-		maxdate = g_date_new_julian(GLOBALS->today);
-		g_date_set_day(maxdate, GLOBALS->auto_weekday);
-		if(g_date_get_day (today) >= GLOBALS->auto_weekday)
-			g_date_add_months(maxdate, 1);
+			//if( today > g_date_get_julian(maxdate) )
+			//	g_date_add_months(maxdate, month);
+
+			nbdays = g_date_days_between(today, maxdate);
 		
-		nbdays = g_date_days_between(today, maxdate);
-	
-		g_date_free(maxdate);
-		g_date_free(today);
-	}
-	//add xx days in advance the current date
-	else
-	{
-		nbdays = GLOBALS->auto_nbdays;
+			g_date_free(maxdate);
+			g_date_free(today);
+		}
+		break;
+
+		//add xx days in advance the current date
+		//if(auto_smode == 1)
+		case ARC_POSTMODE_ADVANCE:
+			nbdays = auto_nbdays;
+			break;
+
+		case ARC_POSTMODE_DUEDATE:
+		default:
+			nbdays = 0;
+			break;
 	}
 
-	DB( hb_print_date(GLOBALS->today, "today") );
-	DB( g_print(" - %d nbdays\n", nbdays) );
-	DB( hb_print_date(GLOBALS->today + nbdays, "maxpostdate") );
-
-	return GLOBALS->today + nbdays;
+	return start + nbdays;
 }
 
 
@@ -680,7 +759,7 @@ Transaction *txn;
 
 	count = 0;
 
-	maxpostdate = scheduled_date_get_post_max();
+	maxpostdate = scheduled_date_get_post_max(GLOBALS->today, GLOBALS->auto_smode, GLOBALS->auto_nbdays, GLOBALS->auto_weekday, GLOBALS->auto_nbmonths);
 	
 	list = g_list_first(GLOBALS->arc_list);
 	while (list != NULL)
