@@ -44,6 +44,7 @@ struct _archive
 	guint32		*tags;
 	//guint32		kxfer;		//strong link xfer key
 	guint32		kxferacc;
+	gdouble		xferamount;	//xfer target alount
 	
 	GPtrArray	*splits;
 
@@ -60,11 +61,20 @@ struct _archive
 enum
 {
 	LST_DEFARC_DATAS,
-	LST_DEFARC_OLDPOS,
-	LST_DEFARC_AUTO,
+//	LST_DEFARC_OLDPOS,
+//	LST_DEFARC_AUTO,
 	NUM_LST_DEFARC
 };
 
+
+enum
+{
+	ARC_POSTMODE_DUEDATE,
+	ARC_POSTMODE_PAYOUT,
+	ARC_POSTMODE_ADVANCE
+};
+
+
 /*
 ** scheduled unit
 */
@@ -78,6 +88,15 @@ enum
 };
 
 
+enum
+{
+	ARC_WEEKEND_POSSIBLE,
+	ARC_WEEKEND_BEFORE,
+	ARC_WEEKEND_AFTER,
+	ARC_WEEKEND_SKIP
+};
+
+
 enum
 {
 	FLT_SCHEDULED_THISMONTH = 1,
@@ -105,12 +124,15 @@ guint32 da_archive_get_max_key(void);
 Archive *da_archive_get(guint32 key);
 
 
+void da_archive_get_display_label(GString *tpltitle, Archive *item);
 void da_archive_consistency(Archive *item);
 
 Archive *da_archive_init_from_transaction(Archive *arc, Transaction *txn, gboolean fromregister);
 
 GList *da_archive_glist_sorted(gint column);
 
+
+void scheduled_nextdate_weekend_adjust(Archive *arc);
 gboolean scheduled_is_postable(Archive *arc);
 guint32 scheduled_get_postdate(Archive *arc, guint32 postdate);
 guint32 scheduled_get_latepost_count(Archive *arc, guint32 jrefdate);
@@ -118,7 +140,7 @@ guint32 scheduled_date_advance(Archive *arc);
 
 void scheduled_date_get_show_minmax(gint select, guint32 *mindate, guint32 *maxdate);
 
-guint32 scheduled_date_get_post_max(void);
+guint32 scheduled_date_get_post_max(guint32 start, gint auto_smode, gint auto_nbdays, gint auto_weekday, gint nbmonth);
 gint scheduled_post_all_pending(void);
 
 
