@@ -288,6 +288,39 @@ Assign *da_asg_init_from_transaction(Assign *asg, Transaction *txn)
 }
 
 
+gchar *assign_get_target_payee(Assign *asgitem)
+{
+gchar *retval = NULL;
+
+	if( asgitem && (asgitem->flags & (ASGF_DOPAY|ASGF_OVWPAY)) )
+	{
+	Payee *pay = da_pay_get(asgitem->kpay);
+
+		if(pay != NULL)
+			retval = pay->name;
+	}
+
+	return retval;
+}
+
+
+gchar *assign_get_target_category(Assign *asgitem)
+{
+gchar *retval = NULL;
+
+	if( asgitem && (asgitem->flags & (ASGF_DOCAT|ASGF_OVWCAT)) )
+	{
+	Category *cat = da_cat_get(asgitem->kcat);
+
+		if(cat != NULL)
+			retval = cat->fullname;
+	}
+
+	return retval;
+}
+
+
+
 static gint
 assign_glist_pos_compare_func(Assign *a, Assign *b)
 {
@@ -371,6 +404,34 @@ gboolean match = FALSE;
 }
 
 
+//#1710085 assignment based on amount 
+static gboolean transaction_auto_assign_rule_match(Assign *rul, gchar *text, gdouble amount)
+{
+gboolean match1, match2;
+
+	match1 = TRUE;
+	match2 = FALSE;
+	if( rul->flags & ASGF_AMOUNT )
+	{
+		if( amount != rul->amount )
+			match1 = FALSE;
+	}
+
+	if( !(rul->flags & ASGF_REGEX) )
+	{
+		if( misc_text_match(text, rul->search, rul->flags & ASGF_EXACT) )
+			match2 = TRUE;
+	}
+	else
+	{
+		if( misc_regex_match(text, rul->search, rul->flags & ASGF_EXACT) )
+			match2 = TRUE;
+	}
+
+	return ((match1==TRUE) && (match2==TRUE)) ? TRUE : FALSE;
+}
+
+
 static GList *transaction_auto_assign_eval_txn(GList *l_rul, Transaction *txn)
 {
 GList *ret_list = NULL;
@@ -390,16 +451,10 @@ gchar *text = NULL;
 				text = pay->name;
 		}
 		
-		if( !(rul->flags & ASGF_REGEX) )
+		if( transaction_auto_assign_rule_match(rul, text, txn->amount) == TRUE )
 		{
-			if( misc_text_match(text, rul->search, rul->flags & ASGF_EXACT) )
-				//TODO: perf must use preprend, see glib doc
-				ret_list = g_list_append(ret_list, rul);
-		}
-		else
-		{
-			if( misc_regex_match(text, rul->search, rul->flags & ASGF_EXACT) )
-				ret_list = g_list_append(ret_list, rul);
+			//TODO: perf must use preprend, see glib doc
+			ret_list = g_list_append(ret_list, rul);
 		}
 
 		list = g_list_next(list);
@@ -411,7 +466,7 @@ gchar *text = NULL;
 }
 
 
-static GList *transaction_auto_assign_eval(GList *l_rul, gchar *text)
+static GList *transaction_auto_assign_eval_split(GList *l_rul, gchar *text, gdouble amount)
 {
 GList *ret_list = NULL;
 GList *list;
@@ -423,16 +478,10 @@ GList *list;
 
 		if( rul->field == 0 )   //memo
 		{
-			if( !(rul->flags & ASGF_REGEX) )
+			if( transaction_auto_assign_rule_match(rul, text, amount) == TRUE )
 			{
-				if( misc_text_match(text, rul->search, rul->flags & ASGF_EXACT) )
 				//TODO: perf must use preprend, see glib doc
-					ret_list = g_list_append(ret_list, rul);
-			}
-			else
-			{
-				if( misc_regex_match(text, rul->search, rul->flags & ASGF_EXACT) )
-					ret_list = g_list_append(ret_list, rul);
+				ret_list = g_list_append(ret_list, rul);
 			}
 		}
 		list = g_list_next(list);
@@ -512,7 +561,7 @@ guint changes = 0;
 					
 					DB( g_print("- eval split '%s'\n", split->memo) );
 
-					l_match = l_tmp = transaction_auto_assign_eval(l_rul, split->memo);
+					l_match = l_tmp = transaction_auto_assign_eval_split(l_rul, split->memo, split->amount);
 					while( l_tmp != NULL )
 					{
 					Assign *rul = l_tmp->data;
