@@ -35,6 +35,7 @@ struct _assign
 	guint32		kcat;		//dst category
 	gushort		paymode;	//dst_payment mode
 	gushort		pos;		//position
+	gdouble		amount;		//5.6 #1710085 assignment based on amount
 };
 
 
@@ -42,11 +43,14 @@ struct _assign
 #define ASGF_DOPAY	(1<<1)
 #define ASGF_DOCAT	(1<<2)
 #define ASGF_DOMOD	(1<<3)
+//#define ASGF_DOTAG (later)
 
+#define ASGF_AMOUNT	(1<<7)	//5.6
 #define ASGF_REGEX	(1<<8)
 #define ASGF_OVWPAY	(1<<9)
 #define ASGF_OVWCAT	(1<<10)
 #define ASGF_OVWMOD	(1<<11)
+//#define ASGF_OVWTAG (later)
 
 
 void
@@ -67,6 +71,9 @@ Assign		*da_asg_get(guint32 key);
 void da_asg_consistency(Assign *item);
 Assign *da_asg_init_from_transaction(Assign *asg, Transaction *txn);
 
+gchar *assign_get_target_payee(Assign *asgitem);
+gchar *assign_get_target_category(Assign *asgitem);
+
 GList *assign_glist_sorted(gint column);
 
 guint transaction_auto_assign(GList *ope_list, guint32 key, gboolean lockrecon);
