@@ -20,10 +20,8 @@
 #ifndef __HB_CATEGORY_H__
 #define __HB_CATEGORY_H__
 
-
 typedef struct _category		Category;
 
-
 struct _category
 {
 	guint32		key;
@@ -35,7 +33,7 @@ struct _category
 
 	/* unsaved datas */
 	gchar		*fullname;
-	gboolean	flt_select;
+	//gboolean	flt_select;
 	guint16		nb_use_txn;
 	guint16		nb_use_txncat;	//cat usage only
 	guint16		nb_use_all;
@@ -49,6 +47,8 @@ struct _category
 #define GF_FORCED	(1<<4)
 #define GF_MIXED	(1<<5)		//#1740368 if cat has mixed exp/inc type
 
+#define GF_HIDDEN	(1<<8)		//hidden by user
+
 
 Category *da_cat_clone(Category *src_item);
 void da_cat_free(Category *item);
