@@ -31,6 +31,12 @@
 #define DB(x);
 #endif
 
+
+//DB out of bounds
+#define DBOOB(x);
+//#define DBOOB(x) (x);
+
+
 /* our global datas */
 extern struct HomeBank *GLOBALS;
 extern struct Preferences *PREFS;
@@ -38,14 +44,71 @@ extern struct Preferences *PREFS;
 
 /* = = = = = = = = = = = = = = = = */
 
+
+static void da_flt_clean(Filter *flt)
+{
+	if(flt != NULL)
+	{
+		g_free(flt->tag);
+		flt->tag = NULL;
+		
+		g_free(flt->memo);
+		flt->memo = NULL;
+
+		g_free(flt->info);
+		flt->info = NULL;
+
+		g_free(flt->name);
+		flt->name = NULL;
+		
+		if(flt->gbtag != NULL)
+		{
+			g_array_free(flt->gbtag, TRUE);
+			flt->gbtag = NULL;
+		}
+
+		if(flt->gbcat != NULL)
+		{
+			g_array_free(flt->gbcat, TRUE);
+			flt->gbcat = NULL;
+		}
+
+		if(flt->gbpay != NULL)
+		{
+			g_array_free(flt->gbpay, TRUE);
+			flt->gbpay = NULL;
+		}
+
+		if(flt->gbacc != NULL)
+		{
+			g_array_free(flt->gbacc, TRUE);
+			flt->gbacc = NULL;
+		}
+	}
+}
+
+
+static void da_flt_init(Filter *flt)
+{
+
+	DB( g_print("da_flt_init\n") );
+
+	//always allocate 1 elt minimum
+	// /!\ each array still ->len = 0
+	flt->gbacc = g_array_sized_new(FALSE, TRUE, sizeof(gchar), 1);
+	flt->gbpay = g_array_sized_new(FALSE, TRUE, sizeof(gchar), 1);
+	flt->gbcat = g_array_sized_new(FALSE, TRUE, sizeof(gchar), 1);
+	flt->gbtag = g_array_sized_new(FALSE, TRUE, sizeof(gchar), 1);
+
+}
+
+
 void da_flt_free(Filter *flt)
 {
 	DB( g_print("da_flt_free\n") );
 	if(flt != NULL)
 	{
-		g_free(flt->memo);
-		g_free(flt->info);
-		g_free(flt->tag);
+		da_flt_clean(flt);
 		g_free(flt);
 	}
 }
@@ -53,117 +116,209 @@ void da_flt_free(Filter *flt)
 
 Filter *da_flt_malloc(void)
 {
+Filter *flt;
+
 	DB( g_print("da_flt_malloc\n") );
-	return g_malloc0(sizeof(Filter));
+	flt = g_malloc0(sizeof(Filter));
+
+	da_flt_init(flt);
+
+	return flt;
+}
+
+
+void da_flt_copy(Filter *src, Filter *dst)
+{
+	DB( g_print("da_flt_copy\n") );
+
+	DB( g_print(" %p (%s) to %p (%s)\n", src, src->name, dst, dst->name) );
+
+	if(!src || !dst)
+		return;
+
+	DB( g_print(" %d acc\n", src->gbacc->len) );
+	DB( g_print(" %d pay\n", src->gbpay->len) );
+	DB( g_print(" %d cat\n", src->gbcat->len) );
+
+	//clean any previous extra memory
+	da_flt_clean(dst);
+	//raw duplicate the memory segment
+	memcpy(dst, src, sizeof(Filter));
+
+	//duplicate extra memory
+	dst->name = g_strdup(src->name);
+	dst->info = g_strdup(src->info);
+	dst->memo = g_strdup(src->memo);
+	dst->tag  = g_strdup(src->tag);
+	
+	dst->gbacc = g_array_copy(src->gbacc);
+	dst->gbpay = g_array_copy(src->gbpay);
+	dst->gbcat = g_array_copy(src->gbcat);
+	dst->gbtag = g_array_copy(src->gbtag);
+
+	DB( g_print(" %d acc\n", dst->gbacc->len) );
+	DB( g_print(" %d pay\n", dst->gbpay->len) );
+	DB( g_print(" %d cat\n", dst->gbcat->len) );
+
+	DB( g_print(" copied\n\n") );
+
+}
+
+
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
+
+#if MYDEBUG == 1
+static void my_debug_garray(gchar *type, GArray *array)
+{
+guint i;
+
+	g_print(" debug '%s' len=%d\n", type, array->len);
+	
+	for(i=0 ; i < array->len ; i++)
+	{
+		g_print("%02d ", array->data[i]);
+	}
+	g_print("\n");
+}
+#endif
+
+
+static void da_flt_item_set(GArray *array, guint32 key, gboolean status)
+{
+	if(key < array->len)
+	{
+	gchar *sel = &g_array_index(array, gchar, key);
+		*sel = status;
+		DB( g_print(" modified existing [%d]=>%d\n", key, status) );
+	}
+	else
+	{
+		DB( g_print(" insert new val [%d]=>%d\n", key, status) );
+		g_array_insert_vals(array, key, &status, 1);
+	}
+}
+
+void da_flt_status_tag_set(Filter *flt, guint32 ktag, gboolean status)
+{
+	da_flt_item_set(flt->gbtag, ktag, status);
+	DB( g_print(" set tag %d to %d\n", ktag, status) );
 }
 
 void da_flt_status_cat_set(Filter *flt, guint32 kcat, gboolean status)
 {
-Category *cat = da_cat_get(kcat);
-	if(cat)
-		cat->flt_select = status;
+	da_flt_item_set(flt->gbcat, kcat, status);
+	DB( g_print(" set cat %d\n", kcat) );
 }
 
-
 void da_flt_status_pay_set(Filter *flt, guint32 kpay, gboolean status)
 {
-Payee *pay = da_pay_get(kpay);
-	if(pay)
-		pay->flt_select = status;
+	da_flt_item_set(flt->gbpay, kpay, status);
+	DB( g_print(" set pay %d\n", kpay) );
 }
 
-
 void da_flt_status_acc_set(Filter *flt, guint32 kacc, gboolean status)
 {
-Account *acc = da_acc_get(kacc);
-	if(acc)
-		acc->flt_select = status;
+	da_flt_item_set(flt->gbacc, kacc, status);
+	DB( g_print(" set acc %d\n", kacc) );
 }
 
 
+gboolean da_flt_status_tag_get(Filter *flt, guint32 ktag)
+{
+	if(flt->gbtag == NULL)
+		return FALSE;
+
+	if(ktag < flt->gbtag->len)
+		return flt->gbtag->data[ktag];
+
+	DBOOB( g_warning("filter get tag out of bounds %d of %d", ktag, flt->gbtag->len) );
+	return FALSE;
+}
+
 gboolean da_flt_status_cat_get(Filter *flt, guint32 kcat)
 {
-Category *cat = da_cat_get(kcat);
-	if(cat)
-		return cat->flt_select;
+	if(flt->gbcat == NULL)
+		return FALSE;
+
+	if(kcat < flt->gbcat->len)
+		return flt->gbcat->data[kcat];
+
+	DBOOB( g_warning("filter get cat out of bounds %d of %d", kcat, flt->gbcat->len) );
 	return FALSE;
 }
 
-
 gboolean da_flt_status_pay_get(Filter *flt, guint32 kpay)
 {
-Payee *pay = da_pay_get(kpay);
-	if(pay)
-		return pay->flt_select;
+	if(flt->gbpay == NULL)
+		return FALSE;
+
+	if(kpay < flt->gbpay->len)
+		return flt->gbpay->data[kpay];
+
+	DBOOB( g_warning("filter get pay out of bounds %d of %d", kpay, flt->gbpay->len) );
 	return FALSE;
 }
 
-
 gboolean da_flt_status_acc_get(Filter *flt, guint32 kacc)
 {
-Account *acc = da_acc_get(kacc);
-	if(acc)
-		return acc->flt_select;
+	if(flt->gbacc == NULL)
+		return FALSE;
+
+
+	if(kacc < flt->gbacc->len)
+		return flt->gbacc->data[kacc];
+
+	DBOOB( g_warning("filter get acc out of bounds %d of %d", kacc, flt->gbacc->len) );
 	return FALSE;
 }
 
 
-/* = = = = = = = = = = = = = = = = = = = = */
 
 
+/* TODO: check this : user in rep_time only */
 void filter_status_acc_clear_except(Filter *flt, guint32 selkey)
 {
-GHashTableIter iter;
-gpointer key, value;
+guint i;
 
-	// set all account
-	g_hash_table_iter_init (&iter, GLOBALS->h_acc);
-	while (g_hash_table_iter_next (&iter, &key, &value))
+	DB( g_print("[filter] acc clear %d\n", flt->gbacc->len) );
+	
+	for(i=0;i<flt->gbacc->len;i++)
 	{
-	Account *item = value;
-		item->flt_select = item->key == selkey ? TRUE : FALSE;
+		flt->gbacc->data[i] = 0;
 	}
-
+	da_flt_status_acc_set(flt, selkey, TRUE);
 }
 
-
 void filter_status_pay_clear_except(Filter *flt, guint32 selkey)
 {
-GHashTableIter iter;
-gpointer key, value;
+guint i;
 
-	// set all payee
-	g_hash_table_iter_init (&iter, GLOBALS->h_pay);
-	while (g_hash_table_iter_next (&iter, &key, &value))
+	DB( g_print("[filter] pay clear %d\n", flt->gbpay->len) );
+	
+	for(i=0;i<flt->gbpay->len;i++)
 	{
-	Payee *item = value;
-		item->flt_select = item->key == selkey ? TRUE : FALSE;
+		flt->gbpay->data[i] = 0;
 	}
-
+	da_flt_status_pay_set(flt, selkey, TRUE);
 }
 
-
 void filter_status_cat_clear_except(Filter *flt, guint32 selkey)
 {
-GHashTableIter iter;
-gpointer key, value;
+guint i;
 
-	// set all category
-	g_hash_table_iter_init (&iter, GLOBALS->h_cat);
-	while (g_hash_table_iter_next (&iter, &key, &value))
+	DB( g_print("[filter] cat clear %d\n", flt->gbcat->len) );
+
+	
+	for(i=0;i<flt->gbcat->len;i++)
 	{
-	Category *item = value;
-
-
-		item->flt_select = FALSE;
-		if( (item->key == selkey) 
-		//#1824561 don't forget subcat
-		//#1829076 but not when selkey is 0
-		   || ((item->parent == selkey) && selkey > 0)
-		)
-			item->flt_select = TRUE;
+		flt->gbcat->data[i] = 0;
 	}
 
+	da_flt_status_cat_set(flt, selkey, TRUE);
+	//todo
+	//#1824561 don't forget subcat
+
 }
 
 
@@ -186,19 +341,16 @@ gint i;
 	//5.4.2: useless, as it is always changed after all
 	//flt->range  = FLT_RANGE_LAST12MONTHS;
 	//filter_preset_daterange_set(flt, flt->range, 0);
-	flt->range = FLT_RANGE_LAST30DAYS;
+	flt->range = FLT_RANGE_LAST_30DAYS;
 	flt->mindate = GLOBALS->today-30;
 	flt->maxdate = GLOBALS->today;
 
 	for(i=0;i<NUM_PAYMODE_MAX;i++)
 		flt->paymode[i] = TRUE;
 
-	g_free(flt->info);
-	g_free(flt->memo);
-	g_free(flt->tag);
-	flt->info = NULL;
-	flt->memo = NULL;
-	flt->tag = NULL;
+	//reinit the array acc/pay/cat/tag + text
+	da_flt_clean(flt);
+	da_flt_init(flt);
 
 	//unsaved
 	flt->nbdaysfuture = 0;
@@ -211,6 +363,8 @@ gint i;
 }
 
 
+/* TODO: check this : used in rep_time only */
+
 void filter_set_tag_by_id(Filter *flt, guint32 key)
 {
 Tag *tag;
@@ -223,6 +377,7 @@ Tag *tag;
 		flt->tag = NULL;
 	}
 
+	//todo change this
 	tag = da_tag_get(key);
 	if(tag)
 	{
@@ -252,7 +407,7 @@ GList *lnk_txn;
 		{
 		Transaction *txn;
 		
-			DB( g_print(" - do '%s'\n", acc->name) );
+			DB( g_print(" collect date for '%s'\n", acc->name) );
 
 			lnk_txn = g_queue_peek_head_link(acc->txn_queue);
 			if(lnk_txn) {
@@ -300,13 +455,13 @@ gboolean filter_preset_daterange_future_enable(gint range)
 {
 	switch( range )
 	{
-		case FLT_RANGE_THISMONTH:
-		case FLT_RANGE_THISQUARTER:
-		case FLT_RANGE_THISYEAR:
-		case FLT_RANGE_LAST30DAYS:
-		case FLT_RANGE_LAST60DAYS:
-		case FLT_RANGE_LAST90DAYS:
-		case FLT_RANGE_LAST12MONTHS:
+		case FLT_RANGE_THIS_MONTH:
+		case FLT_RANGE_THIS_QUARTER:
+		case FLT_RANGE_THIS_YEAR:
+		case FLT_RANGE_LAST_30DAYS:
+		case FLT_RANGE_LAST_60DAYS:
+		case FLT_RANGE_LAST_90DAYS:
+		case FLT_RANGE_LAST_12MONTHS:
 			return TRUE;
 			break;
 	}
@@ -339,6 +494,7 @@ void filter_preset_daterange_set(Filter *flt, gint range, guint32 kacc)
 GDate *tmpdate;
 guint32 jtoday, jfiscal;
 guint16 month, year, yfiscal, qnum;
+GDateWeekday wday;
 
 	DB( g_print("\n[filter] daterange set %p %d\n", flt, range) );
 
@@ -352,15 +508,17 @@ guint16 month, year, yfiscal, qnum;
 	year  = g_date_get_year(tmpdate);
 	DB( hb_print_date(jtoday , "today ") );
 
-	g_date_set_dmy(tmpdate, PREFS->fisc_year_day, PREFS->fisc_year_month, year);
-	jfiscal = g_date_get_julian(tmpdate);
-	DB( hb_print_date(jfiscal, "fiscal") );
-
-	yfiscal = (jtoday >= jfiscal) ? year : year-1;
 	qnum = 0;
-
-	if( range == FLT_RANGE_THISQUARTER || range == FLT_RANGE_LASTQUARTER )
+	yfiscal = year;
+	if( range == FLT_RANGE_LAST_QUARTER || range == FLT_RANGE_THIS_QUARTER ||range == FLT_RANGE_NEXT_QUARTER )
 	{
+
+		g_date_set_dmy(tmpdate, PREFS->fisc_year_day, PREFS->fisc_year_month, year);
+		jfiscal = g_date_get_julian(tmpdate);
+		DB( hb_print_date(jfiscal, "fiscal") );
+
+		yfiscal = (jtoday >= jfiscal) ? year : year-1;
+
 		g_date_set_dmy(tmpdate, PREFS->fisc_year_day, PREFS->fisc_year_month, yfiscal);
 		while( (qnum < 5) && (g_date_get_julian(tmpdate) < jtoday) )
 		{
@@ -372,11 +530,59 @@ guint16 month, year, yfiscal, qnum;
 		
 	switch( range )
 	{
-		case FLT_RANGE_THISMONTH:
-		case FLT_RANGE_LASTMONTH:
+		case FLT_RANGE_LAST_DAY:
+			flt->mindate = flt->maxdate = jtoday - 1;
+			break;
+		case FLT_RANGE_THIS_DAY:
+			flt->mindate = flt->maxdate = jtoday;
+			break;
+		case FLT_RANGE_NEXT_DAY:
+			flt->mindate = flt->maxdate = jtoday + 1;
+			break;
+
+		case FLT_RANGE_LAST_WEEK:
+		case FLT_RANGE_THIS_WEEK:
+		case FLT_RANGE_NEXT_WEEK:
+			//ISO 8601 from must be monday, to slice in correct weekœ
+			wday = g_date_get_weekday(tmpdate);
+			g_date_subtract_days (tmpdate, wday-G_DATE_MONDAY);
+			if( range == FLT_RANGE_LAST_WEEK )
+				g_date_subtract_days(tmpdate, 7);
+			else
+			if( range == FLT_RANGE_NEXT_WEEK )
+				g_date_add_days(tmpdate, 7);
+
+			flt->mindate = g_date_get_julian(tmpdate);
+			g_date_add_days(tmpdate, 7);
+			flt->maxdate = g_date_get_julian(tmpdate) - 1;
+			break;
+
+		case FLT_RANGE_LAST_FORTNIGHT:
+		case FLT_RANGE_THIS_FORTNIGHT:
+		case FLT_RANGE_NEXT_FORTNIGHT:
+			//ISO 8601 from must be monday, to slice in correct weekœ
+			wday = g_date_get_weekday(tmpdate);
+			g_date_subtract_days (tmpdate, wday-G_DATE_MONDAY);
+			if( range == FLT_RANGE_LAST_FORTNIGHT )
+				g_date_subtract_days(tmpdate, 14);
+			else
+			if( range == FLT_RANGE_NEXT_FORTNIGHT )
+				g_date_add_days(tmpdate, 14);
+
+			flt->mindate = g_date_get_julian(tmpdate);
+			g_date_add_days(tmpdate, 14);
+			flt->maxdate = g_date_get_julian(tmpdate) - 1;
+			break;
+
+		case FLT_RANGE_LAST_MONTH:
+		case FLT_RANGE_THIS_MONTH:
+		case FLT_RANGE_NEXT_MONTH:
 			g_date_set_dmy(tmpdate, 1, month, year);
-			if( range == FLT_RANGE_LASTMONTH )
+			if( range == FLT_RANGE_LAST_MONTH )
 				g_date_subtract_months(tmpdate, 1);
+			else
+			if( range == FLT_RANGE_NEXT_MONTH )
+				g_date_add_months(tmpdate, 1);
 			flt->mindate = g_date_get_julian(tmpdate);
 			month = g_date_get_month(tmpdate);
 			year = g_date_get_year(tmpdate);
@@ -384,55 +590,67 @@ guint16 month, year, yfiscal, qnum;
 			flt->maxdate = g_date_get_julian(tmpdate) - 1;
 			break;
 
-		case FLT_RANGE_THISQUARTER:
-		case FLT_RANGE_LASTQUARTER:
+		case FLT_RANGE_LAST_QUARTER:
+		case FLT_RANGE_THIS_QUARTER:
+		case FLT_RANGE_NEXT_QUARTER:
 			g_date_set_dmy(tmpdate, PREFS->fisc_year_day, PREFS->fisc_year_month, yfiscal);
-			if( range == FLT_RANGE_LASTQUARTER )
+			if( range == FLT_RANGE_LAST_QUARTER )
 				g_date_subtract_months(tmpdate, 3);
+			else
+			if( range == FLT_RANGE_NEXT_QUARTER )
+				g_date_add_months(tmpdate, 3);
 			g_date_add_months(tmpdate, 3 * (qnum-1) );
 			flt->mindate = g_date_get_julian(tmpdate);
 			g_date_add_months(tmpdate, 3);
 			flt->maxdate = g_date_get_julian(tmpdate) - 1;
 			break;
 
-		case FLT_RANGE_THISYEAR:
-		case FLT_RANGE_LASTYEAR:
+		case FLT_RANGE_LAST_YEAR:
+		case FLT_RANGE_THIS_YEAR:
+		case FLT_RANGE_NEXT_YEAR:
 			g_date_set_dmy(tmpdate, PREFS->fisc_year_day, PREFS->fisc_year_month, yfiscal);
-			if( range == FLT_RANGE_LASTYEAR )
+			if( range == FLT_RANGE_LAST_YEAR )
 				g_date_subtract_years(tmpdate, 1);
+			else
+			if( range == FLT_RANGE_NEXT_YEAR )
+				g_date_add_years(tmpdate, 1);
 			flt->mindate = g_date_get_julian(tmpdate);
 			g_date_add_years (tmpdate, 1);
 			flt->maxdate = g_date_get_julian(tmpdate) - 1;
 			break;
 
-		case FLT_RANGE_LAST30DAYS:
+		case FLT_RANGE_LAST_30DAYS:
 			flt->mindate = jtoday - 30;
 			flt->maxdate = jtoday;
 			break;
 
-		case FLT_RANGE_LAST60DAYS:
+		case FLT_RANGE_LAST_60DAYS:
 			flt->mindate = jtoday - 60;
 			flt->maxdate = jtoday;
 			break;
 
-		case FLT_RANGE_LAST90DAYS:
+		case FLT_RANGE_LAST_90DAYS:
 			flt->mindate = jtoday - 90;
 			flt->maxdate = jtoday;
 			break;
 
-		case FLT_RANGE_LAST12MONTHS:
+		case FLT_RANGE_LAST_12MONTHS:
 			g_date_set_julian (tmpdate, jtoday);
 			g_date_subtract_months(tmpdate, 12);
 			flt->mindate = g_date_get_julian(tmpdate);
 			flt->maxdate = jtoday;
 			break;
 
-		// case FLT_RANGE_OTHER:
+		// case FLT_RANGE_MISC_CUSTOM:
 			//nothing to do
 			
-		case FLT_RANGE_ALLDATE:
+		case FLT_RANGE_MISC_ALLDATE:
 			filter_set_date_bounds(flt, kacc);
 			break;
+		case FLT_RANGE_MISC_30DAYS:
+			flt->mindate = jtoday - 30;
+			flt->maxdate = jtoday + 30;		
+			break;
 	}
 	g_date_free(tmpdate);
 }
@@ -442,32 +660,272 @@ void filter_preset_type_set(Filter *flt, gint type)
 {
 
 	DB( g_print("\n[filter] preset type set\n") );
-	
-	/* any type */
-	flt->option[FLT_GRP_TYPE] = 1;
+
+	flt->option[FLT_GRP_TYPE] = 0;
 	flt->type = type;
-	/*flt->option[FLT_GRP_AMOUNT] = 0;
-	flt->minamount = G_MINDOUBLE;
-	flt->maxamount = G_MINDOUBLE;
+	flt->typ_exp = FALSE;
+	flt->typ_inc = FALSE;
+	flt->typ_xfr = FALSE;
 
-	switch( type )
+	if( type != FLT_TYPE_ALL )
 	{
-		case FLT_TYPE_EXPENSE:
-			flt->option[FLT_GRP_AMOUNT] = 1;
-			flt->minamount = -G_MAXDOUBLE;
-			flt->maxamount = G_MINDOUBLE;
-			break;
-
-		case FLT_TYPE_INCOME:
-			flt->option[FLT_GRP_AMOUNT] = 1;
-			flt->minamount = G_MINDOUBLE;
-			flt->maxamount = G_MAXDOUBLE;
-			break;
-	}*/
+		flt->option[FLT_GRP_TYPE] = 1;
+		switch(type)
+		{
+			case FLT_TYPE_EXPENSE:
+				flt->typ_exp = TRUE;
+				break;
+			case FLT_TYPE_INCOME:
+				flt->typ_inc = TRUE;
+				break;
+			case FLT_TYPE_INTXFER:
+				flt->typ_xfr = TRUE;
+				break;
+		}
+	}
 
 }
 
 
+/* = = = = = = = = = = = = = = = = */
+
+
+static void filter_group_import_keys(Filter *flt, gint group, gchar *text)
+{
+gchar **str_array;
+gint len, i;
+
+	DB( g_print(" import keys '%s'\n", text) );
+
+	str_array = g_strsplit (text, ",", -1);
+	len = g_strv_length( str_array );
+	for(i=0;i<len;i++)
+	{
+	guint32 key = atoi(str_array[i]);
+
+		
+		switch(group)
+		{
+			case FLT_GRP_ACCOUNT:
+				if( da_acc_get(i) )
+				{
+					da_flt_status_acc_set(flt, key, TRUE);
+					DB( g_print(" set acc='%d' to true\n", key) );
+				}
+				break;
+			case FLT_GRP_PAYEE:
+				if( da_pay_get(i) )
+				{
+					da_flt_status_pay_set(flt, key, TRUE);
+					DB( g_print(" set pay='%d' to true\n", key) );
+				}
+				break;
+			case FLT_GRP_CATEGORY:
+				if( da_cat_get(i) )
+				{
+					da_flt_status_cat_set(flt, key, TRUE);
+					DB( g_print(" set cat='%d' to true\n", key) );
+				}
+				break;
+			/*case FLT_GRP_TAG:
+				da_flt_status_tag_set(flt, key, TRUE);
+				break;*/
+		}
+	}
+	g_strfreev(str_array);
+}
+
+
+void filter_group_import(Filter *flt, gint group, const gchar *text)
+{
+gchar **str_array;
+gint len;
+
+
+	switch(group)
+	{
+		case FLT_GRP_DATE:
+			str_array = g_strsplit (text, "|", 4);
+			len = g_strv_length( str_array );
+
+			if(len == 2)
+			{
+				flt->option[group] = atoi(str_array[0]);
+				flt->range = atoi(str_array[1]);
+			}
+			if(len == 4 && flt->range == FLT_RANGE_MISC_CUSTOM)
+			{
+				flt->mindate = atoi(str_array[2]);
+				flt->maxdate = atoi(str_array[3]);
+			}
+			g_strfreev(str_array);
+			break;
+		
+		case FLT_GRP_ACCOUNT:
+			str_array = g_strsplit (text, "|", 2);
+			len = g_strv_length( str_array );
+
+			if(len == 2)
+			{
+				flt->option[group] = atoi(str_array[0]);
+				filter_group_import_keys(flt, FLT_GRP_ACCOUNT, str_array[1]);
+			}
+			g_strfreev(str_array);
+			break;
+
+		case FLT_GRP_PAYEE:
+			str_array = g_strsplit (text, "|", 2);
+			len = g_strv_length( str_array );
+
+			if(len == 2)
+			{
+				flt->option[group] = atoi(str_array[0]);
+				filter_group_import_keys(flt, FLT_GRP_PAYEE, str_array[1]);
+			}
+			g_strfreev(str_array);
+			break;
+
+		case FLT_GRP_CATEGORY:
+			str_array = g_strsplit (text, "|", 2);
+			len = g_strv_length( str_array );
+
+			if(len == 2)
+			{
+				flt->option[group] = atoi(str_array[0]);
+				filter_group_import_keys(flt, FLT_GRP_CATEGORY, str_array[1]);
+			}
+			g_strfreev(str_array);
+			break;
+
+			
+			
+	}
+}
+
+
+
+gchar *filter_group_export(Filter *flt, gint group)
+{
+gchar *retval = NULL;
+GString *node;
+guint i;
+
+	switch(group)
+	{
+		case FLT_GRP_DATE:
+			if(flt->option[group] > 0)
+			{
+				//TODO: maybe always keep 4 values here
+				if(flt->range == FLT_RANGE_MISC_CUSTOM)
+					retval = g_strdup_printf("%d|%d|%d|%d", flt->option[group], flt->range, flt->mindate, flt->maxdate);
+				else
+					retval = g_strdup_printf("%d|%d", flt->option[group], flt->range);
+			}
+			break;
+		case FLT_GRP_ACCOUNT:
+			if(flt->option[group] > 0)
+			{
+				node = g_string_sized_new(flt->gbacc->len);
+				g_string_append_printf(node, "%d|", flt->option[group]);
+				DB( g_printf("acc len:%d\n", flt->gbacc->len) );
+				for(i=0;i<flt->gbacc->len;i++)
+				{
+					if( da_acc_get(i) )
+						if( da_flt_status_acc_get(flt, i) == TRUE )
+							g_string_append_printf(node, "%d,", i);
+				}
+				g_string_erase(node, node->len-1, 1);
+				retval = node->str;
+				g_string_free(node, FALSE);
+				DB( g_printf(" '%s'\n", retval) );
+				node = NULL;
+			}
+			break;
+		case FLT_GRP_PAYEE:
+			if(flt->option[group] > 0)
+			{
+				node = g_string_sized_new(flt->gbpay->len);
+				g_string_append_printf(node, "%d|", flt->option[group]);
+				DB( g_printf("pay len:%d\n", flt->gbpay->len) );
+				for(i=0;i<flt->gbpay->len;i++)
+				{
+					if( da_pay_get(i) )
+						if( da_flt_status_pay_get(flt, i) == TRUE )
+							g_string_append_printf(node, "%d,", i);
+				}
+				g_string_erase(node, node->len-1, 1);
+				retval = node->str;
+				g_string_free(node, FALSE);
+				DB( g_printf(" '%s'\n", retval) );
+				node = NULL;
+			}
+			break;
+		case FLT_GRP_CATEGORY:
+			if(flt->option[group] > 0)
+			{
+				node = g_string_sized_new(flt->gbcat->len);
+				g_string_append_printf(node, "%d|", flt->option[group]);
+				DB( g_printf("cat len:%d\n", flt->gbcat->len) );
+				for(i=0;i<flt->gbcat->len;i++)
+				{
+					if( da_cat_get(i) )
+						if( da_flt_status_cat_get(flt, i) == TRUE )
+							g_string_append_printf(node, "%d,", i);
+				}
+				g_string_erase(node, node->len-1, 1);
+				retval = node->str;
+				g_string_free(node, FALSE);
+				DB( g_printf(" '%s'\n", retval) );
+				node = NULL;
+			}			break;
+		case FLT_GRP_TAG:
+			if(flt->option[group] > 0)
+			{
+		
+
+			}
+			break;
+		case FLT_GRP_TEXT:
+			if(flt->option[group] > 0)
+			{
+		
+
+			}
+			break;
+		case FLT_GRP_AMOUNT:
+			if(flt->option[group] > 0)
+			{
+		
+
+			}
+			break;
+		case FLT_GRP_PAYMODE:
+			if(flt->option[group] > 0)
+			{
+		
+
+			}
+			break;
+		case FLT_GRP_STATUS:
+			if(flt->option[group] > 0)
+			{
+		
+
+			}
+			break;
+		case FLT_GRP_TYPE:
+			if(flt->option[group] > 0)
+			{
+		
+
+			}
+			break;
+	}
+	return retval;
+}
+
+
+
 void filter_preset_status_set(Filter *flt, gint status)
 {
 
@@ -481,7 +939,10 @@ void filter_preset_status_set(Filter *flt, gint status)
 
 	//#1991459 dont reset type
 	//flt->type   = FLT_TYPE_ALL;
-	flt->status = FLT_STATUS_ALL;
+	flt->status = status;
+	flt->sta_non = FALSE;
+	flt->sta_clr = FALSE;
+	flt->sta_rec = FALSE;
 	//#1602835 fautly set
 	//flt->forceadd = TRUE;
 	//flt->forcechg = TRUE;
@@ -490,38 +951,44 @@ void filter_preset_status_set(Filter *flt, gint status)
 	//#1873324 register status quick filter do not reset
 	//note: status revert to UNRECONCILED here is normal if PREFS->hidereconciled=TRUE
 	//flt->rawstatus = status;
-	
-	switch( status )
+
+	if( status != FLT_STATUS_ALL )
 	{
-		case FLT_STATUS_UNCATEGORIZED:
-			//#1991459 dont reset type: here to hide xfer txn
-			//flt->option[FLT_GRP_TYPE] = 2;
-			//flt->type = FLT_TYPE_INTXFER;
-			flt->option[FLT_GRP_CATEGORY] = 1;
-			filter_status_cat_clear_except(flt, 0);
-			break;
+		switch( status )
+		{
+			case FLT_STATUS_UNCATEGORIZED:
+				//#1991459 dont reset type: here to hide xfer txn
+				//flt->option[FLT_GRP_TYPE] = 2;
+				//flt->type = FLT_TYPE_INTXFER;
+				flt->option[FLT_GRP_CATEGORY] = 1;
+				filter_status_cat_clear_except(flt, 0);
+				
+				DB( my_debug_garray("cat", flt->gbcat) );
+				
+				break;
 
-		case FLT_STATUS_UNRECONCILED:
-			flt->option[FLT_GRP_STATUS] = 2;
-			flt->status = FLT_STATUS_RECONCILED;
-			break;
+			case FLT_STATUS_UNRECONCILED:
+				flt->option[FLT_GRP_STATUS] = 2;
+				flt->sta_rec = TRUE;
+				break;
 
-		case FLT_STATUS_UNCLEARED:
-			flt->option[FLT_GRP_STATUS] = 2;
-			flt->status = FLT_STATUS_CLEARED;
-			break;
+			case FLT_STATUS_UNCLEARED:
+				flt->option[FLT_GRP_STATUS] = 2;
+				flt->sta_clr = TRUE;
+				break;
 
-		case FLT_STATUS_RECONCILED:
-			flt->option[FLT_GRP_STATUS] = 1;
-			flt->status = FLT_STATUS_RECONCILED;
-			break;
-
-		case FLT_STATUS_CLEARED:
-			flt->option[FLT_GRP_STATUS] = 1;
-			flt->status = FLT_STATUS_CLEARED;
-			break;
+			case FLT_STATUS_RECONCILED:
+				flt->option[FLT_GRP_STATUS] = 1;
+				flt->sta_rec = TRUE;
+				break;
 
+			case FLT_STATUS_CLEARED:
+				flt->option[FLT_GRP_STATUS] = 1;
+				flt->sta_clr = TRUE;
+				break;
+		}
 	}
+
 }
 
 
@@ -622,6 +1089,51 @@ end:
 }
 
 
+static gboolean filter_txn_tag_match(Filter *flt, guint32 *tags)
+{
+guint count, i;
+gboolean retval = FALSE;
+
+	if(flt->gbtag == NULL)
+		return FALSE;
+
+	count = tags_count(tags);
+	//if no tag in txn just check (no tag) is set
+	if( count == 0 )
+	{
+		retval = da_flt_status_tag_get(flt, 0);
+		goto end;
+	}
+
+	DB( g_print("\n[filter] tnx tag match\n") );
+
+		//debug loop */
+		#if MYDEBUG == 1
+		g_print(" dbg gbtag %d elt\n", flt->gbtag->len);
+		for(i=0;i<flt->gbtag->len;i++)
+		{
+			g_print("[%d]=%d ", i, flt->gbtag->data[i]);
+		}	
+		g_print("\n\n");
+		#endif
+
+	/* loop on any tags */
+	DB( g_print(" loop txn tags %d\n", count) );
+	for(i=0;i<count;i++)
+	{
+		retval = da_flt_status_tag_get(flt, tags[i]);
+
+		DB( g_print(" %d ktag=%d, sel=%d\n", i, tags[i], retval) );
+
+		if(retval == TRUE)	/* break once a tag match :: OR */
+			break;
+	}
+
+end:
+	return retval;
+}
+
+
 /* used for quicksearch text into transaction */
 gboolean filter_txn_search_match(gchar *needle, Transaction *txn, gint flags)
 {
@@ -719,6 +1231,8 @@ gchar *tags;
 	
 	if(flags & FLT_QSEARCH_TAGS)
 	{
+		//TODO: chnage this
+
 		tags = tags_tostring(txn->tags);
 		if(tags)
 		{
@@ -747,9 +1261,7 @@ end:
 
 gint filter_txn_match(Filter *flt, Transaction *txn)
 {
-Account *accitem;
-Payee *payitem;
-Category *catitem;
+gboolean status;
 gint insert;
 
 	//DB( g_print("\n[filter] txn match\n") );
@@ -759,36 +1271,34 @@ gint insert;
 /*** start filtering ***/
 
 /* date */
-	if(flt->option[FLT_GRP_DATE]) {
+	if(flt->option[FLT_GRP_DATE])
+	{
 		insert = ( (txn->date >= flt->mindate) && (txn->date <= (flt->maxdate + flt->nbdaysfuture) ) ) ? 1 : 0;
 		if(flt->option[FLT_GRP_DATE] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
 
 /* account */
-	if(flt->option[FLT_GRP_ACCOUNT]) {
-		accitem = da_acc_get(txn->kacc);
-		if(accitem)
-		{
-			insert = ( accitem->flt_select == TRUE ) ? 1 : 0;
-			if(flt->option[FLT_GRP_ACCOUNT] == 2) insert ^= 1;
-		}
+	if(flt->option[FLT_GRP_ACCOUNT])
+	{
+		status = da_flt_status_acc_get(flt, txn->kacc);
+		insert = ( status == TRUE ) ? 1 : 0;
+		if(flt->option[FLT_GRP_ACCOUNT] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
 
 /* payee */
-	if(flt->option[FLT_GRP_PAYEE]) {
-		payitem = da_pay_get(txn->kpay);
-		if(payitem)
-		{
-			insert = ( payitem->flt_select == TRUE ) ? 1 : 0;
-			if(flt->option[FLT_GRP_PAYEE] == 2) insert ^= 1;
-		}
+	if(flt->option[FLT_GRP_PAYEE])
+	{
+		status = da_flt_status_pay_get(flt, txn->kpay);
+		insert = ( status == TRUE ) ? 1 : 0;
+		if(flt->option[FLT_GRP_PAYEE] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
 
 /* category */
-	if(flt->option[FLT_GRP_CATEGORY]) {
+	if(flt->option[FLT_GRP_CATEGORY])
+	{
 		if(txn->flags & OF_SPLIT)
 		{
 		guint count, i;
@@ -801,79 +1311,50 @@ gint insert;
 			gint tmpinsert = 0;
 				
 				split = da_splits_get(txn->splits, i);
-				catitem = da_cat_get(split->kcat);
-				if(catitem)
-				{
-					tmpinsert = ( catitem->flt_select == TRUE ) ? 1 : 0;
-					if(flt->option[FLT_GRP_CATEGORY] == 2) tmpinsert ^= 1;
-				}
+				status = da_flt_status_cat_get(flt, split->kcat);
+				tmpinsert = ( status == TRUE ) ? 1 : 0;
+				if(flt->option[FLT_GRP_CATEGORY] == 2) tmpinsert ^= 1;
 				insert |= tmpinsert;
 			}
 		}
 		else
 		{
-			catitem = da_cat_get(txn->kcat);
-			if(catitem)
-			{
-				insert = ( catitem->flt_select == TRUE ) ? 1 : 0;
-				if(flt->option[FLT_GRP_CATEGORY] == 2) insert ^= 1;
-			}
+			status = da_flt_status_cat_get(flt, txn->kcat);
+			insert = ( status == TRUE ) ? 1 : 0;
+			if(flt->option[FLT_GRP_CATEGORY] == 2) insert ^= 1;
 		}
 	}
 	if(!insert) goto end;
 
+/* tag */
+	if(flt->option[FLT_GRP_TAG]) {
+		status = filter_txn_tag_match(flt, txn->tags);
+		insert = ( status == TRUE ) ? 1 : 0;
+		if(flt->option[FLT_GRP_TAG] == 2) insert ^= 1;
+	}
+	if(!insert) goto end;
+
 /* type */
-	if(flt->option[FLT_GRP_TYPE]) {
-		switch( flt->type )
-		{
-			case FLT_TYPE_EXPENSE:
-				insert = !(txn->flags & (OF_INCOME|OF_INTXFER)) ? 1 : 0;
-				break;
-			case FLT_TYPE_INCOME:
-				insert = (txn->flags & (OF_INCOME)) ? 1 : 0;
-				break;
-			case FLT_TYPE_INTXFER:
-				insert = (txn->flags & (OF_INTXFER)) ? 1 : 0;
-				break;
-			case FLT_TYPE_ALL:
-				insert = 1;
-				break;
-		}
+	if(flt->option[FLT_GRP_TYPE])
+	{
+	gint typ1 = ( (flt->typ_exp == TRUE) && !(txn->flags & (OF_INCOME|OF_INTXFER)) ) ? 1 : 0;
+	gint typ2 = ( (flt->typ_inc == TRUE) && (txn->flags & (OF_INCOME)) ) ? 1 : 0;
+	gint typ3 = ( (flt->typ_xfr == TRUE) && (txn->flags & (OF_INTXFER)) ) ? 1 : 0;
+
+		insert = typ1 || typ2 || typ3;
 		if(flt->option[FLT_GRP_TYPE] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
 
 /* status */
-	if(flt->option[FLT_GRP_STATUS]) {
+	if(flt->option[FLT_GRP_STATUS])
+	{
+	gint sta1 = ( (flt->sta_non == TRUE) && (txn->status == TXN_STATUS_NONE) ) ? 1 : 0;
+	gint sta2 = ( (flt->sta_clr == TRUE) && (txn->status == TXN_STATUS_CLEARED) ) ? 1 : 0;
+	gint sta3 = ( (flt->sta_rec == TRUE) && (txn->status == TXN_STATUS_RECONCILED) ) ? 1 : 0;
 
-		switch( flt->status )
-		{
-			case FLT_STATUS_CLEARED:
-				insert = (txn->status == TXN_STATUS_CLEARED) ? 1 : 0;
-				break;
-			case FLT_STATUS_RECONCILED:
-				insert = (txn->status == TXN_STATUS_RECONCILED) ? 1 : 0;
-				break;
-			case FLT_STATUS_ALL:
-				insert = 1;
-				break;
-		}
-		if(flt->option[FLT_GRP_STATUS] == 2)
-		{	
-			//#1853531 fix for more exact uncleared/unreconciled
-			switch( flt->status )
-			{
-			case FLT_STATUS_CLEARED:	//uncleared
-				insert = (txn->status == TXN_STATUS_NONE) ? 1 : 0;
-				break;
-			case FLT_STATUS_RECONCILED:	//unreconciled
-				insert = (txn->status == TXN_STATUS_NONE) || (txn->status == TXN_STATUS_CLEARED) ? 1 : 0;
-				break;
-			default:
-				insert ^= 1;
-				break;					
-			}
-		}
+		insert = sta1 || sta2 || sta3;
+		if(flt->option[FLT_GRP_STATUS] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
 
@@ -885,20 +1366,20 @@ gint insert;
 	if(!insert) goto end;
 
 /* amount */
-	if(flt->option[FLT_GRP_AMOUNT]) {
+	if(flt->option[FLT_GRP_AMOUNT])
+	{
 		insert = ( (txn->amount >= flt->minamount) && (txn->amount <= flt->maxamount) ) ? 1 : 0;
 
 		if(flt->option[FLT_GRP_AMOUNT] == 2) insert ^= 1;
 	}
 	if(!insert) goto end;
 
-/* info/memo/tag */
+/* info/memo */
 	if(flt->option[FLT_GRP_TEXT])
 	{
-	gchar *tags;
-	gint insert1, insert2, insert3;
+	gint insert1, insert2;
 
-		insert1 = insert2 = insert3 = 0;
+		insert1 = insert2 = 0;
 		if(flt->info)
 		{
 			if(txn->info)
@@ -938,19 +1419,7 @@ gint insert;
 		else
 			insert2 = 1;
 
-		if(flt->tag)
-		{
-			tags = tags_tostring(txn->tags);
-			if(tags)
-			{
-				insert3 = hb_string_utf8_strstr(tags, flt->tag, flt->exact);
-			}
-			g_free(tags);
-		}
-		else
-			insert3 = 1;
-
-		insert = insert1 && insert2 && insert3 ? 1 : 0;
+		insert = insert1 && insert2 ? 1 : 0;
 
 		if(flt->option[FLT_GRP_TEXT] == 2) insert ^= 1;
 
