@@ -30,6 +30,7 @@ enum
 	FLT_GRP_CATEGORY,
 	FLT_GRP_PAYEE,
 	FLT_GRP_ACCOUNT,
+	FLT_GRP_TAG,
 	FLT_GRP_TEXT,
 	FLT_GRP_AMOUNT,
 	FLT_GRP_PAYMODE,
@@ -41,24 +42,62 @@ enum
 
 enum
 {
-	FLT_RANGE_THISMONTH = 0,
-	FLT_RANGE_LASTMONTH = 1,
-	FLT_RANGE_THISQUARTER = 2,
-	FLT_RANGE_LASTQUARTER = 3,
-	FLT_RANGE_THISYEAR = 4,
-	FLT_RANGE_LASTYEAR = 5,	 //was not existing on 4.5
+	OLD56_FLT_RANGE_THISMONTH    = 0,
+	OLD56_FLT_RANGE_LASTMONTH    = 1,
+	OLD56_FLT_RANGE_THISQUARTER  = 2,
+	OLD56_FLT_RANGE_LASTQUARTER  = 3,
+	OLD56_FLT_RANGE_THISYEAR     = 4,
+	OLD56_FLT_RANGE_LASTYEAR     = 5,	 //was not existing on 4.5
 	// 6 separator
-	FLT_RANGE_LAST30DAYS = 7,
-	FLT_RANGE_LAST60DAYS = 8,
-	FLT_RANGE_LAST90DAYS = 9,
-	FLT_RANGE_LAST12MONTHS = 10,
+	OLD56_FLT_RANGE_LAST30DAYS   = 7,
+	OLD56_FLT_RANGE_LAST60DAYS   = 8,
+	OLD56_FLT_RANGE_LAST90DAYS   = 9,
+	OLD56_FLT_RANGE_LAST12MONTHS = 10,
 	// 11 separator
-	FLT_RANGE_OTHER = 12,
+	OLD56_FLT_RANGE_OTHER        = 12,
 	// 13 separator
-	FLT_RANGE_ALLDATE = 14
+	OLD56_FLT_RANGE_ALLDATE      = 14
 };
 
 
+enum
+{
+	FLT_RANGE_UNSET = 0,
+	FLT_RANGE_MISC_CUSTOM,
+	FLT_RANGE_MISC_ALLDATE,
+	FLT_RANGE_MISC_30DAYS,
+
+	FLT_RANGE_LAST_DAY = 20,
+	FLT_RANGE_LAST_WEEK,
+	FLT_RANGE_LAST_FORTNIGHT,
+	FLT_RANGE_LAST_MONTH,
+	FLT_RANGE_LAST_QUARTER,
+	FLT_RANGE_LAST_YEAR,
+	FLT_RANGE_LAST_30DAYS,
+	FLT_RANGE_LAST_60DAYS,
+	FLT_RANGE_LAST_90DAYS,
+	FLT_RANGE_LAST_12MONTHS,
+
+	FLT_RANGE_THIS_DAY = 40,
+	FLT_RANGE_THIS_WEEK,
+	FLT_RANGE_THIS_FORTNIGHT,
+	FLT_RANGE_THIS_MONTH,
+	FLT_RANGE_THIS_QUARTER,
+	FLT_RANGE_THIS_YEAR,
+
+	FLT_RANGE_NEXT_DAY = 60,
+	FLT_RANGE_NEXT_WEEK,
+	FLT_RANGE_NEXT_FORTNIGHT,
+	FLT_RANGE_NEXT_MONTH,
+	FLT_RANGE_NEXT_QUARTER,
+	FLT_RANGE_NEXT_YEAR,
+
+	FLT_RANGE_MAX
+};
+
+
+
+
 enum
 {
 	FLT_TYPE_ALL = 0,
@@ -97,13 +136,16 @@ typedef struct _filter	Filter;
 
 struct _filter
 {
-
+	guint32  	key;
+	//gushort 	flags;
 	gshort		option[FLT_GRP_MAX];
 	gint		range;
 	guint32		mindate, maxdate;
 	//gint		rawtype, rawstatus;
 
 	gint		type, status;
+	gboolean	typ_exp, typ_inc, typ_xfr;	//5.6
+	gboolean	sta_non, sta_clr, sta_rec;	//5.6
 
 	gboolean	paymode[NUM_PAYMODE_MAX];
 
@@ -111,10 +153,17 @@ struct _filter
 
 	gboolean	exact;
 
+	//pointer here
+	gchar		*name;
 	gchar		*info;
 	gchar		*memo;
 	gchar		*tag;
 
+	GArray		*gbacc;
+	GArray		*gbpay;
+	GArray		*gbcat;
+	GArray		*gbtag;
+
 	/* unsaved datas */
 	gint		nbdaysfuture;
 	gboolean	forceadd;
@@ -128,15 +177,31 @@ struct _filter
 Filter *da_flt_malloc(void);
 void da_flt_free(Filter *flt);
 
+void da_flt_copy(Filter *src, Filter *dst);
 void da_flt_destroy(void);
 void da_flt_new(void);
 
+guint		da_flt_length(void);
+gboolean	da_flt_create_none(void);
+gboolean	da_flt_remove(guint32 key);
+gboolean	da_flt_insert(Filter *item);
+gboolean	da_flt_append(Filter *item);
+guint32		da_flt_get_max_key(void);
+Filter		*da_flt_get_by_name(gchar *name);
+Filter		*da_flt_get_by_imp_name(gchar *name);
+Filter		*da_flt_get(guint32 key);
+void da_flt_consistency(Filter *item);
+
 void da_flt_status_acc_set(Filter *flt, guint32 kacc, gboolean status);
 void da_flt_status_pay_set(Filter *flt, guint32 kpay, gboolean status);
 void da_flt_status_cat_set(Filter *flt, guint32 kcat, gboolean status);
+void da_flt_status_tag_set(Filter *flt, guint32 ktag, gboolean status);
 gboolean da_flt_status_acc_get(Filter *flt, guint32 kacc);
 gboolean da_flt_status_pay_get(Filter *flt, guint32 kpay);
 gboolean da_flt_status_cat_get(Filter *flt, guint32 kcat);
+gboolean da_flt_status_tag_get(Filter *flt, guint32 ktag);
+
+GList *filter_glist_sorted(gint column);
 
 void filter_status_acc_clear_except(Filter *flt, guint32 selkey);
 void filter_status_pay_clear_except(Filter *flt, guint32 selkey);
@@ -151,7 +216,10 @@ void filter_preset_daterange_add_futuregap(Filter *filter, gint nbdays);
 void filter_set_tag_by_id(Filter *flt, guint32 key);
 void filter_preset_status_set(Filter *flt, gint value);
 
+void filter_group_import(Filter *flt, gint group, const gchar *text);
+gchar *filter_group_export(Filter *flt, gint group);
 gchar *filter_daterange_text_get(Filter *flt);
+
 gboolean filter_txn_search_match(gchar *needle, Transaction *txn, gint flags);
 gboolean filter_tpl_search_match(gchar *needle, Archive *arc);
 
