@@ -568,6 +568,7 @@ void hbfile_setup(gboolean file_clear)
 	da_cur_new();
 	da_grp_new();
 	da_acc_new();
+	//txn queue is alloc/free into account
 	da_pay_new();
 	da_cat_new();
 	da_tag_new();
@@ -599,9 +600,10 @@ void hbfile_setup(gboolean file_clear)
 
 	GLOBALS->vehicle_category = 0;
 	
-	GLOBALS->auto_smode = 1;
-	GLOBALS->auto_nbdays = 0;
+	GLOBALS->auto_smode = ARC_POSTMODE_DUEDATE;
 	GLOBALS->auto_weekday = 1;
+	GLOBALS->auto_nbmonths = 1;
+	GLOBALS->auto_nbdays = 0;
 
 	GLOBALS->changes_count = 0;
 
