@@ -50,6 +50,7 @@ da_pay_free(Payee *item)
 		DB( g_print(" => %d, %s\n", item->key, item->name) );
 
 		g_free(item->name);
+		g_free(item->notes);
 		g_free(item);
 	}
 }
@@ -391,6 +392,9 @@ GList *lst_acc, *lnk_acc;
 GList *lnk_txn;
 GList *lrul, *list;
 
+	DB( g_print("[da_pay] fill usage\n") );
+
+
 	lpay = list = g_hash_table_get_values(GLOBALS->h_pay);
 	while (list != NULL)
 	{
