@@ -22,21 +22,24 @@
 
 typedef struct _payee		Payee;
 
-
 struct _payee
 {
 	guint32   	key;
 	gushort		paymode;
-	gushort 	_pad1;
+	gushort 	flags;		//_pad1 prior 5.6
 	guint32		kcat;
 	gchar   	*name;
+	gchar	    *notes;		//added 5.6
 
 	/* unsaved datas */
-	gboolean	flt_select;
+	//gboolean	flt_select;
 	guint16		nb_use_txn;
 	guint16		nb_use_all;
 };
 
+#define PF_HIDDEN	(1<<8)	//hidden by user
+
+
 void da_pay_free(Payee *item);
 Payee *da_pay_malloc(void);
 
