@@ -148,6 +148,86 @@ gint i;
 }
 
 
+void homebank_pref_setdefault_lst_det_columns(void)
+{
+gint i = 0;
+
+	PREFS->lst_det_columns[i++] = LST_DSPOPE_STATUS;  //always displayed
+	PREFS->lst_det_columns[i++] = LST_DSPOPE_DATE;	  //always displayed
+	PREFS->lst_det_columns[i++] = -LST_DSPOPE_INFO;
+	PREFS->lst_det_columns[i++] = LST_DSPOPE_PAYEE;
+	PREFS->lst_det_columns[i++] = LST_DSPOPE_CATEGORY;
+	PREFS->lst_det_columns[i++] = -LST_DSPOPE_TAGS;
+	PREFS->lst_det_columns[i++] = LST_DSPOPE_CLR;
+	PREFS->lst_det_columns[i++] = LST_DSPOPE_AMOUNT;
+	PREFS->lst_det_columns[i++] = -LST_DSPOPE_EXPENSE;
+	PREFS->lst_det_columns[i++] = -LST_DSPOPE_INCOME;
+	PREFS->lst_det_columns[i++] = -LST_DSPOPE_BALANCE;
+	PREFS->lst_det_columns[i++] = LST_DSPOPE_MEMO;
+	PREFS->lst_det_columns[i++] = LST_DSPOPE_ACCOUNT;
+	PREFS->lst_det_columns[i++] = LST_DSPOPE_MATCH;
+
+	for( i=0;i<NUM_LST_DSPOPE;i++)
+		PREFS->lst_det_col_width[i] = -1;
+}
+
+
+void homebank_pref_setdefault_lst_ope_columns(void)
+{
+gint i = 0;
+
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_STATUS;  //always displayed
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_DATE;	  //always displayed
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INFO;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_PAYEE;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_CATEGORY;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_TAGS;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_CLR;
+	PREFS->lst_ope_columns[i++] = -LST_DSPOPE_AMOUNT;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_EXPENSE;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INCOME;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_BALANCE;
+	PREFS->lst_ope_columns[i++] = LST_DSPOPE_MEMO;
+	PREFS->lst_ope_columns[i++] = -LST_DSPOPE_ACCOUNT;
+	PREFS->lst_ope_columns[i++] = -LST_DSPOPE_MATCH;
+
+
+	PREFS->lst_ope_sort_id    = LST_DSPOPE_DATE;
+	PREFS->lst_ope_sort_order = GTK_SORT_ASCENDING;
+
+	for( i=0;i<NUM_LST_DSPOPE;i++)
+		PREFS->lst_ope_col_width[i] = -1;
+
+}
+
+
+void homebank_pref_setdefault_win(void)
+{
+gint w = 1024, h = 600;
+
+	// windows position/size 1024x600 for netbook
+	// see https://gs.statcounter.com/screen-resolution-stats/desktop/worldwide
+	// and gnome HIG
+
+#if HB_UNSTABLE == TRUE
+	w = 1366; h = 768;
+#endif
+
+	homebank_pref_init_wingeometry(&PREFS->wal_wg, 0, 0, w, h);
+	homebank_pref_init_wingeometry(&PREFS->acc_wg, 0, 0, w, h);
+
+	w = (w * 0.8);
+	h = (h * 0.8);
+	homebank_pref_init_wingeometry(&PREFS->sta_wg, 0, 0, w, h);
+	homebank_pref_init_wingeometry(&PREFS->tme_wg, 0, 0, w, h);
+	homebank_pref_init_wingeometry(&PREFS->ove_wg, 0, 0, w, h);
+	homebank_pref_init_wingeometry(&PREFS->bud_wg, 0, 0, w, h);
+	homebank_pref_init_wingeometry(&PREFS->cst_wg, 0, 0, w, h);
+
+	homebank_pref_init_wingeometry(&PREFS->txn_wg, 0, 0, -1, -1);
+}
+
+
 void homebank_pref_setdefault(void)
 {
 gint i;
@@ -205,16 +285,7 @@ gint i;
 	PREFS->fisc_year_day = 1;
 	PREFS->fisc_year_month = 1;
 
-	/* windows position/size */
-	homebank_pref_init_wingeometry(&PREFS->wal_wg, 0, 0, 1024, 600);
-	homebank_pref_init_wingeometry(&PREFS->acc_wg, 0, 0, 1024, 600);
-	homebank_pref_init_wingeometry(&PREFS->sta_wg, 0, 0, 800, 494);
-	homebank_pref_init_wingeometry(&PREFS->tme_wg, 0, 0, 800, 494);
-	homebank_pref_init_wingeometry(&PREFS->ove_wg, 0, 0, 800, 494);
-	homebank_pref_init_wingeometry(&PREFS->bud_wg, 0, 0, 800, 494);
-	homebank_pref_init_wingeometry(&PREFS->cst_wg, 0, 0, 800, 494);
-
-	homebank_pref_init_wingeometry(&PREFS->txn_wg, 0, 0, -1, -1);
+	homebank_pref_setdefault_win();
 
 	currency_get_system_iso();
 
@@ -234,8 +305,11 @@ gint i;
 	PREFS->lst_acc_columns[i++] = COL_DSPACC_TODAY;
 	PREFS->lst_acc_columns[i++] = COL_DSPACC_FUTURE;
 
+	PREFS->pnl_upc_col_pay_show  = 1;
 	PREFS->pnl_upc_col_pay_width = -1;
+	PREFS->pnl_upc_col_cat_show  = 1;
 	PREFS->pnl_upc_col_cat_width = -1;
+	PREFS->pnl_upc_col_mem_show  = 1;
 	PREFS->pnl_upc_col_mem_width = -1;
 	PREFS->pnl_upc_range = FLT_SCHEDULED_ALLDATE;
 
@@ -246,34 +320,19 @@ gint i;
 	PREFS->lst_impope_columns[i++] = LST_DSPOPE_INFO;
 	PREFS->lst_impope_columns[i++] = LST_DSPOPE_PAYEE;
 	PREFS->lst_impope_columns[i++] = LST_DSPOPE_CATEGORY;
-	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_TAGS;
 	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_CLR;
 	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_STATUS;  //always displayed
 	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_EXPENSE;
 	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_INCOME;
 	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_BALANCE;
 	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_ACCOUNT;
+	PREFS->lst_impope_columns[i++] = -LST_DSPOPE_MATCH;
 
-	i = 0;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_STATUS;  //always displayed
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_DATE;	  //always displayed
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INFO;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_PAYEE;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_CATEGORY;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_TAGS;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_CLR;
-	PREFS->lst_ope_columns[i++] = -LST_DSPOPE_AMOUNT;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_EXPENSE;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_INCOME;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_BALANCE;
-	PREFS->lst_ope_columns[i++] = LST_DSPOPE_MEMO;
-	PREFS->lst_ope_columns[i++] = -LST_DSPOPE_ACCOUNT;
+	//book list column
+	homebank_pref_setdefault_lst_ope_columns();
 
-	PREFS->lst_ope_sort_id    = LST_DSPOPE_DATE;
-	PREFS->lst_ope_sort_order = GTK_SORT_ASCENDING;
-
-	for( i=0;i<NUM_LST_DSPOPE;i++)
-		PREFS->lst_ope_col_width[i] = -1;
+	//detail list column
+	homebank_pref_setdefault_lst_det_columns();
 
 	//PREFS->base_cur.nbdecimal = 2;
 	//PREFS->base_cur.separator = TRUE;
@@ -283,9 +342,9 @@ gint i;
 	//PREFS->date_range_rep = FLT_RANGE_THISYEAR;
 
 	//v5.2 change to let the example file show things
-	PREFS->date_range_wal = FLT_RANGE_ALLDATE;
-	PREFS->date_range_txn = FLT_RANGE_ALLDATE;
-	PREFS->date_range_rep = FLT_RANGE_ALLDATE;
+	PREFS->date_range_wal = FLT_RANGE_MISC_ALLDATE;
+	PREFS->date_range_txn = FLT_RANGE_MISC_ALLDATE;
+	PREFS->date_range_rep = FLT_RANGE_MISC_ALLDATE;
 	PREFS->date_future_nbdays = 0;
 	PREFS->rep_maxspenditems = 10;
 
@@ -314,10 +373,11 @@ gint i;
 	//PREFS->euro_thsep   = TRUE;
 	//PREFS->euro_symbol	= g_strdup("??");
 
-	PREFS->stat_byamount   = FALSE;
-	PREFS->stat_showdetail = FALSE;
-	PREFS->stat_showrate   = FALSE;
-	PREFS->budg_showdetail = FALSE;
+	PREFS->stat_byamount    = FALSE;
+	PREFS->stat_showdetail  = FALSE;
+	PREFS->stat_showrate    = FALSE;
+	PREFS->stat_includexfer = FALSE;
+	PREFS->budg_showdetail  = FALSE;
 	PREFS->report_color_scheme = CHART_COLMAP_HOMEBANK;
 
 	//PREFS->chart_legend = FALSE;
@@ -463,6 +523,29 @@ gchar *string;
 }
 
 
+static gint homebank_pref_upgrade_560_daterange(gint oldrange)
+{
+gint newrange = FLT_RANGE_UNSET;
+
+	switch(oldrange)
+	{
+		case OLD56_FLT_RANGE_THISMONTH:    newrange = FLT_RANGE_THIS_MONTH; break;
+		case OLD56_FLT_RANGE_LASTMONTH:    newrange = FLT_RANGE_LAST_MONTH; break;
+		case OLD56_FLT_RANGE_THISQUARTER:  newrange = FLT_RANGE_THIS_QUARTER; break;
+		case OLD56_FLT_RANGE_LASTQUARTER:  newrange = FLT_RANGE_LAST_QUARTER; break;
+		case OLD56_FLT_RANGE_THISYEAR:     newrange = FLT_RANGE_THIS_YEAR; break;
+		case OLD56_FLT_RANGE_LASTYEAR:     newrange = FLT_RANGE_LAST_YEAR; break;
+		case OLD56_FLT_RANGE_LAST30DAYS:   newrange = FLT_RANGE_LAST_30DAYS; break;
+		case OLD56_FLT_RANGE_LAST60DAYS:   newrange = FLT_RANGE_LAST_60DAYS; break;
+		case OLD56_FLT_RANGE_LAST90DAYS:   newrange = FLT_RANGE_LAST_90DAYS; break;
+		case OLD56_FLT_RANGE_LAST12MONTHS: newrange = FLT_RANGE_LAST_12MONTHS; break;
+		case OLD56_FLT_RANGE_ALLDATE:      newrange = FLT_RANGE_MISC_ALLDATE; break;
+	}
+	DB( g_print(" %d => %d\n", oldrange, newrange) );
+	return newrange;
+}
+
+
 static void homebank_pref_currfmt_convert(Currency *cur, gchar *prefix, gchar *suffix)
 {
 
@@ -746,6 +829,44 @@ GError *error = NULL;
 
 			    DB( g_print(" - set sort to %d %d\n", PREFS->lst_ope_sort_id, PREFS->lst_ope_sort_order) );
 
+				//detail list
+				if( g_key_file_has_key(keyfile, group, "ColumnsDet", NULL) )
+				{
+				gint *src;
+				gsize length;
+
+					src = g_key_file_get_integer_list(keyfile, group, "ColumnsDet", &length, NULL);
+
+					DB( g_print(" - length %d (max=%d)\n", (int)length, NUM_LST_DSPOPE) );
+					if( length == NUM_LST_DSPOPE )
+					{
+						DB( g_print(" - copying column order from pref file\n") );
+						memcpy(PREFS->lst_det_columns, src, length*sizeof(gint));
+					}
+					
+					g_free(src);
+				}
+
+				if( g_key_file_has_key(keyfile, group, "ColumnsDetWidth", NULL) )
+				{
+				gint *src;
+				gsize length;
+
+					src = g_key_file_get_integer_list(keyfile, group, "ColumnsDetWidth", &length, NULL);
+
+					DB( g_print(" - length %d (max=%d)\n", (int)length, NUM_LST_DSPOPE) );
+
+					if( length == NUM_LST_DSPOPE )
+					{
+						DB( g_print(" - copying column width from pref file\n") );
+						memcpy(PREFS->lst_det_col_width, src, length*sizeof(gint));
+					}
+
+					//leak
+					g_free(src);
+				}
+
+
 				homebank_pref_get_short(keyfile, group, "FiscYearDay", &PREFS->fisc_year_day);
 				homebank_pref_get_short(keyfile, group, "FiscYearMonth", &PREFS->fisc_year_month);
 
@@ -804,6 +925,9 @@ GError *error = NULL;
 					g_free(src);
 				}						
 
+				homebank_pref_get_short(keyfile, group, "UpcColPayV", &PREFS->pnl_upc_col_pay_show);
+				homebank_pref_get_short(keyfile, group, "UpcColCatV", &PREFS->pnl_upc_col_cat_show);
+				homebank_pref_get_short(keyfile, group, "UpcColMemV", &PREFS->pnl_upc_col_mem_show);
 				homebank_pref_get_short(keyfile, group, "UpcColPayW", &PREFS->pnl_upc_col_pay_width);
 				homebank_pref_get_short(keyfile, group, "UpcColCatW", &PREFS->pnl_upc_col_cat_width);
 				homebank_pref_get_short(keyfile, group, "UpcColMemW", &PREFS->pnl_upc_col_mem_width);
@@ -845,11 +969,11 @@ GError *error = NULL;
 				if(version <= 7)
 				{
 					// shift date range >= 5, since we inserted a new one at position 5
-					if(PREFS->date_range_wal >= FLT_RANGE_LASTYEAR)
+					if(PREFS->date_range_wal >= OLD56_FLT_RANGE_LASTYEAR)
 						PREFS->date_range_wal++;
-					if(PREFS->date_range_txn >= FLT_RANGE_LASTYEAR)
+					if(PREFS->date_range_txn >= OLD56_FLT_RANGE_LASTYEAR)
 						PREFS->date_range_txn++;
-					if(PREFS->date_range_rep >= FLT_RANGE_LASTYEAR)
+					if(PREFS->date_range_rep >= OLD56_FLT_RANGE_LASTYEAR)
 						PREFS->date_range_rep++;
 				}
 
@@ -913,6 +1037,7 @@ GError *error = NULL;
 				homebank_pref_get_boolean(keyfile, group, "StatByAmount", &PREFS->stat_byamount);
 				homebank_pref_get_boolean(keyfile, group, "StatDetail", &PREFS->stat_showdetail);
 				homebank_pref_get_boolean(keyfile, group, "StatRate", &PREFS->stat_showrate);
+				homebank_pref_get_boolean(keyfile, group, "StatIncXfer", &PREFS->stat_includexfer);
 				homebank_pref_get_boolean(keyfile, group, "BudgDetail", &PREFS->budg_showdetail);
 				homebank_pref_get_integer(keyfile, group, "ColorScheme", &PREFS->report_color_scheme);
 				homebank_pref_get_boolean(keyfile, group, "SmallFont", &PREFS->rep_smallfont);
@@ -937,6 +1062,16 @@ GError *error = NULL;
 			//group = "Chart";
 			//PREFS->chart_legend = g_key_file_get_boolean (keyfile, group, "Legend", NULL);
 
+			/* file upgrade */
+			if(version < 560)
+			{
+				DB( g_print(" ugrade 5.6 daterange\n") );
+				//convert old daterange
+				PREFS->date_range_wal = homebank_pref_upgrade_560_daterange(PREFS->date_range_wal);	//top spending	
+				PREFS->date_range_txn = homebank_pref_upgrade_560_daterange(PREFS->date_range_txn);	//transactions
+				PREFS->date_range_rep = homebank_pref_upgrade_560_daterange(PREFS->date_range_rep);	//report options
+			}
+
 
 			/*
 			#if MYDEBUG == 1
@@ -1047,6 +1182,10 @@ GError *error = NULL;
 		g_key_file_set_integer     (keyfile, group, "OpeSortId" , PREFS->lst_ope_sort_id);
 		g_key_file_set_integer     (keyfile, group, "OpeSortOrder" , PREFS->lst_ope_sort_order);
 
+		//detail colmuns
+		g_key_file_set_integer_list(keyfile, group, "ColumnsDet", PREFS->lst_det_columns, NUM_LST_DSPOPE);
+		g_key_file_set_integer_list(keyfile, group, "ColumnsDetWidth", PREFS->lst_det_col_width, NUM_LST_DSPOPE);
+
 		g_key_file_set_integer     (keyfile, group, "FiscYearDay" , PREFS->fisc_year_day);
 		g_key_file_set_integer     (keyfile, group, "FiscYearMonth" , PREFS->fisc_year_month);
 
@@ -1078,6 +1217,9 @@ GError *error = NULL;
 		g_key_file_set_integer(keyfile, group, "AccShowBy" , PREFS->pnl_acc_show_by);
 		g_key_file_set_integer_list(keyfile, group, "AccColumns", PREFS->lst_acc_columns, NUM_LST_COL_DSPACC);
 
+		g_key_file_set_integer(keyfile, group, "UpcColPayV", PREFS->pnl_upc_col_pay_show);
+		g_key_file_set_integer(keyfile, group, "UpcColCatV", PREFS->pnl_upc_col_cat_show);
+		g_key_file_set_integer(keyfile, group, "UpcColMemV", PREFS->pnl_upc_col_mem_show);
 		g_key_file_set_integer(keyfile, group, "UpcColPayW", PREFS->pnl_upc_col_pay_width);
 		g_key_file_set_integer(keyfile, group, "UpcColCatW", PREFS->pnl_upc_col_cat_width);
 		g_key_file_set_integer(keyfile, group, "UpcColMemW", PREFS->pnl_upc_col_mem_width);
@@ -1131,6 +1273,7 @@ GError *error = NULL;
 		g_key_file_set_boolean (keyfile, group, "StatByAmount" , PREFS->stat_byamount);
 		g_key_file_set_boolean (keyfile, group, "StatDetail"   , PREFS->stat_showdetail);
 		g_key_file_set_boolean (keyfile, group, "StatRate"     , PREFS->stat_showrate);
+		g_key_file_set_boolean (keyfile, group, "StatIncXfer"  , PREFS->stat_includexfer);
 		g_key_file_set_boolean (keyfile, group, "BudgDetail"   , PREFS->budg_showdetail);
 		g_key_file_set_integer (keyfile, group, "ColorScheme"  , PREFS->report_color_scheme);
 		g_key_file_set_boolean (keyfile, group, "SmallFont"    , PREFS->rep_smallfont);
