@@ -130,6 +130,7 @@ struct Preferences
 	gboolean	stat_byamount;
 	gboolean	stat_showrate;
 	gboolean	stat_showdetail;
+	gboolean	stat_includexfer;
 	gboolean	budg_showdetail;	
 
 	//backup option
@@ -164,7 +165,11 @@ struct Preferences
 	gint 		lst_ope_col_width[NUM_LST_DSPOPE+1];
 	gint		lst_ope_sort_id;	// -- implicit --
 	gint		lst_ope_sort_order; // -- implicit --
-	
+
+	//detail list column
+	gint 		lst_det_columns[NUM_LST_DSPOPE+1];
+	gint 		lst_det_col_width[NUM_LST_DSPOPE+1];
+
 	/* windows/dialogs size an position */
 	struct WinGeometry	wal_wg;
 	struct WinGeometry	acc_wg;
@@ -190,8 +195,11 @@ struct Preferences
 	gint 		lst_acc_columns[NUM_LST_COL_DSPACC+1];
 	gshort		pnl_acc_show_by;
 
+	gshort		pnl_upc_col_pay_show;
 	gshort		pnl_upc_col_pay_width;
+	gshort		pnl_upc_col_cat_show;
 	gshort		pnl_upc_col_cat_width;
+	gshort		pnl_upc_col_mem_show;
 	gshort		pnl_upc_col_mem_width;
 	gint		pnl_upc_range;
 	
@@ -209,6 +217,9 @@ struct Preferences
 
 gint homebank_pref_list_column_get(gint *cols_id, gint uid, gint maxcol);
 
+void homebank_pref_setdefault_lst_ope_columns(void);
+void homebank_pref_setdefault_lst_det_columns(void);
+void homebank_pref_setdefault_win(void);
 void homebank_prefs_set_default(void);
 void homebank_pref_free(void);
 void homebank_pref_createformat(void);
