@@ -694,7 +694,111 @@ gint n_result, n_cols;
 			list = g_list_next(list);
 		}
 	}
+
+	return dt;
+}
+
+
+DataTable *report_compute_trend_balance(gint tmpsrc, gint tmpintvl, Filter *flt)
+{
+DataTable *dt;
+GList *lst_acc, *lnk_acc;
+GList *lnk_txn;
+gint n_result, n_cols;
+guint row, col;
+
+	DB( g_print("\n[report] compute_trend_balance\n") );
 	
+	//todo: remove this later on
+	n_result = report_items_count(tmpsrc, flt->mindate, flt->maxdate);
+	n_cols   = report_interval_count(tmpintvl, flt->mindate, flt->maxdate);
+
+	DB( g_print(" %d :: n_result=%d\n", tmpsrc, n_result) );
+	
+	dt = da_datatable_malloc (0, n_result, n_cols);
+	if( dt != NULL )
+	{
+		datatable_init_items(dt, tmpsrc, flt->mindate);
+
+		// account initial amount
+		lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
+		lnk_acc = g_list_first(lst_acc);
+		while (lnk_acc != NULL)
+		{
+		Account *acc = lnk_acc->data;
+		guint32 pos = 0;
+		guint32 col = 0;
+		gdouble trn_amount;
+
+			//#1674045 ony rely on nosummary
+			if( (acc->flags & (AF_NOREPORT)) )
+				goto next_acc;
+
+			//add initial amount
+			trn_amount = hb_amount_base(acc->initial, acc->kcur);
+			//col = column
+			//pos = kacc
+			DB( g_print("  ** add initbal %8.2f to row:%d, col:%d\n", trn_amount, acc->key, 0) );
+			datatable_trend_add(dt, acc->key, 0, trn_amount, TRUE);
+
+			lnk_txn = g_queue_peek_head_link(acc->txn_queue);
+			while (lnk_txn != NULL)
+			{
+			Transaction *txn = lnk_txn->data;
+			
+				//5.5 forgot to filter...
+				if( !((txn->status == TXN_STATUS_REMIND) || (txn->status == TXN_STATUS_VOID)) )
+				{
+					pos = report_items_get_pos(tmpsrc, flt->mindate, txn);
+
+					trn_amount = report_txn_amount_get(flt, txn);
+					trn_amount = hb_amount_base(trn_amount, txn->kcur);
+
+					DB( g_print("srctxn: %d - cat=%d, pay=%d, acc=%d | [%d - %d]\n", txn->date, txn->kcat, txn->kpay, txn->kacc, flt->mindate, flt->maxdate) );
+
+					//if( (filter_txn_match(flt, txn) == 1) )
+					if( (txn->date >= flt->mindate) && (txn->date <= flt->maxdate) )
+					{
+						col = report_interval_get_pos(tmpintvl, flt->mindate, txn);
+						DB( g_print("  add %8.2f row:%d, col:%d\n", trn_amount, pos, col) );
+						datatable_trend_add(dt, pos, col, trn_amount, TRUE);
+					}
+					else
+					if( txn->date < flt->mindate)
+					{
+						DB( g_print("  **add %8.2f row:%d, col:%d\n", trn_amount, pos, 0) );
+						datatable_trend_add(dt, pos, 0, trn_amount, TRUE);
+					}
+				}
+				lnk_txn = g_list_next(lnk_txn);
+			}
+
+		next_acc:
+			lnk_acc = g_list_next(lnk_acc);
+		}
+		g_list_free(lst_acc);
+
+	}
+	
+	//cumulate columns
+	if( dt->nbcols > 1 )
+	{
+		for(row=0;row<dt->nbrows;row++)
+		{
+		DataRow *dr = dt->rows[row];
+
+			for(col=1;col<dt->nbcols;col++)
+			{
+				dr->income[col]  += dr->income[col-1];
+				dr->expense[col] += dr->expense[col-1];		
+			
+				dt->totrow->income[col] += dr->income[col-1];
+
+				dt->totrow->expense[col] += dr->expense[col-1];
+			}
+		}
+	}
+
 	return dt;
 }
 
