@@ -20,6 +20,9 @@
 #include "homebank.h"
 #include "hb-tag.h"
 
+/****************************************************************************/
+/* Debug macros                                                             */
+/****************************************************************************/
 #define MYDEBUG 0
 
 #if MYDEBUG
@@ -67,8 +70,15 @@ void da_tag_destroy(void)
 
 void da_tag_new(void)
 {
+Tag *item;
+
 	DB( g_print("da_tag_new\n") );
 	GLOBALS->h_tag = g_hash_table_new_full(g_int_hash, g_int_equal, (GDestroyNotify)g_free, (GDestroyNotify)da_tag_free);
+
+	// insert our 'no tag'
+	item = da_tag_malloc();
+	item->name = g_strdup("");
+	da_tag_insert(item);
 }
 
 
@@ -173,6 +183,25 @@ guint32 *new_key;
 	return FALSE;
 }
 
+Tag *
+da_tag_append_if_new(gchar *rawname)
+{
+Tag *retval = NULL;
+
+	retval = da_tag_get_by_name(rawname);
+	if(retval == NULL)
+	{
+		retval = da_tag_malloc();
+		retval->key = da_tag_get_max_key() + 1;
+		retval->name = g_strdup(rawname);
+		g_strstrip(retval->name);
+		da_tag_insert(retval);
+	}
+
+	return retval;
+}
+
+
 /**
  * da_tag_get_max_key:
  *
@@ -591,5 +620,91 @@ GList *list = g_hash_table_get_values(GLOBALS->h_tag);
 
 
 
+gboolean
+tag_load_csv(gchar *filename, gchar **error)
+{
+gboolean retval;
+GIOChannel *io;
+gchar *tmpstr;
+gint io_stat;
+const gchar *encoding;
+
+	encoding = homebank_file_getencoding(filename);
+	DB( g_print(" -> encoding should be %s\n", encoding) );
+
+	retval = TRUE;
+	*error = NULL;
+	io = g_io_channel_new_file(filename, "r", NULL);
+	if(io != NULL)
+	{
+		if( encoding != NULL )
+		{
+			g_io_channel_set_encoding(io, encoding, NULL);
+		}
+
+		for(;;)
+		{
+			io_stat = g_io_channel_read_line(io, &tmpstr, NULL, NULL, NULL);
+			if( io_stat == G_IO_STATUS_EOF)
+				break;
+			if( io_stat == G_IO_STATUS_NORMAL)
+			{
+				if( tmpstr != NULL)
+				{
+				Tag *tag;
+				
+					DB( g_print("\n + strip\n") );
+					hb_string_strip_crlf(tmpstr);
+
+					DB( g_print(" add tag:'%s' ?\n", tmpstr) );
+					tag = da_tag_append_if_new(tmpstr);
+					if(	tag != NULL )
+					{
+						GLOBALS->changes_count++;
+					}
+				}
+				g_free(tmpstr);
+			}
+
+		}
+		g_io_channel_unref (io);
+	}
+
+	return retval;
+}
 
 
+void
+tag_save_csv(gchar *filename)
+{
+GIOChannel *io;
+GList *ltag, *list;
+gchar *outstr;
+
+	io = g_io_channel_new_file(filename, "w", NULL);
+	if(io != NULL)
+	{
+		ltag = list = tag_glist_sorted(1);
+
+		while (list != NULL)
+		{
+		Tag *item = list->data;
+
+			if(item->key != 0)
+			{
+				outstr = g_strdup_printf("%s\n", item->name);
+
+				DB( g_print(" + export %s\n", outstr) );
+
+				g_io_channel_write_chars(io, outstr, -1, NULL, NULL);
+
+				g_free(outstr);
+			}
+			list = g_list_next(list);
+		}
+		g_list_free(ltag);
+
+		g_io_channel_unref (io);
+	}
+}
+
