@@ -45,6 +45,7 @@ gboolean	da_tag_create_none(void);
 gboolean	da_tag_delete(guint32 key);
 gboolean	da_tag_insert(Tag *acc);
 gboolean	da_tag_append(Tag *acc);
+Tag *da_tag_append_if_new(gchar *rawname);
 guint32		da_tag_get_max_key(void);
 Tag		*da_tag_get_by_name(gchar *name);
 Tag		*da_tag_get(guint32 key);
@@ -59,5 +60,8 @@ gboolean tag_rename(Tag *item, const gchar *newname);
 
 GList *tag_glist_sorted(gint column);
 
+gboolean tag_load_csv(gchar *filename, gchar **error);
+void tag_save_csv(gchar *filename);
+
 #endif
 
