@@ -135,6 +135,8 @@ guint32 date;
 	txn->kpay		= arc->kpay;
 	txn->kcat		= arc->kcat;
 	txn->kxferacc	= arc->kxferacc;
+	//#1673260
+	txn->xferamount = arc->xferamount;
 	if(arc->memo != NULL)
 		txn->memo	    = g_strdup(arc->memo);
 	if(arc->info != NULL)
@@ -278,18 +280,18 @@ GList *da_transaction_sort(GList *list)
 }
 
 
-gboolean da_transaction_insert_memo(Transaction *item)
+gboolean da_transaction_insert_memo(gchar *memo, guint32 date)
 {
 gboolean retval = FALSE;
 
-	if( item->memo != NULL )
+	if( memo != NULL )
 	{
 		//# 1673048 add filter on status and date obsolete
-		if( (PREFS->txn_memoacp == TRUE) && (item->date >= (GLOBALS->today - PREFS->txn_memoacp_days)) )
+		if( (PREFS->txn_memoacp == TRUE) && (date >= (GLOBALS->today - PREFS->txn_memoacp_days)) )
 		{
-			if( g_hash_table_lookup(GLOBALS->h_memo, item->memo) == NULL )
+			if( g_hash_table_lookup(GLOBALS->h_memo, memo) == NULL )
 			{
-				retval = g_hash_table_insert(GLOBALS->h_memo, g_strdup(item->memo), NULL);
+				retval = g_hash_table_insert(GLOBALS->h_memo, g_strdup(memo), NULL);
 			}
 		}
 	}
@@ -320,7 +322,7 @@ GList *lnk_txn;
 	// we're at insert point, insert after txn
 	g_queue_insert_after(acc->txn_queue, lnk_txn, newitem);
 
-	da_transaction_insert_memo(newitem);
+	da_transaction_insert_memo(newitem->memo, newitem->date);
 	return TRUE;
 }
 
@@ -337,7 +339,7 @@ Account *acc;
 	
 	item->kcur = acc->kcur;
 	g_queue_push_tail(acc->txn_queue, item);
-	da_transaction_insert_memo(item);
+	da_transaction_insert_memo(item->memo, item->date);
 	return TRUE;
 }
 
@@ -538,7 +540,6 @@ static void transaction_xfer_create_child(Transaction *ope)
 {
 Transaction *child;
 Account *acc;
-guint32 swap;
 
 	DB( g_print("\n[transaction] xfer_create_child\n") );
 
@@ -549,16 +550,28 @@ guint32 swap;
 		ope->flags |= (OF_CHANGED | OF_INTXFER);
 		child->flags |= (OF_ADDED | OF_INTXFER);
 
-		child->amount = -child->amount;
-		child->flags ^= (OF_INCOME);	// invert flag
+		//#1673260 deal with multi currency amount
+		if( !(ope->flags & OF_ADVXFER) )
+		{
+			child->amount = -ope->amount;
+			//TODO:maybe
+			//child->xferamount = 0;
+		}
+		else
+		{
+			child->amount = ope->xferamount;
+			child->xferamount = ope->amount;
+		}
+
+		da_transaction_set_flag(child);	// set income/xpense
+
 		//#1268026 #1690555
 		if( (child->status == TXN_STATUS_CLEARED) || (child->status == TXN_STATUS_RECONCILED) )
 			child->status = TXN_STATUS_NONE;
 		//child->flags &= ~(OF_VALID);	// delete reconcile state
 
-		swap = child->kacc;
 		child->kacc = child->kxferacc;
-		child->kxferacc = swap;
+		child->kxferacc = ope->kacc;
 
 		/* update acc flags */
 		acc = da_acc_get( child->kacc );
@@ -568,29 +581,24 @@ guint32 swap;
 
 			//strong link
 			guint maxkey = da_transaction_get_max_kxfer();
-
 			DB( g_print(" + maxkey is %d\n", maxkey) );
 
-
 			ope->kxfer = maxkey+1;
 			child->kxfer = maxkey+1;
-
 			DB( g_print(" + strong link to %d\n", ope->kxfer) );
 
+			child->kcur = acc->kcur;
 
 			DB( g_print(" + add transfer, %p to acc %d\n", child, acc->key) );
-
 			da_transaction_insert_sorted(child);
-
 			account_balances_add (child);
-
 		}
 	}
 
 }
 
 
-static gint transaction_xfer_child_match_rate(Transaction *stxn, Transaction *ptxn)
+static gint transaction_xfer_child_match_rate(Transaction *stxn, Transaction *ptxn, guint32 daygap)
 {
 gint rate = 0;
 
@@ -606,7 +614,7 @@ gint rate = 0;
 		rate++;
 	//TODO: maybe add info & tag here	
 
-	rate = (rate *100) / 5;
+	rate = (rate * 100) / 5;
 
 	DB( g_print(" return %d\n", rate) );
 
@@ -628,6 +636,7 @@ gboolean retval = FALSE;
 	DB( g_print(" src: %d %d %d %f %d\n", stxn->kcur, stxn->date, stxn->kacc, stxn->amount, stxn->kxfer ) );
 	DB( g_print(" dst: %d %d %d %f %d\n", dtxn->kcur, dtxn->date, dtxn->kacc, dtxn->amount, dtxn->kxfer ) );
 
+	//disable for != currencies
 	if( stxn->kcur == dtxn->kcur &&
 	    //stxn->date == dtxn->date &&
 		//# 1708974 enable different date
@@ -677,7 +686,7 @@ GList *list, *matchlist = NULL;
 				if( transaction_xfer_child_might(ope, item, PREFS->txn_xfer_daygap) == TRUE )
 				{
 					// evaluate here a match rate based on several fields
-					item->matchrate = transaction_xfer_child_match_rate(ope, item);
+					item->matchrate = transaction_xfer_child_match_rate(ope, item, PREFS->txn_xfer_daygap);
 					DB( g_print(" - match %3d: %d %s %f %d=>%d\n", item->matchrate, item->date, item->memo, item->amount, item->kacc, item->kxferacc) );
 					matchlist = g_list_append(matchlist, item);
 				}
@@ -782,11 +791,11 @@ void transaction_xfer_change_to_normal(Transaction *ope)
 	DB( g_print("\n[transaction] xfer_change_to_normal\n") );
 
 	//remove xfer flags
-	ope->flags &= ~(OF_INTXFER);
+	ope->flags &= ~(OF_INTXFER|OF_ADVXFER);
 
 	ope->kxfer = 0;
 	ope->kxferacc = 0;
-
+	ope->xferamount = 0;
 }
 
 
@@ -798,6 +807,7 @@ Account *dstacc;
 	DB( g_print("\n[transaction] xfer_change_to_child\n") );
 
 	//disable for != currencies
+	//5.6 we keep this as the usage of this func is only equal kcur !
 	if(ope->kcur != child->kcur)
 		return;
 
@@ -843,12 +853,32 @@ Account *acc;
 
 	//# 1708974 enable different date
 	//child->date		= s_txn->date;
-	child->amount   = -s_txn->amount;
+
+	//# 1673260 enable different currency
+	if( !(child->flags & OF_ADVXFER) )
+	{
+		DB( g_print(" sync amount (!=kcur)\n") );
+		child->amount   = -s_txn->amount;
+	}
+	else
+	{
+		DB( g_print(" sync amount (==kcur)\n") );
+		child->amount = s_txn->xferamount;
+		child->xferamount = s_txn->amount;
+	}
+
 	child->flags	= child->flags | OF_CHANGED;
-	//#1295877
+	//#1295877 flag update to avoid bad column display
 	child->flags &= ~(OF_INCOME);
-	if( child->amount > 0)
+	if( child->amount > 0 )
 	  child->flags |= (OF_INCOME);
+	// ensure to have INC to good display payee direction
+	else if( child->amount == 0 )
+	{
+		if( s_txn->amount < 0 )
+			child->flags |= (OF_INCOME);
+	}
+
 	child->kpay		= s_txn->kpay;
 	child->kcat		= s_txn->kcat;
 	if(child->memo)
