@@ -46,14 +46,15 @@ struct _transaction
 	guint32		*tags;
 	guint32		kxfer;		//strong link xfer key
 	guint32		kxferacc;
+	gdouble		xferamount;	//xfer target amount
 
 	GPtrArray	*splits;
 
 	/* unsaved datas */
-	guint32		kcur;
-	gushort		dspflags;
-	gushort		matchrate;
-	gdouble		balance;
+	guint32		kcur;		//init at loadxml (preprend) + add
+	gushort		dspflags;	//
+	gushort		matchrate;	//used only when find xfer target
+	gdouble		balance;	//init at dsp balance refresh
 	//GList		*same;		//used for import todo: change this
 };
 
@@ -73,8 +74,8 @@ struct _transaction
 #define OF_INCOME	(1<<1)
 #define OF_AUTO		(1<<2)	//scheduled
 #define OF_INTXFER	(1<<3)
-//FREE (1<<4)
-//FREE (1<<5) 
+#define OF_ADVXFER  (1<<4)	//xfer with != kcur
+//FREE (1<<5)
 #define OF_CHEQ2	(1<<6)
 #define OF_LIMIT	(1<<7)	//scheduled
 #define OF_SPLIT	(1<<8)
@@ -152,7 +153,7 @@ guint da_transaction_length(void);
 
 void transaction_remove(Transaction *ope);
 void transaction_changed(Transaction *txn, gboolean saverecondate);
-gboolean da_transaction_insert_memo(Transaction *item);
+gboolean da_transaction_insert_memo(gchar *memo, guint32 date);
 Transaction *transaction_add(GtkWindow *parent, Transaction *ope);
 
 gchar *transaction_get_status_string(Transaction *txn);
