@@ -434,6 +434,34 @@ GList *list;
 }
 
 
+static void homebank_upgrade_to_v14_12(void)
+{
+gint oldsmode, smode;
+
+	DB( g_print("\n[hb-xml] homebank_upgrade_to_v14_12\n") );
+
+	//convert old smode to new one
+	oldsmode = GLOBALS->auto_smode;
+	smode = 0;
+	switch(oldsmode)
+	{
+		case 0: 
+			smode = ARC_POSTMODE_PAYOUT;
+			break;
+		case 1:
+		{
+			if(GLOBALS->auto_nbdays == 0)
+				smode = ARC_POSTMODE_DUEDATE;
+			else
+				smode = ARC_POSTMODE_ADVANCE;
+		}
+		break;
+	}
+	DB( g_print("migrated smode: %d to %d\n", oldsmode, smode) );
+	GLOBALS->auto_smode = smode;
+
+}
+
 
 // lower v0.6 : we must assume categories/payee exists
 // and strong link to xfer
@@ -595,6 +623,8 @@ gint i;
 		else if(!strcmp (attribute_names[i], "name" )) { entry->name = g_strdup(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "category")) { entry->kcat = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "paymode" )) { entry->paymode = atoi(attribute_values[i]); }
+		else if(!strcmp (attribute_names[i], "notes"   )) { if(strcmp(attribute_values[i],"(null)") && attribute_values[i] != NULL) entry->notes = g_strdup(attribute_values[i]); }
+
 	}
 
 	//all attribute loaded: append
@@ -613,6 +643,7 @@ gint i;
 		else if(!strcmp (attribute_names[i], "car_category")) { GLOBALS->vehicle_category = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "auto_smode"  )) { GLOBALS->auto_smode = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "auto_weekday")) { GLOBALS->auto_weekday = atoi(attribute_values[i]); }
+		else if(!strcmp (attribute_names[i], "auto_nbmonths")) { GLOBALS->auto_nbmonths = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "auto_nbdays" )) { GLOBALS->auto_nbdays = atoi(attribute_values[i]); }
 	}
 }
@@ -702,7 +733,7 @@ gint i;
 }
 
 
-/*static void homebank_load_xml_tag(ParseContext *ctx, const gchar **attribute_names, const gchar **attribute_values)
+static void homebank_load_xml_tag(ParseContext *ctx, const gchar **attribute_names, const gchar **attribute_values)
 {
 Tag *entry = da_tag_malloc();
 gint i;
@@ -718,7 +749,7 @@ gint i;
 
 	//all attribute loaded: append
 	da_tag_insert(entry);
-}*/
+}
 
 
 static void homebank_load_xml_fav(ParseContext *ctx, const gchar **attribute_names, const gchar **attribute_values)
@@ -737,6 +768,8 @@ gint i;
 		     if(!strcmp (attribute_names[i], "key"        )) { entry->key = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "amount"     )) { entry->amount = g_ascii_strtod(attribute_values[i], NULL); }
 		else if(!strcmp (attribute_names[i], "account"    )) { entry->kacc = atoi(attribute_values[i]); }
+		//#1673260
+		else if(!strcmp (attribute_names[i], "damt"      )) { entry->xferamount = g_ascii_strtod(attribute_values[i], NULL); }
 		else if(!strcmp (attribute_names[i], "dst_account")) { entry->kxferacc = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "paymode"    )) { entry->paymode = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "st"         )) { entry->status = atoi(attribute_values[i]); }
@@ -795,6 +828,8 @@ gint i;
 		     if(!strcmp (attribute_names[i], "date"       )) { entry->date = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "amount"     )) { entry->amount = g_ascii_strtod(attribute_values[i], NULL); }
 		else if(!strcmp (attribute_names[i], "account"    )) { entry->kacc = atoi(attribute_values[i]); }
+		//#1673260
+		else if(!strcmp (attribute_names[i], "damt"      )) { entry->xferamount = g_ascii_strtod(attribute_values[i], NULL); }
 		else if(!strcmp (attribute_names[i], "dst_account")) { entry->kxferacc = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "paymode"    )) { entry->paymode = atoi(attribute_values[i]); }
 		else if(!strcmp (attribute_names[i], "st"         )) { entry->status = atoi(attribute_values[i]); }
@@ -902,14 +937,14 @@ ParseContext *ctx = user_data;
 
 		//TODO: < 5.2 misstyped here, should be tag without a s
 		//commented > 5.2 useless not loaded, but no side effect
-		/*case 't':
+		case 't':
 		{
-			if(!strcmp (element_name, "tags"))
+			if(!strcmp (element_name, "tag"))
 			{
 				homebank_load_xml_tag(ctx, attribute_names, attribute_values);
 			}
 		}
-		break;*/
+		break;
 
 		case 'f':
 		{
@@ -1021,19 +1056,13 @@ gboolean rc, dosanity;
 		if( ctx.file_version > FILE_VERSION )
 			return XML_VERSION_ERROR;
 
-		
 		DB( g_print("- file ok : v=%.1f data_v=%06d\n", ctx.file_version, ctx.data_version) );
 
 		/* 1st: validate the file is well in utf-8 */
-		DB( g_print("- ensure UTF-8\n") );
+
 		buffer = homebank_utf8_ensure(buffer);
 
 		/* then process the buffer */
-		#if MYDEBUG == 1
-			GTimer *t = g_timer_new();
-			g_print("- start parse\n");
-		#endif
-
 		context = g_markup_parse_context_new (&hb_parser, 0, &ctx, NULL);
 
 		error = NULL;
@@ -1044,7 +1073,6 @@ gboolean rc, dosanity;
 			g_print("failed: %s\n", error->message);
 			g_error_free (error);
 		}
-
 			
 		if( rc == FALSE )
 		{
@@ -1061,9 +1089,6 @@ gboolean rc, dosanity;
 		g_markup_parse_context_free (context);
 		g_free (buffer);
 
-		DB( g_print("- end parse : %f sec\n", g_timer_elapsed(t, NULL)) );
-		DB( g_timer_destroy (t) );
-
 		/* file upgrade / bugfix */
 		dosanity = FALSE;
 		// group a test for very old version
@@ -1143,6 +1168,10 @@ gboolean rc, dosanity;
 			//fix income txn flag that may be incorrect (multiple edit)
 			dosanity = TRUE;
 		}
+		if( ctx.data_version < 50600 ) 
+		{
+			homebank_upgrade_to_v14_12();
+		}		
 		// next ?
 
 
@@ -1291,6 +1320,7 @@ GError *error = NULL;
 	hb_xml_append_int(node, "car_category", GLOBALS->vehicle_category);
 	hb_xml_append_int0(node, "auto_smode", GLOBALS->auto_smode);
 	hb_xml_append_int(node, "auto_weekday", GLOBALS->auto_weekday);
+	hb_xml_append_int(node, "auto_nbmonths", GLOBALS->auto_nbmonths);
 	hb_xml_append_int(node, "auto_nbdays", GLOBALS->auto_nbdays);
 
 	g_string_append(node, "/>\n");
@@ -1433,6 +1463,7 @@ GError *error = NULL;
 			hb_xml_append_txt(node, "name", item->name);
 			hb_xml_append_int(node, "category", item->kcat);
 			hb_xml_append_int(node, "paymode" , item->paymode);
+			hb_xml_append_txt_crlf(node, "notes", item->notes);
 
 			g_string_append(node, "/>\n");
 
@@ -1553,7 +1584,7 @@ GError *error = NULL;
 /*
 ** XML tag save
 */
-/*static gint homebank_save_xml_tag(GIOChannel *io)
+static gint homebank_save_xml_tag(GIOChannel *io)
 {
 GList *ltag, *list;
 gchar *tmpstr;
@@ -1586,7 +1617,7 @@ GError *error = NULL;
 	}
 	g_list_free(ltag);
 	return retval;
-}*/
+}
 
 
 /*
@@ -1637,7 +1668,6 @@ GError *error = NULL;
 }
 
 
-
 /*
 ** XML archive save
 */
@@ -1663,6 +1693,9 @@ GError *error = NULL;
 		hb_xml_append_int(node, "key", item->key);
 		hb_xml_append_amt(node, "amount", item->amount);
 		hb_xml_append_int(node, "account", item->kacc);
+		//#1673260
+		if( item->flags & OF_ADVXFER )
+			hb_xml_append_amt(node, "damt", item->xferamount);
 		hb_xml_append_int(node, "dst_account", item->kxferacc);
 		hb_xml_append_int(node, "paymode", item->paymode);
 		hb_xml_append_int(node, "st", item->status);
@@ -1749,6 +1782,9 @@ GError *error = NULL;
 			hb_xml_append_int(node, "date", item->date);
 			hb_xml_append_amt(node, "amount", item->amount);
 			hb_xml_append_int(node, "account", item->kacc);
+			//#1673260
+			if( item->flags & OF_ADVXFER )
+				hb_xml_append_amt(node, "damt", item->xferamount);
 			hb_xml_append_int(node, "dst_account", item->kxferacc);
 			hb_xml_append_int(node, "paymode", item->paymode);
 			hb_xml_append_int(node, "st", item->status);
@@ -1834,7 +1870,7 @@ GError *error = NULL;
 	retval = homebank_save_xml_acc(io);
 	retval = homebank_save_xml_pay(io);
 	retval = homebank_save_xml_cat(io);
-	//retval = homebank_save_xml_tag(io);
+	retval = homebank_save_xml_tag(io);
 	retval = homebank_save_xml_asg(io);
 	retval = homebank_save_xml_arc(io);
 	retval = homebank_save_xml_ope(io);
