@@ -684,7 +684,7 @@ gboolean exists;
 /*
 ** application cleanup: icons, GList, memory
 */
-static void homebank_cleanup()
+static void homebank_cleanup(void)
 {
 
 	DB( g_print("\n[homebank] cleanup\n") );
@@ -816,6 +816,7 @@ gchar *pathfilename;
 	return window;
 }
 
+
 static void
 homebank_init_i18n (void)
 {
@@ -1001,6 +1002,7 @@ GtkWidget *splash = NULL;
 	return EXIT_SUCCESS;
 }
 
+
 #ifdef G_OS_WIN32
 /* In case we build this as a windows application */
 
