@@ -74,14 +74,14 @@
 
 
 #define HOMEBANK_MAJOR	5
-#define HOMEBANK_MINOR	5
-#define HOMEBANK_MICRO	8
+#define HOMEBANK_MINOR	6
+#define HOMEBANK_MICRO	0
 
-#define HB_VERSION		"5.5.8"
+#define HB_VERSION		"5.6"
 #define HB_VERSION_NUM	(HOMEBANK_MAJOR*10000) + (HOMEBANK_MINOR*100) + HOMEBANK_MICRO
 
 #define FILE_VERSION		1.4
-#define PREF_VERSION		558
+#define PREF_VERSION		560
 
 #if HB_UNSTABLE == FALSE
 	#define	PROGNAME		"HomeBank"
@@ -205,6 +205,9 @@ typedef enum
 #define ICONNAME_LIST_EDIT			"document-edit-symbolic"
 #define ICONNAME_LIST_DELETE		"list-remove-symbolic"
 #define ICONNAME_LIST_DELETE_ALL	"list-remove-all-symbolic"
+#define ICONNAME_LIST_MOVE_UP		"hb-go-up-symbolic"
+#define ICONNAME_LIST_MOVE_DOWN		"hb-go-down-symbolic"
+#define ICONNAME_LIST_MOVE_AFTER	"list-move-after-symbolic"
 #define ICONNAME_CHANGES_PREVENT	"changes-prevent-symbolic"
 #define ICONNAME_CHANGES_ALLOW  	"changes-allow-symbolic"
 #define ICONNAME_SYSTEM_SEARCH		"system-search-symbolic"
@@ -218,6 +221,8 @@ typedef enum
 #define ICONNAME_HB_BUTTON_DELETE	"edit-delete-symbolic"
 #define ICONNAME_HB_TOGGLE_SIGN		"toggle-sign-symbolic"
 #define ICONNAME_HB_LIST_MERGE		"list-merge-symbolic"
+#define ICONNAME_HB_BUTTON_HIDE		"eye-not-looking-symbolic"
+#define ICONNAME_HB_BUTTON_USAGE	"data-usage-symbolic"
 
 #define ICONNAME_HB_TEXT_CASE		"text-casesensitive-symbolic"
 #define ICONNAME_HB_TEXT_REGEX		"text-regularexpression-symbolic"
@@ -279,7 +284,7 @@ typedef enum
 #define ICONNAME_HB_OPE_MOVUP		"hb-go-up"
 #define ICONNAME_HB_OPE_MOVDW		"hb-go-down"
 
-#define ICONNAME_HB_OPE_NEW		     "hb-ope-new"
+#define ICONNAME_HB_OPE_NEW		    "hb-ope-new"
 // edit is defined above
 #define ICONNAME_HB_OPE_VOID        "hb-ope-void"
 #define ICONNAME_HB_OPE_REMIND      "hb-ope-remind"
@@ -321,6 +326,7 @@ struct HomeBank
 	gchar			*owner;
 	gshort			auto_smode;
 	gshort			auto_weekday;
+	gshort			auto_nbmonths;
 	gshort			auto_nbdays;
 
 	guint32			vehicle_category;
