@@ -216,17 +216,24 @@ guint j;
 
 			if(acc)
 			{
-				g->bal_recon += hb_amount_base(acc->bal_recon, acc->kcur);
-				g->bal_clear += hb_amount_base(acc->bal_clear, acc->kcur);
-				g->bal_today += hb_amount_base(acc->bal_today, acc->kcur);
-				g->bal_future += hb_amount_base(acc->bal_future, acc->kcur);
-
-				//#1950234 show subtotal when single with foreign currency
-				if( (g->acclist->len == 1) && (acc->kcur == GLOBALS->kcur) )
+				//#1896441 outflow summary
+				if( (acc->flags & AF_OUTFLOWSUM) == FALSE )
 				{
-					g->showtotal = FALSE;
-				}
+					g->bal_recon += hb_amount_base(acc->bal_recon, acc->kcur);
+					g->bal_clear += hb_amount_base(acc->bal_clear, acc->kcur);
+					g->bal_today += hb_amount_base(acc->bal_today, acc->kcur);
+					g->bal_future += hb_amount_base(acc->bal_future, acc->kcur);
 
+					//#1950234 show subtotal when single with foreign currency
+					if( (g->acclist->len == 1) && (acc->kcur == GLOBALS->kcur) )
+					{
+						g->showtotal = FALSE;
+					}
+				}
+				else
+				{
+					DB( g_print("  '%s' is outflow\n", acc->name) );
+				}
 			}
 		}
 		
