@@ -366,7 +366,7 @@ GDate *date;
 
 	PREFS->pnl_upc_range = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_sched_range));
 	
-	maxpostdate = scheduled_date_get_post_max();
+	maxpostdate = scheduled_date_get_post_max(GLOBALS->today, GLOBALS->auto_smode, GLOBALS->auto_nbdays, GLOBALS->auto_weekday, GLOBALS->auto_nbmonths);
 	date = g_date_new_julian (maxpostdate);
 	g_date_strftime (buffer, 256-1, PREFS->date_format, date);
 	g_date_free(date);
@@ -508,7 +508,7 @@ GtkToolItem *toolitem;
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 	gtk_box_pack_start (GTK_BOX (vbox), sw, TRUE, TRUE, 0);
 	
-	widget = (GtkWidget *)create_list_upcoming();
+	widget = (GtkWidget *)lst_sch_widget_new();
 	data->LV_upc = widget;
 	gtk_container_add (GTK_CONTAINER (sw), widget);
 
