@@ -138,7 +138,7 @@ GVariant *variant = g_action_group_get_action_state(G_ACTION_GROUP(data->action_
 	DB( g_print(" - range=%d\n", range) );
 	DB( g_print(" - pref range=%d\n", PREFS->date_range_wal) );
 
-	if(range == FLT_RANGE_OTHER)
+	if(range == FLT_RANGE_MISC_CUSTOM)
 		return;
 
 	filter_preset_daterange_set(data->filter, range, 0);
