@@ -56,8 +56,8 @@ GtkTreeIter	iter;
 	model1 = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_txn[HUB_TXN_TYPE_FUTURE]));
 	model2 = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_txn[HUB_TXN_TYPE_REMIND]));
 
-	gtk_list_store_clear (GTK_LIST_STORE(model1));
-	gtk_list_store_clear (GTK_LIST_STORE(model2));
+	gtk_tree_store_clear (GTK_TREE_STORE(model1));
+	gtk_tree_store_clear (GTK_TREE_STORE(model2));
 
 	
 	lst_acc = g_hash_table_get_values(GLOBALS->h_acc);
@@ -77,7 +77,7 @@ GtkTreeIter	iter;
 
 			if(txn->date > GLOBALS->today)
 			{
-				gtk_list_store_insert_with_values(GTK_LIST_STORE(model1), &iter, -1,
+				gtk_tree_store_insert_with_values(GTK_TREE_STORE(model1), &iter, NULL, -1,
 						MODEL_TXN_POINTER, txn,
 						MODEL_TXN_SPLITAMT, txn->amount,
 						-1);
@@ -85,7 +85,7 @@ GtkTreeIter	iter;
 
 			if(txn->status == TXN_STATUS_REMIND)
 			{
-				gtk_list_store_insert_with_values(GTK_LIST_STORE(model2), &iter, -1,
+				gtk_tree_store_insert_with_values(GTK_TREE_STORE(model2), &iter, NULL, -1,
 						MODEL_TXN_POINTER, txn,
 						MODEL_TXN_SPLITAMT, txn->amount,
 						-1);
