@@ -493,6 +493,7 @@ GString *node;
 gint dt;
 Account *acc;
 gboolean hastext = FALSE;
+gchar *escapedname;
 
 	if (!gtk_tree_view_get_tooltip_context (GTK_TREE_VIEW (widget),
 					  &x, &y,
@@ -512,10 +513,13 @@ gboolean hastext = FALSE;
 		return FALSE;
 	}
 
+	//#1993599 tooltip fail when & into acc name
+	escapedname = g_markup_escape_text(acc->name, -1);
 	node = g_string_sized_new(255);
 	g_string_append(node, "<b>");
-	g_string_append(node, acc->name);
+	g_string_append(node, escapedname);
 	g_string_append(node, "</b>\n");
+	g_free(escapedname);
 
 	if( acc->rdate > 0 )
 	{
@@ -629,9 +633,6 @@ GtkTreeViewColumn  *column;
 	g_object_set_data(G_OBJECT(treeview), "inst_data", (gpointer)data);
 	DB( g_print(" - treeview=%p, inst_data=%p\n", treeview, data) );
 
-	g_signal_connect (treeview, "destroy", G_CALLBACK (lst_accview_destroy), NULL);
-
-	
 	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (treeview), PREFS->grid_lines);
 	//gtk_tree_view_set_search_column (GTK_TREE_VIEW (treeview),
 	//			       COLUMN_DESCRIPTION);
@@ -719,7 +720,9 @@ GtkTreeViewColumn  *column;
 
 	//add tooltip
 	gtk_widget_set_has_tooltip (GTK_WIDGET (treeview), TRUE);
-	
+
+	g_signal_connect (treeview, "destroy", G_CALLBACK (lst_accview_destroy), NULL);
+
 	g_signal_connect (treeview, "button-press-event", G_CALLBACK (lst_accview_cb_button_pressed_event), popmenu);
 
 	g_signal_connect (treeview, "query-tooltip",
