@@ -196,6 +196,36 @@ list_txn_sort_iter_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIte
 static void
 list_txn_eval_future(GtkCellRenderer *renderer, Transaction *txn)
 {
+	
+	//it seems we are not able to get a valid GdkRGBA
+	//nor to set/use the alpha
+	/*GdkRGBA *rgba;
+	g_object_get(renderer, "foreground-rgba", &rgba, NULL);
+	//g_print("forcol: %p %f %f %f %f\n", rgba, rgba->red, rgba->green, rgba->blue, rgba->alpha);
+	//rgba->red = 1.0;
+	rgba->alpha = 0.5;
+	g_object_set(renderer, "foreground-set", TRUE, 
+		"foreground-rgba", rgba,
+	NULL);
+	gdk_rgba_free(rgba);*/
+
+	/*GdkRGBA rgba = {1, 0, 0, 0.15};
+
+	GdkRGBA *rgba2;
+
+	g_print("forcol: %p %f %f %f %f\n", rgba, rgba.red, rgba.green, rgba.blue, rgba.alpha);
+
+	
+	g_object_get(renderer, "background-rgba", &rgba2, NULL);
+	g_print("forcol: %p %f %f %f %f\n", rgba2, rgba2->red, rgba2->green, rgba2->blue, rgba2->alpha);
+	//rgba->red = 1.0;
+	//rgba->alpha = 0.5;
+	g_object_set(renderer, "background-set", TRUE, 
+		"background-rgba", &rgba,
+	NULL);
+	*/
+
+
 	if(txn->date > GLOBALS->today)
 	{
 		g_object_set(renderer, 
@@ -245,67 +275,73 @@ list_txn_eval_future(GtkCellRenderer *renderer, Transaction *txn)
 
 
 static void 
-list_txn_status_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+list_txn_cell_data_func_status (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
+Split *split;
 gchar *iconname = NULL;
 
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
 
-	/*
-		stat[0] = ( entry->ope_Flags & OF_ADDED  ) ? data->istatus[2] : data->istatus[0];
-		stat[1] = ( entry->ope_Flags & OF_CHANGED) ? data->istatus[3] : data->istatus[0];
-		stat[2] = ( entry->ope_Flags & OF_VALID  ) ? data->istatus[4] : data->istatus[0];
-		if( entry->ope_Flags & OF_REMIND ) stat[2] = data->istatus[1];
-	*/
-
-	switch(GPOINTER_TO_INT(user_data))
+	if( split == NULL )
 	{
-		case 1:
-			iconname = ( ope->flags & OF_AUTO  ) ? ICONNAME_HB_OPE_AUTO : ( ope->flags & OF_ADDED ) ? ICONNAME_HB_OPE_NEW : NULL;
-			break;
-		case 2:
-			iconname = ( ope->flags & OF_CHANGED  ) ? ICONNAME_HB_OPE_EDIT : NULL;
-			break;
-		case 3:
-			//iconname = ( ope->marker == TXN_MARK_DUPDST ) ? ICONNAME_HB_OPE_SIMILAR : NULL;
-			iconname = ( ope->dspflags & TXN_DSPFLG_DUPDST ) ? ICONNAME_HB_OPE_SIMILAR : NULL;
-			break;
-		/*case 3:
-			if( entry->flags & OF_VALID )
-				iconname = ICONNAME_HB_OPE_VALID;
-			else
-			{
-				if( entry->flags & OF_REMIND )
-					iconname = ICONNAME_HB_OPE_REMIND;
-			}
-			break;*/
+		switch(GPOINTER_TO_INT(user_data))
+		{
+			case 1:
+				iconname = ( ope->flags & OF_AUTO  ) ? ICONNAME_HB_OPE_AUTO : ( ope->flags & OF_ADDED ) ? ICONNAME_HB_OPE_NEW : NULL;
+				break;
+			case 2:
+				iconname = ( ope->flags & OF_CHANGED  ) ? ICONNAME_HB_OPE_EDIT : NULL;
+				break;
+			case 3:
+				//iconname = ( ope->marker == TXN_MARK_DUPDST ) ? ICONNAME_HB_OPE_SIMILAR : NULL;
+				iconname = ( ope->dspflags & TXN_DSPFLG_DUPDST ) ? ICONNAME_HB_OPE_SIMILAR : NULL;
+				break;
+			/*case 3:
+				if( entry->flags & OF_VALID )
+					iconname = ICONNAME_HB_OPE_VALID;
+				else
+				{
+					if( entry->flags & OF_REMIND )
+						iconname = ICONNAME_HB_OPE_REMIND;
+				}
+				break;*/
+		}
 	}
 
 	g_object_set(renderer, "icon-name", iconname, NULL);
 }
 
 
-static void 
-list_txn_account_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void
+list_txn_cell_data_func_account (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
-Account *acc;
+Split *split;
+gchar *text = NULL;
+	
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
 
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
-
-	acc = da_acc_get(ope->kacc);
-	if( acc )
+	if( split == NULL )
 	{
-		g_object_set(renderer, "text", acc->name, NULL);
+	Account *acc = da_acc_get(ope->kacc);
+		if( acc )
+		{
+			text = acc->name;
+		}
 	}
-	else
-		g_object_set(renderer, "text", "", NULL);
+	g_object_set(renderer, "text", text, NULL);
 }
 
 
-static void 
-list_txn_match_rate_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void
+list_txn_cell_data_func_match_rate (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
 gchar buffer[8];
@@ -317,142 +353,194 @@ gchar buffer[8];
 }
 
 
-static void 
-list_txn_date_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void
+list_txn_cell_data_func_date (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
+Split *split;
 gchar buffer[256];
 GDate date;
 
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
-	list_txn_eval_future(renderer, ope);
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
 
-	if(ope->date > 0)
+	if( split != NULL )
 	{
-		g_date_set_julian (&date, ope->date);
-		g_date_strftime (buffer, 256-1, PREFS->date_format, &date);
-		#if MYDEBUG
-		gchar *ds = g_strdup_printf ("%s [%02d]", buffer, ope->pos );
-		g_object_set(renderer, "text", ds, NULL);
-		g_free(ds);
-		#else
-		g_object_set(renderer, "text", buffer, NULL);
-		#endif
+		g_object_set(renderer, "text", NULL, NULL);
 	}
 	else
-		g_object_set(renderer, "text", "????", NULL);
+	{
+		list_txn_eval_future(renderer, ope);
+
+		if(ope->date > 0)
+		{
+			g_date_set_julian (&date, ope->date);
+			g_date_strftime (buffer, 256-1, PREFS->date_format, &date);
+			#if MYDEBUG
+			gchar *ds = g_strdup_printf ("%s [%02d]", buffer, ope->pos );
+			g_object_set(renderer, "text", ds, NULL);
+			g_free(ds);
+			#else
+			g_object_set(renderer, "text", buffer, NULL);
+			#endif
+		}
+		else
+			g_object_set(renderer, "text", "????", NULL);
+	}
 }
 
 
 static void 
-list_txn_info_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+list_txn_cell_data_func_info (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
+Split *split;
+gchar *iconname = NULL;
+gchar *text = NULL;
 
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
 
 	switch(GPOINTER_TO_INT(user_data))
 	{
 		case 1:
-			if(ope->flags & OF_INTXFER)
-				g_object_set(renderer, "icon-name", ICONNAME_HB_PM_INTXFER, NULL);
-			else
-				g_object_set(renderer, "icon-name", get_paymode_icon_name(ope->paymode), NULL);
+			if( split == NULL )
+			{
+				iconname = (ope->flags & OF_INTXFER) ? ICONNAME_HB_PM_INTXFER : (gchar *)get_paymode_icon_name(ope->paymode);
+			}
+			g_object_set(renderer, "icon-name", iconname, NULL);
 			break;
 		case 2:
-			list_txn_eval_future(renderer, ope);
-			g_object_set(renderer, "text", ope->info, NULL);
+			if( split == NULL )
+			{
+				list_txn_eval_future(renderer, ope);
+				text = ope->info;
+			}
+			g_object_set(renderer, "text", text, NULL);
 			break;
 	}
 }
 
 
-static void 
-list_txn_payeexfer_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void
+list_txn_cell_data_func_payee (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
-gchar *direction = "";
-	
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
-	list_txn_eval_future(renderer, ope);
+Split *split;
+gchar *text = NULL;
 
-	if(ope->flags & OF_INTXFER)
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
+
+	if( split == NULL )
 	{
-		direction = ( ope->flags & OF_INCOME ) ? "<" : ">";
+		list_txn_eval_future(renderer, ope);
+
+		//#926782
+		if(ope->flags & OF_INTXFER)
+		{
+		Account *acc = da_acc_get(ope->kxferacc);
+			
+			//5.6 use acc strings for 5.3 add > < for internal xfer
+			if( acc )
+				text = ( ope->flags & OF_INCOME ) ? acc->xferincname : acc->xferexpname;
+			
+		}
+		else
+		{
+		Payee *pay = da_pay_get(ope->kpay);
+			
+			text = (pay != NULL) ? pay->name : NULL;
+		}
 	}
-	g_object_set(renderer, "text", direction, NULL);
+
+	g_object_set(renderer, "text", text, NULL);
+
 }
 
 
-static void 
-list_txn_payee_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
-{
-Transaction *ope;
-
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
-	list_txn_eval_future(renderer, ope);
-
-	//#926782
-	if(ope->flags & OF_INTXFER)
-	{
-	Account *acc = da_acc_get(ope->kxferacc);
-		
-		g_object_set(renderer, "text", (acc != NULL) ? acc->name : "", NULL);
-	}
-	else
-	{
-	Payee *pay = da_pay_get(ope->kpay);
-		
-		g_object_set(renderer, "text", pay != NULL ? pay->name : "", NULL);
-	}
-}
-
-
-static void 
-list_txn_tags_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void
+list_txn_cell_data_func_tags (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
+Split *split;
 Transaction *ope;
 gchar *str;
 
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
-	list_txn_eval_future(renderer, ope);
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
 
-	if(ope->tags != NULL)
+	if( split == NULL )
 	{
-		str = tags_tostring(ope->tags);
-		g_object_set(renderer, "text", str, NULL);
-		g_free(str);
+
+		list_txn_eval_future(renderer, ope);
+
+		if(ope->tags != NULL)
+		{
+			str = tags_tostring(ope->tags);
+			g_object_set(renderer, "text", str, NULL);
+			g_free(str);
+		}
+		else
+			g_object_set(renderer, "text", "", NULL);
+
 	}
 	else
-		g_object_set(renderer, "text", "", NULL);
+		g_object_set(renderer, "text", NULL, NULL);
 }
 
 
-
-static void 
-list_txn_memo_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void
+list_txn_cell_data_func_memo (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
+Split *split;
 
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
-	list_txn_eval_future(renderer, ope);
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
+
+	if( split == NULL )
+	{
+		list_txn_eval_future(renderer, ope);
+    	g_object_set(renderer, "text", ope->memo, NULL);
+	}
+	else if( split != NULL )
+	{
+		g_object_set(renderer, "text", split->memo, NULL);
+	}
 
-	g_object_set(renderer, "text", ope->memo, NULL);
 }
 
 
 static void 
-list_txn_account_icon_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+list_txn_cell_data_func_account_icon (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Transaction *ope;
+Split *split;
 Account *acc;
 gchar *iconname = NULL;
 	
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
-	acc = da_acc_get(ope->kacc);
-	if( acc && (acc->flags & AF_CLOSED) )
-	{
-		iconname = ICONNAME_CHANGES_PREVENT;
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
+
+	if( split == NULL )
+	{	    
+		acc = da_acc_get(ope->kacc);
+		if( acc && (acc->flags & AF_CLOSED) )
+		{
+			iconname = ICONNAME_CHANGES_PREVENT;
+		}
 	}
 
 	g_object_set(renderer, "icon-name", iconname, NULL);
@@ -460,11 +548,12 @@ gchar *iconname = NULL;
 
 
 static void 
-list_txn_clr_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+list_txn_cell_data_func_clr (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 struct list_txn_data *data = NULL;
 GtkWidget *widget;
 Transaction *ope;
+Split *split;
 gchar *iconname = NULL;
 //const gchar *c = "";
 
@@ -472,7 +561,10 @@ gchar *iconname = NULL;
 	if( widget )
 		data = g_object_get_data(G_OBJECT(widget), "inst_data");
 
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+		MODEL_TXN_POINTER, &ope, 
+		 -1);
 
 	switch(GPOINTER_TO_INT(user_data))
 	{
@@ -483,16 +575,20 @@ gchar *iconname = NULL;
 
 		case 2:
 		{
-			switch(ope->status)
+			if( split == NULL )
 			{
-				/*case TXN_STATUS_CLEARED: c = "c"; break;
-				case TXN_STATUS_RECONCILED: c = "R"; break;
-				case TXN_STATUS_REMIND: c = "!"; break;*/
-				case TXN_STATUS_CLEARED:	iconname = ICONNAME_HB_OPE_CLEARED; break;
-				case TXN_STATUS_RECONCILED: iconname = ICONNAME_HB_OPE_RECONCILED; break;
-				case TXN_STATUS_REMIND:     iconname = ICONNAME_HB_OPE_REMIND; break;
-				case TXN_STATUS_VOID:     iconname = ICONNAME_HB_OPE_VOID; break;		
+				switch(ope->status)
+				{
+					/*case TXN_STATUS_CLEARED: c = "c"; break;
+					case TXN_STATUS_RECONCILED: c = "R"; break;
+					case TXN_STATUS_REMIND: c = "!"; break;*/
+					case TXN_STATUS_CLEARED:	iconname = ICONNAME_HB_OPE_CLEARED; break;
+					case TXN_STATUS_RECONCILED: iconname = ICONNAME_HB_OPE_RECONCILED; break;
+					case TXN_STATUS_REMIND:     iconname = ICONNAME_HB_OPE_REMIND; break;
+					case TXN_STATUS_VOID:       iconname = ICONNAME_HB_OPE_VOID; break;		
+				}
 			}
+			break;
 		}
 	}
 
@@ -501,12 +597,13 @@ gchar *iconname = NULL;
 }
 
 
-static void 
-list_txn_amount_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void
+list_txn_cell_data_func_amount (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 struct list_txn_data *data = NULL;
 GtkWidget *widget;
 Transaction *ope;
+Split *split;
 gint column = GPOINTER_TO_INT(user_data);
 gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 gint type;
@@ -518,27 +615,39 @@ gchar *color;
 		data = g_object_get_data(G_OBJECT(widget), "inst_data");
 	
 	// get the transaction
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, MODEL_TXN_SPLITAMT, &samount, -1);
-	list_txn_eval_future(renderer, ope);
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+		MODEL_TXN_SPLITAMT, &samount,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
 
-	if(column == LST_DSPOPE_BALANCE)
-		amount = ope->balance;
-	else
-		amount = ope->amount;
-
-	//for detail display the split part (if any)
-	if( data && (data->list_type == LIST_TXN_TYPE_DETAIL) )
-		amount = samount;
-	
-	if(column == LST_DSPOPE_INCOME || column == LST_DSPOPE_EXPENSE)
+	if( split == NULL )
 	{
-		type = (ope->flags & OF_INCOME) ? LST_DSPOPE_INCOME : LST_DSPOPE_EXPENSE;
-		if( type != column)
+		list_txn_eval_future(renderer, ope);
+
+		if(column == LST_DSPOPE_BALANCE)
+			amount = ope->balance;
+		else
+			amount = ope->amount;
+
+		if(column == LST_DSPOPE_INCOME || column == LST_DSPOPE_EXPENSE)
 		{
-			g_object_set(renderer, "markup", NULL, NULL);
-			return;
+			type = (ope->flags & OF_INCOME) ? LST_DSPOPE_INCOME : LST_DSPOPE_EXPENSE;
+			if( type != column)
+			{
+				g_object_set(renderer, "markup", NULL, NULL);
+				return;
+			}
 		}
+
+		//for detail display the split part (if any)
+		if( data && (data->list_type == LIST_TXN_TYPE_DETAIL) )
+			amount = samount;
 	}
+	else if( split != NULL )
+		{
+			amount = split->amount;
+		}
 
 	//if(amount != 0)
 	//{
@@ -566,12 +675,13 @@ gchar *color;
 }
 
 
-static void 
-list_txn_category_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+static void
+list_txn_cell_data_func_category (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 struct list_txn_data *data = NULL;
 GtkWidget *widget;
 Transaction *ope;
+Split *split;
 Category *cat;
 gchar *color = NULL;
 gchar *text = NULL;
@@ -580,34 +690,46 @@ gchar *text = NULL;
 	if( widget )
 		data = g_object_get_data(G_OBJECT(widget), "inst_data");
 	
-	gtk_tree_model_get(model, iter, MODEL_TXN_POINTER, &ope, -1);
-	list_txn_eval_future(renderer, ope);
+	gtk_tree_model_get(model, iter, 
+		MODEL_TXN_SPLITPTR, &split,
+	    MODEL_TXN_POINTER, &ope, 
+	    -1);
 
-	color = NULL;
-	text = "";
-	
-	if(ope->flags & OF_SPLIT)
+	if( split == NULL )
 	{
-		text = _("- split -");
-	}
-	else
-	{
-		if( ope->kcat > 0 )
+		list_txn_eval_future(renderer, ope);
+		if(ope->flags & OF_SPLIT)
 		{
-			cat = da_cat_get(ope->kcat);
-			text = (cat != NULL) ? cat->fullname : "";
+			text = _("- split -");
 		}
 		else
 		{
-			//#1673902 add a visual marker for uncategorized txn
-			//#1844881 but not for internal xfer
-			if( (data->warnnocategory == TRUE) && !(ope->flags & OF_INTXFER) )
+			if( ope->kcat > 0 )
 			{
-				color = PREFS->color_warn;
-				text = _("- this needs a category -");
+				cat = da_cat_get(ope->kcat);
+				text = (cat != NULL) ? cat->fullname : "";
+			}
+			else
+			{
+				//#1673902 add a visual marker for uncategorized txn
+				//#1844881 but not for internal xfer
+				if( (data->warnnocategory == TRUE) && !(ope->flags & OF_INTXFER) )
+				{
+					color = PREFS->color_warn;
+					text = _("- this needs a category -");
+				}
 			}
 		}
 	}
+	else
+		if( split != NULL )
+	{
+		if( split->kcat > 0 )
+		{
+			cat = da_cat_get(split->kcat);
+			text = (cat != NULL) ? cat->fullname : "";
+		}	
+	}	
 
 	g_object_set(renderer,
 		"foreground",  color,
@@ -930,6 +1052,7 @@ struct list_txn_data *data;
 	data->lockreconciled = lockreconciled;
 }
 
+
 void list_txn_set_warn_nocategory(GtkTreeView *treeview, gboolean warn)
 {
 struct list_txn_data *data;
@@ -984,11 +1107,23 @@ static void list_txn_get_columns(GtkTreeView *treeview)
 struct list_txn_data *data;
 GtkTreeViewColumn *column;
 gint i, col_id;
+gint *col_id_ptr;
+gint *col_width_ptr;
 
 	DB( g_print("\n[list_txn] get columns position/width\n") );
 	
 	data = g_object_get_data(G_OBJECT(treeview), "inst_data");
 
+	//default for LIST_TXN_TYPE_BOOK
+	col_id_ptr = PREFS->lst_ope_columns;
+	col_width_ptr = PREFS->lst_ope_col_width;
+
+	if( data->list_type == LIST_TXN_TYPE_DETAIL )
+	{
+		col_id_ptr = PREFS->lst_det_columns;
+		col_width_ptr = PREFS->lst_det_col_width;
+	}
+
 	DB( g_print(" nbcol=%d, nbsortid=%d\n", NUM_LST_DSPOPE, gtk_tree_view_get_n_columns (treeview)) );
 	
 	for(i=0 ; i < NUM_LST_DSPOPE-1 ; i++ )   // -1 'caus: account and blank column
@@ -1007,17 +1142,17 @@ gint i, col_id;
 
 				if( visible )
 				{
-					PREFS->lst_ope_columns[i] = col_id;
+					col_id_ptr[i] = col_id;
 					//5.2 moved here to keep old width in case not visible
-					PREFS->lst_ope_col_width[col_id-1] = gtk_tree_view_column_get_width(column);
+					col_width_ptr[col_id-1] = gtk_tree_view_column_get_width(column);
 				}							
 				else
-					PREFS->lst_ope_columns[i] = -col_id;
+					col_id_ptr[i] = -col_id;
 
 				DB( g_print(" col-%2d => %2d '%s' w=%d\n", i, col_id, gtk_tree_view_column_get_title(column), PREFS->lst_ope_col_width[col_id-1] ) );
 			}
 			else	//should not occurs
-				PREFS->lst_ope_columns[i] = 0;
+				col_id_ptr[i] = 0;
 		}
 	}
 }
@@ -1031,6 +1166,7 @@ gboolean visible;
 GList *list;
 gint i = 0;
 gint id;
+gint *col_width_ptr;
 
 	DB( g_print("\n[list_txn] set columns order/width\n") );
 	
@@ -1078,21 +1214,36 @@ gint id;
 				if( id == LST_DSPOPE_STATUS || id == LST_DSPOPE_EXPENSE || id == LST_DSPOPE_INCOME )
 					visible = FALSE;
 			}
-			
-			gtk_tree_view_column_set_visible (column, visible);
+
+			if(data->list_type == LIST_TXN_TYPE_DETAIL)
+			{
+				if( id == LST_DSPOPE_STATUS )
+					visible = TRUE;
+			}
+
 			if( id == LST_DSPOPE_BALANCE )
 			{
 				data->tvc_is_visible = visible;
 			}
 
-			if(   id == LST_DSPOPE_INFO
-			   || id == LST_DSPOPE_PAYEE
-			   || id == LST_DSPOPE_MEMO
-			   || id == LST_DSPOPE_CATEGORY
-			   || id == LST_DSPOPE_TAGS
-			   || id == LST_DSPOPE_ACCOUNT )
+			gtk_tree_view_column_set_visible (column, visible);
+
+			//5.6 only apply width to BOOK||DETAIL to allow autosize on XFER dialog
+			if( (data->list_type == LIST_TXN_TYPE_BOOK) || (data->list_type == LIST_TXN_TYPE_DETAIL) )
 			{
-				gtk_tree_view_column_set_fixed_width( column, PREFS->lst_ope_col_width[id - 1]);
+				col_width_ptr = PREFS->lst_ope_col_width;
+				if( data->list_type == LIST_TXN_TYPE_DETAIL )
+					col_width_ptr = PREFS->lst_det_col_width;
+
+				if(   id == LST_DSPOPE_INFO
+				   || id == LST_DSPOPE_PAYEE
+				   || id == LST_DSPOPE_MEMO
+				   || id == LST_DSPOPE_CATEGORY
+				   || id == LST_DSPOPE_TAGS
+				   || id == LST_DSPOPE_ACCOUNT )
+				{
+					gtk_tree_view_column_set_fixed_width( column, col_width_ptr[id - 1]);
+				}
 			}
 		}
 
@@ -1126,8 +1277,7 @@ gboolean showBalance;
 
 
 static void
-list_txn_column_popup_menuitem_on_activate (GtkCheckMenuItem *checkmenuitem,
-               gpointer          user_data)
+list_txn_column_popup_menuitem_on_activate (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
 {
 GtkTreeViewColumn *column = user_data;
 
@@ -1137,6 +1287,15 @@ GtkTreeViewColumn *column = user_data;
 }
 
 
+//beta
+static void
+list_txn_popmenu_destroy(GtkTreeView *treeview, gpointer user_data)
+{
+	DB( g_print ("\n[list_txn] menu destroy\n") );
+
+}
+
+
 static gboolean
 list_txn_column_popup_callback ( GtkWidget *button,
                         GdkEventButton *ev,
@@ -1153,6 +1312,9 @@ gint i, col_id;
 		DB( g_print("should popup\n") );
 	
 		menu = gtk_menu_new ();
+
+		//beta
+		g_signal_connect (menu, "destroy", G_CALLBACK (list_txn_popmenu_destroy), NULL);
 		
 		//note: deactive this disable any menuitem action
 		g_signal_connect (menu, "selection-done", G_CALLBACK (gtk_widget_destroy), NULL);
@@ -1238,20 +1400,12 @@ GtkCellRenderer    *renderer;
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, title);
 	
-	//5.3 add > < for internal xfer
-	if( sortcolumnid == LST_DSPOPE_PAYEE )
-	{
-		renderer = gtk_cell_renderer_text_new ();
-		gtk_tree_view_column_pack_start(column, renderer, FALSE);
-		gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_payeexfer_cell_data_function, NULL, NULL);
-	}
-
 	//#1861337 add icon for closed account
 	if( sortcolumnid == LST_DSPOPE_ACCOUNT )
 	{
 		renderer = gtk_cell_renderer_pixbuf_new ();
 		gtk_tree_view_column_pack_start(column, renderer, TRUE);
-		gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_account_icon_cell_data_function, NULL, NULL);
+		gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_account_icon, NULL, NULL);
 	}
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -1291,7 +1445,7 @@ GtkCellRenderer    *renderer;
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start(column, renderer, FALSE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_info_cell_data_function, GINT_TO_POINTER(1), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_info, GINT_TO_POINTER(1), NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, 
@@ -1301,7 +1455,7 @@ GtkCellRenderer    *renderer;
 	    "width-chars", 40,
 	    NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_info_cell_data_function, GINT_TO_POINTER(2), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_info, GINT_TO_POINTER(2), NULL);
 
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_column_set_resizable(column, TRUE);
@@ -1417,7 +1571,7 @@ Transaction *ope;
 GtkWidget *create_list_transaction(gint list_type, gboolean *pref_columns)
 {
 struct list_txn_data *data;
-GtkListStore *store;
+GtkTreeStore *store;
 GtkWidget *treeview;
 GtkCellRenderer *renderer;
 GtkTreeViewColumn *column, *col_acc = NULL, *col_status = NULL, *col_match = NULL;
@@ -1431,9 +1585,10 @@ GtkTreeViewColumn *column, *col_acc = NULL, *col_status = NULL, *col_match = NUL
 	data->save_column_width = FALSE;
 
 	/* create list store */
-	store = gtk_list_store_new(
-		2, G_TYPE_POINTER,	// MODEL_TXN_POINTER
-	       G_TYPE_DOUBLE	// MODEL_TXN_SPLITAMT amount part of split for detail only
+	store = gtk_tree_store_new(
+		3, G_TYPE_POINTER,	// MODEL_TXN_POINTER
+	       G_TYPE_DOUBLE,	// MODEL_TXN_SPLITAMT amount part of split for detail only
+		   G_TYPE_POINTER	// MODEL_TXN_SPLITPTR
 		);
 
 	//treeview
@@ -1463,17 +1618,17 @@ GtkTreeViewColumn *column, *col_acc = NULL, *col_status = NULL, *col_match = NUL
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	//gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_status_cell_data_function, GINT_TO_POINTER(1), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_status, GINT_TO_POINTER(1), NULL);
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	//gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_status_cell_data_function, GINT_TO_POINTER(2), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_status, GINT_TO_POINTER(2), NULL);
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	//gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_status_cell_data_function, GINT_TO_POINTER(3), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_status, GINT_TO_POINTER(3), NULL);
 
 	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_STATUS);
 	//gtk_tree_view_column_set_resizable(column, TRUE);
@@ -1484,21 +1639,28 @@ GtkTreeViewColumn *column, *col_acc = NULL, *col_status = NULL, *col_match = NUL
 	GtkWidget *img = gtk_image_new_from_icon_name (ICONNAME_EMBLEM_SYSTEM, GTK_ICON_SIZE_BUTTON);
 	gtk_widget_show(img);
 	gtk_tree_view_column_set_widget(column, img);
-	if(list_type == LIST_TXN_TYPE_BOOK)
+	if( list_type == LIST_TXN_TYPE_BOOK || list_type == LIST_TXN_TYPE_DETAIL )
 		g_signal_connect ( G_OBJECT (gtk_tree_view_column_get_button (column)), 
 			"button-press-event",
 			G_CALLBACK ( list_txn_column_popup_callback ),
 			data );
 
 	//5.2 Account is always created but not visible for BOOK
-	column = list_txn_column_text_create(list_type, _("Account"), LST_DSPOPE_ACCOUNT, list_txn_account_cell_data_function, NULL);
+	column = list_txn_column_text_create(list_type, _("Account"), LST_DSPOPE_ACCOUNT, list_txn_cell_data_func_account, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	col_acc = column;
 
 	//5.5 Match Rate
 	if(list_type == LIST_TXN_TYPE_XFERTARGET)
 	{
-		column = list_txn_column_amount_create(list_type, _("Match"), LST_DSPOPE_MATCH, list_txn_match_rate_cell_data_function);
+		column = gtk_tree_view_column_new();
+		gtk_tree_view_column_set_title(column, _("Match"));
+		renderer = gtk_cell_renderer_text_new ();
+		gtk_tree_view_column_pack_start(column, renderer, TRUE);
+		g_object_set(renderer, "xalign", 0.5, NULL);
+		gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_match_rate, NULL, NULL);
+		gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_MATCH);
+		//gtk_tree_view_column_set_resizable(column, TRUE);
 		col_match = column;
 		gtk_tree_view_column_set_clickable(column, FALSE);
 		gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
@@ -1510,7 +1672,7 @@ GtkTreeViewColumn *column, *col_acc = NULL, *col_status = NULL, *col_match = NUL
 	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	g_object_set(renderer, "xalign", 1.0, NULL);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_date_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_date, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_DATE);
 	//gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
@@ -1518,10 +1680,10 @@ GtkTreeViewColumn *column, *col_acc = NULL, *col_status = NULL, *col_match = NUL
 	column = list_txn_column_info_create(list_type);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	column = list_txn_column_text_create(list_type, _("Payee"), LST_DSPOPE_PAYEE, list_txn_payee_cell_data_function, NULL);
+	column = list_txn_column_text_create(list_type, _("Payee"), LST_DSPOPE_PAYEE, list_txn_cell_data_func_payee, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	column = list_txn_column_text_create(list_type, _("Memo"), LST_DSPOPE_MEMO, list_txn_memo_cell_data_function, NULL);
+	column = list_txn_column_text_create(list_type, _("Memo"), LST_DSPOPE_MEMO, list_txn_cell_data_func_memo, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* column status CLR */
@@ -1529,40 +1691,42 @@ GtkTreeViewColumn *column, *col_acc = NULL, *col_status = NULL, *col_match = NUL
 	gtk_tree_view_column_set_title(column, _("Status"));
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
-	//gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	g_object_set(renderer, "xalign", 1.0, NULL);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_clr_cell_data_function, GINT_TO_POINTER(1), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_clr, GINT_TO_POINTER(1), NULL);
 
 	renderer = gtk_cell_renderer_pixbuf_new();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	g_object_set(renderer, "xalign", 1.0, NULL);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_clr_cell_data_function, GINT_TO_POINTER(2), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_func_clr, GINT_TO_POINTER(2), NULL);
 
 	gtk_tree_view_column_set_reorderable(column, TRUE);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_CLR);
 	//gtk_tree_view_column_set_sort_indicator (column, FALSE);
 	//gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
-	column = list_txn_column_amount_create(list_type, _("Amount"), LST_DSPOPE_AMOUNT, list_txn_amount_cell_data_function);
+	column = list_txn_column_amount_create(list_type, _("Amount"), LST_DSPOPE_AMOUNT, list_txn_cell_data_func_amount);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	column = list_txn_column_amount_create(list_type, _("Expense"), LST_DSPOPE_EXPENSE, list_txn_amount_cell_data_function);
+	column = list_txn_column_amount_create(list_type, _("Expense"), LST_DSPOPE_EXPENSE, list_txn_cell_data_func_amount);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	column = list_txn_column_amount_create(list_type, _("Income"), LST_DSPOPE_INCOME, list_txn_amount_cell_data_function);
+	column = list_txn_column_amount_create(list_type, _("Income"), LST_DSPOPE_INCOME, list_txn_cell_data_func_amount);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	column = list_txn_column_text_create(list_type, _("Category"), LST_DSPOPE_CATEGORY, list_txn_category_cell_data_function, NULL);
+	column = list_txn_column_text_create(list_type, _("Category"), LST_DSPOPE_CATEGORY, list_txn_cell_data_func_category, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	column = list_txn_column_text_create(list_type, _("Tags"), LST_DSPOPE_TAGS, list_txn_tags_cell_data_function, NULL);
+	//set expander column for LIST_TXN_TYPE_DETAIL
+	if(list_type == LIST_TXN_TYPE_DETAIL) 
+		gtk_tree_view_set_expander_column(GTK_TREE_VIEW(treeview), column);
+
+	column = list_txn_column_text_create(list_type, _("Tags"), LST_DSPOPE_TAGS, list_txn_cell_data_func_tags, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	if(list_type == LIST_TXN_TYPE_BOOK)
 	{
-		column = list_txn_column_amount_create(list_type, _("Balance"), LST_DSPOPE_BALANCE, list_txn_amount_cell_data_function);
+		column = list_txn_column_amount_create(list_type, _("Balance"), LST_DSPOPE_BALANCE, list_txn_cell_data_func_amount);
 		data->tvc_balance = column;
 		gtk_tree_view_column_set_clickable(column, FALSE);
 		gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
@@ -1585,6 +1749,7 @@ GtkTreeViewColumn *column, *col_acc = NULL, *col_status = NULL, *col_match = NUL
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_TAGS    , list_txn_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_TAGS), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_CLR     , list_txn_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_CLR), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_ACCOUNT , list_txn_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_ACCOUNT), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DSPOPE_MATCH   , list_txn_sort_iter_compare_func, GINT_TO_POINTER(LST_DSPOPE_MATCH), NULL);
 
   /* apply user preference for columns */
 	list_txn_set_columns(GTK_TREE_VIEW(treeview), pref_columns);
