@@ -32,7 +32,8 @@ enum {
 
 enum {
 	MODEL_TXN_POINTER = 0,
-	MODEL_TXN_SPLITAMT
+	MODEL_TXN_SPLITAMT,
+	MODEL_TXN_SPLITPTR
 };
 
 
