@@ -47,6 +47,8 @@ GtkTreeIter	iter;
 gboolean valid;
 const gchar *format;
 
+	DB( g_print("\n[list_rep_total] to string\n") );
+
 	node = g_string_new(NULL);
 
 	// header
@@ -182,7 +184,8 @@ GtkCellRenderer    *renderer;
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_rep_total_amount_cell_data_function, GINT_TO_POINTER(id), NULL);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	//gtk_tree_view_column_set_sort_column_id (column, id);
+	//#1933164
+	gtk_tree_view_column_set_sort_column_id (column, id);
 	return column;
 }
 
@@ -215,6 +218,13 @@ gint retval = 0;
 gint pos1, pos2;
 gdouble val1, val2;
 
+	//#1933164
+	gint csid;
+	GtkSortType cso;
+
+	gtk_tree_sortable_get_sort_column_id(GTK_TREE_SORTABLE(model), &csid, &cso);
+	DB( g_print(" csid=%d cso=%s\n", csid, cso == GTK_SORT_ASCENDING ? "asc" : "desc") );
+
 	gtk_tree_model_get(model, a,
 		LST_REPDIST_POS, &pos1,
 		sortcol, &val1,
@@ -224,33 +234,41 @@ gdouble val1, val2;
 		sortcol, &val2,
 		-1);
 
+	//#1933164 should return
+	// > 0 if a sorts before b 
+	// = 0 if a sorts with b
+	// < 0 if a sorts after b
+
 	//total always at bottom
 	if( pos1 == LST_REPDIST_POS_TOTAL )
 	{
-		retval = -1;
+		retval = cso == GTK_SORT_ASCENDING ? 1 : -1;
+		DB( g_print(" sort p1=%d ? p2=%d = %d\n", pos1, pos2, retval) );
 	}
 	else
 	{
 		if( pos2 == LST_REPDIST_POS_TOTAL )
 		{
-			retval = 1;
+			retval = cso == GTK_SORT_ASCENDING ? -1 : 1;
+			DB( g_print(" sort p1=%d ? p2=%d = %d\n", pos1, pos2, retval) )
 		}
 		else
 		{
 			switch(sortcol)
 			{
 				case LST_REPDIST_POS:
-					retval = pos2 - pos1;
+					retval = pos1 - pos2;
 					//DB( g_print(" sort %3d = %3d :: %d\n", pos1, pos2, retval) );
 					break;
 				default:
-					retval = (ABS(val1) - ABS(val2)) > 0 ? 1 : -1;
+					retval = (ABS(val1) - ABS(val2)) > 0 ? -1 : 1;
 					//DB( g_print(" sort %.2f = %.2f :: %d\n", val1, val2, retval) );
 					break;
 			}
 		}
 	}
 
+
 	return retval;
 }
 
@@ -286,6 +304,8 @@ GtkWidget *view;
 GtkCellRenderer    *renderer;
 GtkTreeViewColumn  *column;
 
+	DB( g_print("\n[list_rep_total] create\n") );
+
 	/* create list store */
 	store = gtk_list_store_new(
 	  	NUM_LST_REPDIST,
@@ -307,13 +327,22 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (view), PREFS->grid_lines);
 
 	/* column: Name */
+	renderer = gtk_cell_renderer_text_new ();
+
+	g_object_set(renderer, 
+		"ellipsize", PANGO_ELLIPSIZE_END,
+	    "ellipsize-set", TRUE,
+		//taken from nemo, not exactly a resize to content, but good compromise
+	    "width-chars", 40,
+	    NULL);
+
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Result"));
-	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_rep_total_name_cell_data_function, NULL, NULL);
 	//gtk_tree_view_column_add_attribute(column, renderer, "text", LST_REPDIST_NAME);
-	//gtk_tree_view_column_set_sort_column_id (column, LST_REPDIST_NAME);
+	//#1933164
+	gtk_tree_view_column_set_sort_column_id (column, LST_REPDIST_POS);
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
@@ -349,6 +378,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_REPDIST_INCOME , lst_rep_total_compare_func, GINT_TO_POINTER(LST_REPDIST_INCOME), NULL);
 	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_REPDIST_TOTAL  , lst_rep_total_compare_func, GINT_TO_POINTER(LST_REPDIST_TOTAL), NULL);
 
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), LST_REPDIST_POS, GTK_SORT_ASCENDING);
 
 	return(view);
 }
@@ -368,6 +398,8 @@ gboolean valid;
 guint32 nbcols, r, i;
 gchar sep;
 
+	DB( g_print("\n[list_rep_time] to string\n") );
+
 	node = g_string_new(NULL);
 
 	sep = (clipboard == TRUE) ? '\t' : ';';
@@ -621,13 +653,15 @@ gint pos;
 
 
 /* test new listview */
-void lst_rep_time_renewcol(GtkTreeView *treeview, guint32 nbintvl, guint32 jfrom, gint intvl)
+void lst_rep_time_renewcol(GtkTreeView *treeview, guint32 nbintvl, guint32 jfrom, gint intvl, gboolean avg)
 {
 GtkCellRenderer    *renderer;
 GtkTreeViewColumn  *column;
 GList *columns, *list;
 guint i;
 
+	DB( g_print("\n[list_rep_time] renewcol\n") );
+
 	/* remove all columns */
 	columns = gtk_tree_view_get_columns(GTK_TREE_VIEW(treeview));
 
@@ -651,10 +685,14 @@ guint i;
 	//gtk_tree_view_column_set_title(column, _("Acc/Cat/Pay"));
 	//gtk_tree_view_column_set_title(column, "ItemsType (todo)");
 	renderer = gtk_cell_renderer_text_new ();
-	/*g_object_set(renderer, 
+
+	g_object_set(renderer, 
 		"ellipsize", PANGO_ELLIPSIZE_END,
 	    "ellipsize-set", TRUE,
-	    NULL);*/
+		//taken from nemo, not exactly a resize to content, but good compromise
+	    "width-chars", 40,
+	    NULL);
+
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_rep_time_name_cell_data_function, NULL, NULL);
 	//gtk_tree_view_column_add_attribute(column, renderer, "text", LST_REPDIST2_LABEL);
@@ -674,8 +712,11 @@ guint i;
 		gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	}
 
-	column = lst_rep_time_column_create_amount(_("Average"), i++);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
+	if( avg == TRUE )
+	{
+		column = lst_rep_time_column_create_amount(_("Average"), i++);
+		gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
+	}
 
 	column = lst_rep_time_column_create_amount(_("Total"), i++);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
@@ -687,11 +728,48 @@ guint i;
 }
 
 
+/*
+GtkWidget *lst_rep_time_createtype(GtkListStore *store)
+{
+GtkWidget *view;
+GtkCellRenderer    *renderer;
+GtkTreeViewColumn  *column;
+
+	//treeview
+	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
+
+	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (view), PREFS->grid_lines);
+
+	// column: Name
+	column = gtk_tree_view_column_new();
+	//gtk_tree_view_column_set_title(column, _("Acc/Cat/Pay"));
+	//gtk_tree_view_column_set_title(column, "ItemsType (todo)");
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_rep_time_name_cell_data_function, NULL, NULL);
+	//gtk_tree_view_column_add_attribute(column, renderer, "text", LST_REPDIST2_LABEL);
+	//gtk_tree_view_column_set_sort_column_id (column, LST_REPTIME_NAME);
+	//gtk_tree_view_column_set_resizable(column, TRUE);
+	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
+	gtk_tree_view_column_set_alignment (column, 0.5);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+
+
+	// prevent selection of total
+	gtk_tree_selection_set_select_function(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), lst_rep_time_selectionfunc, NULL, NULL);
+
+
+	return view;
+}*/
+
+
 GtkWidget *lst_rep_time_create(void)
 {
 GtkTreeStore *store;
 GtkWidget *view;
 
+	DB( g_print("\n[list_rep_time] create\n") );
+
 	/* create list store */
 	store = gtk_tree_store_new(
 	  	NUM_LST_REPDIST2,
