@@ -56,7 +56,7 @@ GString *lst_rep_total_to_string(GtkTreeView *treeview, gchar *title, gboolean c
 GString *lst_rep_time_to_string(GtkTreeView *treeview, gchar *title, gboolean clipboard);
 GtkWidget *lst_rep_time_createtype(GtkListStore *store);
 GtkWidget *lst_rep_time_create(void);
-void lst_rep_time_renewcol(GtkTreeView *treeview, guint32 nbintvl, guint32 jfrom, gint intvl);
+void lst_rep_time_renewcol(GtkTreeView *treeview, guint32 nbintvl, guint32 jfrom, gint intvl, gboolean avg);
 
 
-#endif
+#endif
\ No newline at end of file
