@@ -39,7 +39,7 @@ extern struct Preferences *PREFS;
 
 
 static void
-list_sch_lateicon_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+lst_sch_cell_data_func_lateicon (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 gchar *iconname = NULL;
 gint nblate;
@@ -55,7 +55,7 @@ gint nblate;
 
 
 static void 
-list_sch_latetext_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+lst_sch_cell_data_func_latetext (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar *markuptxt;
@@ -95,7 +95,7 @@ gint nblate;
 
 
 static void
-list_sch_date_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+lst_sch_cell_data_func_date (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar buffer[256];
@@ -123,7 +123,7 @@ GDate *date;
 
 
 static void 
-list_sch_still_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+lst_sch_cell_data_func_still (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar *markuptxt;
@@ -144,7 +144,7 @@ gchar *markuptxt;
 
 
 static void 
-list_sch_payee_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+lst_sch_cell_data_func_payee (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 Payee *pay;
@@ -168,7 +168,7 @@ Payee *pay;
 
 
 static void
-list_sch_category_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+lst_sch_cell_data_func_category (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar *text = NULL;
@@ -192,7 +192,7 @@ gchar *text = NULL;
 
 
 static void 
-list_sch_memo_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+lst_sch_cell_data_func_memo (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar *memo;
@@ -215,7 +215,7 @@ gint weight;
 
 
 static void 
-list_sch_amount_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+lst_sch_cell_data_func_amount (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gdouble expense, income, amount;
@@ -260,7 +260,7 @@ gint weight;
 
 
 static void 
-list_sch_account_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+lst_sch_cell_data_func_account (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Account *acc;
 gchar *name = NULL;
@@ -280,7 +280,7 @@ gchar *name = NULL;
 
 
 static gboolean 
-list_account_selectionfunc(GtkTreeSelection *selection, GtkTreeModel *model, GtkTreePath *path, gboolean path_currently_selected, gpointer data)
+lst_sch_cb_selection_func(GtkTreeSelection *selection, GtkTreeModel *model, GtkTreePath *path, gboolean path_currently_selected, gpointer data)
 {
 GtkTreeIter iter;
 Archive *arc;
@@ -299,67 +299,210 @@ Archive *arc;
 }
 
 
-static GtkTreeViewColumn *
-list_upcoming_get_column(GtkTreeView *treeview, gint uid)
+static void
+lst_sch_popmenu_cb_activate (GtkCheckMenuItem *checkmenuitem, gpointer user_data)
+{
+GtkTreeViewColumn *column = user_data;
+//GtkWidget *treeview;
+
+	DB( g_print ("\n[lst_sch] menuitem activated\n") );
+
+	if( !GTK_IS_TREE_VIEW_COLUMN(column) )
+		return;
+
+	//TDOO: useless until we link dsp_accoutn balance to this list
+	//treeview = gtk_tree_view_column_get_tree_view(GTK_TREE_VIEW_COLUMN(column));
+	gtk_tree_view_column_set_visible(column, gtk_check_menu_item_get_active(checkmenuitem) );
+	//lst_sch_columns_prefs_get(GTK_TREE_VIEW(treeview));
+}
+
+
+static gint
+lst_sch_cb_button_pressed_event (GtkWidget *widget, GdkEventButton *event, GtkWidget *menu)
+{
+
+	DB( g_print ("\n[lst_sch] popmenu\n") );
+	
+	if (event->type == GDK_BUTTON_PRESS && event->button == 3)
+	{
+
+		// check we ARE in the header but in bin window
+		if (event->window != gtk_tree_view_get_bin_window (GTK_TREE_VIEW (widget)))
+		{
+			#if( (GTK_MAJOR_VERSION == 3) && (GTK_MINOR_VERSION >= 22) )
+				gtk_menu_popup_at_pointer(GTK_MENU(menu), (GdkEvent *)event);
+			#else
+				gtk_menu_popup (GTK_MENU(menu), NULL, NULL, NULL, NULL, event->button, event->time);
+			#endif
+				// On indique à l'appelant que l'on a géré cet événement.
+
+				return TRUE;
+		}
+
+		// On indique à l'appelant que l'on n'a pas géré cet événement.
+	}
+		return FALSE;
+}
+
+
+static void
+lst_sch_popmenu_destroy(GtkTreeView *treeview, gpointer user_data)
+{
+	DB( g_print ("\n[lst_sch] menu destroy\n") );
+
+}
+
+
+static GtkWidget *
+lst_sch_popmenu_new(GtkTreeView *treeview)
+{
+GtkTreeViewColumn *column;
+GtkWidget *menu;
+GtkWidget *menuitem;
+gint i, uid;
+//GtkAccelGroup *accel_group = NULL;
+
+	//accel_group = gtk_accel_group_new();
+	//gtk_window_add_accel_group(GTK_WINDOW(data->window), accel_group);
+
+	DB( g_print ("\n[lst_sch] create popmenu\n") );
+	
+	menu = gtk_menu_new();
+	//data->ME_popmenu = menu;
+
+	for(i=0 ; i < NUM_LST_COL_DSPUPC ; i++ )
+	{
+		column = gtk_tree_view_get_column(GTK_TREE_VIEW(treeview), i);
+		if( column != NULL )
+		{
+			//uid = gtk_tree_view_column_get_sort_column_id (column);
+			uid = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(column), "uid"));
+
+			DB( g_print (" col %d\n", uid) );
+			
+			if( (uid == -1) || (uid == 0)
+				|| (uid == COL_DSPUPC_ACCOUNT) 
+			)
+				continue;
+
+			menuitem = gtk_check_menu_item_new_with_label ( gtk_tree_view_column_get_title (column) );
+			gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+			gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem), gtk_tree_view_column_get_visible (column) );
+
+			g_signal_connect (menuitem, "activate",
+								G_CALLBACK (lst_sch_popmenu_cb_activate), column);
+
+		}
+	}
+	
+	g_signal_connect (menu, "destroy", G_CALLBACK (lst_sch_popmenu_destroy), NULL);
+	
+	gtk_widget_show_all(menu);
+
+	return menu;
+}
+
+
+static void
+lst_sch_widget_columns_prefs_set(struct lst_sch_data *data)
 {
-GtkTreeViewColumn *retval = NULL;
 guint i;
 
-	for(i=0;i<gtk_tree_view_get_n_columns(treeview);i++)
+	DB( g_print ("\n[lst_sch] colums prefs set\n") );
+
+	for(i=COL_DSPUPC_PAYEE;i<gtk_tree_view_get_n_columns(GTK_TREE_VIEW(data->treeview));i++)
 	{
-	GtkTreeViewColumn *column = gtk_tree_view_get_column(treeview, i);
+	GtkTreeViewColumn *column = gtk_tree_view_get_column(GTK_TREE_VIEW(data->treeview), i);
 
 		if(column)
 		{
-			gint coluid = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(column), "uid"));
-			if( coluid == uid )
-				retval = column;
+		gint coluid = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(column), "uid"));
+
+			switch(coluid)
+			{
+				case COL_DSPUPC_PAYEE:
+					gtk_tree_view_column_set_visible(column, PREFS->pnl_upc_col_pay_show);
+					gtk_tree_view_column_set_fixed_width(column, PREFS->pnl_upc_col_pay_width);
+					break;
+				case COL_DSPUPC_CATEGORY:
+					gtk_tree_view_column_set_visible(column, PREFS->pnl_upc_col_cat_show);
+					gtk_tree_view_column_set_fixed_width(column, PREFS->pnl_upc_col_cat_width);
+					break;
+				case COL_DSPUPC_MEMO:
+					gtk_tree_view_column_set_visible(column, PREFS->pnl_upc_col_mem_show);
+					gtk_tree_view_column_set_fixed_width(column, PREFS->pnl_upc_col_mem_width);
+					break;
+			}
+		}
+	}
+
+}
+
+
+static void
+lst_sch_widget_columns_prefs_get(struct lst_sch_data *data)
+{
+guint i;
+
+	DB( g_print ("\n[lst_sch] colums prefs get\n") );
+
+	for(i=COL_DSPUPC_PAYEE;i<gtk_tree_view_get_n_columns(GTK_TREE_VIEW(data->treeview));i++)
+	{
+	GtkTreeViewColumn *column = gtk_tree_view_get_column(GTK_TREE_VIEW(data->treeview), i);
+
+		if(column)
+		{
+		gint coluid = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(column), "uid"));
+
+			//#1830656 use xxx_get_fixed_width instead of width, as if not visible will save 0 otherwise
+			switch(coluid)
+			{
+				case COL_DSPUPC_PAYEE:
+					PREFS->pnl_upc_col_pay_show  = gtk_tree_view_column_get_visible(column);
+					PREFS->pnl_upc_col_pay_width = gtk_tree_view_column_get_fixed_width(column);
+					break;
+				case COL_DSPUPC_CATEGORY:
+					PREFS->pnl_upc_col_cat_show  = gtk_tree_view_column_get_visible(column);
+					PREFS->pnl_upc_col_cat_width = gtk_tree_view_column_get_fixed_width(column);
+					break;
+				case COL_DSPUPC_MEMO:
+					PREFS->pnl_upc_col_mem_show  = gtk_tree_view_column_get_visible(column);
+					PREFS->pnl_upc_col_mem_width = gtk_tree_view_column_get_fixed_width(column);
+					break;
+			}
 		}
 	}
-	return retval;	
 }
 
 
 static void 
-list_upcoming_destroy(GtkTreeView *treeview, gpointer user_data)
+lst_sch_widget_destroy(GtkTreeView *treeview, gpointer user_data)
 {
-GtkTreeViewColumn *column;
+struct lst_sch_data *data;
 
-	DB( g_print ("\n[list_upcoming] destroy\n") );
+	data = g_object_get_data(G_OBJECT(treeview), "inst_data");
 
-	//#1830656 use xxx_get_fixed_width instead of width, as if not visible will save 0 otherwise
-	column = list_upcoming_get_column(treeview, COL_DSPUPC_PAYEE);
-	if( column )
-	{
-		PREFS->pnl_upc_col_pay_width = gtk_tree_view_column_get_fixed_width(column);
-	}
-	
-	column = list_upcoming_get_column(treeview, COL_DSPUPC_CATEGORY);
-	if( column )
-	{
-		PREFS->pnl_upc_col_cat_width = gtk_tree_view_column_get_fixed_width(column);
-	}
+	DB( g_print ("\n[lst_sch] destroy\n") );
 
-	column = list_upcoming_get_column(treeview, COL_DSPUPC_MEMO);
-	if( column )
-	{
-		PREFS->pnl_upc_col_mem_width = gtk_tree_view_column_get_fixed_width(column);
-	}
-
-	DB( g_print(" width payee:%d, memo:%d\n", PREFS->pnl_upc_col_pay_width, PREFS->pnl_upc_col_mem_width) );
+	lst_sch_widget_columns_prefs_get(data);
 
+	gtk_widget_destroy (data->menu);
 }
 
 
 GtkWidget *
-create_list_upcoming(void)
+lst_sch_widget_new(void)
 {
+struct lst_sch_data *data;
 GtkListStore *store;
-GtkWidget *view;
+GtkWidget *treeview;
 GtkCellRenderer  *renderer;
 GtkTreeViewColumn *column;
 
-	DB( g_print ("\n[list_upcoming] create\n") );
+	DB( g_print ("\n[lst_sch] create\n") );
+
+	data = g_malloc0(sizeof(struct lst_sch_data));
+	if(!data) return NULL;
 
 	/* create list store */
 	store = gtk_list_store_new(
@@ -374,11 +517,26 @@ GtkTreeViewColumn *column;
 		);
 
 	//treeview
-	view = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
+	treeview = gtk_tree_view_new_with_model(GTK_TREE_MODEL(store));
+	data->treeview = treeview;
 	g_object_unref(store);
 
-	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (view), PREFS->grid_lines);
-	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), GTK_SELECTION_MULTIPLE);
+	//store our window private data
+	g_object_set_data(G_OBJECT(treeview), "inst_data", (gpointer)data);
+	DB( g_print(" - treeview=%p, inst_data=%p\n", treeview, data) );
+
+	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (treeview), PREFS->grid_lines);
+	gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview)), GTK_SELECTION_MULTIPLE);
+
+	/* column: system */
+	column = gtk_tree_view_column_new();
+    gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
+
+	//add system icon to 1st column
+	gtk_tree_view_column_set_clickable(column, TRUE);
+	GtkWidget *img = gtk_image_new_from_icon_name (ICONNAME_EMBLEM_SYSTEM, GTK_ICON_SIZE_BUTTON);
+	gtk_widget_show(img);
+	gtk_tree_view_column_set_widget(column, img);
 
 	/* column : Late */
 	column = gtk_tree_view_column_new();
@@ -387,16 +545,16 @@ GtkTreeViewColumn *column;
 
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_lateicon_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_lateicon, NULL, NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_latetext_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_latetext, NULL, NULL);
 
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPUPC_NB_LATE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* column : Still (for limited scheduled) */
 	column = gtk_tree_view_column_new();
@@ -406,10 +564,10 @@ GtkTreeViewColumn *column;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_still_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_still, NULL, NULL);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPUPC_REMAINING);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
 	/* column: Next on */
 	renderer = gtk_cell_renderer_text_new ();
@@ -417,10 +575,10 @@ GtkTreeViewColumn *column;
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Next date"));
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_date_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_date, NULL, NULL);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPUPC_DATE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* column: Payee */
 	renderer = gtk_cell_renderer_text_new ();
@@ -434,15 +592,14 @@ GtkTreeViewColumn *column;
 	g_object_set_data(G_OBJECT(column), "uid", GUINT_TO_POINTER(COL_DSPUPC_PAYEE));
 	gtk_tree_view_column_set_title(column, _("Payee"));
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_payee_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_payee, NULL, NULL);
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	//gtk_tree_view_column_add_attribute(column, renderer, "text", 1);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPACC_NAME);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_column_set_min_width(column, HB_MINWIDTH_LIST/2);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	gtk_tree_view_column_set_fixed_width(column, PREFS->pnl_upc_col_pay_width);
 
 	/* column: Category */
 	renderer = gtk_cell_renderer_text_new ();
@@ -456,16 +613,13 @@ GtkTreeViewColumn *column;
 	g_object_set_data(G_OBJECT(column), "uid", GUINT_TO_POINTER(COL_DSPUPC_CATEGORY));
 	gtk_tree_view_column_set_title(column, _("Category"));
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_category_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_category, NULL, NULL);
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	//gtk_tree_view_column_add_attribute(column, renderer, "text", 1);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPACC_NAME);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_column_set_min_width(column, HB_MINWIDTH_LIST/2);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
-
-	gtk_tree_view_column_set_fixed_width(column, PREFS->pnl_upc_col_cat_width);
-
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
 	/* column: Memo */
 	renderer = gtk_cell_renderer_text_new ();
@@ -480,15 +634,13 @@ GtkTreeViewColumn *column;
 	g_object_set_data(G_OBJECT(column), "uid", GUINT_TO_POINTER(COL_DSPUPC_MEMO));
 	gtk_tree_view_column_set_title(column, _("Memo"));
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_memo_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_memo, NULL, NULL);
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	//gtk_tree_view_column_add_attribute(column, renderer, "text", 2);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPACC_NAME);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_column_set_min_width(column, HB_MINWIDTH_LIST/2);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
-
-	gtk_tree_view_column_set_fixed_width(column, PREFS->pnl_upc_col_mem_width);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* column: Amount */
 	column = gtk_tree_view_column_new();
@@ -496,10 +648,10 @@ GtkTreeViewColumn *column;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_amount_cell_data_function, GINT_TO_POINTER(-1), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_amount, GINT_TO_POINTER(-1), NULL);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPACC_NAME);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* column: Amount */
 	column = gtk_tree_view_column_new();
@@ -507,10 +659,10 @@ GtkTreeViewColumn *column;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_amount_cell_data_function, GINT_TO_POINTER(1), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_amount, GINT_TO_POINTER(1), NULL);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPACC_NAME);
 	gtk_tree_view_column_set_alignment (column, 0.5);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* column: Account */
 	renderer = gtk_cell_renderer_text_new ();
@@ -525,25 +677,32 @@ GtkTreeViewColumn *column;
 	g_object_set_data(G_OBJECT(column), "uid", GUINT_TO_POINTER(COL_DSPUPC_ACCOUNT));
 	gtk_tree_view_column_set_title(column, _("Account"));
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_sch_account_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, lst_sch_cell_data_func_account, NULL, NULL);
 	gtk_tree_view_column_set_resizable(column, TRUE);
 	//gtk_tree_view_column_set_sort_column_id (column, LST_DSPOPE_DATE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	//gtk_tree_view_column_set_min_width(column, HB_MINWIDTH_LIST);
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* column: empty */
 	column = gtk_tree_view_column_new();
-	gtk_tree_view_append_column (GTK_TREE_VIEW(view), column);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
-	gtk_tree_selection_set_select_function(gtk_tree_view_get_selection(GTK_TREE_VIEW(view)), list_account_selectionfunc, NULL, NULL);
+	// treeview func
+	gtk_tree_selection_set_select_function(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview)), lst_sch_cb_selection_func, NULL, NULL);
 
-	
-	/* set initial sort order */
 	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), LST_DSPUPC_NEXT, GTK_SORT_ASCENDING);
 
-	g_signal_connect (view, "destroy", G_CALLBACK (list_upcoming_destroy), NULL);
+	lst_sch_widget_columns_prefs_set(data);
 
-	return(view);
+	GtkWidget *popmenu = lst_sch_popmenu_new(GTK_TREE_VIEW(treeview));
+	data->menu = popmenu;
+
+	g_signal_connect (treeview, "destroy", G_CALLBACK (lst_sch_widget_destroy), NULL);
+
+	g_signal_connect (treeview, "button-press-event", G_CALLBACK (lst_sch_cb_button_pressed_event), popmenu);
+
+
+	return(treeview);
 }
 
