@@ -36,7 +36,7 @@ enum
 
 enum
 {
-	COL_DSPUPC_LATE,
+	COL_DSPUPC_LATE = 1,
 	COL_DSPUPC_STILL,
 	COL_DSPUPC_NEXTDATE,
 	COL_DSPUPC_PAYEE,
@@ -44,10 +44,19 @@ enum
 	COL_DSPUPC_MEMO,
 	COL_DSPUPC_EXPENSE,
 	COL_DSPUPC_INCOME,
-	COL_DSPUPC_ACCOUNT
+	COL_DSPUPC_ACCOUNT,
+	NUM_LST_COL_DSPUPC
 };
 
-GtkWidget *create_list_upcoming(void);
+
+struct lst_sch_data
+{
+	GtkWidget	*treeview;
+	GtkWidget	*menu;
+};
 
 
-#endif
+GtkWidget *lst_sch_widget_new(void);
+
+
+#endif
\ No newline at end of file
