@@ -61,6 +61,8 @@ static void lst_repbal_set_cur(GtkTreeView *treeview, guint32 kcur);
 //prev
 //next
 
+
+//extern gchar *CYA_REPORT_MODE[];
 extern HbKvData CYA_REPORT_INTVL[];
 
 
@@ -73,6 +75,15 @@ struct repbalance_data *data = user_data;
 	repbalance_sensitive(data->window, NULL);
 }
 
+/*static void repbalance_action_mode_changed(GtkToolButton *toolbutton, gpointer user_data)
+{
+struct repbalance_data *data = user_data;
+
+	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(data->BT_list), TRUE);
+	repbalance_action_viewlist(toolbutton, data);
+}
+*/
+
 static void repbalance_action_viewline(GtkToolButton *toolbutton, gpointer user_data)
 {
 struct repbalance_data *data = user_data;
@@ -111,7 +122,7 @@ struct repbalance_data *data;
 	gtk_date_entry_set_mindate(GTK_DATE_ENTRY(data->PO_maxdate), data->filter->mindate);
 	
 	g_signal_handler_block(data->CY_range, data->handler_id[HID_REPBALANCE_RANGE]);
-	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_OTHER);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_MISC_CUSTOM);
 	g_signal_handler_unblock(data->CY_range, data->handler_id[HID_REPBALANCE_RANGE]);
 
 
@@ -152,7 +163,7 @@ gint range;
 
 	range = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_range));
 
-	if(range != FLT_RANGE_OTHER)
+	if(range != FLT_RANGE_MISC_CUSTOM)
 	{
 		filter_preset_daterange_set(data->filter, range, 0);
 
@@ -256,7 +267,7 @@ guint active = GPOINTER_TO_INT(user_data);
 guint tmpintvl;
 GList *list;
 GtkTreeModel *model;
-GtkTreeIter  iter;
+GtkTreeIter  iter, child;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -266,7 +277,7 @@ GtkTreeIter  iter;
 	
 	/* clear and detach our model */
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail));
-	gtk_list_store_clear (GTK_LIST_STORE(model));
+	gtk_tree_store_clear (GTK_TREE_STORE(model));
 
 	if(data->detail)
 	{
@@ -278,7 +289,7 @@ GtkTreeIter  iter;
 		while (list != NULL)
 		{
 		Transaction *ope = list->data;
-		guint pos;
+		guint i, pos;
 
 			if( (ope->date >= data->filter->mindate) && (ope->date <= data->filter->maxdate) )
 			{
@@ -295,11 +306,28 @@ GtkTreeIter  iter;
 				{
 					DB( g_print(" insert\n") );
 					
-					gtk_list_store_insert_with_values (GTK_LIST_STORE(model), 
-						&iter, -1,
+					gtk_tree_store_insert_with_values (GTK_TREE_STORE(model), 
+						&iter, NULL, -1,
 						MODEL_TXN_POINTER, ope,
 						MODEL_TXN_SPLITAMT, ope->amount,
 						-1);
+
+					//#1875801 show split detail
+					if( ope->flags & OF_SPLIT )
+					{
+					guint nbsplit = da_splits_length(ope->splits);
+
+						for(i=0;i<nbsplit;i++)
+						{
+						Split *split = da_splits_get(ope->splits, i);
+						
+							gtk_tree_store_insert_with_values (GTK_TREE_STORE(model), &child, &iter, -1,
+								MODEL_TXN_POINTER, ope,
+								MODEL_TXN_SPLITPTR, split,
+								-1);
+						}
+					}
+
 				}
 			}
 			list = g_list_next(list);
@@ -319,37 +347,12 @@ static gboolean
 repbalance_cb_acc_activate_link (GtkWidget *label, const gchar *uri, gpointer user_data)
 {
 struct repbalance_data *data;
-GtkTreeModel *model;
-GtkTreeIter	iter;
-gboolean valid;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(label), GTK_TYPE_WINDOW)), "inst_data");
 
-	DB( g_print(" comboboxlink '%s' \n", uri) );
+	ui_acc_listview_quick_select(GTK_TREE_VIEW(data->LV_acc), uri);
 
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_acc));
-
-	if (g_strcmp0 (uri, "all") == 0)	
-	{
-		valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
-		while (valid)
-		{
-			gtk_list_store_set (GTK_LIST_STORE (model), &iter, LST_DEFACC_TOGGLE, TRUE, -1);
-			valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
-		}
-	}
-	else
-	if (g_strcmp0 (uri, "non") == 0)	
-	{
-		valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
-		while (valid)
-		{
-			gtk_list_store_set (GTK_LIST_STORE (model), &iter, LST_DEFACC_TOGGLE, FALSE, -1);
-			valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
-		}
-	}
-
-	g_signal_emit_by_name(gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_acc)), "changed", NULL);
+	repbalance_compute (GTK_WIDGET(data->LV_acc), NULL);
 
     return TRUE;
 }
@@ -357,12 +360,11 @@ gboolean valid;
 
 
 static void
-repbalance_cb_acc_changed(GtkTreeSelection *treeselection, gpointer user_data)
+repbalance_cb_acc_changed(GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data)
 {
-GtkTreeView *treeview;
+struct repbalance_data *data = user_data;
 
-	treeview = gtk_tree_selection_get_tree_view(treeselection);
-	repbalance_compute (GTK_WIDGET(treeview), NULL);
+	repbalance_compute (GTK_WIDGET(data->LV_acc), NULL);
 }
 
 
@@ -384,6 +386,10 @@ gboolean result;
 	{
 	Transaction *old_txn, *new_txn;
 
+		//#1909749 skip reconciled if lock is ON
+		if( PREFS->lockreconciled == TRUE && active_txn->status == TXN_STATUS_RECONCILED )
+			return;
+
 		old_txn = da_transaction_clone (active_txn);
 		new_txn = active_txn;
 		result = deftransaction_external_edit(GTK_WINDOW(data->window), old_txn, new_txn);
@@ -628,7 +634,7 @@ gint usrnbacc, usrrange;
 		goto end;
 
 	// update the date range if alldate is selected
-	if( (usrrange == FLT_RANGE_ALLDATE) )
+	if( (usrrange == FLT_RANGE_MISC_ALLDATE) )
 	{
 		data->filter->mindate = jmindate;
 		data->filter->maxdate = jmaxdate;
@@ -792,6 +798,8 @@ GtkWidget *toolbar, *button;
 	gtk_widget_set_tooltip_text(button, _("View results as lines"));
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button), -1);
 
+	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), gtk_separator_tool_item_new(), -1);
+
 	button = gtk_widget_new(GTK_TYPE_TOGGLE_TOOL_BUTTON,
 		"icon-name", ICONNAME_HB_OPE_SHOW,
 		"label", _("Detail"),
@@ -825,17 +833,93 @@ static void repbalance_window_setup(struct repbalance_data *data, guint32 accnum
 {
 	DB( g_print(" \n[repbalance] setup\n") );
 
-	repbalance_filter_setup(data);
+	DB( g_print(" init data\n") );
 
-	repbalance_update_quickdate(data->window, NULL);
+	repbalance_filter_setup(data);
+	data->detail = 0;
+
+	DB( g_print(" populate\n") );
 	
 	ui_acc_listview_populate(data->LV_acc, ACC_LST_INSERT_REPORT);
-	ui_acc_listview_set_active(GTK_TREE_VIEW(data->LV_acc), accnum ? accnum : 1);
+
+	DB( g_print(" set widgets default\n") );
+
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor),GLOBALS->minor);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
+
+	//5.6 set default account
+	if(!accnum)
+	{
+		accnum = da_acc_get_first_key();
+	}
+	ui_acc_listview_set_active(GTK_TREE_VIEW(data->LV_acc), accnum);
+
+	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
 
 	gtk_chart_show_legend(GTK_CHART(data->RE_chart), FALSE, FALSE);
 	gtk_chart_show_xval(GTK_CHART(data->RE_chart), TRUE);
 	gtk_chart_set_smallfont (GTK_CHART(data->RE_chart), PREFS->rep_smallfont);
 
+	DB( g_print(" connect widgets signals\n") );
+
+	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (repbalance_toggle_minor), NULL);
+
+	g_signal_connect (data->CY_intvl, "changed", G_CALLBACK (repbalance_compute), (gpointer)data);
+
+    data->handler_id[HID_REPBALANCE_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (repbalance_date_change), (gpointer)data);
+    data->handler_id[HID_REPBALANCE_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (repbalance_date_change), (gpointer)data);
+
+	data->handler_id[HID_REPBALANCE_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (repbalance_range_change), NULL);
+
+
+	//hbtk_radio_button_connect (GTK_CONTAINER(data->RA_mode), "toggled", G_CALLBACK (repbalance_action_mode_changed), (gpointer)data);
+
+	// acc treeview
+	g_signal_connect (data->BT_all, "activate-link", G_CALLBACK (repbalance_cb_acc_activate_link), NULL);
+	g_signal_connect (data->BT_non, "activate-link", G_CALLBACK (repbalance_cb_acc_activate_link), NULL);
+	g_signal_connect (data->BT_inv, "activate-link", G_CALLBACK (repbalance_cb_acc_activate_link), NULL);
+
+
+	//item filter
+	GtkCellRendererToggle *renderer;
+
+	renderer = g_object_get_data(G_OBJECT(data->LV_acc), "togrdr_data");
+	g_signal_connect_after (G_OBJECT(renderer), "toggled", G_CALLBACK (repbalance_cb_acc_changed), (gpointer)data);
+
+	//g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_acc)), "changed", G_CALLBACK (repbalance_cb_acc_changed), NULL);
+
+
+	g_signal_connect (data->CM_showempty, "toggled", G_CALLBACK (repbalance_compute), NULL);
+
+	g_signal_connect (data->RG_zoomx, "value-changed", G_CALLBACK (repbalance_zoomx_callback), NULL);
+
+	g_signal_connect (G_OBJECT (data->BT_list), "clicked", G_CALLBACK (repbalance_action_viewlist), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_line), "clicked", G_CALLBACK (repbalance_action_viewline), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_detail), "clicked", G_CALLBACK (repbalance_toggle_detail), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (repbalance_compute), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_print), "clicked", G_CALLBACK (repbalance_action_print), (gpointer)data);
+	
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), "changed", G_CALLBACK (repbalance_selection), NULL);
+	
+	g_signal_connect (GTK_TREE_VIEW(data->LV_detail), "row-activated", G_CALLBACK (repbalance_detail_onRowActivated), NULL);
+
+}
+
+
+static gboolean repbalance_window_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct repbalance_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n[repbalance] window mapped\n") );
+
+	//setup, init and show window
+	repbalance_window_setup(data, data->accnum);
+	repbalance_update_quickdate(data->window, NULL);
+	repbalance_compute(data->window, NULL);
+
+	return FALSE;
 }
 
 
@@ -895,6 +979,7 @@ gint row;
 	data = g_malloc0(sizeof(struct repbalance_data));
 	if(!data) return NULL;
 
+	data->accnum = accnum;
 	repbalance_window_acquire (data);
 
 	//disable define windows
@@ -935,6 +1020,14 @@ gint row;
 	label = make_label_group(_("Display"));
 	gtk_grid_attach (GTK_GRID (table), label, 0, row, 3, 1);
 
+	/*row++;
+	label = make_label_widget(_("Mode:"));
+	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
+	widget = hbtk_radio_button_new(GTK_ORIENTATION_HORIZONTAL, CYA_REPORT_MODE, TRUE);
+	data->RA_mode = widget;
+	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
+	*/
+
 	//5.5
 	row++;
 	label = make_label_widget(_("Inter_val:"));
@@ -1013,6 +1106,10 @@ gint row;
 		data->BT_non = label;
 		gtk_box_pack_start (GTK_BOX (treebox), label, FALSE, FALSE, 0);
 
+		label = make_clicklabel("inv", _("Invert"));
+		data->BT_inv = label;
+		gtk_box_pack_start (GTK_BOX (treebox), label, FALSE, FALSE, 0);
+
 
 	row++;
  	sw = gtk_scrolled_window_new(NULL,NULL);
@@ -1082,12 +1179,13 @@ gint row;
 	//gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW (widget), GTK_CORNER_TOP_RIGHT);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	treeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_ope_columns);
+	treeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_det_columns);
 	data->LV_detail = treeview;
 	gtk_container_add (GTK_CONTAINER(widget), treeview);
 
     gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
 
+	list_txn_set_save_column_width(GTK_TREE_VIEW(treeview), TRUE);
 
 	//page: 2d lines
 	widget = gtk_chart_new(CHART_TYPE_LINE);
@@ -1096,90 +1194,33 @@ gint row;
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), widget, NULL);
 
 
-
-
-	//todo:should move this
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor),GLOBALS->minor);
-
-
-
-	/* attach our minor to treeview */
-	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
-
-
-
-
-
-	/* signal connect */
+	// connect dialog signals
     g_signal_connect (window, "delete-event", G_CALLBACK (repbalance_window_dispose), (gpointer)data);
+	g_signal_connect (window, "map-event"   , G_CALLBACK (repbalance_window_mapped), NULL);
 
-	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (repbalance_toggle_minor), NULL);
+	// setup, init and show window
+	wg = &PREFS->ove_wg;
+	if( wg->l && wg->t )
+		gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
+	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
 
-	g_signal_connect (data->CY_intvl, "changed", G_CALLBACK (repbalance_compute), (gpointer)data);
-
-    data->handler_id[HID_REPBALANCE_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (repbalance_date_change), (gpointer)data);
-    data->handler_id[HID_REPBALANCE_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (repbalance_date_change), (gpointer)data);
-
-	data->handler_id[HID_REPBALANCE_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (repbalance_range_change), NULL);
-
-
-	//setup, init and show window
-	repbalance_window_setup(data, accnum);
-
-
-	// acc treeview
-	g_signal_connect (data->BT_all, "activate-link", G_CALLBACK (repbalance_cb_acc_activate_link), NULL);
-	g_signal_connect (data->BT_non, "activate-link", G_CALLBACK (repbalance_cb_acc_activate_link), NULL);
-
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_acc)), "changed", G_CALLBACK (repbalance_cb_acc_changed), NULL);
-
-
-	g_signal_connect (data->CM_showempty, "toggled", G_CALLBACK (repbalance_compute), NULL);
-
-	g_signal_connect (data->RG_zoomx, "value-changed", G_CALLBACK (repbalance_zoomx_callback), NULL);
-
-	g_signal_connect (G_OBJECT (data->BT_list), "clicked", G_CALLBACK (repbalance_action_viewlist), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_line), "clicked", G_CALLBACK (repbalance_action_viewline), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_detail), "clicked", G_CALLBACK (repbalance_toggle_detail), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (repbalance_compute), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_print), "clicked", G_CALLBACK (repbalance_action_print), (gpointer)data);
-	
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), "changed", G_CALLBACK (repbalance_selection), NULL);
-	
-	g_signal_connect (GTK_TREE_VIEW(data->LV_detail), "row-activated", G_CALLBACK (repbalance_detail_onRowActivated), NULL);
-
-
-	/* toolbar */
+	// toolbar	
 	if(PREFS->toolbar_style == 0)
 		gtk_toolbar_unset_style(GTK_TOOLBAR(data->TB_bar));
 	else
 		gtk_toolbar_set_style(GTK_TOOLBAR(data->TB_bar), PREFS->toolbar_style-1);
 
-
-	//setup, init and show window
-	wg = &PREFS->ove_wg;
-	gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
-	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
-	data->detail = 0;
-
-
 	gtk_widget_show_all (window);
 
 	//minor ?
-	if( PREFS->euro_active )
-		gtk_widget_show(data->CM_minor);
-	else
-		gtk_widget_hide(data->CM_minor);
-
+	hb_widget_visible(data->CM_minor, PREFS->euro_active);
 	repbalance_sensitive(window, NULL);
 	repbalance_update_detail(window, NULL);
 
-	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
-
-
 	return(window);
 }
 
+
 /*
 ** ============================================================================
 */
