@@ -42,6 +42,8 @@ enum
 
 struct repbalance_data
 {
+	//DataTable	*trend;
+
 	GList		*ope_list;
 	Filter		*filter;
 
@@ -49,6 +51,7 @@ struct repbalance_data
 	gdouble		minimum;
 
 	gboolean	detail;
+	guint32		accnum;
 
 	guint32		*tmp_acckeys;
 	gdouble		*tmp_income;
@@ -72,7 +75,7 @@ struct repbalance_data
 	GtkWidget	*CM_minor;
 	GtkWidget	*LV_report;
 
-	GtkWidget	*BT_all, *BT_non;
+	GtkWidget	*BT_all, *BT_non, *BT_inv;
 	GtkWidget	*SW_acc, *LV_acc;
 	GtkWidget	*CY_intvl;
 	GtkWidget	*CM_showempty;
