@@ -174,7 +174,7 @@ struct repbudget_data *data;
 	gtk_date_entry_set_mindate(GTK_DATE_ENTRY(data->PO_maxdate), data->filter->mindate);
 
 	g_signal_handler_block(data->CY_range, data->handler_id[HID_REPBUDGET_RANGE]);
-	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_OTHER);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_MISC_CUSTOM);
 	g_signal_handler_unblock(data->CY_range, data->handler_id[HID_REPBUDGET_RANGE]);
 
 
@@ -196,7 +196,7 @@ gint range;
 	range = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_range));
 	
 
-	if(range != FLT_RANGE_OTHER)
+	if(range != FLT_RANGE_MISC_CUSTOM)
 	{
 		filter_preset_daterange_set(data->filter, range, 0);
 
@@ -469,7 +469,7 @@ guint active = GPOINTER_TO_INT(user_data);
 GList *list;
 guint tmpfor;
 GtkTreeModel *model;
-GtkTreeIter  iter;
+GtkTreeIter  iter, child;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -479,7 +479,7 @@ GtkTreeIter  iter;
 	{
 		/* clear and detach our model */
 		model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail));
-		gtk_list_store_clear (GTK_LIST_STORE(model));
+		gtk_tree_store_clear (GTK_TREE_STORE(model));
 		g_object_ref(model); /* Make sure the model stays with us after the tree view unrefs it */
 		gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_detail), NULL); /* Detach model from view */
 
@@ -492,8 +492,8 @@ GtkTreeIter  iter;
 		Account *acc;
 		Transaction *ope = list->data;
 		gdouble dtlamt = ope->amount;
-		guint pos = 0;
-		gboolean insert = FALSE;
+		guint i, pos = 0;
+		gboolean match = FALSE;
 
 			//DB( g_print(" get %s\n", ope->ope_Word) );
 
@@ -514,23 +514,10 @@ GtkTreeIter  iter;
 				for(i=0;i<nbsplit;i++)
 				{
 					split = da_splits_get(ope->splits, i);
-					switch(tmpfor)
-					{
-						case BUDG_CATEGORY:
-							{
-							Category *catentry = da_cat_get(split->kcat);
-								if(catentry)
-									pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
-							}
-							break;
-						case BUDG_SUBCATEGORY:
-							pos = split->kcat;
-							break;
-					}
-					
+					pos = category_report_id(split->kcat, (tmpfor == BUDG_SUBCATEGORY) ? TRUE : FALSE);
 					if( pos == active )
 					{
-						insert = TRUE; 
+						match = TRUE; 
 						dtlamt += split->amount;
 						// no more break here as we need to compute split 4 cat
 						//break;
@@ -539,33 +526,41 @@ GtkTreeIter  iter;
 			}
 			else
 			{
-				switch(tmpfor)
-				{
-					case BUDG_CATEGORY:
-						{
-						Category *catentry = da_cat_get(ope->kcat);
-							if(catentry)
-								pos = (catentry->flags & GF_SUB) ? catentry->parent : catentry->key;
-						}
-						break;
-					case BUDG_SUBCATEGORY:
-						pos = ope->kcat;
-						break;
-				}
-				
+				pos = category_report_id(ope->kcat, (tmpfor == BUDG_SUBCATEGORY) ? TRUE : FALSE);
 				if( pos == active )
-					insert = TRUE;
+					match = TRUE;
 			}
 
 			//insert
-			if( insert == TRUE )
+			if( match == TRUE )
 			{
-
-		    	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-	     		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
+		    	gtk_tree_store_append (GTK_TREE_STORE(model), &iter, NULL);
+	     		gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
 					MODEL_TXN_POINTER, ope,
 			        MODEL_TXN_SPLITAMT, dtlamt,
 					-1);
+
+				//#1875801 show split detail
+				if( ope->flags & OF_SPLIT )
+				{
+				guint nbsplit = da_splits_length(ope->splits);
+				Split *split;
+
+					for(i=0;i<nbsplit;i++)
+					{
+						split = da_splits_get(ope->splits, i);
+						pos = category_report_id(split->kcat, (tmpfor == BUDG_SUBCATEGORY) ? TRUE : FALSE);
+						if( pos == active )
+						{
+							gtk_tree_store_insert_with_values (GTK_TREE_STORE(model), &child, &iter, -1,
+								MODEL_TXN_POINTER, ope,
+								MODEL_TXN_SPLITPTR, split,
+								-1);
+						}
+					}
+				}
+
+
 			}
 
 			
@@ -1098,14 +1093,14 @@ static void repbudget_filter_setup(struct repbudget_data *data)
 
 	filter_preset_daterange_set(data->filter, PREFS->date_range_rep, 0);
 	
-	g_signal_handler_block(data->PO_mindate, data->handler_id[HID_REPBUDGET_MINDATE]);
-	g_signal_handler_block(data->PO_maxdate, data->handler_id[HID_REPBUDGET_MAXDATE]);
+	//g_signal_handler_block(data->PO_mindate, data->handler_id[HID_REPBUDGET_MINDATE]);
+	//g_signal_handler_block(data->PO_maxdate, data->handler_id[HID_REPBUDGET_MAXDATE]);
 
 	gtk_date_entry_set_date(GTK_DATE_ENTRY(data->PO_mindate), data->filter->mindate);
 	gtk_date_entry_set_date(GTK_DATE_ENTRY(data->PO_maxdate), data->filter->maxdate);
 
-	g_signal_handler_unblock(data->PO_mindate, data->handler_id[HID_REPBUDGET_MINDATE]);
-	g_signal_handler_unblock(data->PO_maxdate, data->handler_id[HID_REPBUDGET_MAXDATE]);
+	//g_signal_handler_unblock(data->PO_mindate, data->handler_id[HID_REPBUDGET_MINDATE]);
+	//g_signal_handler_unblock(data->PO_maxdate, data->handler_id[HID_REPBUDGET_MAXDATE]);
 
 }
 
@@ -1115,11 +1110,108 @@ static void repbudget_window_setup(struct repbudget_data *data)
 {
 	DB( g_print("\n[repbudget] setup\n") );
 
+	DB( g_print(" init data\n") );
+	
 	repbudget_filter_setup(data);
-
 	data->detail = PREFS->budg_showdetail;
 	data->legend = 1;
 
+	DB( g_print(" set widgets default\n") );
+	
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor),GLOBALS->minor);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
+
+	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
+	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail))), "minor", (gpointer)data->CM_minor);
+
+
+	DB( g_print(" connect widgets signals\n") );
+
+
+	g_signal_connect (data->CM_onlyout, "toggled", G_CALLBACK (repbudget_compute), NULL);
+	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (repbudget_toggle), NULL);
+
+
+	data->handler_id[HID_REPBUDGET_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (repbudget_range_change), NULL);
+
+    g_signal_connect (data->CY_for , "changed", G_CALLBACK (repbudget_compute), (gpointer)data);
+    g_signal_connect (data->CY_kind, "changed", G_CALLBACK (repbudget_compute), (gpointer)data);
+
+    data->handler_id[HID_REPBUDGET_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (repbudget_date_change), (gpointer)data);
+    data->handler_id[HID_REPBUDGET_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (repbudget_date_change), (gpointer)data);
+
+	g_signal_connect (G_OBJECT (data->BT_list), "clicked", G_CALLBACK (repbudget_action_viewlist), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_progress), "clicked", G_CALLBACK (repbudget_action_viewstack), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_detail), "clicked", G_CALLBACK (repbudget_toggle_detail), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (repbudget_compute), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_print), "clicked", G_CALLBACK (repbudget_action_print), (gpointer)data);
+	//export is a menu
+
+
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), "changed", G_CALLBACK (repbudget_selection), NULL);
+
+	g_signal_connect (GTK_TREE_VIEW(data->LV_detail), "row-activated", G_CALLBACK (repbudget_detail_onRowActivated), NULL);
+
+}
+
+
+static gboolean repbudget_window_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct repbudget_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n[repbudget] window mapped\n") );
+
+	//hb_window_run_pending();
+	//hb_window_set_busy(GTK_WINDOW(data->window), TRUE);
+
+	//g_usleep( G_USEC_PER_SEC * 10 );
+
+	//setup, init and show window
+	repbudget_window_setup(data);	
+	repbudget_compute(data->window, NULL);
+	repbudget_update_daterange(data->window, NULL);
+
+	//hb_window_set_busy(GTK_WINDOW(data->window), FALSE);
+
+
+
+	//check for any account included into the budget or warn
+	{
+	guint count =0;
+	GList *lacc, *list;
+
+		lacc = list = g_hash_table_get_values(GLOBALS->h_acc);
+
+		while (list != NULL)
+		{
+		Account *acc;
+			acc = list->data;
+			//#1674045 ony rely on nosummary
+			//if((acc->flags & (AF_CLOSED|AF_NOREPORT))) goto next1;
+			if((acc->flags & (AF_NOREPORT))) goto next1;
+			if(!(acc->flags & AF_NOBUDGET))
+				count++;
+		next1:
+			list = g_list_next(list);
+		}
+		g_list_free(lacc);
+
+		if(count <= 0)
+		{
+			ui_dialog_msg_infoerror(GTK_WINDOW(data->window), GTK_MESSAGE_WARNING,
+				_("No account is defined to be part of the budget."),
+				_("You should include some accounts from the account dialog.")
+				);
+		}
+
+	
+	
+	}
+
+
+	return FALSE;
 }
 
 
@@ -1338,127 +1430,45 @@ gint row;
 	data->GR_detail = widget;
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	treeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_ope_columns);
+	treeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_det_columns);
 	data->LV_detail = treeview;
 	gtk_container_add (GTK_CONTAINER(widget), treeview);
 
     gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
 
+	list_txn_set_save_column_width(GTK_TREE_VIEW(treeview), TRUE);
+
 	//page: 2d bar
 	//widget = gtk_chart_new(CHART_TYPE_COL);
 	widget = ui_chart_progress_new();
 	data->RE_progress = widget;
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), widget, NULL);
 
-	//todo:should move this
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor),GLOBALS->minor);
 
-
-	/* attach our minor to treeview */
-	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
-	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail))), "minor", (gpointer)data->CM_minor);
-
-	/* signal connect */
+	// connect dialog signals
     g_signal_connect (window, "delete-event", G_CALLBACK (repbudget_window_dispose), (gpointer)data);
+	g_signal_connect (window, "map-event"   , G_CALLBACK (repbudget_window_mapped), NULL);
 
-	g_signal_connect (data->CM_onlyout, "toggled", G_CALLBACK (repbudget_compute), NULL);
-	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (repbudget_toggle), NULL);
+	// setup, init and show window
+	wg = &PREFS->bud_wg;
+	if( wg->l && wg->t )
+		gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
+	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
 
-
-	data->handler_id[HID_REPBUDGET_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (repbudget_range_change), NULL);
-
-    g_signal_connect (data->CY_for , "changed", G_CALLBACK (repbudget_compute), (gpointer)data);
-    g_signal_connect (data->CY_kind, "changed", G_CALLBACK (repbudget_compute), (gpointer)data);
-
-    data->handler_id[HID_REPBUDGET_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (repbudget_date_change), (gpointer)data);
-    data->handler_id[HID_REPBUDGET_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (repbudget_date_change), (gpointer)data);
-
-	g_signal_connect (G_OBJECT (data->BT_list), "clicked", G_CALLBACK (repbudget_action_viewlist), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_progress), "clicked", G_CALLBACK (repbudget_action_viewstack), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_detail), "clicked", G_CALLBACK (repbudget_toggle_detail), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (repbudget_compute), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_print), "clicked", G_CALLBACK (repbudget_action_print), (gpointer)data);
-	//export is a menu
-
-
-	
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), "changed", G_CALLBACK (repbudget_selection), NULL);
-
-	g_signal_connect (GTK_TREE_VIEW(data->LV_detail), "row-activated", G_CALLBACK (repbudget_detail_onRowActivated), NULL);
-
-
-	//setup, init and show window
-	repbudget_window_setup(data);
-
-
-	/* toolbar */
+	// toolbar
 	if(PREFS->toolbar_style == 0)
 		gtk_toolbar_unset_style(GTK_TOOLBAR(data->TB_bar));
 	else
 		gtk_toolbar_set_style(GTK_TOOLBAR(data->TB_bar), PREFS->toolbar_style-1);
 
-
-	//setup, init and show window
-	wg = &PREFS->bud_wg;
-	gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
-	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
-
-
-
 	gtk_widget_show_all (window);
 
 
 	//minor ?
-	if( PREFS->euro_active )
-		gtk_widget_show(data->CM_minor);
-	else
-		gtk_widget_hide(data->CM_minor);
-
-	//check for any account included into the budget or warn
-	{
-	guint count =0;
-	GList *lacc, *list;
-
-		lacc = list = g_hash_table_get_values(GLOBALS->h_acc);
-
-		while (list != NULL)
-		{
-		Account *acc;
-			acc = list->data;
-			//#1674045 ony rely on nosummary
-			//if((acc->flags & (AF_CLOSED|AF_NOREPORT))) goto next1;
-			if((acc->flags & (AF_NOREPORT))) goto next1;
-			if(!(acc->flags & AF_NOBUDGET))
-				count++;
-		next1:
-			list = g_list_next(list);
-		}
-		g_list_free(lacc);
-
-		if(count <= 0)
-		{
-			ui_dialog_msg_infoerror(GTK_WINDOW(data->window), GTK_MESSAGE_WARNING,
-				_("No account is defined to be part of the budget."),
-				_("You should include some accounts from the account dialog.")
-				);
-		}
-
-	
-	
-	}
-
-
-
-	//gtk_widget_hide(data->GR_detail);
-
+	hb_widget_visible(data->CM_minor, PREFS->euro_active);
 	repbudget_sensitive(window, NULL);
 	repbudget_update_detail(window, NULL);
 
-	if( PREFS->date_range_rep != 0)
-		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
-	else
-		repbudget_compute(window, NULL);
-
 	return(window);
 }
 
@@ -1532,6 +1542,7 @@ gchar *entry1, *entry2;
 
 	retval = hb_string_utf8_compare(entry1, entry2);
 
+	//leak
 	g_free(entry2);
 	g_free(entry1);
 
@@ -1657,9 +1668,17 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (view), PREFS->grid_lines);
 
 	/* column: Name */
+	renderer = gtk_cell_renderer_text_new ();
+
+	g_object_set(renderer, 
+		"ellipsize", PANGO_ELLIPSIZE_END,
+	    "ellipsize-set", TRUE,
+		//taken from nemo, not exactly a resize to content, but good compromise
+	    "width-chars", 40,
+	    NULL);
+
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Category"));
-	renderer = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	//gtk_tree_view_column_set_cell_data_func(column, renderer, ope_result_cell_data_function, NULL, NULL);
 	gtk_tree_view_column_add_attribute(column, renderer, "text", LST_BUDGET_NAME);
