@@ -32,6 +32,7 @@
 #include "ui-transaction.h"
 
 
+
 /****************************************************************************/
 /* Debug macros                                                             */
 /****************************************************************************/
@@ -87,7 +88,7 @@ extern HbKvData CYA_REPORT_INTVL[];
 
 
 
-static void repstats_action_viewlist(GtkToolButton *toolbutton, gpointer user_data)
+static void repstats_action_viewlist(GtkRadioButton *toolbutton, gpointer user_data)
 {
 struct repstats_data *data = user_data;
 gint tmpmode;
@@ -103,12 +104,16 @@ gint tmpmode;
 }
 
 
-static void repstats_action_mode_changed(GtkToolButton *toolbutton, gpointer user_data)
+static void repstats_action_mode_changed(GtkRadioButton *radiobutton, gpointer user_data)
 {
 struct repstats_data *data = user_data;
 
+	//ignore event triggered from inactive radiobutton
+	if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(radiobutton)) == FALSE )
+		return;
+	
 	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(data->BT_list), TRUE);
-	repstats_action_viewlist(toolbutton, data);
+	repstats_action_viewlist(radiobutton, data);
 	
 	if( data->detail == TRUE )
 	{
@@ -206,7 +211,7 @@ gint response_id;
 		}
 		else
 		{
-			if( data->filter->range == FLT_RANGE_OTHER )
+			if( data->filter->range == FLT_RANGE_MISC_CUSTOM )
 			{
 				filter_preset_daterange_set(data->filter, data->filter->range, 0);
 			}
@@ -229,6 +234,7 @@ gint response_id;
 */
 
 
+
 static void repstats_date_change(GtkWidget *widget, gpointer user_data)
 {
 struct repstats_data *data;
@@ -245,7 +251,7 @@ struct repstats_data *data;
 	gtk_date_entry_set_mindate(GTK_DATE_ENTRY(data->PO_maxdate), data->filter->mindate);
 
 	g_signal_handler_block(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
-	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_OTHER);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_MISC_CUSTOM);
 	g_signal_handler_unblock(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
 
 	repstats_compute(widget, NULL);
@@ -265,7 +271,7 @@ gint range;
 
 	range = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_range));
 
-	if(range != FLT_RANGE_OTHER)
+	if(range != FLT_RANGE_MISC_CUSTOM)
 	{
 		filter_preset_daterange_set(data->filter, range, 0);
 
@@ -274,6 +280,7 @@ gint range;
 		repstats_compute(data->window, NULL);
 		repstats_update_daterange(data->window, NULL);
 	}
+	//TODO: this can never happen anymore
 	else
 	{
 		if(ui_flt_manage_dialog_new(GTK_WINDOW(data->window), data->filter, TRUE, FALSE) != GTK_RESPONSE_REJECT)
@@ -329,8 +336,8 @@ gchar *title;
 	}
 
 	DB( g_print(" sort on column %d\n\n", column) );
+	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), column, GTK_SORT_ASCENDING);
 
-	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), column, GTK_SORT_DESCENDING);
 
 	gtk_chart_set_color_scheme(GTK_CHART(data->RE_chart), PREFS->report_color_scheme);
 
@@ -381,7 +388,7 @@ gchar *title;
 				column = LST_REPDIST_TOTAL;
 				break;
 		} 
-
+		
 		DB( g_print(" set bar to %d\n\n", column) );
 		gtk_chart_set_datas(GTK_CHART(data->RE_chart), model, column, title, NULL);
 	}
@@ -606,7 +613,7 @@ guint active = GPOINTER_TO_INT(user_data);
 guint tmpsrc;
 GList *list;
 GtkTreeModel *model;
-GtkTreeIter  iter;
+GtkTreeIter  iter, child;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -614,7 +621,7 @@ GtkTreeIter  iter;
 
 	/* clear and detach our model */
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail));
-	gtk_list_store_clear (GTK_LIST_STORE(model));
+	gtk_tree_store_clear (GTK_TREE_STORE(model));
 
 	if(data->detail)
 	{
@@ -691,10 +698,43 @@ GtkTreeIter  iter;
 
 				if( match == TRUE )
 				{
-					gtk_list_store_insert_with_values (GTK_LIST_STORE(model), &iter, -1,
-						MODEL_TXN_POINTER, ope,
+					gtk_tree_store_insert_with_values (GTK_TREE_STORE(model), &iter, NULL, -1,
+					    MODEL_TXN_POINTER, ope,
 						MODEL_TXN_SPLITAMT, dtlamt,
 						-1);
+
+
+					//#1875801 show split detail
+					if( ope->flags & OF_SPLIT )
+					{
+					guint nbsplit = da_splits_length(ope->splits);
+					Split *split;
+					gboolean sinsert = TRUE;
+
+						for(i=0;i<nbsplit;i++)
+						{
+							sinsert = TRUE;
+							split = da_splits_get(ope->splits, i);
+							if( (tmpsrc == REPORT_SRC_CATEGORY || tmpsrc == REPORT_SRC_SUBCATEGORY) )
+							{
+								pos = category_report_id(split->kcat, (tmpsrc == REPORT_SRC_SUBCATEGORY) ? TRUE : FALSE);
+								DB( g_print("  %d =? %d => %d\n", pos, active, pos != active ? FALSE : TRUE) );
+								if( pos != active )
+								{
+									sinsert = FALSE;
+								}
+							}
+												
+							if( sinsert == TRUE )							
+							{
+								gtk_tree_store_insert_with_values (GTK_TREE_STORE(model), &child, &iter, -1,
+									MODEL_TXN_POINTER, ope,
+									MODEL_TXN_SPLITPTR, split,
+									-1);
+							}
+						}
+					}
+					
 				}
 			}
 
@@ -706,6 +746,7 @@ GtkTreeIter  iter;
 		g_object_unref(model);
 
 		gtk_tree_view_columns_autosize( GTK_TREE_VIEW(data->LV_detail) );
+		//gtk_tree_view_expand_all( GTK_TREE_VIEW(data->LV_detail) );
 
 	}
 
@@ -862,7 +903,7 @@ GtkTreeIter  iter;
 	if( n_cols > 365*4 )
 	{
 
-		lst_rep_time_renewcol(GTK_TREE_VIEW(data->LV_report2), 0, data->filter->mindate, tmpintvl);
+		//lst_rep_time_renewcol(GTK_TREE_VIEW(data->LV_report2), 0, data->filter->mindate, tmpintvl);
 
 		ui_dialog_msg_infoerror(GTK_WINDOW(data->window), GTK_MESSAGE_INFO,
 		_("Too much columns to display"),
@@ -871,12 +912,25 @@ GtkTreeIter  iter;
 	}
 	else
 	{
+	gboolean tmpaccbal;
+
 		DB( g_print("\n[repdist] compute test multi\n") );
 		
 		if(data->trend)
 			da_datatable_free (data->trend);
 
-		dt = report_compute_trend(tmpsrc, tmpintvl, data->filter, data->txn_queue);
+		//beta
+		tmpaccbal = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_balance));
+		if( tmpsrc != REPORT_SRC_ACCOUNT )
+			tmpaccbal = FALSE;
+
+		if(!tmpaccbal)
+			//not beta
+			dt = report_compute_trend(tmpsrc, tmpintvl, data->filter, data->txn_queue);
+		else
+			dt = report_compute_trend_balance(tmpsrc, tmpintvl, data->filter);
+		//beta end
+
 		data->trend = dt;
 
 		DB( g_print("\npopulate time listview\n") );
@@ -885,7 +939,7 @@ GtkTreeIter  iter;
 		g_object_ref(model); /* Make sure the model stays with us after the tree view unrefs it */
 		gtk_tree_view_set_model(GTK_TREE_VIEW(data->LV_report2), NULL); /* Detach model from view */
 
-		lst_rep_time_renewcol(GTK_TREE_VIEW(data->LV_report2), n_cols, data->filter->mindate, tmpintvl);
+		lst_rep_time_renewcol(GTK_TREE_VIEW(data->LV_report2), n_cols, data->filter->mindate, tmpintvl, tmpaccbal ? FALSE : TRUE);
 
 		/* update column 0 title */
 		GtkTreeViewColumn *column = gtk_tree_view_get_column( GTK_TREE_VIEW(data->LV_report2), 0);
@@ -960,7 +1014,7 @@ static void repstats_sensitive(GtkWidget *widget, gpointer user_data)
 {
 struct repstats_data *data;
 gboolean visible, sensitive;
-gint mode, type, page;
+gint mode, type, tmpsrc, page;
 
 	DB( g_print("\n[repdist] sensitive\n") );
 
@@ -968,6 +1022,7 @@ gint mode, type, page;
 
 	mode = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_mode));
 	type = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_type));
+	tmpsrc  = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_src));
 	page = gtk_notebook_get_current_page(GTK_NOTEBOOK(data->GR_result));
 	
 	//total
@@ -986,6 +1041,9 @@ gint mode, type, page;
 	visible = (mode==0 && page == 0) ? TRUE : FALSE;
 	hb_widget_visible(data->BT_rate, visible);
 
+	visible = ((mode == 1) && (tmpsrc == REPORT_SRC_ACCOUNT)) ? TRUE : FALSE;
+	hb_widget_visible(data->CM_balance, visible);
+
 	//zoom
 	visible = (data->charttype == CHART_TYPE_COL 
 			|| data->charttype == CHART_TYPE_STACK 
@@ -1001,7 +1059,6 @@ gint mode, type, page;
 	hb_widget_visible (data->BT_detail, visible);
 	hb_widget_visible (data->BT_export, visible);
 
-	//visible = (mode==0 && page > 0) ? TRUE : FALSE;
 	visible = (page > 0) ? TRUE : FALSE;
 	hb_widget_visible (data->BT_legend, visible);
 	hb_widget_visible (data->BT_print, visible);
@@ -1213,6 +1270,16 @@ struct repstats_data *data;
 }
 
 
+static void repstats_cb_sortcolumnchanged(GtkTreeSortable *sortable, gpointer user_data)
+{
+	DB( g_print("\n[repdist] sort column chnaged\n") );
+
+
+
+
+}
+
+
 static void repstats_selection(GtkTreeSelection *treeselection, gpointer user_data)
 {
 GtkTreeModel *model;
@@ -1382,12 +1449,19 @@ static void repstats_filter_setup(struct repstats_data *data)
 
 	filter_reset(data->filter);
 	filter_preset_daterange_set(data->filter, PREFS->date_range_rep, 0);
-	repstats_update_date_widget(data->window, NULL);
 
-	/* 3.4 : make int transfer out of stats */
-	data->filter->option[FLT_GRP_TYPE] = 2;
-	data->filter->type = FLT_TYPE_INTXFER;
-	
+	gtk_date_entry_set_date(GTK_DATE_ENTRY(data->PO_mindate), data->filter->mindate);
+	gtk_date_entry_set_date(GTK_DATE_ENTRY(data->PO_maxdate), data->filter->maxdate);
+
+	//#1989211 option to inlcude xfer by default
+	if( PREFS->stat_includexfer == FALSE )
+	{
+		/* 3.4 : make int transfer out of stats */
+		data->filter->option[FLT_GRP_TYPE] = 2;
+		//data->filter->type = FLT_TYPE_INTXFER;
+		data->filter->typ_xfr = TRUE;
+	}
+
 }
 
 
@@ -1396,17 +1470,97 @@ static void repstats_window_setup(struct repstats_data *data)
 {
 	DB( g_print("\n[repdist] setup\n") );
 
-	repstats_filter_setup(data);
+	DB( g_print(" init data\n") );
 	
+	repstats_filter_setup(data);
 	data->detail = PREFS->stat_showdetail;
 	data->legend = 1;
 	data->rate = PREFS->stat_showrate^1;
 
-	repstats_toggle_rate(data->window, NULL);
+	//DB( g_print(" populate\n") );
+
+	DB( g_print(" set widgets default\n") );
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor), GLOBALS->minor);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_byamount), PREFS->stat_byamount);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_type), REPORT_TYPE_EXPENSE);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
+
+	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
+	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail))), "minor", (gpointer)data->CM_minor);
 	
 	gtk_chart_set_smallfont (GTK_CHART(data->RE_chart), PREFS->rep_smallfont);
 	gtk_chart_set_smallfont (GTK_CHART(data->RE_chart2), PREFS->rep_smallfont);
 
+	repstats_toggle_rate(data->window, NULL);
+
+	DB( g_print(" connect widgets signals\n") );
+	
+	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (repstats_toggle_minor), NULL);
+
+    data->handler_id[HID_REPDIST_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (repstats_date_change), (gpointer)data);
+    data->handler_id[HID_REPDIST_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (repstats_date_change), (gpointer)data);
+
+	data->handler_id[HID_REPDIST_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (repstats_range_change), NULL);
+
+    g_signal_connect (data->CY_src, "changed", G_CALLBACK (repstats_compute), (gpointer)data);
+
+	//test multi
+	hbtk_radio_button_connect (GTK_CONTAINER(data->RA_mode), "toggled", G_CALLBACK (repstats_action_mode_changed), (gpointer)data);
+
+	g_signal_connect (data->CY_intvl, "changed", G_CALLBACK (repstats_compute), (gpointer)data);
+	
+    data->handler_id[HID_REPDIST_VIEW] = g_signal_connect (data->CY_type, "changed", G_CALLBACK (repstats_compute), (gpointer)data);
+
+	g_signal_connect (data->RG_zoomx, "value-changed", G_CALLBACK (repstats_zoomx_callback), NULL);
+
+
+	g_signal_connect (data->CM_balance, "toggled", G_CALLBACK (repstats_compute), NULL);
+	g_signal_connect (data->CM_byamount, "toggled", G_CALLBACK (repstats_update), NULL);
+	g_signal_connect (data->CM_compare, "toggled", G_CALLBACK (repstats_update), NULL);
+
+	g_signal_connect (G_OBJECT (data->BT_list), "clicked", G_CALLBACK (repstats_action_viewlist), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_column), "clicked", G_CALLBACK (repstats_action_viewbar), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_donut), "clicked", G_CALLBACK (repstats_action_viewpie), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_stack), "clicked", G_CALLBACK (repstats_action_viewstack), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_stack100), "clicked", G_CALLBACK (repstats_action_viewstack100), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_detail), "clicked", G_CALLBACK (repstats_toggle_detail), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_legend), "clicked", G_CALLBACK (repstats_toggle_legend), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_rate), "clicked", G_CALLBACK (repstats_toggle_rate), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_filter), "clicked", G_CALLBACK (repstats_action_filter), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (repstats_compute), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_print), "clicked", G_CALLBACK (repstats_action_print), (gpointer)data);
+
+	//export is a menu
+
+	
+	
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report )), "changed", G_CALLBACK (repstats_selection), NULL);
+	g_signal_connect (gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report)), "sort-column-changed", G_CALLBACK (repstats_cb_sortcolumnchanged), NULL);
+
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report2)), "changed", G_CALLBACK (repstats_selection2), NULL);
+
+
+	g_signal_connect (GTK_TREE_VIEW(data->LV_detail), "row-activated", G_CALLBACK (repstats_detail_onRowActivated), NULL);
+	
+
+
+}
+
+
+static gboolean repstats_window_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct repstats_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n[repdist] window mapped\n") );
+
+	//setup, init and show window
+	repstats_window_setup(data);	
+	repstats_compute(data->window, NULL);
+	//repstats_update_daterange(data->window, NULL);
+
+	return FALSE;
 }
 
 
@@ -1535,6 +1689,11 @@ gint row;
 	data->CY_type = widget;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("_Balance mode"));
+	data->CM_balance = widget;
+	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
+
 	row++;
 	label = make_label_widget(_("Inter_val:"));
 	data->LB_intvl = label;
@@ -1602,6 +1761,22 @@ gint row;
 	data->PO_maxdate = gtk_date_entry_new(label);
 	gtk_grid_attach (GTK_GRID (table), data->PO_maxdate, 2, row, 1, 1);
 
+	//widget = gtk_combo_box_text_new();
+	//gtk_widget_set_hexpand(widget, FALSE);
+	//gtk_combo_box_text_append_text (widget, "--------");
+	//gtk_combo_box_text_append_text (widget, "EDF invoices from 2012 to 2016");
+	//gtk_combo_box_text_append_text (widget, "Lorem ipsum dolor sit amet, consectetur adipiscing elit");
+	//gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
+
+	/*row++;
+	label = gtk_label_new(_("Lorem ipsum dolor sit amet, consectetur adipiscing elit"));
+	gtk_label_set_ellipsize(GTK_LABEL(label), PANGO_ELLIPSIZE_END);
+	//gtk_widget_set_hexpand(label, FALSE);
+	gtk_widget_set_size_request(label, HB_MINWIDTH_LIST, -1);
+	gtk_grid_attach (GTK_GRID (table), label, 2, row, 1, 1);
+	*/
+	
+
 	//part: info + report
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
@@ -1611,6 +1786,27 @@ gint row;
 	data->TB_bar = widget;
 	gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 0);
 
+	
+	
+	//test date on top right
+	/*
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
+	gtk_container_set_border_width (GTK_CONTAINER(hbox), SPACING_SMALL);
+    gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
+	
+	data->PO_mindate = gtk_date_entry_new(NULL);
+	gtk_widget_set_hexpand(data->PO_mindate, FALSE);
+	gtk_box_pack_start (GTK_BOX (hbox), data->PO_mindate, FALSE, FALSE, 0);
+
+	data->PO_maxdate = gtk_date_entry_new(NULL);
+	gtk_widget_set_hexpand(data->PO_maxdate, FALSE);
+	gtk_box_pack_start (GTK_BOX (hbox), data->PO_maxdate, FALSE, FALSE, 0);
+	
+	data->CY_range = make_daterange(label, DATE_RANGE_CUSTOM_DISABLE);
+	gtk_box_pack_start (GTK_BOX (hbox), data->CY_range, FALSE, FALSE, 0);
+	*/
+	//end test date
+	
 
 	//infos + total
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
@@ -1683,11 +1879,13 @@ gint row;
 	//gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW (sw), GTK_CORNER_TOP_RIGHT);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (sw), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	treeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_ope_columns);
+	treeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_det_columns);
 	data->LV_detail = treeview;
 	gtk_container_add (GTK_CONTAINER(sw), treeview);
 	gtk_paned_pack2 (GTK_PANED(vpaned), sw, TRUE, TRUE);	
 
+	list_txn_set_save_column_width(GTK_TREE_VIEW(treeview), TRUE);
+
 	//page: 2d bar /pie
 	widget = gtk_chart_new(CHART_TYPE_COL);
 	data->RE_chart = widget;
@@ -1702,103 +1900,33 @@ gint row;
 	gtk_chart_set_currency(GTK_CHART(widget), GLOBALS->kcur);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), widget, NULL);
 
-	//todo: setup should move this
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor), GLOBALS->minor);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_byamount), PREFS->stat_byamount);
 
-	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_type), REPORT_TYPE_EXPENSE);
+	// connect dialog signals
+	g_signal_connect (window, "delete-event", G_CALLBACK (repstats_window_dispose), (gpointer)data);
+	g_signal_connect (window, "map-event"   , G_CALLBACK (repstats_window_mapped), NULL);
 
-	/* attach our minor to treeview */
-	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
-	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail))), "minor", (gpointer)data->CM_minor);
+	// setup, init and show window
+	wg = &PREFS->sta_wg;
+	if( wg->l && wg->t )
+		gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
+	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
 
-	/* signal connect */
-    g_signal_connect (window, "delete-event", G_CALLBACK (repstats_window_dispose), (gpointer)data);
-
-	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (repstats_toggle_minor), NULL);
-
-    data->handler_id[HID_REPDIST_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (repstats_date_change), (gpointer)data);
-    data->handler_id[HID_REPDIST_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (repstats_date_change), (gpointer)data);
-
-	data->handler_id[HID_REPDIST_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (repstats_range_change), NULL);
-
-    g_signal_connect (data->CY_src, "changed", G_CALLBACK (repstats_compute), (gpointer)data);
-
-	//test multi
-	hbtk_radio_button_connect (GTK_CONTAINER(data->RA_mode), "toggled", G_CALLBACK (repstats_action_mode_changed), (gpointer)data);
-
-	g_signal_connect (data->CY_intvl, "changed", G_CALLBACK (repstats_compute), (gpointer)data);
-	
-    data->handler_id[HID_REPDIST_VIEW] = g_signal_connect (data->CY_type, "changed", G_CALLBACK (repstats_compute), (gpointer)data);
-
-	g_signal_connect (data->RG_zoomx, "value-changed", G_CALLBACK (repstats_zoomx_callback), NULL);
-
-
-	g_signal_connect (data->CM_byamount, "toggled", G_CALLBACK (repstats_update), NULL);
-	g_signal_connect (data->CM_compare, "toggled", G_CALLBACK (repstats_update), NULL);
-
-	g_signal_connect (G_OBJECT (data->BT_list), "clicked", G_CALLBACK (repstats_action_viewlist), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_column), "clicked", G_CALLBACK (repstats_action_viewbar), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_donut), "clicked", G_CALLBACK (repstats_action_viewpie), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_stack), "clicked", G_CALLBACK (repstats_action_viewstack), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_stack100), "clicked", G_CALLBACK (repstats_action_viewstack100), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_detail), "clicked", G_CALLBACK (repstats_toggle_detail), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_legend), "clicked", G_CALLBACK (repstats_toggle_legend), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_rate), "clicked", G_CALLBACK (repstats_toggle_rate), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_filter), "clicked", G_CALLBACK (repstats_action_filter), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (repstats_compute), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_print), "clicked", G_CALLBACK (repstats_action_print), (gpointer)data);
-
-	//export is a menu
-
-	
-	
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report )), "changed", G_CALLBACK (repstats_selection), NULL);
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report2)), "changed", G_CALLBACK (repstats_selection2), NULL);
-
-
-	g_signal_connect (GTK_TREE_VIEW(data->LV_detail), "row-activated", G_CALLBACK (repstats_detail_onRowActivated), NULL);
-
-	//setup, init and show window
-	repstats_window_setup(data);
-
-	/* toolbar */
+	// toolbar
 	if(PREFS->toolbar_style == 0)
 		gtk_toolbar_unset_style(GTK_TOOLBAR(data->TB_bar));
 	else
 		gtk_toolbar_set_style(GTK_TOOLBAR(data->TB_bar), PREFS->toolbar_style-1);
 
-	
-	//setup, init and show window
-	wg = &PREFS->sta_wg;
-	gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
-	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
-
 	gtk_widget_show_all (window);
 
-	gtk_widget_hide(data->SW_trend);
 
 	//minor ?
-	if( PREFS->euro_active )
-		gtk_widget_show(data->CM_minor);
-	else
-		gtk_widget_hide(data->CM_minor);
-
-	//gtk_widget_hide(data->GR_detail);
-
-
+	hb_widget_visible(data->CM_minor, PREFS->euro_active);
+	gtk_widget_hide(data->SW_trend);
 
 	repstats_sensitive(window, NULL);
 	repstats_update_detail(window, NULL);
 
-	DB( g_print("range: %d\n", PREFS->date_range_rep) );
-
-	if( PREFS->date_range_rep != 0)
-		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
-	else
-		repstats_compute(window, NULL);
-
-
 	return window;
 }
 
