@@ -72,11 +72,17 @@ struct repstats_data
 	GtkWidget	*CY_type, *LB_type;
 	GtkWidget	*CY_intvl, *LB_intvl;
 
+	//beta start
+	GtkWidget	*PO_hubfilter;
+	GtkWidget	*BT_reset;
+	//beat end
+
 	GtkWidget	*RG_zoomx, *LB_zoomx;
 	GtkWidget	*SW_total, *SW_trend;
 	GtkWidget	*LV_report;
 	GtkWidget	*LV_report2;
 	
+	GtkWidget	*CM_balance;
 	GtkWidget	*CM_byamount;
 	GtkWidget	*CM_compare;
 
