@@ -62,6 +62,12 @@ static GtkWidget *lst_reptime_create(void);
 static GString *lst_reptime_to_string(GtkTreeView *treeview, gchar *title, gboolean clipboard);
 static void lst_reptime_set_cur(GtkTreeView *treeview, guint32 kcur);
 
+static void reptime_cb_acc_changed(GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data);
+static void reptime_cb_cat_changed(GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data);
+static void reptime_cb_pay_changed(GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data);
+static void reptime_cb_tag_changed(GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data);
+
+
 
 HbKvData CYA_REPORT_SRC_TREND[] = {
 	{ REPORT_SRC_ACCOUNT, 	N_("Account") },
@@ -87,8 +93,7 @@ extern gchar *RA_REPORT_MODE2[];
 extern gchar *CYA_ABMONTHS[];
 
 
-
-/* action functions -------------------- */
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
 static void reptime_action_viewlist(GtkToolButton *toolbutton, gpointer user_data)
@@ -138,9 +143,30 @@ gchar *name;
 }
 
 
-/*
-** ============================================================================
-*/
+//beta
+#if MYDEBUG
+static void reptime_action_filter(GtkToolButton *toolbutton, gpointer user_data)
+{
+struct reptime_data *data = user_data;
+
+	//debug
+	//create_deffilter_window(data->filter, TRUE);
+
+	if(ui_flt_manage_dialog_new(GTK_WINDOW(data->window), data->filter, TRUE, FALSE) != GTK_RESPONSE_REJECT)
+	{
+		reptime_compute(data->window, NULL);
+		//ui_repdtime_update_date_widget(data->window, NULL);
+		//ui_repdtime_update_daterange(data->window, NULL);
+
+		/*g_signal_handler_block(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
+		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_MISC_ALLDATE);
+		g_signal_handler_unblock(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
+		*/
+	}
+}
+#endif
+
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
 static void reptime_date_change(GtkWidget *widget, gpointer user_data)
@@ -159,7 +185,7 @@ struct reptime_data *data;
 	gtk_date_entry_set_mindate(GTK_DATE_ENTRY(data->PO_maxdate), data->filter->mindate);
 
 	g_signal_handler_block(data->CY_range, data->handler_id[HID_REPTIME_RANGE]);
-	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_OTHER);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_MISC_CUSTOM);
 	g_signal_handler_unblock(data->CY_range, data->handler_id[HID_REPTIME_RANGE]);
 
 	reptime_compute(widget, NULL);
@@ -199,7 +225,7 @@ gint range;
 
 	range = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_range));
 
-	if(range != FLT_RANGE_OTHER)
+	if(range != FLT_RANGE_MISC_CUSTOM)
 	{
 		filter_preset_daterange_set(data->filter, range, data->accnum);
 
@@ -402,31 +428,56 @@ gint tmpsrc;
 static void reptime_update_for(GtkWidget *widget, gpointer user_data)
 {
 struct reptime_data *data;
-gint tmpsrc;
-gboolean visible;
+gint tmpsrc, pageid;
+Filter *flt;
 
 	DB( g_print("\n[reptime] update for\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	tmpsrc  = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_src));
+	flt = data->filter;
 
-	visible = tmpsrc == REPORT_SRC_ACCOUNT ? TRUE : FALSE;
-	hb_widget_visible(data->LB_acc, visible);
-	hb_widget_visible(data->PO_acc, visible);
+	DB( g_print("  src=%d\n", tmpsrc) );
+
+	//filter_reset(flt);
+
+	//inactive all filters
+	flt->option[FLT_GRP_CATEGORY] = 0;
+	flt->option[FLT_GRP_PAYEE] = 0;
+	flt->option[FLT_GRP_ACCOUNT] = 0;
+	flt->option[FLT_GRP_TAG] = 0;
+
+	switch(tmpsrc)
+	{
+		case REPORT_SRC_CATEGORY:
+			pageid = 1;
+			flt->option[FLT_GRP_CATEGORY] = 1;
+			da_flt_status_cat_set(flt, 0, TRUE);
+			break;
+		case REPORT_SRC_PAYEE:
+			pageid = 2;
+			flt->option[FLT_GRP_PAYEE] = 1;
+			da_flt_status_pay_set(flt, 0, TRUE);
+			break;
+		case REPORT_SRC_TAG:
+			pageid = 3;
+			flt->option[FLT_GRP_TAG] = 1;
+			//da_flt_status_tag_set(flt, 0, TRUE);
+			break;
+		default: //REPORT_SRC_ACCOUNT
+			pageid = 0;
+			flt->option[FLT_GRP_ACCOUNT] = 1;
+			//todo:
+			break;
+	}
+
+	gtk_notebook_set_current_page(GTK_NOTEBOOK(data->GR_itemtype), pageid);
+
+	//hb_widget_visible(data->CM_all, defvisible);
+	//hb_widget_visible(data->BT_filter, !monoflt);
 
-	visible = tmpsrc == REPORT_SRC_CATEGORY ? TRUE : FALSE;
-	hb_widget_visible(data->LB_cat, visible);
-	hb_widget_visible(data->PO_cat, visible);
-	
-	visible = tmpsrc == REPORT_SRC_PAYEE ? TRUE : FALSE;
-	hb_widget_visible(data->LB_pay, visible);
-	hb_widget_visible(data->PO_pay, visible);
 
-	visible = tmpsrc == REPORT_SRC_TAG ? TRUE : FALSE;
-	hb_widget_visible(data->LB_tag, visible);
-	hb_widget_visible(data->PO_tag, visible);
-	
 }
 
 
@@ -445,37 +496,6 @@ struct reptime_data *data;
 }
 
 
-//TODO: this is temporary, as at end we will enable filter
-static void reptime_compute_set_filter(Filter *flt, gint tmpsrc, guint32 selkey)
-{
-	//inactive all filters
-	flt->option[FLT_GRP_CATEGORY] = 0;
-	flt->option[FLT_GRP_PAYEE] = 0;
-	flt->option[FLT_GRP_ACCOUNT] = 0;
-	flt->option[FLT_GRP_TEXT] = 0;
-
-	switch(tmpsrc)
-	{
-		case REPORT_SRC_ACCOUNT:
-			flt->option[FLT_GRP_ACCOUNT] = 1;
-			filter_status_acc_clear_except(flt, selkey);
-			break;
-		case REPORT_SRC_CATEGORY:
-			flt->option[FLT_GRP_CATEGORY] = 1;
-			filter_status_cat_clear_except(flt, selkey);
-			break;
-		case REPORT_SRC_PAYEE:
-			flt->option[FLT_GRP_PAYEE] = 1;
-			filter_status_pay_clear_except(flt, selkey);
-			break;
-		case REPORT_SRC_TAG:
-			flt->option[FLT_GRP_TEXT] = 1;
-			filter_set_tag_by_id(flt, selkey);
-			break;
-	}
-}
-
-
 static void reptime_detail(GtkWidget *widget, gpointer user_data)
 {
 struct reptime_data *data;
@@ -484,7 +504,7 @@ guint tmpintvl;
 guint32 from;
 GList *list;
 GtkTreeModel *model;
-GtkTreeIter  iter;
+GtkTreeIter  iter, child;
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
@@ -501,7 +521,7 @@ GtkTreeIter  iter;
 
 	/* clear and detach our model */
 	model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail));
-	gtk_list_store_clear (GTK_LIST_STORE(model));
+	gtk_tree_store_clear (GTK_TREE_STORE(model));
 
 	if(data->detail)
 	{
@@ -513,7 +533,7 @@ GtkTreeIter  iter;
 		while (list != NULL)
 		{
 		Transaction *ope = list->data;
-		guint pos;
+		guint i, pos;
 
 			if(filter_txn_match(data->filter, ope) == 1)
 			{
@@ -522,11 +542,28 @@ GtkTreeIter  iter;
 				{
 				gdouble dtlamt = report_txn_amount_get(data->filter, ope);
 
-					gtk_list_store_insert_with_values (GTK_LIST_STORE(model),
-						&iter, -1,
+					gtk_tree_store_insert_with_values (GTK_TREE_STORE(model),
+						&iter, NULL, -1,
 						MODEL_TXN_POINTER, ope,
 					    MODEL_TXN_SPLITAMT, dtlamt,
 						-1);
+
+					//#1875801 show split detail
+					if( ope->flags & OF_SPLIT )
+					{
+					guint nbsplit = da_splits_length(ope->splits);
+
+						for(i=0;i<nbsplit;i++)
+						{
+						Split *split = da_splits_get(ope->splits, i);
+						
+							gtk_tree_store_insert_with_values (GTK_TREE_STORE(model), &child, &iter, -1,
+								MODEL_TXN_POINTER, ope,
+								MODEL_TXN_SPLITPTR, split,
+								-1);
+						}
+					}
+
 				}
 			}
 
@@ -543,14 +580,48 @@ GtkTreeIter  iter;
 }
 
 
+static gboolean
+reptime_cb_activate_link (GtkWidget *label, const gchar *uri, gpointer user_data)
+{
+struct reptime_data *data;
+gint tmpsrc;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(label), GTK_TYPE_WINDOW)), "inst_data");
+
+	tmpsrc = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_src));
+
+	switch(tmpsrc)
+	{
+		case REPORT_SRC_ACCOUNT:
+			ui_acc_listview_quick_select(GTK_TREE_VIEW(data->LV_acc), uri);
+			reptime_cb_acc_changed(NULL, NULL, data);
+			break;
+		case REPORT_SRC_CATEGORY:
+			ui_cat_listview_quick_select(GTK_TREE_VIEW(data->LV_cat), uri);
+			reptime_cb_cat_changed(NULL, NULL, data);
+			break;
+		case REPORT_SRC_PAYEE:
+			ui_pay_listview_quick_select(GTK_TREE_VIEW(data->LV_pay), uri);
+			reptime_cb_pay_changed(NULL, NULL, data);
+			break;
+		case REPORT_SRC_TAG:
+			ui_tag_listview_quick_select(GTK_TREE_VIEW(data->LV_tag), uri);
+			reptime_cb_tag_changed(NULL, NULL, data);
+			break;
+	}
+
+	reptime_compute (GTK_WIDGET(data->window), NULL);
+
+    return TRUE;
+}
+
+
 static void reptime_compute(GtkWidget *widget, gpointer user_data)
 {
 struct reptime_data *data;
-gint tmpsrc, tmpintvl, range, showempty;
+gint tmpintvl, showempty;
 guint32 from, to;
 gboolean cumul;
-gboolean showall;
-
 gdouble cumulation, average;
 
 GtkTreeModel *model;
@@ -559,60 +630,25 @@ GList *list;
 gint id;
 guint n_result, i;
 gdouble *tmp_amount;
-guint32 selkey;
 
-	DB( g_print("\n[reptime] compute\n") );
+	DB( g_print("----------------\n[reptime] compute\n") );
 
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
-	tmpsrc    = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_src));
 	tmpintvl  = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_intvl));
 	cumul     = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_cumul));
-	showall   = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_all));
-	range     = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_range));
+	//range     = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_range));
 	showempty = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_showempty));
 
-	selkey = 0;
-	
 	data->accnum = 0;
-	switch(tmpsrc)
-	{
-		case REPORT_SRC_ACCOUNT:
-			selkey = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_acc));
-			if(showall == FALSE)
-				data->accnum = selkey;
-			break;
-		case REPORT_SRC_CATEGORY:
-			selkey = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_cat));
-			break;
-		case REPORT_SRC_PAYEE:
-			selkey = ui_pay_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_pay));
-			break;
-		case REPORT_SRC_TAG:
-			selkey = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->PO_tag));
-			break;
-	}
-
-	if( showall == TRUE )
-	{
-		data->filter->option[FLT_GRP_CATEGORY] = 0;
-		data->filter->option[FLT_GRP_PAYEE] = 0;
-		data->filter->option[FLT_GRP_ACCOUNT] = 0;
-		data->filter->option[FLT_GRP_TEXT] = 0;
-	}
-	else	
-		reptime_compute_set_filter(data->filter, tmpsrc, selkey);
-
-	
-	DB( g_print(" source=%d-%s, intvl=%d-%s:: key=%d\n", tmpsrc, hbtk_get_label(CYA_REPORT_SRC_TREND, tmpsrc), tmpintvl, hbtk_get_label(CYA_REPORT_INTVL, tmpintvl), selkey) );
 
 	//to remove > 5.0.2
 	//#1715532 5.0.5: no... but only showall
-	if( (showall == TRUE) && (range == FLT_RANGE_ALLDATE) )
+	/*if( (showall == TRUE) && (range == FLT_RANGE_MISC_ALLDATE) )
 	{
 		filter_preset_daterange_set(data->filter, data->filter->range, data->accnum);
 		reptime_update_quickdate(widget, NULL);
-	}
+	}*/
 
 	//get our min max date
 	from = data->filter->mindate;
@@ -624,6 +660,7 @@ guint32 selkey;
 
 	n_result = report_interval_count(tmpintvl, from, to);
 
+	DB( gint tmpsrc = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_src)); );
 	DB( g_print(" %s :: n_result=%d\n", hbtk_get_label(CYA_REPORT_SRC_TREND, tmpsrc), n_result) );
 
 	/* allocate some memory */
@@ -636,7 +673,7 @@ guint32 selkey;
 		{
 		Transaction *ope = list->data;
 
-			//DB( g_print("\n** testing '%s', cat=%d==> %d\n", ope->memo, ope->kcat, filter_txn_match(data->filter, ope)) );
+			//DB( g_print("** testing '%s', acc=%d, cat=%d, pay=%d\n", ope->memo, ope->kacc, ope->kcat, ope->kpay) );
 
 			if( (filter_txn_match(data->filter, ope) == 1) )
 			{
@@ -646,18 +683,18 @@ guint32 selkey;
 				trn_amount = report_txn_amount_get(data->filter, ope);
 
 				 //#1829603 Multi currencies problem in Trend Time Report
-				if( ! ( tmpsrc == REPORT_SRC_ACCOUNT && showall == FALSE) )
+				//if( ! ( tmpsrc == REPORT_SRC_ACCOUNT && showall == FALSE) )
 					trn_amount = hb_amount_base(trn_amount, ope->kcur);
 
 				pos = report_interval_get_pos(tmpintvl, from, ope);
 				if( pos <= n_result )
 				{
-					DB( g_print("** pos=%d : add of %.2f\n", pos, trn_amount) );
+					//DB( g_print("** pos=%d : add of %.2f\n", pos, trn_amount) );
 					tmp_amount[pos] += trn_amount;
 				}
 				else
 				{
-					DB( g_print("** pos=%d : invalid offset\n", pos) );
+					//DB( g_print("** pos=%d : invalid offset\n", pos) );
 				}
 			}
 			list = g_list_next(list);
@@ -682,14 +719,14 @@ guint32 selkey;
 
 			report_interval_snprint_name(intvlname, sizeof(intvlname)-1, tmpintvl, from, i);
 
-			DB( g_print("try to insert item %d\n", i) );
+			//DB( g_print("try to insert item %d\n", i) );
 
 			cumulation += tmp_amount[i];
 			value = (cumul == TRUE) ? cumulation : tmp_amount[i];
 
-			DB( g_print(" inserting %2d, '%s', %9.2f\n", i, intvlname, value) );
+			//DB( g_print(" inserting %2d, '%s', %9.2f\n", i, intvlname, value) );
 
-	    	gtk_list_store_insert_with_values (GTK_LIST_STORE(model), &iter, -1, 
+	    	gtk_list_store_insert_with_values (GTK_LIST_STORE(model), &iter, -1,
 				LST_REPTIME_POS, id++,
 				LST_REPTIME_KEY, i,
 				LST_REPTIME_TITLE, intvlname,
@@ -699,17 +736,24 @@ guint32 selkey;
 		}
 
 		// set chart and listview currency
+		//TODO: we should maybe display in native instead of global ?
+		//maybe to be done while getting active checkbos and store into filter
 		guint32 kcur = GLOBALS->kcur;
-		if( (showall == FALSE) && (tmpsrc == REPORT_SRC_ACCOUNT) )
+		/*if( (showall == FALSE) && (tmpsrc == REPORT_SRC_ACCOUNT) )
 		{
-		Account *acc = da_acc_get(selkey);
+		Account *acc;
+
+			//selkey = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_acc));
+			selkey = ui_acc_entry_popover_get_key(GTK_BOX(data->PO_acc));
+			acc = da_acc_get(selkey);
+
 			if( acc != NULL )
 			{
 				kcur = acc->kcur;
 				//fix 5.4.2 crash here
 				gtk_chart_set_overdrawn(GTK_CHART(data->RE_chart), acc->minimum);
 			}
-		}
+		}*/
 
 		lst_reptime_set_cur(GTK_TREE_VIEW(data->LV_report), kcur);
 		gtk_chart_set_currency(GTK_CHART(data->RE_chart), kcur);
@@ -747,7 +791,7 @@ guint32 selkey;
 
 	/* free our memory */
 	g_free(tmp_amount);
-	
+
 	reptime_update(widget, user_data);
 }
 
@@ -781,6 +825,54 @@ gint page;
 }
 
 
+static void
+reptime_cb_acc_changed(GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data)
+{
+struct reptime_data *data = user_data;
+
+	DB( g_print ("\n[reptime] acc list changed\n") );
+
+	ui_acc_listview_toggle_to_filter(GTK_TREE_VIEW(data->LV_acc), data->filter);
+	reptime_compute(GTK_WIDGET(data->LV_acc), NULL);
+}
+
+
+static void
+reptime_cb_cat_changed(GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data)
+{
+struct reptime_data *data = user_data;
+
+	DB( g_print ("\n[reptime] cat list changed\n") );
+
+	ui_cat_listview_toggle_to_filter(GTK_TREE_VIEW(data->LV_cat), data->filter);
+	reptime_compute(GTK_WIDGET(data->LV_cat), NULL);
+}
+
+
+static void
+reptime_cb_pay_changed(GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data)
+{
+struct reptime_data *data = user_data;
+
+	DB( g_print ("\n[reptime] pay list changed\n") );
+
+	ui_pay_listview_toggle_to_filter(GTK_TREE_VIEW(data->LV_pay), data->filter);
+	reptime_compute(GTK_WIDGET(data->LV_pay), NULL);
+}
+
+
+static void
+reptime_cb_tag_changed(GtkCellRendererToggle *cell, gchar *path_str, gpointer user_data)
+{
+struct reptime_data *data = user_data;
+
+	DB( g_print ("\n[reptime] tag list changed\n") );
+
+	ui_tag_listview_toggle_to_filter(GTK_TREE_VIEW(data->LV_tag), data->filter);
+	reptime_compute(GTK_WIDGET(data->LV_tag), NULL);
+}
+
+
 static void reptime_detail_onRowActivated (GtkTreeView        *treeview,
                        GtkTreePath        *path,
                        GtkTreeViewColumn  *col,
@@ -905,7 +997,6 @@ gdouble value;
 }
 
 
-
 static void reptime_toggle_minor(GtkWidget *widget, gpointer user_data)
 {
 struct reptime_data *data;
@@ -924,30 +1015,6 @@ struct reptime_data *data;
 }
 
 
-static void reptime_toggle_showall(GtkWidget *widget, gpointer user_data)
-{
-struct reptime_data *data;
-gboolean showall;
-
-	DB( g_print("\n[reptime] toggle\n") );
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
-	showall = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_all));
-
-	gtk_widget_set_sensitive(GTK_WIDGET(data->PO_acc), showall^1);
-	gtk_widget_set_sensitive(GTK_WIDGET(data->PO_cat), showall^1);
-	gtk_widget_set_sensitive(GTK_WIDGET(data->PO_pay), showall^1);
-	gtk_widget_set_sensitive(GTK_WIDGET(data->PO_tag), showall^1);
-
-	reptime_compute(widget, data);
-
-}
-
-
-
-
-
 static void reptime_selection(GtkTreeSelection *treeselection, gpointer user_data)
 {
 GtkTreeModel *model;
@@ -1004,6 +1071,12 @@ GtkWidget *toolbar, *button;
 	data->BT_detail = button;
 	gtk_toolbar_insert(GTK_TOOLBAR(toolbar), GTK_TOOL_ITEM(button), -1);
 
+
+#if MYDEBUG
+	button = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_FILTER, _("Filter"), _("Edit filter"));
+	data->BT_filter = button;
+#endif
+
 	button = hbtk_toolbar_add_toolbutton(GTK_TOOLBAR(toolbar), ICONNAME_HB_REFRESH, _("Refresh"), _("Refresh results"));
 	data->BT_refresh = button;
 
@@ -1068,47 +1141,122 @@ static void reptime_filter_setup(struct reptime_data *data)
 
 	filter_preset_daterange_set(data->filter, PREFS->date_range_rep, data->accnum);
 
-	g_signal_handler_block(data->PO_mindate, data->handler_id[HID_REPTIME_MINDATE]);
-	g_signal_handler_block(data->PO_maxdate, data->handler_id[HID_REPTIME_MAXDATE]);
+	//g_signal_handler_block(data->PO_mindate, data->handler_id[HID_REPTIME_MINDATE]);
+	//g_signal_handler_block(data->PO_maxdate, data->handler_id[HID_REPTIME_MAXDATE]);
 
 	gtk_date_entry_set_date(GTK_DATE_ENTRY(data->PO_mindate), data->filter->mindate);
 	gtk_date_entry_set_date(GTK_DATE_ENTRY(data->PO_maxdate), data->filter->maxdate);
 
-	g_signal_handler_unblock(data->PO_mindate, data->handler_id[HID_REPTIME_MINDATE]);
-	g_signal_handler_unblock(data->PO_maxdate, data->handler_id[HID_REPTIME_MAXDATE]);
-
-	
+	//g_signal_handler_unblock(data->PO_mindate, data->handler_id[HID_REPTIME_MINDATE]);
+	//g_signal_handler_unblock(data->PO_maxdate, data->handler_id[HID_REPTIME_MAXDATE]);
 }
 
 
 static void reptime_window_setup(struct reptime_data *data, guint32 accnum)
 {
-	DB( g_print("\n[reptime] setup\n") );
+	DB( g_print("\n[reptime] window setup\n") );
+
+	DB( g_print(" init data\n") );
 
 	reptime_filter_setup(data);
-
 	data->detail = 0;
 
+
 	DB( g_print(" populate\n") );
-	ui_acc_comboboxentry_populate(GTK_COMBO_BOX(data->PO_acc), GLOBALS->h_acc, ACC_LST_INSERT_REPORT);
-	if( accnum )
-		ui_acc_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_acc), accnum);
-	else
-		gtk_combo_box_set_active(GTK_COMBO_BOX(data->PO_acc), 0);
+	
+	ui_acc_listview_populate(data->LV_acc, ACC_LST_INSERT_REPORT);
+	ui_cat_listview_populate(data->LV_cat, CAT_TYPE_ALL, NULL, FALSE);
+	ui_pay_listview_populate(data->LV_pay, NULL, FALSE);
+	ui_tag_listview_populate(data->LV_tag, 0);
 
-	ui_pay_comboboxentry_populate(GTK_COMBO_BOX(data->PO_pay), GLOBALS->h_pay);
-	ui_pay_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_pay), 0);
+	DB( g_print(" set widgets default\n") );
 
-	ui_cat_comboboxentry_populate(GTK_COMBO_BOX(data->PO_cat), GLOBALS->h_cat);
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->PO_cat), 0);
+	//src is account
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_intvl), REPORT_INTVL_MONTH);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor), GLOBALS->minor);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
 
-	ui_tag_combobox_populate(GTK_COMBO_BOX_TEXT(data->PO_tag));
+	//5.6 set default account
+	if(!accnum)
+	{
+		accnum = da_acc_get_first_key();
+	}
+	ui_acc_listview_set_active(GTK_TREE_VIEW(data->LV_acc), accnum);
+	da_flt_status_acc_set(data->filter, accnum, TRUE);
 
+	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
+	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail))), "minor", (gpointer)data->CM_minor);
 
 	gtk_chart_set_smallfont (GTK_CHART(data->RE_chart), PREFS->rep_smallfont);
 
-	DB( g_print(" all ok\n") );
+	reptime_update_for(data->window, data);
 
+
+	DB( g_print(" connect widgets signals\n") );
+
+	g_signal_connect (data->CM_cumul, "toggled", G_CALLBACK (reptime_compute), NULL);
+	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (reptime_toggle_minor), NULL);
+    data->handler_id[HID_REPTIME_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (reptime_date_change), (gpointer)data);
+    data->handler_id[HID_REPTIME_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (reptime_date_change), (gpointer)data);
+	data->handler_id[HID_REPTIME_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (reptime_range_change), NULL);
+	g_signal_connect (data->CY_src, "changed", G_CALLBACK (reptime_for), (gpointer)data);
+	data->handler_id[HID_REPTIME_VIEW] = g_signal_connect (data->CY_intvl, "changed", G_CALLBACK (reptime_compute), (gpointer)data);
+	g_signal_connect (data->CM_showempty, "toggled", G_CALLBACK (reptime_compute), NULL);
+
+	g_signal_connect (data->RG_zoomx, "value-changed", G_CALLBACK (reptime_zoomx_callback), NULL);
+
+	g_signal_connect (G_OBJECT (data->BT_list), "clicked", G_CALLBACK (reptime_action_viewlist), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_line), "clicked", G_CALLBACK (reptime_action_viewline), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_column), "clicked", G_CALLBACK (reptime_action_viewcolumn), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_detail), "clicked", G_CALLBACK (reptime_toggle_detail), (gpointer)data);
+#if MYDEBUG
+	g_signal_connect (G_OBJECT (data->BT_filter), "clicked", G_CALLBACK (reptime_action_filter), (gpointer)data);
+#endif
+	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (reptime_compute), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_print), "clicked", G_CALLBACK (reptime_action_print), (gpointer)data);
+	//export is a menu
+
+	//item filter
+	g_signal_connect (data->BT_all, "activate-link", G_CALLBACK (reptime_cb_activate_link), NULL);
+	g_signal_connect (data->BT_non, "activate-link", G_CALLBACK (reptime_cb_activate_link), NULL);
+	g_signal_connect (data->BT_inv, "activate-link", G_CALLBACK (reptime_cb_activate_link), NULL);
+	
+	
+	GtkCellRendererToggle *renderer;
+
+	renderer = g_object_get_data(G_OBJECT(data->LV_acc), "togrdr_data");
+	g_signal_connect_after (G_OBJECT(renderer), "toggled", G_CALLBACK (reptime_cb_acc_changed), (gpointer)data);
+
+	renderer = g_object_get_data(G_OBJECT(data->LV_cat), "togrdr_data");
+	g_signal_connect_after (G_OBJECT(renderer), "toggled", G_CALLBACK (reptime_cb_cat_changed), (gpointer)data);
+	
+	renderer = g_object_get_data(G_OBJECT(data->LV_pay), "togrdr_data");
+	g_signal_connect_after (G_OBJECT(renderer), "toggled", G_CALLBACK (reptime_cb_pay_changed), (gpointer)data);
+
+	renderer = g_object_get_data(G_OBJECT(data->LV_tag), "togrdr_data");
+	g_signal_connect_after (G_OBJECT(renderer), "toggled", G_CALLBACK (reptime_cb_tag_changed), (gpointer)data);
+
+
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), "changed", G_CALLBACK (reptime_selection), NULL);
+
+	g_signal_connect (GTK_TREE_VIEW(data->LV_detail), "row-activated", G_CALLBACK (reptime_detail_onRowActivated), NULL);
+}
+
+
+static gboolean reptime_window_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct reptime_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n[reptime] window mapped\n") );
+
+	//setup, init and show window
+	reptime_window_setup(data, data->accnum);	
+	reptime_compute(data->window, NULL);
+	reptime_update_daterange(data->window, NULL);
+
+	return FALSE;
 }
 
 
@@ -1117,7 +1265,7 @@ static gboolean reptime_window_dispose(GtkWidget *widget, GdkEvent *event, gpoin
 struct reptime_data *data = user_data;
 struct WinGeometry *wg;
 
-	DB( g_print("\n[reptime] dispose\n") );
+	DB( g_print("\n[reptime] window dispose\n") );
 
 	g_queue_free (data->txn_queue);
 
@@ -1148,7 +1296,7 @@ struct WinGeometry *wg;
 //allocate our object/memory
 static void reptime_window_acquire(struct reptime_data *data)
 {
-	DB( g_print("\n[repdist] acquire\n") );
+	DB( g_print("\n[repdist] window acquire\n") );
 
 	data->txn_queue = g_queue_new ();
 	data->filter = da_flt_malloc();
@@ -1160,16 +1308,16 @@ GtkWidget *reptime_window_new(guint32 accnum)
 {
 struct reptime_data *data;
 struct WinGeometry *wg;
-GtkWidget *window, *mainvbox, *hbox, *vbox, *notebook, *treeview;
+GtkWidget *window, *mainvbox, *hbox, *vbox, *notebook, *treeview, *treebox, *sw;
 GtkWidget *label, *widget, *table;
 gint row;
 
-	DB( g_print("\n[reptime] new\n") );
-
+	DB( g_print("\n[reptime] window new\n") );
 
 	data = g_malloc0(sizeof(struct reptime_data));
 	if(!data) return NULL;
 
+	data->accnum = accnum;
 	reptime_window_acquire(data);
 
 	//disable define windows
@@ -1186,7 +1334,6 @@ gint row;
 	g_object_set_data(G_OBJECT(window), "inst_data", (gpointer)data);
 	DB( g_print(" - new window=%p, inst_data=%p\n", window, data) );
 
-
 	gtk_window_set_title (GTK_WINDOW (window), _("Trend Time Report"));
 
 	//window contents
@@ -1211,49 +1358,13 @@ gint row;
 
 	row++;
 	label = make_label_widget(_("_View by:"));
+	data->LB_src = label;
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 	//widget = make_cycle(label, CYA_TIMESELECT);
 	widget = hbtk_combo_box_new_with_data(label, CYA_REPORT_SRC_TREND);
 	data->CY_src = widget;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
-	row++;
-	label = make_label_widget(_("A_ccount:"));
-	data->LB_acc = label;
-	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
-	widget = ui_acc_comboboxentry_new(label);
-	data->PO_acc = widget;
-	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
-
-	row++;
-	label = make_label_widget(_("_Category:"));
-	data->LB_cat = label;
-	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
-	widget = ui_cat_comboboxentry_new(label);
-	data->PO_cat = widget;
-	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
-
-	row++;
-	label = make_label_widget(_("_Payee:"));
-	data->LB_pay = label;
-	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
-	widget = ui_pay_comboboxentry_new(label);
-	data->PO_pay = widget;
-	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
-
-	row++;
-	label = make_label_widget(_("_Tag:"));
-	data->LB_tag = label;
-	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
-	widget = ui_tag_combobox_new(label);
-	data->PO_tag = widget;
-	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
-
-	row++;
-	widget = gtk_check_button_new_with_mnemonic (_("Select _all"));
-	data->CM_all = widget;
-	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
-
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("_Cumulate"));
 	data->CM_cumul = widget;
@@ -1272,7 +1383,6 @@ gint row;
 	data->CM_showempty = widget;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
-
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("Euro _minor"));
 	data->CM_minor = widget;
@@ -1312,19 +1422,100 @@ gint row;
 	data->PO_maxdate = gtk_date_entry_new(label);
 	gtk_grid_attach (GTK_GRID (table), data->PO_maxdate, 2, row, 1, 1);
 
+	row++;
+	widget = gtk_separator_new(GTK_ORIENTATION_HORIZONTAL);
+	gtk_grid_attach (GTK_GRID (table), widget, 0, row, 3, 1);
+
+	row++;
+	label = make_label_group(_("Item filter"));
+	gtk_grid_attach (GTK_GRID (table), label, 0, row, 3, 1);
+
+	row++;
+	treebox = gtk_box_new(GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
+	
+	gtk_grid_attach (GTK_GRID (table), treebox, 1, row, 2, 1);
+
+		label = make_label (_("Select:"), 0, 0.5);
+		gimp_label_set_attributes (GTK_LABEL (label), PANGO_ATTR_SCALE, PANGO_SCALE_SMALL, -1);
+		gtk_box_pack_start (GTK_BOX (treebox), label, FALSE, FALSE, 0);
+
+		label = make_clicklabel("all", _("All"));
+		data->BT_all = label;
+		gtk_box_pack_start (GTK_BOX (treebox), label, FALSE, FALSE, 0);
+		
+		label = make_clicklabel("non", _("None"));
+		data->BT_non = label;
+		gtk_box_pack_start (GTK_BOX (treebox), label, FALSE, FALSE, 0);
+
+		label = make_clicklabel("inv", _("Invert"));
+		data->BT_inv = label;
+		gtk_box_pack_start (GTK_BOX (treebox), label, FALSE, FALSE, 0);
+
+	row++;
+	notebook = gtk_notebook_new();
+	data->GR_itemtype = notebook;
+	gtk_widget_show(notebook);
+	gtk_notebook_set_show_tabs(GTK_NOTEBOOK(notebook), FALSE);
+	gtk_notebook_set_show_border(GTK_NOTEBOOK(notebook), FALSE);	
+	gtk_grid_attach (GTK_GRID (table), notebook, 1, row, 2, 1);
+
+	 	sw = gtk_scrolled_window_new(NULL,NULL);
+	 	data->SW_acc = sw;
+		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
+		gtk_widget_set_margin_bottom (sw, SPACING_LARGE);
+		widget = ui_acc_listview_new(TRUE);
+		data->LV_acc = widget;
+		gtk_widget_set_vexpand (widget, TRUE);
+		//gtk_widget_set_size_request(widget, HB_MINWIDTH_LIST, -1);
+		gtk_container_add(GTK_CONTAINER(sw), widget);
+		gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, NULL);
+
+	 	sw = gtk_scrolled_window_new(NULL,NULL);
+	 	//data->SW_acc = sw;
+		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
+		gtk_widget_set_margin_bottom (sw, SPACING_LARGE);
+		widget = ui_cat_listview_new(TRUE, FALSE);
+		data->LV_cat = widget;
+		gtk_widget_set_vexpand (widget, TRUE);
+		//gtk_widget_set_size_request(widget, HB_MINWIDTH_LIST, -1);
+		gtk_container_add(GTK_CONTAINER(sw), widget);
+		gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, NULL);
+
+	 	sw = gtk_scrolled_window_new(NULL,NULL);
+	 	//data->SW_acc = sw;
+		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
+		gtk_widget_set_margin_bottom (sw, SPACING_LARGE);
+		widget = ui_pay_listview_new(TRUE, FALSE);
+		data->LV_pay = widget;
+		gtk_widget_set_vexpand (widget, TRUE);
+		//gtk_widget_set_size_request(widget, HB_MINWIDTH_LIST, -1);
+		gtk_container_add(GTK_CONTAINER(sw), widget);
+		gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, NULL);
+
+	 	sw = gtk_scrolled_window_new(NULL,NULL);
+	 	//data->SW_acc = sw;
+		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(sw), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (sw), GTK_SHADOW_ETCHED_IN);
+		gtk_widget_set_margin_bottom (sw, SPACING_LARGE);
+		widget = ui_tag_listview_new(TRUE);
+		data->LV_tag = widget;
+		gtk_widget_set_vexpand (widget, TRUE);
+		//gtk_widget_set_size_request(widget, HB_MINWIDTH_LIST, -1);
+		gtk_container_add(GTK_CONTAINER(sw), widget);
+		gtk_notebook_append_page(GTK_NOTEBOOK(notebook), sw, NULL);
 
 	//part: info + report
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
     gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
-
 	//toolbar
 	widget = reptime_toolbar_create(data);
 	data->TB_bar = widget;
 	gtk_box_pack_start (GTK_BOX (vbox), widget, FALSE, FALSE, 0);
 
-
-
 	//infos
 	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
 	gtk_container_set_border_width (GTK_CONTAINER(hbox), SPACING_SMALL);
@@ -1339,7 +1530,7 @@ gint row;
 	data->TX_info = label;
 	gtk_box_pack_end (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
-
+	//notebook
 	notebook = gtk_notebook_new();
 	data->GR_result = notebook;
 	gtk_widget_show(notebook);
@@ -1352,27 +1543,27 @@ gint row;
 	vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), vbox, NULL);
 
-	widget = gtk_scrolled_window_new (NULL, NULL);
-	//gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW (widget), GTK_CORNER_TOP_RIGHT);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	treeview = lst_reptime_create();
-	data->LV_report = treeview;
-	gtk_container_add (GTK_CONTAINER(widget), treeview);
-    gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
+		widget = gtk_scrolled_window_new (NULL, NULL);
+		//gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW (widget), GTK_CORNER_TOP_RIGHT);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		treeview = lst_reptime_create();
+		data->LV_report = treeview;
+		gtk_container_add (GTK_CONTAINER(widget), treeview);
+		gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
 
-	//detail
-	widget = gtk_scrolled_window_new (NULL, NULL);
-	data->GR_detail = widget;
-	//gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW (widget), GTK_CORNER_TOP_RIGHT);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	treeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_ope_columns);
-	data->LV_detail = treeview;
-	gtk_container_add (GTK_CONTAINER(widget), treeview);
-
-    gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
+		//detail
+		widget = gtk_scrolled_window_new (NULL, NULL);
+		data->GR_detail = widget;
+		//gtk_scrolled_window_set_placement(GTK_SCROLLED_WINDOW (widget), GTK_CORNER_TOP_RIGHT);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (widget), GTK_SHADOW_ETCHED_IN);
+		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (widget), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
+		treeview = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_det_columns);
+		data->LV_detail = treeview;
+		gtk_container_add (GTK_CONTAINER(widget), treeview);
+		gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
 
+		list_txn_set_save_column_width(GTK_TREE_VIEW(treeview), TRUE);
 
 	//page: lines
 	widget = gtk_chart_new(CHART_TYPE_LINE);
@@ -1380,96 +1571,29 @@ gint row;
 	//gtk_chart_set_minor_prefs(GTK_CHART(widget), PREFS->euro_value, PREFS->minor_cur.suffix_symbol);
 	gtk_notebook_append_page(GTK_NOTEBOOK(notebook), widget, NULL);
 
-	//todo:should move this
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor), GLOBALS->minor);
 
-	//duplicate, see below
-	//gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_intvl), 1);
-
-	/* attach our minor to treeview */
-	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
-	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_detail))), "minor", (gpointer)data->CM_minor);
-
-
-
-	/* signal connect */
+	// connect dialog signals
 	g_signal_connect (window, "delete-event", G_CALLBACK (reptime_window_dispose), (gpointer)data);
+	g_signal_connect (window, "map-event"   , G_CALLBACK (reptime_window_mapped), NULL);
+	
+	// setup, init and show window
+	wg = &PREFS->tme_wg;
+	if( wg->l && wg->t )
+		gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
+	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);	
 
-	g_signal_connect (data->CM_cumul, "toggled", G_CALLBACK (reptime_compute), NULL);
-
-	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (reptime_toggle_minor), NULL);
-
-    data->handler_id[HID_REPTIME_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (reptime_date_change), (gpointer)data);
-    data->handler_id[HID_REPTIME_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (reptime_date_change), (gpointer)data);
-
-	data->handler_id[HID_REPTIME_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (reptime_range_change), NULL);
-
-	g_signal_connect (data->CY_src, "changed", G_CALLBACK (reptime_for), (gpointer)data);
-	data->handler_id[HID_REPTIME_VIEW] = g_signal_connect (data->CY_intvl, "changed", G_CALLBACK (reptime_compute), (gpointer)data);
-
-	g_signal_connect (data->CM_showempty, "toggled", G_CALLBACK (reptime_compute), NULL);
-
-	//setup, init and show window
-	reptime_window_setup(data, accnum);
-
-	g_signal_connect (data->CM_all, "toggled", G_CALLBACK (reptime_toggle_showall), NULL);
-	g_signal_connect (data->PO_acc, "changed", G_CALLBACK (reptime_compute), NULL);
-	g_signal_connect (data->PO_cat, "changed", G_CALLBACK (reptime_compute), NULL);
-	g_signal_connect (data->PO_pay, "changed", G_CALLBACK (reptime_compute), NULL);
-	g_signal_connect (data->PO_tag, "changed", G_CALLBACK (reptime_compute), NULL);
-
-	g_signal_connect (data->RG_zoomx, "value-changed", G_CALLBACK (reptime_zoomx_callback), NULL);
-
-	g_signal_connect (G_OBJECT (data->BT_list), "clicked", G_CALLBACK (reptime_action_viewlist), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_line), "clicked", G_CALLBACK (reptime_action_viewline), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_column), "clicked", G_CALLBACK (reptime_action_viewcolumn), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_detail), "clicked", G_CALLBACK (reptime_toggle_detail), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (reptime_compute), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_print), "clicked", G_CALLBACK (reptime_action_print), (gpointer)data);
-	//export is a menu
-
-
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_report)), "changed", G_CALLBACK (reptime_selection), NULL);
-
-	g_signal_connect (GTK_TREE_VIEW(data->LV_detail), "row-activated", G_CALLBACK (reptime_detail_onRowActivated), NULL);
-
-
-	/* toolbar */
+	// toolbar
 	if(PREFS->toolbar_style == 0)
 		gtk_toolbar_unset_style(GTK_TOOLBAR(data->TB_bar));
 	else
 		gtk_toolbar_set_style(GTK_TOOLBAR(data->TB_bar), PREFS->toolbar_style-1);
 
-	//setup, init and show window
-	wg = &PREFS->tme_wg;
-	gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
-	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
-
-	//TODO: !! here
-	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_intvl), REPORT_INTVL_MONTH);
-
 	gtk_widget_show_all (window);
 
 	//minor ?
-	if( PREFS->euro_active )
-		gtk_widget_show(data->CM_minor);
-	else
-		gtk_widget_hide(data->CM_minor);
-
-	reptime_update_for(window, data);
-	//gtk_widget_hide(data->GR_detail);
-
-
-
-	reptime_sensitive(window, NULL);
-	reptime_update_detail(window, NULL);
-
-	DB( g_print("range: %d\n", PREFS->date_range_rep) );
-
-	if( PREFS->date_range_rep != 0)
-		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
-	else
-		reptime_compute(window, NULL);
+	hb_widget_visible(data->CM_minor, PREFS->euro_active);
+	reptime_sensitive(data->window, NULL);
+	reptime_update_detail(data->window, NULL);
 
 	return window;
 }
