@@ -74,6 +74,7 @@ struct reptime_data
 	GtkWidget	*BT_line;
 	GtkWidget	*BT_column;
 	GtkWidget	*BT_detail;
+	GtkWidget	*BT_filter;
 	GtkWidget	*BT_refresh;
 	GtkWidget	*BT_print;
 	GtkWidget	*BT_export;
@@ -82,22 +83,25 @@ struct reptime_data
 	
 	GtkWidget	*TX_info;
 	GtkWidget	*TX_daterange;
-	GtkWidget	*CY_src;
+	GtkWidget	*CY_mode;
 	GtkWidget	*CY_intvl;
 	GtkWidget	*RG_zoomx, *LB_zoomx;
 	GtkWidget	*CM_minor;
 	GtkWidget	*CM_cumul;
-	GtkWidget	*RA_mode;
+
 	GtkWidget	*LV_report;
 
-	//GtkWidget	*GR_select;
-	GtkWidget	*CM_all;
-	GtkWidget	*LB_acc, *PO_acc;
-	GtkWidget	*LB_cat, *PO_cat;
-	GtkWidget	*LB_pay, *PO_pay;
-	GtkWidget	*LB_tag, *PO_tag;
+	GtkWidget	*GR_itemtype;
+	GtkWidget	*LB_src, *CY_src;
 
-	GtkWidget *CM_showempty;
+	GtkWidget	*BT_all, *BT_non, *BT_inv;
+	
+	GtkWidget	*SW_acc, *LV_acc;
+	GtkWidget	*SW_cat, *LV_cat;
+	GtkWidget	*SW_pay, *LV_pay;
+	GtkWidget	*SW_tag, *LV_tag;
+
+	GtkWidget   *CM_showempty;
 
 	GtkWidget	*PO_mindate, *PO_maxdate;
 
