@@ -72,7 +72,7 @@ struct repvehicle_data *data;
 	gtk_date_entry_set_mindate(GTK_DATE_ENTRY(data->PO_maxdate), data->filter->mindate);
 
 	g_signal_handler_block(data->CY_range, data->handler_id[HID_REPVEHICLE_RANGE]);
-	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_OTHER);
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), FLT_RANGE_MISC_CUSTOM);
 	g_signal_handler_unblock(data->CY_range, data->handler_id[HID_REPVEHICLE_RANGE]);
 
 
@@ -108,7 +108,7 @@ gint range;
 
 	range = hbtk_combo_box_get_active_id(GTK_COMBO_BOX_TEXT(data->CY_range));
 
-	if(range != FLT_RANGE_OTHER)
+	if(range != FLT_RANGE_MISC_CUSTOM)
 	{
 		filter_preset_daterange_set(data->filter, range, 0);
 
@@ -501,7 +501,8 @@ guint lastmeter = 0;
 	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
 
 	// get the category key
-	selkey = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_cat));
+	//selkey = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_cat));
+	selkey = ui_cat_entry_popover_get_key(GTK_BOX(data->PO_cat));
 
 	DB( g_print(" selkey=%d\n\n", selkey) );
 
@@ -708,7 +709,6 @@ noselkey:
 	//hb_label_set_colvaluecurr(GTK_LABEL(data->LA_total[CAR_RES_TOTALCOST]), data->total_fuelcost + data->total_misccost, GLOBALS->kcur);
 	hb_label_set_colvalue(GTK_LABEL(data->LA_total[CAR_RES_TOTALCOST]), data->total_fuelcost + data->total_misccost, GLOBALS->kcur, GLOBALS->minor);
 
-
 }
 
 
@@ -747,21 +747,24 @@ guint32 kcat, *key, i;
 
 	kcat = GLOBALS->vehicle_category;
 
-	g_signal_handler_block(data->PO_cat, data->handler_id[HID_REPVEHICLE_VEHICLE]);
+	//g_signal_handler_block(data->PO_cat, data->handler_id[HID_REPVEHICLE_VEHICLE]);
 
 	if( array != NULL )
 	{
 		//get previous category
-		kcat = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_cat));
+		//kcat = ui_cat_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_cat));
+		kcat = ui_cat_entry_popover_get_key(GTK_BOX(data->PO_cat));
 
 		//populate with the array
-		ui_cat_combobox_entry_clear(GTK_COMBO_BOX(data->PO_cat));
+		//ui_cat_combobox_entry_clear(GTK_COMBO_BOX(data->PO_cat));
+		ui_cat_entry_popover_clear(GTK_BOX(data->PO_cat));
 
 		cat = da_cat_get(0);
 		if(cat)
 		{
 			DB( g_print(" add %d '%s'\n", cat->key, cat->fullname) );
-			ui_cat_comboboxentry_add(GTK_COMBO_BOX(data->PO_cat), cat);
+			//ui_cat_comboboxentry_add(GTK_COMBO_BOX(data->PO_cat), cat);
+			ui_cat_entry_popover_add(GTK_BOX(data->PO_cat), cat);
 		}
 
 		for(i=0;i<array->len;i++)
@@ -771,13 +774,16 @@ guint32 kcat, *key, i;
 			if(cat)
 			{
 				DB( g_print(" add %d %s\n", cat->key, cat->fullname) );
-				ui_cat_comboboxentry_add(GTK_COMBO_BOX(data->PO_cat), cat);
+				//ui_cat_comboboxentry_add(GTK_COMBO_BOX(data->PO_cat), cat);
+				ui_cat_entry_popover_add(GTK_BOX(data->PO_cat), cat);
 			}
 		}
 	}
 
-	ui_cat_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_cat), kcat);
-	g_signal_handler_unblock(data->PO_cat, data->handler_id[HID_REPVEHICLE_VEHICLE]);
+	//ui_cat_comboboxentry_set_active(GTK_COMBO_BOX(data->PO_cat), kcat);
+	ui_cat_entry_popover_set_active(GTK_BOX(data->PO_cat), kcat);
+	
+	//g_signal_handler_unblock(data->PO_cat, data->handler_id[HID_REPVEHICLE_VEHICLE]);
 }
 
 
@@ -811,14 +817,14 @@ static void repvehicle_filter_setup(struct repvehicle_data *data)
 
 	filter_preset_daterange_set(data->filter, PREFS->date_range_rep, 0);
 	
-	g_signal_handler_block(data->PO_mindate, data->handler_id[HID_REPVEHICLE_MINDATE]);
-	g_signal_handler_block(data->PO_maxdate, data->handler_id[HID_REPVEHICLE_MAXDATE]);
+	//g_signal_handler_block(data->PO_mindate, data->handler_id[HID_REPVEHICLE_MINDATE]);
+	//g_signal_handler_block(data->PO_maxdate, data->handler_id[HID_REPVEHICLE_MAXDATE]);
 
 	gtk_date_entry_set_date(GTK_DATE_ENTRY(data->PO_mindate), data->filter->mindate);
 	gtk_date_entry_set_date(GTK_DATE_ENTRY(data->PO_maxdate), data->filter->maxdate);
 
-	g_signal_handler_unblock(data->PO_mindate, data->handler_id[HID_REPVEHICLE_MINDATE]);
-	g_signal_handler_unblock(data->PO_maxdate, data->handler_id[HID_REPVEHICLE_MAXDATE]);
+	//g_signal_handler_unblock(data->PO_mindate, data->handler_id[HID_REPVEHICLE_MINDATE]);
+	//g_signal_handler_unblock(data->PO_maxdate, data->handler_id[HID_REPVEHICLE_MAXDATE]);
 
 }
 
@@ -827,10 +833,54 @@ static void repvehicle_window_setup(struct repvehicle_data *data)
 {
 	DB( g_print("\n[vehiclecost] setup\n") );
 
+	DB( g_print(" init data\n") );
+
 	repvehicle_filter_setup(data);
 
+	DB( g_print(" populate\n") );
+
 	repvehicle_setup_categories(data, NULL);
 
+	DB( g_print(" set widgets default\n") );
+
+	hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor),GLOBALS->minor);
+
+	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
+
+	DB( g_print(" connect widgets signals\n") );
+	
+
+	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (repvehicle_toggle_minor), NULL);
+
+    data->handler_id[HID_REPVEHICLE_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (repvehicle_date_change), (gpointer)data);
+    data->handler_id[HID_REPVEHICLE_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (repvehicle_date_change), (gpointer)data);
+
+	data->handler_id[HID_REPVEHICLE_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (repvehicle_range_change), NULL);
+
+	//data->handler_id[HID_REPVEHICLE_VEHICLE] = g_signal_connect (data->PO_cat, "changed", G_CALLBACK (repvehicle_update), NULL);
+	data->handler_id[HID_REPVEHICLE_VEHICLE] = g_signal_connect (ui_cat_entry_popover_get_entry(GTK_BOX(data->PO_cat)), "changed", G_CALLBACK (repvehicle_update), NULL);
+
+	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (repvehicle_action_refresh), (gpointer)data);
+	g_signal_connect (G_OBJECT (data->BT_export) , "clicked", G_CALLBACK (repvehicle_action_export), (gpointer)data);
+
+
+}
+
+
+static gboolean repvehicle_window_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct repvehicle_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n[vehiclecost] window mapped\n") );
+
+	//setup, init and show window
+	repvehicle_window_setup(data);
+	repvehicle_compute(data->window, NULL);
+
+	return FALSE;
 }
 
 
@@ -881,7 +931,6 @@ static void repvehicle_window_acquire(struct repvehicle_data *data)
 }
 
 
-
 // the window creation
 GtkWidget *repvehicle_window_new(void)
 {
@@ -938,7 +987,8 @@ gint row, col;
 	label = make_label_widget(_("Vehi_cle:"));
 	gtk_grid_attach (GTK_GRID (table), label, 1, row, 1, 1);
 
-	widget = ui_cat_comboboxentry_new(label);
+	//widget = ui_cat_comboboxentry_new(label);
+	widget = ui_cat_entry_popover_new(label);
 	data->PO_cat = widget;
 	gtk_grid_attach (GTK_GRID (table), widget, 2, row, 1, 1);
 
@@ -1049,34 +1099,15 @@ gint row, col;
     gtk_box_pack_start (GTK_BOX (vbox), widget, TRUE, TRUE, 0);
 
 
-	//todo:should move this
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_minor),GLOBALS->minor);
-
-
-
-	/* attach our minor to treeview */
-	g_object_set_data(G_OBJECT(gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_report))), "minor", (gpointer)data->CM_minor);
-
-
-
-	/* signal connect */
+	// connect dialog signals
     g_signal_connect (window, "delete-event", G_CALLBACK (repvehicle_window_dispose), (gpointer)data);
+	g_signal_connect (window, "map-event"   , G_CALLBACK (repvehicle_window_mapped), NULL);
 
-	g_signal_connect (data->CM_minor, "toggled", G_CALLBACK (repvehicle_toggle_minor), NULL);
-
-    data->handler_id[HID_REPVEHICLE_MINDATE] = g_signal_connect (data->PO_mindate, "changed", G_CALLBACK (repvehicle_date_change), (gpointer)data);
-    data->handler_id[HID_REPVEHICLE_MAXDATE] = g_signal_connect (data->PO_maxdate, "changed", G_CALLBACK (repvehicle_date_change), (gpointer)data);
-
-	data->handler_id[HID_REPVEHICLE_RANGE] = g_signal_connect (data->CY_range, "changed", G_CALLBACK (repvehicle_range_change), NULL);
-
-	data->handler_id[HID_REPVEHICLE_VEHICLE] = g_signal_connect (data->PO_cat, "changed", G_CALLBACK (repvehicle_update), NULL);
-
-	g_signal_connect (G_OBJECT (data->BT_refresh), "clicked", G_CALLBACK (repvehicle_action_refresh), (gpointer)data);
-	g_signal_connect (G_OBJECT (data->BT_export) , "clicked", G_CALLBACK (repvehicle_action_export), (gpointer)data);
-
-	
-	//setup, init and show window
-	repvehicle_window_setup(data);
+	// setup, init and show window
+	wg = &PREFS->cst_wg;
+	if( wg->l && wg->t )
+		gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
+	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
 
 	/* toolbar */
 	if(PREFS->toolbar_style == 0)
@@ -1084,29 +1115,15 @@ gint row, col;
 	else
 		gtk_toolbar_set_style(GTK_TOOLBAR(data->TB_bar), PREFS->toolbar_style-1);
 
-	//setup, init and show window
-	wg = &PREFS->cst_wg;
-	gtk_window_move(GTK_WINDOW(window), wg->l, wg->t);
-	gtk_window_resize(GTK_WINDOW(window), wg->w, wg->h);
-
 	gtk_widget_show_all (window);
 
 	//minor ?
-	if( PREFS->euro_active )
-		gtk_widget_show(data->CM_minor);
-	else
-		gtk_widget_hide(data->CM_minor);
-
-
-
-	if( PREFS->date_range_rep )
-		hbtk_combo_box_set_active_id(GTK_COMBO_BOX_TEXT(data->CY_range), PREFS->date_range_rep);
-	else
-		repvehicle_compute(window, NULL);
+	hb_widget_visible(data->CM_minor, PREFS->euro_active);
 
 	return(window);
 }
 
+
 /*
 ** ============================================================================
 */
