@@ -195,8 +195,8 @@ Account *acc = value;
 	if( (acc->key == ctx->except_key) ) return;
 
 
-	//todo check this
-	if( (ctx->kcur > 0 ) && (acc->kcur != ctx->kcur) ) return;
+	//#1673260 this was for xfer with same currency only
+	//if( (ctx->kcur > 0 ) && (acc->kcur != ctx->kcur) ) return;
 	
     DB( g_print (" -> append model '%s'\n", acc->name) );
 	
@@ -233,11 +233,12 @@ struct accPopContext ctx;
 	/* clear and populate */
 	ctx.model = model;
 	ctx.except_key = except_key;
-	ctx.kcur = 0;
 	ctx.insert_type = insert_type;
-	Account *acc = da_acc_get(except_key);
-	if(acc != NULL)
-		ctx.kcur = acc->kcur;
+	//#1673260 xfer same currency
+	//ctx.kcur = 0;
+	//Account *acc = da_acc_get(except_key);
+	//if(acc != NULL)
+		//ctx.kcur = acc->kcur;
 	
 	gtk_list_store_clear (GTK_LIST_STORE(model));
 	//5.3 empty the entry
@@ -416,244 +417,43 @@ GtkCellRenderer *renderer;
 	if(label)
 		gtk_label_set_mnemonic_widget (GTK_LABEL(label), entry);
 
-	//gtk_widget_set_size_request(comboboxentry, HB_MINWIDTH_LIST, -1);
-
 	return mainbox;
 }
 
 
-
-
-
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
-
-/**
- * ui_acc_comboboxentry_get_key:
- * 
- * get the key of the active account
- * and create the account if it do not exists
- * 
- * Return value: the key or 0
- *
- */
-guint32
-ui_acc_comboboxentry_get_key(GtkComboBox *entry_box)
-{
-gchar *name;
-Account *item;
-
-	name = (gchar *)gtk_entry_get_text(GTK_ENTRY (gtk_bin_get_child(GTK_BIN (entry_box))));
-	item = da_acc_get_by_name(name);
-
-	if( item == NULL )
-	{
-		//todo: future : ask the user here		
-		return 0;
-	}
-
-	return item->key;
-}
-
-
-Account
-*ui_acc_comboboxentry_get(GtkComboBox *entry_box)
-{
-Account *item = NULL;
-gchar *name;
-
-	name = (gchar *)gtk_entry_get_text(GTK_ENTRY (gtk_bin_get_child(GTK_BIN (entry_box))));
-	item = da_acc_get_by_name(name);
-	return item;
-}
-
-
-gboolean
-ui_acc_comboboxentry_set_active(GtkComboBox *entry_box, guint32 key)
-{
-Account *item;
-
-	if( key > 0 )
-	{	
-		item = da_acc_get(key);
-		if( (item != NULL) )
-		{
-			gtk_entry_set_text(GTK_ENTRY (gtk_bin_get_child(GTK_BIN (entry_box))), item->name);
-			return TRUE;
-		}
-	}
-	gtk_entry_set_text(GTK_ENTRY (gtk_bin_get_child(GTK_BIN (entry_box))), "");
-	return FALSE;
-}
-
-
-/**
- * ui_acc_comboboxentry_add:
- * 
- * Add a single element (useful for dynamics add)
- * 
- * Return value: --
- *
- */
-void
-ui_acc_comboboxentry_add(GtkComboBox *entry_box, Account *acc)
-{
-	if( acc->name != NULL )
-	{
-	GtkTreeModel *model;
-	GtkTreeIter  iter;
-
-		model = gtk_combo_box_get_model(GTK_COMBO_BOX(entry_box));
-	
-		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
-		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
-			0, acc->name,
-			1, acc->pos,
-			-1);
-	}
-}
-
-
-static void
-ui_acc_comboboxentry_populate_ghfunc(gpointer key, gpointer value, struct accPopContext *ctx)
-{
-GtkTreeIter  iter;
-Account *acc = value;
-
-	if( (acc->flags & AF_CLOSED) ) return;
-	if( (ctx->insert_type == ACC_LST_INSERT_REPORT) && (acc->flags & AF_NOREPORT) ) return;
-	if( (acc->key == ctx->except_key) ) return;
-
-	//todo check this
-	if( (ctx->kcur > 0 ) && (acc->kcur != ctx->kcur) ) return;
-
-    DB( g_print (" -> append %s\n", acc->name) );
-	
-	
-	gtk_list_store_append (GTK_LIST_STORE(ctx->model), &iter);
-	gtk_list_store_set (GTK_LIST_STORE(ctx->model), &iter,
-			0, acc->name,
-			1, acc->pos,
-			-1);
-}
-
-/**
- * ui_acc_comboboxentry_populate:
- * 
- * Populate the list and completion
- * 
- * Return value: --
- *
- */
-void
-ui_acc_comboboxentry_populate(GtkComboBox *entry_box, GHashTable *hash, gint insert_type)
-{
-	ui_acc_comboboxentry_populate_except(entry_box, hash, 0, insert_type);
-}
-
-void
-ui_acc_comboboxentry_populate_except(GtkComboBox *entry_box, GHashTable *hash, guint except_key, gint insert_type)
+void ui_acc_listview_toggle_to_filter(GtkTreeView *treeview, Filter *filter)
 {
 GtkTreeModel *model;
-GtkEntryCompletion *completion;
-struct accPopContext ctx;
+GtkTreeIter iter;
+gboolean valid;
 
-    DB( g_print ("ui_acc_comboboxentry_populate\n") );
+	DB( g_print("(ui_acc_listview) toggle_to_filter\n") );
 
-    DB( g_print (" -> except is %d\n", except_key) );
+	model = gtk_tree_view_get_model(treeview);
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+	while (valid)
+	{
+	Account *item;
+	gboolean toggled;
 
-	model = gtk_combo_box_get_model(GTK_COMBO_BOX(entry_box));
-	completion = gtk_entry_get_completion(GTK_ENTRY (gtk_bin_get_child(GTK_BIN (entry_box))));
-	
-	/* keep our model alive and detach from comboboxentry and completion */
-	g_object_ref(model);
-	gtk_combo_box_set_model(GTK_COMBO_BOX(entry_box), NULL);
-	gtk_entry_completion_set_model (completion, NULL);
+		gtk_tree_model_get (model, &iter,
+			LST_DEFACC_TOGGLE, &toggled,
+			LST_DEFACC_DATAS , &item,
+			-1);
 
-	/* clear and populate */
-	ctx.model = model;
-	ctx.except_key = except_key;
-	ctx.kcur = 0;
-	ctx.insert_type = insert_type;
-	Account *acc = da_acc_get(except_key);
-	if(acc != NULL)
-		ctx.kcur = acc->kcur;
-	
-	gtk_list_store_clear (GTK_LIST_STORE(model));
-	//5.3 empty the entry
-	gtk_entry_set_text(GTK_ENTRY (gtk_bin_get_child(GTK_BIN (entry_box))), "");
-	g_hash_table_foreach(hash, (GHFunc)ui_acc_comboboxentry_populate_ghfunc, &ctx);
-
-	/* reatach our model */
-	gtk_combo_box_set_model(GTK_COMBO_BOX(entry_box), model);
-	gtk_entry_completion_set_model (completion, model);
-	g_object_unref(model);
-
-	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(model), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
+		DB( g_print(" acc k:%3d = %d (%s)\n", item->key, toggled, item->name) );
+		da_flt_status_acc_set(filter, item->key, toggled);
 	
+		/* Make iter point to the next row in the list store */
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+	}
 }
 
 
-static gint
-ui_acc_comboboxentry_compare_func (GtkTreeModel *model, GtkTreeIter  *a, GtkTreeIter  *b, gpointer      userdata)
-{
-gint pos1, pos2;
-  
-    gtk_tree_model_get(model, a, 1, &pos1, -1);
-    gtk_tree_model_get(model, b, 1, &pos2, -1);
-  	return (pos1 - pos2);
-}
 
 
-/**
- * ui_acc_comboboxentry_new:
- * 
- * Create a new account comboboxentry
- * 
- * Return value: the new widget
- *
- */
-GtkWidget *
-ui_acc_comboboxentry_new(GtkWidget *label)
-{
-GtkListStore *store;
-GtkWidget *comboboxentry;
-GtkEntryCompletion *completion;
-
-	store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_INT);
-	gtk_tree_sortable_set_default_sort_func(GTK_TREE_SORTABLE(store), ui_acc_comboboxentry_compare_func, NULL, NULL);
-	//gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), GTK_TREE_SORTABLE_DEFAULT_SORT_COLUMN_ID, GTK_SORT_ASCENDING);
-
-    completion = gtk_entry_completion_new ();
-    gtk_entry_completion_set_model (completion, GTK_TREE_MODEL(store));
-    gtk_entry_completion_set_text_column (completion, 0);
-
-/*	renderer = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (completion), renderer, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (completion), renderer, "text", 0, NULL);
-*/
-
-	comboboxentry = gtk_combo_box_new_with_model_and_entry(GTK_TREE_MODEL(store));
-	gtk_entry_set_completion (GTK_ENTRY (gtk_bin_get_child(GTK_BIN (comboboxentry))), completion);
-	gtk_combo_box_set_entry_text_column(GTK_COMBO_BOX(comboboxentry), 0);
-
-/*	gtk_cell_layout_clear(GTK_CELL_LAYOUT (comboboxentry));
-
-	renderer = gtk_cell_renderer_text_new ();
-	gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (comboboxentry), renderer, TRUE);
-	gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (comboboxentry), renderer, "text", 0, NULL);
-*/
-	g_object_unref(store);
-
-	if(label)
-		gtk_label_set_mnemonic_widget (GTK_LABEL(label), comboboxentry);
-
-	//gtk_widget_set_size_request(comboboxentry, HB_MINWIDTH_LIST, -1);
-	
-	return comboboxentry;
-}
-
-/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
 static void
@@ -679,9 +479,6 @@ gboolean fixed;
 
 	/* clean up */
 	gtk_tree_path_free (path);
-
-
-	g_signal_emit_by_name(gtk_tree_view_get_selection(treeview), "changed", NULL);
 }
 
 
@@ -732,9 +529,6 @@ ui_acc_listview_name_cell_data_function (GtkTreeViewColumn *col,
 {
 Account *entry;
 gchar *name;
-#if MYDEBUG
-gchar *string;
-#endif
 
 	gtk_tree_model_get(model, iter, LST_DEFACC_DATAS, &entry, -1);
 	if(entry->name == NULL)
@@ -742,17 +536,24 @@ gchar *string;
 	else
 		name = entry->name;
 
-	#if MYDEBUG
-		string = g_strdup_printf ("[%d] %s", entry->key, name );
-		g_object_set(renderer, "text", string, NULL);
-		g_free(string);
-	#else
-		g_object_set(renderer, "text", name, NULL);
-	#endif
-
+	g_object_set(renderer, "text", name, NULL);
 }
 
 
+#if MYDEBUG == 1
+static void
+ui_acc_listview_cell_data_function_debugkey (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{
+Account *item;
+gchar *string;
+
+	gtk_tree_model_get(model, iter, LST_DEFACC_DATAS, &item, -1);
+	string = g_strdup_printf ("[%d]", item->key );
+	g_object_set(renderer, "text", string, NULL);
+	g_free(string);
+}
+#endif	
+
 
 /* = = = = = = = = = = = = = = = = */
 
@@ -897,12 +698,45 @@ GtkTreeIter			 iter;
 }
 
 
-static gint ui_acc_glist_compare_func(Account *a, Account *b)
+void
+ui_acc_listview_quick_select(GtkTreeView *treeview, const gchar *uri)
 {
-	return ((gint)a->pos - b->pos);
+GtkTreeModel *model;
+GtkTreeIter	iter;
+gboolean valid;
+gboolean toggle;
+gint qselect = hb_clicklabel_to_int(uri);
+
+	DB( g_print("(ui_acc_listview) quick select\n") );
+
+
+	DB( g_print(" comboboxlink '%s' %d\n", uri, qselect) );
+
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+	while (valid)
+	{
+		switch(qselect)
+		{
+			case HB_LIST_QUICK_SELECT_ALL:
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, LST_DEFACC_TOGGLE, TRUE, -1);
+				break;
+			case HB_LIST_QUICK_SELECT_NONE:
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, LST_DEFACC_TOGGLE, FALSE, -1);
+				break;
+			case HB_LIST_QUICK_SELECT_INVERT:
+					gtk_tree_model_get (model, &iter, LST_DEFACC_TOGGLE, &toggle, -1);
+					toggle ^= 1;
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, LST_DEFACC_TOGGLE, toggle, -1);
+				break;
+		}
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+	}
 }
 
 
+static gint ui_acc_glist_compare_func(Account *a, Account *b) { return ((gint)a->pos - b->pos); }
+
 void ui_acc_listview_populate(GtkWidget *view, gint insert_type)
 {
 GtkTreeModel *model;
@@ -1011,6 +845,15 @@ GtkTreeViewColumn	*column;
 
 	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (treeview), PREFS->grid_lines);
 
+
+	#if MYDEBUG == 1
+	column = gtk_tree_view_column_new();
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ui_acc_listview_cell_data_function_debugkey, NULL, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
+	#endif
+
 	// column 1: toggle
 	if( withtoggle == TRUE )
 	{
@@ -1026,6 +869,8 @@ GtkTreeViewColumn	*column;
 		g_signal_connect (renderer, "toggled",
 			    G_CALLBACK (ui_acc_listview_toggled_cb), treeview);
 
+		g_object_set_data(G_OBJECT(treeview), "togrdr_data", renderer);
+
 	}
 
 	// column 2: name
@@ -1036,6 +881,8 @@ GtkTreeViewColumn	*column;
 	g_object_set(renderer, 
 		"ellipsize", PANGO_ELLIPSIZE_END,
 	    "ellipsize-set", TRUE,
+		//taken from nemo, not exactly a resize to content, but good compromise
+	    "width-chars", 40,
 	    NULL);
 
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
@@ -1168,54 +1015,54 @@ static gchar *dialog_get_name(gchar *title, gchar *origname, GtkWindow *parentwi
 {
 GtkWidget *dialog, *content, *mainvbox, *getwidget;
 gchar *retval = NULL;
-	
-		dialog = gtk_dialog_new_with_buttons (title,
-						    GTK_WINDOW (parentwindow),
-						    0,
-						    _("_Cancel"),
-						    GTK_RESPONSE_REJECT,
-						    _("_OK"),
-						    GTK_RESPONSE_ACCEPT,
-						    NULL);
 
-		content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
-	
-		mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
-		gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
-		gtk_container_set_border_width (GTK_CONTAINER (mainvbox), SPACING_SMALL);
+	dialog = gtk_dialog_new_with_buttons (title,
+					    GTK_WINDOW (parentwindow),
+					    0,
+					    _("_Cancel"),
+					    GTK_RESPONSE_REJECT,
+					    _("_OK"),
+					    GTK_RESPONSE_ACCEPT,
+					    NULL);
 
-		getwidget = gtk_entry_new();
-		gtk_entry_set_width_chars(GTK_ENTRY(getwidget), 24);
-		gtk_box_pack_start (GTK_BOX (mainvbox), getwidget, TRUE, TRUE, 0);
-		gtk_widget_show_all(mainvbox);
+	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
 
-		if(origname != NULL)
-			gtk_entry_set_text(GTK_ENTRY(getwidget), origname);
-		gtk_widget_grab_focus (getwidget);
+	mainvbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (mainvbox), SPACING_LARGE);
+	gtk_box_pack_start (GTK_BOX (content), mainvbox, TRUE, TRUE, 0);
 
-		gtk_entry_set_activates_default (GTK_ENTRY(getwidget), TRUE);
+	getwidget = gtk_entry_new();
+	gtk_entry_set_width_chars(GTK_ENTRY(getwidget), 24);
+	gtk_box_pack_start (GTK_BOX (mainvbox), getwidget, FALSE, FALSE, 0);
+	gtk_widget_show_all(mainvbox);
 
-		gtk_dialog_set_default_response(GTK_DIALOG( dialog ), GTK_RESPONSE_ACCEPT);
+	if(origname != NULL)
+		gtk_entry_set_text(GTK_ENTRY(getwidget), origname);
+	gtk_widget_grab_focus (getwidget);
 
-		//wait for the user
-		gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_entry_set_activates_default (GTK_ENTRY(getwidget), TRUE);
 
-		if(result == GTK_RESPONSE_ACCEPT)
+	gtk_dialog_set_default_response(GTK_DIALOG( dialog ), GTK_RESPONSE_ACCEPT);
+
+	//wait for the user
+	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	if(result == GTK_RESPONSE_ACCEPT)
+	{
+	const gchar *name;
+
+		name = gtk_entry_get_text(GTK_ENTRY(getwidget));
+
+		/* ignore if entry is empty */
+		if (name && *name)
 		{
-		const gchar *name;
+			retval = g_strdup(name);
+		}
+    }
 
-			name = gtk_entry_get_text(GTK_ENTRY(getwidget));
+	// cleanup and destroy
+	gtk_widget_destroy (dialog);
 
-			/* ignore if entry is empty */
-			if (name && *name)
-			{
-				retval = g_strdup(name);
-			}
-	    }
-
-		// cleanup and destroy
-		gtk_widget_destroy (dialog);
-	
 
 	return retval;
 }
@@ -1277,6 +1124,12 @@ Account *item;
 		bool = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_noreport));
 		if(bool) item->flags |= AF_NOREPORT;
 
+		//#1896441 outflow summary
+		item->flags &= ~(AF_OUTFLOWSUM);
+		bool = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_outflowsum));
+		if(bool) item->flags |= AF_OUTFLOWSUM;
+		
+		
 		gtk_spin_button_update(GTK_SPIN_BUTTON(data->ST_initial));
 		value = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_initial));
 		item->initial = value;
@@ -1382,6 +1235,8 @@ Account *item;
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_nobudget), item->flags & AF_NOBUDGET);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_nosummary), item->flags & AF_NOSUMMARY);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_noreport), item->flags & AF_NOREPORT);
+		//#1896441 outflow summary
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_outflowsum), item->flags & AF_OUTFLOWSUM);
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_closed), item->flags & AF_CLOSED);
 
 		gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_initial), item->initial);
@@ -1796,39 +1651,92 @@ gboolean doupdate = FALSE;
 static void ui_acc_manage_setup(struct ui_acc_manage_data *data)
 {
 GList *tmplist;
+GString *tpltitle;
 
 	DB( g_print("\n(ui_acc_manage_setup)\n") );
 
+	DB( g_print(" init data\n") );
+
 	//init GList
 	data->tmp_list = NULL; //hb-glist_clone_list(GLOBALS->acc_list, sizeof(struct _Account));
 	data->action = 0;
 	data->change = 0;
 	data->lastkey = 0;
 
+	DB( g_print(" populate\n") );
+
 	ui_acc_listview_populate(data->LV_acc, ACC_LST_INSERT_NORMAL);
 	ui_cur_combobox_populate(GTK_COMBO_BOX(data->CY_curr), GLOBALS->h_cur);
 	//populate_view_acc(data->LV_acc, GLOBALS->acc_list, TRUE);
 
 	ui_grp_comboboxentry_populate(GTK_COMBO_BOX(data->ST_group), GLOBALS->h_grp);
-	
+
+	//TODO: move to ui-archive
+	DB( g_print(" populate tpl start\n") );
+
+	//setting wrap causes O(n^2) performance regression because after
+	//every insert the drop-down list size is re-computed.
+	//gtk_combo_box_set_wrap_width(GTK_COMBO_BOX(data->CY_template), 0);
+
 	//populate template
 	hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(data->CY_template), 0, _("(none)"));
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_template), 0);
+
+	tpltitle = g_string_sized_new(255);
 
 	tmplist = g_list_first(GLOBALS->arc_list);
 	while (tmplist != NULL)
 	{
 	Archive *item = tmplist->data;
-
 		if( !(item->flags & OF_AUTO) )
 		{
-			hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(data->CY_template), item->key, item->memo);
+			da_archive_get_display_label(tpltitle, item);
+			hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(data->CY_template), item->key, tpltitle->str);
 		}
 		tmplist = g_list_next(tmplist);
 	}
+	
+	g_string_free(tpltitle, TRUE);
+
+	//gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_template), 0);
+	//gtk_combo_box_set_wrap_width(GTK_COMBO_BOX(data->CY_template), 1);
+
+	DB( g_print(" populate tpl end\n") );
+
+	//DB( g_print(" set widgets default\n") );
+
+	DB( g_print(" connect widgets signals\n") );
+
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_acc)), "changed", G_CALLBACK (ui_acc_manage_selection), NULL);
+	g_signal_connect (GTK_TREE_VIEW(data->LV_acc), "row-activated", G_CALLBACK (ui_acc_manage_rowactivated), GINT_TO_POINTER(2));
+
+	g_signal_connect (data->CY_curr  , "changed", G_CALLBACK (ui_acc_manage_changed_curr_cb), NULL);
+	g_signal_connect (data->CM_closed, "toggled", G_CALLBACK (ui_acc_manage_toggled_closed), NULL);
+	g_signal_connect (data->CM_nobudget, "toggled", G_CALLBACK (ui_acc_manage_toggled_nobudget), NULL);
+	
+	g_signal_connect (G_OBJECT (data->BT_add) , "clicked", G_CALLBACK (ui_acc_manage_add), NULL);
+	g_signal_connect (G_OBJECT (data->BT_edit), "clicked", G_CALLBACK (ui_acc_manage_rename), NULL);
+	g_signal_connect (G_OBJECT (data->BT_rem) , "clicked", G_CALLBACK (ui_acc_manage_delete), NULL);
 
 }
 
+
+static gboolean
+ui_acc_manage_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct ui_acc_manage_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n(ui_acc_manage_mapped)\n") );
+
+	ui_acc_manage_setup(data);
+	
+	ui_acc_manage_update(data->LV_acc, NULL);
+
+	return FALSE;
+}
+
+
 /*
 **
 */
@@ -1903,18 +1811,28 @@ gint w, h, dw, dh, row;
 	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
 	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
 	
-	widget = make_image_button(ICONNAME_LIST_ADD, _("Add"));
-	data->BT_add = widget;
-	gtk_container_add (GTK_CONTAINER(bbox), widget);
+		widget = make_image_button(ICONNAME_LIST_ADD, _("Add"));
+		data->BT_add = widget;
+		gtk_container_add (GTK_CONTAINER(bbox), widget);
 
-	widget = make_image_button(ICONNAME_LIST_EDIT, _("Rename"));
-	data->BT_edit = widget;
-	gtk_container_add (GTK_CONTAINER(bbox), widget);
+		widget = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
+		data->BT_rem = widget;
+		gtk_container_add (GTK_CONTAINER(bbox), widget);
+
+	toolitem = gtk_separator_tool_item_new ();
+	//gtk_tool_item_set_expand (toolitem, TRUE);
+	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+
+	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	toolitem = gtk_tool_item_new();
+	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+
+		widget = make_image_button(ICONNAME_LIST_EDIT, _("Rename"));
+		data->BT_edit = widget;
+		gtk_container_add (GTK_CONTAINER(bbox), widget);
 	
-	widget = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
-	data->BT_rem = widget;
-	gtk_container_add (GTK_CONTAINER(bbox), widget);
-
 	toolitem = gtk_separator_tool_item_new ();
 	gtk_tool_item_set_expand (toolitem, TRUE);
 	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
@@ -2042,6 +1960,13 @@ gint w, h, dw, dh, row;
 	gtk_widget_set_hexpand(widget, TRUE);
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 2, 1);
 
+/* test not working
+GValue gvalue = G_VALUE_INIT;
+
+	g_value_set_boolean (&gvalue, TRUE);
+	g_object_set_property(data->CY_template, "appears-as-list", &gvalue);
+*/
+
 
 	// group :: Report exclusion
     group_grid = gtk_grid_new ();
@@ -2057,6 +1982,12 @@ gint w, h, dw, dh, row;
 	data->CM_nosummary = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
 
+	//#1896441 outflow summary
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("outflow into summary"));
+	data->CM_outflowsum= widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 1, 1);
+	
 	row++;
 	widget = gtk_check_button_new_with_mnemonic (_("exclude from the _budget"));
 	data->CM_nobudget = widget;
@@ -2131,29 +2062,31 @@ gint w, h, dw, dh, row;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 2, row, 1, 1);
 	*/
 
-	//connect all our signals
-	g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_acc)), "changed", G_CALLBACK (ui_acc_manage_selection), NULL);
-	g_signal_connect (GTK_TREE_VIEW(data->LV_acc), "row-activated", G_CALLBACK (ui_acc_manage_rowactivated), GINT_TO_POINTER(2));
 
-	g_signal_connect (data->CY_curr  , "changed", G_CALLBACK (ui_acc_manage_changed_curr_cb), NULL);
-	g_signal_connect (data->CM_closed, "toggled", G_CALLBACK (ui_acc_manage_toggled_closed), NULL);
-	g_signal_connect (data->CM_nobudget, "toggled", G_CALLBACK (ui_acc_manage_toggled_nobudget), NULL);
-	
-	g_signal_connect (G_OBJECT (data->BT_add) , "clicked", G_CALLBACK (ui_acc_manage_add), NULL);
-	g_signal_connect (G_OBJECT (data->BT_edit), "clicked", G_CALLBACK (ui_acc_manage_rename), NULL);
-	g_signal_connect (G_OBJECT (data->BT_rem) , "clicked", G_CALLBACK (ui_acc_manage_delete), NULL);
+	// connect dialog signals
+	g_signal_connect (dialog, "destroy"  , G_CALLBACK (gtk_widget_destroyed), &dialog);
+	g_signal_connect (dialog, "map-event", G_CALLBACK (ui_acc_manage_mapped), &dialog);
 
+	// setup, init and show dialog
+	//moved to mapped-event
+	//g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_acc)), "changed", G_CALLBACK (ui_acc_manage_selection), NULL);
+	//g_signal_connect (GTK_TREE_VIEW(data->LV_acc), "row-activated", G_CALLBACK (ui_acc_manage_rowactivated), GINT_TO_POINTER(2));
+	//g_signal_connect (data->CY_curr  , "changed", G_CALLBACK (ui_acc_manage_changed_curr_cb), NULL);
+	//g_signal_connect (data->CM_closed, "toggled", G_CALLBACK (ui_acc_manage_toggled_closed), NULL);
+	//g_signal_connect (data->CM_nobudget, "toggled", G_CALLBACK (ui_acc_manage_toggled_nobudget), NULL);
+	//g_signal_connect (G_OBJECT (data->BT_add) , "clicked", G_CALLBACK (ui_acc_manage_add), NULL);
+	//g_signal_connect (G_OBJECT (data->BT_edit), "clicked", G_CALLBACK (ui_acc_manage_rename), NULL);
+	//g_signal_connect (G_OBJECT (data->BT_rem) , "clicked", G_CALLBACK (ui_acc_manage_delete), NULL);
 	//setup, init and show dialog
-	ui_acc_manage_setup(data);
-	ui_acc_manage_update(data->LV_acc, NULL);
+	//ui_acc_manage_setup(data);
+	//ui_acc_manage_update(data->LV_acc, NULL);
 
+	// show & run dialog
+	DB( g_print(" run dialog\n") );
 	gtk_widget_show_all (dialog);
-
-	//wait for the user
 	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
-	// cleanup and destroy
+	// cleanup & destroy
 	ui_acc_manage_cleanup(data, result);
 	gtk_widget_destroy (dialog);
 
