@@ -86,10 +86,13 @@ struct ui_acc_manage_data
 	//GtkWidget	*ST_warning;
 	GtkWidget	*ST_minimum;
 	GtkWidget	*ST_maximum;
+
 	GtkWidget	*CY_template;
 	GtkWidget	*CM_nosummary;
 	GtkWidget	*CM_nobudget;
 	GtkWidget	*CM_noreport;
+	GtkWidget	*CM_outflowsum;
+	
 	GtkWidget	*ST_cheque1;
 	GtkWidget	*ST_cheque2;
 };
@@ -99,7 +102,7 @@ struct accPopContext
 {
 	GtkTreeModel *model;
 	guint32	except_key;
-	guint32 kcur;
+	//guint32 kcur;
 	gint	insert_type;
 };
 
@@ -119,19 +122,14 @@ void ui_acc_entry_popover_set_single(GtkBox *box);
 void ui_acc_entry_popover_set_active(GtkBox *box, guint32 key);
 GtkWidget *ui_acc_entry_popover_new(GtkWidget *label);
 
-/* = = = = = = = = = = */
-
-gchar *ui_acc_comboboxentry_get_name(GtkComboBox *entry_box);
-guint32 ui_acc_comboboxentry_get_key(GtkComboBox *entry_box);
-Account *ui_acc_comboboxentry_get(GtkComboBox *entry_box);
-gboolean ui_acc_comboboxentry_set_active(GtkComboBox *entry_box, guint32 key);
-void ui_acc_comboboxentry_add(GtkComboBox *entry_box, Account *acc);
-void ui_acc_comboboxentry_populate(GtkComboBox *entry_box, GHashTable *hash, gint insert_type);
-void ui_acc_comboboxentry_populate_except(GtkComboBox *entry_box, GHashTable *hash, guint except_key, gint insert_type);
-GtkWidget *ui_acc_comboboxentry_new(GtkWidget *label);
 
 /* = = = = = = = = = = */
 
+void ui_acc_listview_toggle_to_filter(GtkTreeView *treeview, Filter *filter);
+
+void ui_acc_listview_quick_select(GtkTreeView *treeview, const gchar *uri);
+
+
 guint ui_acc_listview_fill_keys(GtkTreeView *treeview, guint32 *keys, guint32 *kcur);
 void ui_acc_listview_set_active(GtkTreeView *treeview, guint32 key);
 void ui_acc_listview_add(GtkTreeView *treeview, Account *item);
