@@ -59,7 +59,13 @@ extern gchar *CYA_TXN_TYPE[];
 
 
 
-static void list_tpl_select_by_pointer(GtkTreeView *treeview, gpointer user_data)
+
+
+/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
+
+
+
+static void ui_arc_listview_select_by_pointer(GtkTreeView *treeview, gpointer user_data)
 {
 GtkTreeModel *model;
 GtkTreeIter	iter;
@@ -94,7 +100,7 @@ Archive *arc = user_data;
 ** 0 if they are equal,
 ** or a positive integer if the first value comes after the second.
 */
-static gint list_tpl_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
+static gint ui_arc_listview_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
 gint sortcol = GPOINTER_TO_INT(userdata);
 Archive *item1, *item2;
@@ -168,7 +174,7 @@ gint retval = 0;
 
 
 static void 
-list_tpl_auto_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+ui_arc_listview_cell_data_function_auto (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *item;
 gchar *info, *iconname;
@@ -198,7 +204,7 @@ gchar *info, *iconname;
 
 
 static void
-list_tpl_date_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+ui_arc_listview_cell_data_function_date (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar buffer[256];
@@ -226,7 +232,7 @@ GDate *date;
 
 
 static void 
-list_tpl_cell_data_function_memo (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+ui_arc_listview_cell_data_function_memo (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar *text = NULL;
@@ -241,7 +247,7 @@ gchar *text = NULL;
 
 
 static void
-list_tpl_cell_data_function_payee (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+ui_arc_listview_cell_data_function_payee (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar *text = NULL;
@@ -259,7 +265,7 @@ gchar *text = NULL;
 
 
 static void
-list_tpl_cell_data_function_category (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+ui_arc_listview_cell_data_function_category (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar *text = NULL;
@@ -283,7 +289,7 @@ gchar *text = NULL;
 
 
 static void 
-list_tpl_cell_data_function_account (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+ui_arc_listview_cell_data_function_account (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gchar *text = NULL;
@@ -301,7 +307,7 @@ gchar *text = NULL;
 
 
 static void
-list_tpl_amount_cell_data_function (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+ui_arc_listview_cell_data_function_amount (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *arc;
 gdouble amount;
@@ -345,7 +351,7 @@ gint weight;
 
 #if MYDEBUG == 1
 static void
-list_tpl_cell_data_function_debugkey (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+ui_arc_listview_cell_data_function_debugkey (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
 {
 Archive *item;
 gchar *string;
@@ -359,7 +365,7 @@ gchar *string;
 
 
 static GtkTreeViewColumn *
-list_tpl_column_text_create(gchar *title, gint sortcolumnid, GtkTreeCellDataFunc func, gpointer user_data)
+ui_arc_listview_column_text_create(gchar *title, gint sortcolumnid, GtkTreeCellDataFunc func, gpointer user_data)
 {
 GtkTreeViewColumn  *column;
 GtkCellRenderer    *renderer;
@@ -389,13 +395,8 @@ GtkCellRenderer    *renderer;
 }
 
 
-
-
-
-
 //TODO: we could maybe merge this list with the scheduled list
-
-static GtkWidget *list_tpl_new(void)
+static GtkWidget *ui_arc_listview_new(void)
 {
 GtkListStore *store;
 GtkWidget *treeview;
@@ -405,9 +406,9 @@ GtkTreeViewColumn  *column;
 	//store
 	store = gtk_list_store_new (
 		NUM_LST_DEFARC,
-		G_TYPE_POINTER,
-		G_TYPE_UINT,
-		G_TYPE_BOOLEAN
+		G_TYPE_POINTER /* scheduled */
+//		G_TYPE_UINT,
+//		G_TYPE_BOOLEAN
 		);
 
 	//treeview
@@ -418,7 +419,10 @@ GtkTreeViewColumn  *column;
 
 
 	#if MYDEBUG == 1
-	column = list_tpl_column_text_create(NULL, 0, list_tpl_cell_data_function_debugkey, NULL);
+	column = gtk_tree_view_column_new();
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ui_arc_listview_cell_data_function_debugkey, NULL, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	#endif
 
@@ -427,7 +431,7 @@ GtkTreeViewColumn  *column;
 	renderer = gtk_cell_renderer_pixbuf_new ();
 	//gtk_cell_renderer_set_fixed_size(renderer, GLOBALS->lst_pixbuf_maxwidth, -1);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_tpl_auto_cell_data_function, GINT_TO_POINTER(1), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ui_arc_listview_cell_data_function_auto, GINT_TO_POINTER(1), NULL);
 
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, 
@@ -437,7 +441,8 @@ GtkTreeViewColumn  *column;
 	    "width-chars", 40,
 	    NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_tpl_auto_cell_data_function, GINT_TO_POINTER(2), NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ui_arc_listview_cell_data_function_auto, GINT_TO_POINTER(2), NULL);
+	gtk_tree_view_column_set_spacing(column, SPACING_TINY);
 	
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
@@ -447,21 +452,21 @@ GtkTreeViewColumn  *column;
 	column = gtk_tree_view_column_new();
 	gtk_tree_view_column_set_title(column, _("Next date"));
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_tpl_date_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ui_arc_listview_cell_data_function_date, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DEFARC_SORT_DATE);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
 	/* column: Payee */
-	column = list_tpl_column_text_create(_("Payee"), LST_DEFARC_SORT_PAYEE, list_tpl_cell_data_function_payee, NULL);
+	column = ui_arc_listview_column_text_create(_("Payee"), LST_DEFARC_SORT_PAYEE, ui_arc_listview_cell_data_function_payee, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	/* column: Category */
-	column = list_tpl_column_text_create(_("Category"), LST_DEFARC_SORT_CATEGORY, list_tpl_cell_data_function_category, NULL);
+	column = ui_arc_listview_column_text_create(_("Category"), LST_DEFARC_SORT_CATEGORY, ui_arc_listview_cell_data_function_category, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
 	/* column: Memo */
-	column = list_tpl_column_text_create(_("Memo"), LST_DEFARC_SORT_MEMO, list_tpl_cell_data_function_memo, NULL);
+	column = ui_arc_listview_column_text_create(_("Memo"), LST_DEFARC_SORT_MEMO, ui_arc_listview_cell_data_function_memo, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
 	/* column : amount */
@@ -470,13 +475,13 @@ GtkTreeViewColumn  *column;
 	renderer = gtk_cell_renderer_text_new ();
 	g_object_set(renderer, "xalign", 1.0, NULL);
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
-	gtk_tree_view_column_set_cell_data_func(column, renderer, list_tpl_amount_cell_data_function, NULL, NULL);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ui_arc_listview_cell_data_function_amount, NULL, NULL);
 	gtk_tree_view_column_set_sort_column_id (column, LST_DEFARC_SORT_AMOUNT);
 	gtk_tree_view_column_set_alignment (column, 0.5);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 	
 	/* column : Account */
-	column = list_tpl_column_text_create(_("Account"), LST_DEFARC_SORT_ACCOUNT, list_tpl_cell_data_function_account, NULL);
+	column = ui_arc_listview_column_text_create(_("Account"), LST_DEFARC_SORT_ACCOUNT, ui_arc_listview_cell_data_function_account, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
   	/* column : empty */
@@ -484,12 +489,12 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
 	//sortable
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_DATE, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_DATE), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_MEMO, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_MEMO), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_PAYEE, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_PAYEE), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_CATEGORY, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_CATEGORY), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_AMOUNT, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_AMOUNT), NULL);
-	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_ACCOUNT, list_tpl_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_ACCOUNT), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_DATE, ui_arc_listview_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_DATE), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_MEMO, ui_arc_listview_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_MEMO), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_PAYEE, ui_arc_listview_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_PAYEE), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_CATEGORY, ui_arc_listview_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_CATEGORY), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_AMOUNT, ui_arc_listview_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_AMOUNT), NULL);
+	gtk_tree_sortable_set_sort_func(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_ACCOUNT, ui_arc_listview_compare_func, GINT_TO_POINTER(LST_DEFARC_SORT_ACCOUNT), NULL);
 
 	gtk_tree_sortable_set_sort_column_id(GTK_TREE_SORTABLE(store), LST_DEFARC_SORT_MEMO, GTK_SORT_ASCENDING);
 
@@ -652,7 +657,7 @@ gint i, typsch, typtpl;
 			{
 				gtk_list_store_insert_with_values (GTK_LIST_STORE(model), &iter, -1,
 					LST_DEFARC_DATAS, item,	//data struct
-					LST_DEFARC_OLDPOS, i,		//oldpos
+//					LST_DEFARC_OLDPOS, i,		//oldpos
 					-1);
 			}
 		}
@@ -718,7 +723,7 @@ gboolean result;
 		gtk_list_store_append (GTK_LIST_STORE(model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE(model), &iter,
 			LST_DEFARC_DATAS, item,
-			LST_DEFARC_OLDPOS, 0,
+//			LST_DEFARC_OLDPOS, 0,
 			-1);
 
 		gtk_tree_selection_select_iter (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_arc)), &iter);
@@ -891,7 +896,10 @@ gboolean active;
 		item->limit   = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(data->NB_limit));
 
 		item->weekend = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_weekend));
-		
+
+		//#1906953 add ignore weekend
+		scheduled_nextdate_weekend_adjust(item);
+
 		data->change++;
 	}	
 }
@@ -928,6 +936,29 @@ gboolean selected;
 }
 
 
+
+static gboolean ui_arc_manage_cb_on_key_press(GtkWidget *source, GdkEventKey *event, gpointer user_data)
+{
+struct ui_arc_manage_data *data = user_data;
+
+	// On Control-f enable search entry
+	if (event->state & GDK_CONTROL_MASK
+		&& event->keyval == GDK_KEY_f)
+	{
+		gtk_widget_grab_focus(data->ST_search);
+	}
+	else
+	if (event->keyval == GDK_KEY_Escape && gtk_widget_has_focus(data->ST_search))
+	{
+		hbtk_entry_set_text(GTK_ENTRY(data->ST_search), NULL);
+		gtk_widget_grab_focus(data->LV_arc);
+		return TRUE;
+	}
+
+	return GDK_EVENT_PROPAGATE;
+}
+
+
 static void
 ui_arc_manage_cb_selection_changed(GtkTreeSelection *treeselection, gpointer user_data)
 {
@@ -992,15 +1023,61 @@ ui_arc_manage_setup(struct ui_arc_manage_data *data)
 
 	DB( g_print("\n[ui_scheduled] setup\n") );
 
+	DB( g_print(" init data\n") );
+
 	//init GList
 	data->tmp_list = NULL; //hb-glist_clone_list(GLOBALS->arc_list, sizeof(struct _Archive));
 	data->change = 0;
 
-	//hb-glist_populate_treeview(data->tmp_list, data->LV_arc, LST_DEFARC_DATAS, LST_DEFARC_OLDPOS);
+	//DB( g_print(" populate\n") );
 
-	//insert all glist item into treeview
-	ui_arc_manage_populate_listview(data); 
+	DB( g_print(" set widgets default\n") );
+
+	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_unit), 2);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->BT_typsch), TRUE);
+
+	DB( g_print(" connect widgets signals\n") );
+
+	g_signal_connect (data->BT_typsch, "toggled", G_CALLBACK (ui_arc_manage_cb_flttype_changed), data);
+	g_signal_connect (data->BT_typtpl, "toggled", G_CALLBACK (ui_arc_manage_cb_flttype_changed), data);
+
+	gtk_tree_view_set_search_entry(GTK_TREE_VIEW(data->LV_arc), GTK_ENTRY(data->ST_search));
+
+	g_signal_connect (data->ST_search, "search-changed", G_CALLBACK (ui_arc_manage_cb_flttype_changed), data);
 	
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_arc)), "changed", G_CALLBACK (ui_arc_manage_cb_selection_changed), NULL);
+	g_signal_connect (data->LV_arc, "row-activated", G_CALLBACK (ui_arc_manage_cb_row_activated), NULL);
+
+	g_signal_connect (data->BT_add , "clicked", G_CALLBACK (ui_arc_manage_cb_add_clicked), NULL);
+	g_signal_connect (data->BT_edit, "clicked", G_CALLBACK (ui_arc_manage_cb_edit_clicked), NULL);
+	g_signal_connect (data->BT_rem , "clicked", G_CALLBACK (ui_arc_manage_cb_delete_clicked), NULL);
+
+	g_signal_connect (data->PO_schedule, "closed", G_CALLBACK (ui_arc_manage_cb_popover_closed), NULL);
+	
+	g_signal_connect (data->CM_auto,  "notify::active", G_CALLBACK (ui_arc_manage_cb_schedule_changed), NULL);
+	g_signal_connect (data->CM_limit, "toggled", G_CALLBACK (ui_arc_manage_cb_schedule_changed), NULL);
+
+	if(data->ext_arc != NULL)
+		ui_arc_listview_select_by_pointer(GTK_TREE_VIEW(data->LV_arc), data->ext_arc);
+
+}
+
+
+static gboolean
+ui_arc_manage_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct ui_arc_manage_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n(ui_arc_manage_mapped)\n") );
+
+	ui_arc_manage_setup(data);
+	ui_arc_manage_populate_listview(data);
+	ui_arc_manage_update(data->LV_arc, NULL);
+	gtk_widget_grab_focus(GTK_WIDGET(data->LV_arc));
+
+	return FALSE;
 }
 
 
@@ -1104,15 +1181,16 @@ gint w, h, dw, dh;
 
 	data = g_malloc0(sizeof(struct ui_arc_manage_data));
 	if(!data) return NULL;
-	
+
 	dialog = gtk_dialog_new_with_buttons (_("Manage scheduled/template transactions"),
-					    GTK_WINDOW(GLOBALS->mainwindow),
-					    0,
-					    _("_Close"),
-					    GTK_RESPONSE_ACCEPT,
-					    NULL);
+				GTK_WINDOW(GLOBALS->mainwindow),
+				0,
+		    	_("_Close"),
+			    GTK_RESPONSE_ACCEPT,
+			    NULL);
 
 	data->dialog = dialog;
+	data->ext_arc = ext_arc;
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
@@ -1168,7 +1246,7 @@ gint w, h, dw, dh;
 	//#1970509 enable hscrollbar
 	//gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scrollwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	treeview = (GtkWidget *)list_tpl_new();
+	treeview = (GtkWidget *)ui_arc_listview_new();
 	data->LV_arc = treeview;
 	gtk_widget_set_size_request(treeview, HB_MINWIDTH_LIST, -1);
 	gtk_container_add(GTK_CONTAINER(scrollwin), treeview);
@@ -1184,12 +1262,25 @@ gint w, h, dw, dh;
 	toolitem = gtk_tool_item_new();
 	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
 	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
-	
-	//widget = gtk_button_new_with_mnemonic(_("_Add"));
-	widget = make_image_button(ICONNAME_LIST_ADD, _("Add"));
-	data->BT_add = widget;
-	gtk_container_add (GTK_CONTAINER(bbox), widget);
-	
+
+		widget = make_image_button(ICONNAME_LIST_ADD, _("Add"));
+		data->BT_add = widget;
+		gtk_container_add (GTK_CONTAINER(bbox), widget);
+
+		widget = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
+		data->BT_rem = widget;
+		gtk_container_add (GTK_CONTAINER(bbox), widget);
+
+	toolitem = gtk_separator_tool_item_new ();
+	//gtk_tool_item_set_expand (toolitem, TRUE);
+	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+
+	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	toolitem = gtk_tool_item_new();
+	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+
 	//widget = gtk_button_new_with_mnemonic(_("_Edit"));
 	widget = make_image_button(ICONNAME_LIST_EDIT, _("Edit"));
 	data->BT_edit = widget;
@@ -1212,80 +1303,24 @@ gint w, h, dw, dh;
 	gtk_container_add(GTK_CONTAINER(menubutton), box);
 	GtkWidget *template = ui_arc_manage_create_scheduling(data);
 	GtkWidget *popover = create_popover (menubutton, template, GTK_POS_TOP);
+	data->PO_schedule = popover;
 	gtk_menu_button_set_popover(GTK_MENU_BUTTON(menubutton), popover);
 	
-	//widget = gtk_button_new_with_mnemonic(_("_Delete"));
-	widget = make_image_button(ICONNAME_LIST_DELETE, _("_Delete"));
-	data->BT_rem = widget;
-	gtk_container_add (GTK_CONTAINER(bbox), widget);
-	
-	toolitem = gtk_separator_tool_item_new ();
-	gtk_tool_item_set_expand (toolitem, TRUE);
-	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
-	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
 
-	//toolitem = gtk_tool_item_new();
-	//gtk_container_add (GTK_CONTAINER(toolitem), widget);
-	//gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
-
-	toolitem = gtk_separator_tool_item_new ();
-	gtk_tool_item_set_expand (toolitem, TRUE);
-	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
-	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
-
-
-	
-	/* set default periodicity to month */
-	//todo: move elsewhere
-	gtk_combo_box_set_active(GTK_COMBO_BOX(data->CY_unit), 2);
-	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->BT_typsch), TRUE);
-
-	gtk_widget_show_all(content);
-
-	//connect all our signals
+	// connect dialog signals
 	g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
+	g_signal_connect (dialog, "map-event", G_CALLBACK (ui_arc_manage_mapped), &dialog);
+	g_signal_connect (dialog, "key-press-event", G_CALLBACK (ui_arc_manage_cb_on_key_press), (gpointer)data);
 
-	g_signal_connect (data->BT_typsch, "toggled", G_CALLBACK (ui_arc_manage_cb_flttype_changed), data);
-	g_signal_connect (data->BT_typtpl, "toggled", G_CALLBACK (ui_arc_manage_cb_flttype_changed), data);
 
-	g_signal_connect (data->ST_search, "search-changed", G_CALLBACK (ui_arc_manage_cb_flttype_changed), data);
-	
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_arc)), "changed", G_CALLBACK (ui_arc_manage_cb_selection_changed), NULL);
-	g_signal_connect (data->LV_arc, "row-activated", G_CALLBACK (ui_arc_manage_cb_row_activated), NULL);
-
-	g_signal_connect (data->BT_add , "clicked", G_CALLBACK (ui_arc_manage_cb_add_clicked), NULL);
-	g_signal_connect (data->BT_edit, "clicked", G_CALLBACK (ui_arc_manage_cb_edit_clicked), NULL);
-	g_signal_connect (data->BT_rem , "clicked", G_CALLBACK (ui_arc_manage_cb_delete_clicked), NULL);
-
-	g_signal_connect (popover, "closed", G_CALLBACK (ui_arc_manage_cb_popover_closed), NULL);
-	
-	g_signal_connect (data->CM_auto,  "notify::active", G_CALLBACK (ui_arc_manage_cb_schedule_changed), NULL);
-	g_signal_connect (data->CM_limit, "toggled", G_CALLBACK (ui_arc_manage_cb_schedule_changed), NULL);
-	
-	//setup, init and show dialog
-	ui_arc_manage_setup(data);
-	ui_arc_manage_update(data->LV_arc, NULL);
-	gtk_widget_grab_focus(GTK_WIDGET(data->LV_arc));
-
-	
+	// show & run dialog
+	DB( g_print(" run dialog\n") );
+	gtk_widget_show_all(content);
 	gtk_widget_show (dialog);
 
-	if(ext_arc != NULL)
-		list_tpl_select_by_pointer(GTK_TREE_VIEW(data->LV_arc), ext_arc);
-
 	// wait for the user
 	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
 
-	switch (result)
-    {
-	case GTK_RESPONSE_ACCEPT:
-	   //do_application_specific_something ();
-	   break;
-	default:
-	   //do_nothing_since_dialog_was_cancelled ();
-	   break;
-    }
-
 	// cleanup and destroy
 	ui_arc_manage_cleanup(data, result);
 	gtk_widget_destroy (dialog);
