@@ -43,15 +43,16 @@ struct ui_arc_manage_data
 {
 	GtkWidget	*dialog;
 
-	GList	*tmp_list;
-	gint	change;
+	GList		*tmp_list;
+	gint		change;
+	Archive		*ext_arc;
 
 	GtkWidget	*BT_typsch, *BT_typtpl;
 	GtkWidget	*ST_search;
 	GtkWidget	*LV_arc;
 	GtkWidget	*BT_add, *BT_edit, *BT_rem;
 
-	GtkWidget	*MB_schedule;
+	GtkWidget	*MB_schedule, *PO_schedule;
 	
 	GtkWidget	*CM_auto;
 	GtkWidget	*LB_next, *PO_next;
