@@ -20,6 +20,16 @@
 #ifndef __HB_ASSIGN_GTK_H__
 #define __HB_ASSIGN_GTK_H__
 
+
+enum {
+	LST_DEFASG_SORT_POS = 1,
+	LST_DEFASG_SORT_SEARCH,
+	LST_DEFASG_SORT_PAYEE,
+	LST_DEFASG_SORT_CATEGORY,
+	LST_DEFASG_SORT_NOTES
+};
+
+
 enum
 {
 	LST_DEFASG_TOGGLE,
@@ -27,42 +37,22 @@ enum
 	NUM_LST_DEFASG
 };
 
-gchar *ui_asg_comboboxentry_get_name(GtkComboBox *entry_box);
-guint32 ui_asg_comboboxentry_get_key(GtkComboBox *entry_box);
-gboolean ui_asg_comboboxentry_set_active(GtkComboBox *entry_box, guint32 key);
-void ui_asg_comboboxentry_add(GtkComboBox *entry_box, Assign *asg);
-void ui_asg_comboboxentry_populate(GtkComboBox *entry_box, GHashTable *hash);
-void ui_asg_comboboxentry_populate_except(GtkComboBox *entry_box, GHashTable *hash, guint except_key);
-GtkWidget *ui_asg_comboboxentry_new(GtkWidget *label);
 
-/* = = = = = = = = = = */
-
-void ui_asg_listview_add(GtkTreeView *treeview, Assign *item);
-guint32 ui_asg_listview_get_selected_key(GtkTreeView *treeview);
-void ui_asg_listview_remove_selected(GtkTreeView *treeview);
-void ui_asg_listview_populate(GtkWidget *view);
-GtkWidget *ui_asg_listview_new(gboolean withtoggle);
-
-/* = = = = = = = = = = */
-
-struct ui_asg_manage_data
+struct ui_asg_dialog_data
 {
-	GList	*tmp_list;
+	//GList	*tmp_list;
+	Assign  *asgitem;
 	gint	change;
-	gint	action;
-	guint32	lastkey;
 
 	GtkWidget	*dialog;
 
-	GtkWidget	*LV_rul;
-	GtkWidget	*BT_add, *BT_rem;
-
 	GtkWidget   *GR_condition;
 	GtkWidget   *CY_field;
 	GtkWidget	*ST_search;
 	GtkWidget	*GR_wrntxt, *LB_wrntxt;
 	GtkWidget	*CM_exact;
 	GtkWidget	*CM_re;
+	GtkWidget	*CM_amount, *LB_amount, *ST_amount;
 
 	GtkWidget   *GR_assignment;
 	GtkWidget	*RA_pay;
@@ -79,6 +69,23 @@ struct ui_asg_manage_data
 
 	GtkWidget   *GR_misc;
 	GtkWidget	*ST_notes;
+
+};
+
+
+struct ui_asg_manage_data
+{
+	GList	*tmp_list;
+	gint	change;
+
+	GtkWidget	*dialog;
+
+	GtkWidget	*ST_search;
+	GtkWidget	*LV_rul;
+	GtkWidget	*BT_add, *BT_rem, *BT_edit, *BT_up, *BT_down, *BT_move;
+
+	GtkWidget	*MB_moveto, *ST_poppos, *BT_popmove;
+
 };
 
 
@@ -89,6 +96,23 @@ struct rulPopContext
 };
 
 
+gchar *ui_asg_comboboxentry_get_name(GtkComboBox *entry_box);
+guint32 ui_asg_comboboxentry_get_key(GtkComboBox *entry_box);
+gboolean ui_asg_comboboxentry_set_active(GtkComboBox *entry_box, guint32 key);
+void ui_asg_comboboxentry_add(GtkComboBox *entry_box, Assign *asg);
+void ui_asg_comboboxentry_populate(GtkComboBox *entry_box, GHashTable *hash);
+void ui_asg_comboboxentry_populate_except(GtkComboBox *entry_box, GHashTable *hash, guint except_key);
+GtkWidget *ui_asg_comboboxentry_new(GtkWidget *label);
+
+/* = = = = = = = = = = */
+
+void ui_asg_listview_add(GtkTreeView *treeview, Assign *item);
+guint32 ui_asg_listview_get_selected_key(GtkTreeView *treeview);
+void ui_asg_listview_remove_selected(GtkTreeView *treeview);
+void ui_asg_listview_populate(GtkWidget *view, gchar *needle);
+GtkWidget *ui_asg_listview_new(gboolean withtoggle);
+
+/* = = = = = = = = = = */
 
 GtkWidget *ui_asg_manage_dialog (void);
 
