@@ -235,17 +235,27 @@ GenTxn *item;
 }
 
 
-static void list_txn_importfixed_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer data)
+static void list_txn_importfixed_toggled (GtkCellRendererToggle *cell, gchar *path_str, gpointer userdata)
 {
-GtkTreeModel *model = (GtkTreeModel *)data;
+GtkTreeView *treeview;
+GtkTreeModel *model;
 GtkTreeIter  iter;
 GtkTreePath *path = gtk_tree_path_new_from_string (path_str);
 GenTxn *gentxn;
 
+	g_return_if_fail(GTK_IS_TREE_VIEW(userdata));
+
+	treeview = userdata;
+	model = gtk_tree_view_get_model(treeview);
+
 	gtk_tree_model_get_iter (model, &iter, path);
 	gtk_tree_model_get (model, &iter, LST_GENTXN_POINTER, &gentxn, -1);
 	gentxn->to_import ^= 1;
 	gtk_tree_path_free (path);
+
+	//#1993727 no update after toggle
+	//fake a treeview changed signal
+	g_signal_emit_by_name(gtk_tree_view_get_selection(treeview), "changed", NULL);
 }
 
 
@@ -340,7 +350,7 @@ GtkTreeViewColumn  *column;
 	gtk_tree_view_column_pack_start(column, renderer, TRUE);
 	gtk_tree_view_column_set_cell_data_func(column, renderer, list_txn_cell_data_function_toggle, NULL, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
-	g_signal_connect (renderer, "toggled", G_CALLBACK (list_txn_importfixed_toggled), store);
+	g_signal_connect (renderer, "toggled", G_CALLBACK (list_txn_importfixed_toggled), treeview);
 
 	// icons
 	column = gtk_tree_view_column_new();
@@ -971,6 +981,53 @@ static ImpTxnData *ui_import_page_transaction_data_get(GArray *txndata, guint32
 }
 
 
+//#1993727 no update after toggle
+static void ui_import_page_transaction_update_count(struct import_data *data)
+{
+ImpTxnData *txndata;
+ImportContext *ictx;
+gchar *label = NULL;
+GtkTreeModel *model;
+GtkTreeIter	iter;
+gboolean valid;
+gint count;
+
+	DB( g_print("\n[ui-import] txn update count\n") );
+
+	ictx = &data->ictx;
+
+	//get the account, it will be the account into the glist
+	gint acckey = gtk_assistant_get_current_page(GTK_ASSISTANT(data->assistant)) - (PAGE_IMPORT);
+	GenAcc *genacc = da_gen_acc_get_by_key(ictx->gen_lst_acc, acckey);
+	txndata = ui_import_page_transaction_data_get(data->txndata, acckey);
+
+	//count gentxn total and toimport
+	count = 0;
+	genacc->n_txnimp = 0;
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(txndata->LV_gentxn));
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+	while (valid)
+	{
+	GenTxn *gentxn;
+
+		gtk_tree_model_get(model, &iter, 
+			LST_GENTXN_POINTER, &gentxn, 
+			-1);
+
+		count++;
+		if(gentxn->to_import)
+			genacc->n_txnimp++;
+
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+	}
+
+	if(genacc->n_txnsimimp || genacc->n_txnsimdst)
+		label = g_strdup_printf(_("%d transaction(s), %d similar, %d existing, %d selected"), count, genacc->n_txnsimimp, genacc->n_txnsimdst, genacc->n_txnimp);	
+	else
+		label = g_strdup_printf(_("%d transaction(s), %d selected"), count, genacc->n_txnimp);
+	gtk_label_set_markup (GTK_LABEL(txndata->LB_txn_title), label);
+	g_free(label);
+}
 
 
 static void ui_import_page_transaction_cb_fill_same(GtkTreeSelection *treeselection, gpointer user_data)
@@ -1000,8 +1057,11 @@ guint count = 0;
 	//txndata = &data->txndata[acckey];
 	txndata = ui_import_page_transaction_data_get(data->txndata, acckey);
 
+	ui_import_page_transaction_update_count(data);
+
+	//update same
 	dupmodel = gtk_tree_view_get_model(GTK_TREE_VIEW(txndata->LV_duptxn));
-	gtk_list_store_clear (GTK_LIST_STORE(dupmodel));
+	gtk_tree_store_clear (GTK_TREE_STORE(dupmodel));
 
 	selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(txndata->LV_gentxn));
 
@@ -1024,7 +1084,7 @@ guint count = 0;
 				//gtk_list_store_set (GTK_LIST_STORE(dupmodel), &newiter,
 				//#1830523/#1840393
 				count++;
-				gtk_list_store_insert_with_values(GTK_LIST_STORE(dupmodel), &newiter, -1,
+				gtk_tree_store_insert_with_values(GTK_TREE_STORE(dupmodel), &newiter, NULL, -1,
 					MODEL_TXN_POINTER, tmp,
 				    MODEL_TXN_SPLITAMT, tmp->amount,
 					-1);
@@ -1302,7 +1362,7 @@ gboolean visible;
 		{
 		GenTxn *item = tmplist->data;
 
-			//todo: chnage this, this should be account
+			//todo: change this, this should be account
 			if(item->kacc == genacc->key)
 			{
 				// append to our treeview
@@ -1330,19 +1390,16 @@ gboolean visible;
 
 		label = g_strdup_printf(_("Name: %s\nNumber: %s\nFile: %s\nEncoding: %s"), genacc->name, genacc->number, genfile->filepath, genfile->encoding);
 		gtk_widget_set_tooltip_text (GTK_WIDGET(txndata->LB_acc_title), label);
+		gtk_widget_set_tooltip_text (GTK_WIDGET(txndata->LB_acc_info), label);
 		g_free(label);
 		
 		//label = g_strdup_printf(_("Account %d of %d"), acckey+1, nbacc);
 		//gtk_label_set_markup (GTK_LABEL(txndata->LB_acc_count), label);
 		//g_free(label);
 
-		if(genacc->n_txnsimimp || genacc->n_txnsimdst)
-			label = g_strdup_printf(_("%d transaction(s), %d similar, %d existing, %d selected"), count, genacc->n_txnsimimp, genacc->n_txnsimdst, genacc->n_txnimp);	
-		else
-			label = g_strdup_printf(_("%d transaction(s), %d selected"), count, genacc->n_txnimp);
-		gtk_label_set_markup (GTK_LABEL(txndata->LB_txn_title), label);
-		g_free(label);
-		
+		//#1993727 no update after toggle
+		ui_import_page_transaction_update_count(data);
+
 		visible = (genacc->filetype == FILETYPE_OFX) ? FALSE : TRUE;
 		hb_widget_visible(GTK_WIDGET(txndata->GR_date), visible);
 		
@@ -1566,14 +1623,21 @@ gchar *txt;
 static gboolean
 ui_import_page_transaction_cb_activate_link (GtkWidget *label, const gchar *uri, gpointer user_data)
 {
+struct import_data *data;
+ImpTxnData *txndata;
 GtkTreeModel *model;
 GtkTreeIter	iter;
 gboolean valid;
 guint action;
 	
-	g_return_val_if_fail(GTK_IS_TREE_VIEW(user_data), TRUE);
+	//g_return_val_if_fail(GTK_IS_TREE_VIEW(user_data), TRUE);
 
-	model = gtk_tree_view_get_model(GTK_TREE_VIEW(user_data));
+	data = user_data;
+
+	gint acckey = gtk_assistant_get_current_page(GTK_ASSISTANT(data->assistant)) - (PAGE_IMPORT);
+	txndata = ui_import_page_transaction_data_get(data->txndata, acckey);	
+	
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(txndata->LV_gentxn));
 
 	DB( g_print(" comboboxlink '%s' \n", uri) );
 
@@ -1610,7 +1674,9 @@ guint action;
 		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
 	}
 
-	gtk_widget_queue_draw(GTK_WIDGET(user_data));
+	gtk_widget_queue_draw(GTK_WIDGET(txndata->LV_gentxn));
+
+	ui_import_page_transaction_update_count(data);
 
     return TRUE;
 }
@@ -1646,6 +1712,11 @@ gint row;
 	//gtk_widget_set_hexpand(box, TRUE);
 	gtk_grid_attach (GTK_GRID(table), box, 0, row, 1, 1);
 
+		//5.6 info icon
+		widget = gtk_image_new_from_icon_name (ICONNAME_INFO, GTK_ICON_SIZE_BUTTON);
+		txndata->LB_acc_info = widget;
+		gtk_box_pack_start (GTK_BOX (box), widget, FALSE, FALSE, 0);
+
 		// XXX (type) + accname
 		label = make_label(NULL, 0.0, 0.5);
 		txndata->LB_acc_title = label;
@@ -1716,7 +1787,7 @@ gint row;
 
 	// n transaction ...
 	row++;
-	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
+	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_MEDIUM);
 	//gtk_widget_set_hexpand(box, TRUE);
 	gtk_grid_attach (GTK_GRID(table), box, 0, row, 1, 1);
 	
@@ -1744,10 +1815,10 @@ gint row;
 			gtk_box_pack_start (GTK_BOX (group), label, FALSE, FALSE, 0);
 
 	
-			label = make_label(NULL, 0.5, 0.5);
-			txndata->LB_txn_title = label;
-			//gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
-			gtk_box_pack_start (GTK_BOX (group), label, FALSE, FALSE, 0);
+		label = make_label(NULL, 0.5, 0.5);
+		txndata->LB_txn_title = label;
+		//gtk_widget_set_valign(label, GTK_ALIGN_CENTER);
+		gtk_box_pack_start (GTK_BOX (box), label, TRUE, TRUE, 0);
 
 	// import into
 	box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
@@ -1812,7 +1883,7 @@ gint row;
 		gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrollwin), GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
 		gtk_widget_set_hexpand(scrollwin, TRUE);
 		//widget = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_ope_columns);
-		widget = create_list_transaction(LIST_TXN_TYPE_DETAIL, PREFS->lst_impope_columns);
+		widget = create_list_transaction(LIST_TXN_TYPE_IMPOPE, PREFS->lst_impope_columns);
 		txndata->LV_duptxn = widget;
 		gtk_container_add (GTK_CONTAINER (scrollwin), widget);
 		gtk_widget_set_size_request(scrollwin, -1, HB_MINWIDTH_LIST/2);
@@ -1859,10 +1930,11 @@ gint row;
 	gtk_widget_hide(txndata->GR_qif);
 	gtk_widget_hide(txndata->GR_ofx);
 
-	g_signal_connect (txndata->BT_all, "activate-link", G_CALLBACK (ui_import_page_transaction_cb_activate_link), txndata->LV_gentxn);
-	g_signal_connect (txndata->BT_non, "activate-link", G_CALLBACK (ui_import_page_transaction_cb_activate_link), txndata->LV_gentxn);
-	g_signal_connect (txndata->BT_inv, "activate-link", G_CALLBACK (ui_import_page_transaction_cb_activate_link), txndata->LV_gentxn);
-	g_signal_connect (txndata->BT_val, "activate-link", G_CALLBACK (ui_import_page_transaction_cb_activate_link), txndata->LV_gentxn);
+	//#1993727 no update after toggle
+	g_signal_connect (txndata->BT_all, "activate-link", G_CALLBACK (ui_import_page_transaction_cb_activate_link), data);
+	g_signal_connect (txndata->BT_non, "activate-link", G_CALLBACK (ui_import_page_transaction_cb_activate_link), data);
+	g_signal_connect (txndata->BT_inv, "activate-link", G_CALLBACK (ui_import_page_transaction_cb_activate_link), data);
+	g_signal_connect (txndata->BT_val, "activate-link", G_CALLBACK (ui_import_page_transaction_cb_activate_link), data);
 
 	g_signal_connect (txndata->CY_acc          , "changed", G_CALLBACK (ui_import_page_transaction_cb_account_changed), data);
 	g_signal_connect (txndata->CY_txn_dateorder, "changed", G_CALLBACK (ui_import_page_transaction_cb_account_changed), data);
@@ -2318,7 +2390,7 @@ gint w, h;
 	g_signal_connect (G_OBJECT (assistant), "apply", G_CALLBACK (ui_import_assistant_apply), NULL);
 
 #ifdef G_OS_WIN32
-	hbtk_assistant_hack_button_order(assistant);
+	hbtk_assistant_hack_button_order(GTK_ASSISTANT(assistant));
 #endif
 
 	gtk_widget_show (assistant);
