@@ -771,7 +771,7 @@ GtkWidget *assistant, *page;
 	g_signal_connect (G_OBJECT (assistant), "prepare", G_CALLBACK (ui_newfile_assistant_prepare), data);
 
 #ifdef G_OS_WIN32
-	hbtk_assistant_hack_button_order(assistant);
+	hbtk_assistant_hack_button_order(GTK_ASSISTANT(assistant));
 #endif
 	
 	gtk_widget_show (assistant);
