@@ -2297,7 +2297,8 @@ gint response;
 				GTK_WINDOW(data->dialog),
 				title,
 				secondtext,
-				_("_Delete")
+				_("_Delete"),
+				TRUE
 			);
 
 		g_free(title);
@@ -2511,7 +2512,8 @@ gint response;
 				GTK_WINDOW(data->dialog),
 				title,
 				secondtext,
-				_("_Clear")
+				_("_Clear"),
+				TRUE
 			);
 
 		g_free(title);
@@ -2760,8 +2762,6 @@ gint gridrow;
 
 	data->dialog = dialog;
 
-	gtk_window_set_icon_name(GTK_WINDOW (dialog), ICONNAME_HB_BUDGET);
-
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
 	dh = (h*1.33/PHI);
