@@ -1020,7 +1020,7 @@ gint type;
 	
 	type = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type)) == 1 ? CAT_TYPE_INCOME : CAT_TYPE_EXPENSE;
 
-	ui_cat_listview_populate(data->LV_cat, type);
+	ui_cat_listview_populate(data->LV_cat, type, NULL, FALSE);
 	//gtk_tree_view_expand_all (GTK_TREE_VIEW(data->LV_cat));
 
 	DB( g_print(" -- end populate listview\n") );
@@ -1067,25 +1067,57 @@ gboolean doupdate = FALSE;
 }
 
 
-
-
-
 static void ui_bud_manage_setup(struct ui_bud_manage_data *data)
 {
 
 	DB( g_print("\n[ui-budget] setup\n") );
 
+	DB( g_print(" init data\n") );
+
 	data->tmp_list = NULL;
 	data->change = 0;
 	data->cat = NULL;
 	data->lastcatitem = NULL;
 
+	DB( g_print(" populate\n") );
+
 	ui_bud_manage_populate_listview(data);
+
+	//DB( g_print(" set widgets default\n") );
+
+	DB( g_print(" connect widgets signals\n") );
+
+	hbtk_radio_button_connect (GTK_CONTAINER(data->RA_type), "toggled", G_CALLBACK (ui_bud_manage_cb_type_changed), data);
+
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_cat)), "changed", G_CALLBACK (ui_bud_manage_selection), NULL);
+	//g_signal_connect (GTK_TREE_VIEW(data->LV_cat), "row-activated", G_CALLBACK (ui_bud_manage_onRowActivated), NULL);
+
+	g_signal_connect (G_OBJECT (data->BT_expand), "clicked", G_CALLBACK (ui_bud_manage_expand_all), NULL);
+	g_signal_connect (G_OBJECT (data->BT_collapse), "clicked", G_CALLBACK (ui_bud_manage_collapse_all), NULL);
+
+	g_signal_connect (data->CM_type[0], "toggled", G_CALLBACK (ui_bud_manage_toggle), NULL);
+
+	g_signal_connect (G_OBJECT (data->BT_clear), "clicked", G_CALLBACK (ui_bud_manage_clear), NULL);
+
+	g_signal_connect (data->CM_force, "toggled", G_CALLBACK (ui_bud_manage_cb_forcemonitor_toggled), NULL);
+	
+}
+
+
+static gboolean
+ui_bud_manage_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct ui_bud_manage_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n(ui_bud_manage_mapped)\n") );
+
+	ui_bud_manage_setup(data);
 	ui_bud_manage_compute_total(data->dialog, NULL);
 	ui_bud_manage_update(data->dialog, NULL);
 
-	DB( g_print("-- end setup\n") );
-
+	return FALSE;
 }
 
 
@@ -1349,43 +1381,16 @@ gint crow, row;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 4, 1);
 
 
-	//connect all our signals
-    g_signal_connect (dialog, "destroy",
-			G_CALLBACK (gtk_widget_destroyed), &dialog);
-
-	hbtk_radio_button_connect (GTK_CONTAINER(data->RA_type), "toggled", G_CALLBACK (ui_bud_manage_cb_type_changed), data);
-
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_cat)), "changed", G_CALLBACK (ui_bud_manage_selection), NULL);
-	//g_signal_connect (GTK_TREE_VIEW(data->LV_cat), "row-activated", G_CALLBACK (ui_bud_manage_onRowActivated), NULL);
-
-	g_signal_connect (G_OBJECT (data->BT_expand), "clicked", G_CALLBACK (ui_bud_manage_expand_all), NULL);
-	g_signal_connect (G_OBJECT (data->BT_collapse), "clicked", G_CALLBACK (ui_bud_manage_collapse_all), NULL);
-
-	g_signal_connect (data->CM_type[0], "toggled", G_CALLBACK (ui_bud_manage_toggle), NULL);
-
-	g_signal_connect (G_OBJECT (data->BT_clear), "clicked", G_CALLBACK (ui_bud_manage_clear), NULL);
-
-	g_signal_connect (data->CM_force, "toggled", G_CALLBACK (ui_bud_manage_cb_forcemonitor_toggled), NULL);
-	
-	//data->custom = FALSE;
-	//gtk_widget_set_sensitive(data->table, FALSE);
-
-	//setup, init and show window
-	ui_bud_manage_setup(data);
+	// connect dialog signals
+	g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
+	g_signal_connect (dialog, "map-event", G_CALLBACK (ui_bud_manage_mapped), &dialog);
 
+	// show & run dialog
+	DB( g_print(" run dialog\n") );
 	gtk_widget_show_all (dialog);
 
-	//result
+	// wait for the user
 	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
-  switch (result)
-    {
-      case GTK_RESPONSE_ACCEPT:
-         //do_application_specific_something ();
-         break;
-      default:
-         //do_nothing_since_dialog_was_cancelled ();
-         break;
-    }
 
 	// cleanup and destroy
 	ui_bud_manage_cleanup(data, result);
