@@ -1618,17 +1618,51 @@ static void ui_cur_manage_dialog_setup(struct ui_cur_manage_dialog_data *data)
 
 	DB( g_printf("\n[ui_cur_manage] setup\n") );
 
+	DB( g_print(" init data\n") );
+	data->change = 0;
+	
+	DB( g_print(" populate\n") );
 
 	ui_cur_listview_populate(data->LV_cur);
 
 	//ui_cur_combobox_populate(data->CY_curr, GLOBALS->h_cur);
 	//ui_cur_combobox_set_active(GTK_COMBO_BOX(data->CY_curr), GLOBALS->kcur);
 
+	//DB( g_print(" set widgets default\n") );
 
+	DB( g_print(" connect widgets signals\n") );
+	
+	//g_signal_connect (G_OBJECT (data->ST_name), "activate", G_CALLBACK (ui_cur_manage_dialog_add), NULL);
+
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_cur)), "changed", G_CALLBACK (ui_cur_manage_dialog_selection), NULL);
+	g_signal_connect (GTK_TREE_VIEW(data->LV_cur), "row-activated", G_CALLBACK (ui_cur_manage_dialog_onRowActivated), NULL);
+
+	g_signal_connect (G_OBJECT (data->BT_add), "clicked", G_CALLBACK (ui_cur_manage_dialog_add), NULL);
+	g_signal_connect (G_OBJECT (data->BT_del), "clicked", G_CALLBACK (ui_cur_manage_dialog_delete), NULL);
+	g_signal_connect (G_OBJECT (data->BT_edit), "clicked", G_CALLBACK (ui_cur_manage_dialog_modify), NULL);
+	//g_signal_connect (G_OBJECT (data->BT_mov), "clicked", G_CALLBACK (ui_cur_manage_dialog_move), NULL);
+	g_signal_connect (G_OBJECT (data->BT_base), "clicked", G_CALLBACK (ui_cur_manage_dialog_setbase), NULL);
 
 }
 
 
+static gboolean ui_cur_manage_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct ui_cur_manage_dialog_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_printf("\n[ui_cur_manage] mapped\n") );
+
+	ui_cur_manage_dialog_setup(data);
+	ui_cur_manage_dialog_update(data->LV_cur, NULL);
+	
+	return FALSE;
+}
+
+
+
+
 GtkWidget *ui_cur_manage_dialog (void)
 {
 struct ui_cur_manage_dialog_data *data;
@@ -1648,7 +1682,6 @@ gint crow, row, w, h, dw, dh;
 					    NULL);
 
 	data->dialog = dialog;
-	data->change = 0;
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
@@ -1663,8 +1696,7 @@ gint crow, row, w, h, dw, dh;
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
 	DB( g_printf("[ui_cur_manage] new dialog=%p, inst_data=%p\n", dialog, data) );
 
-    g_signal_connect (dialog, "destroy",
-			G_CALLBACK (gtk_widget_destroyed), &dialog);
+  
 
 	content_area = gtk_dialog_get_content_area(GTK_DIALOG (dialog));	// return a vbox
 
@@ -1721,57 +1753,43 @@ gint crow, row, w, h, dw, dh;
 	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
 	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
 
-	widget = make_image_button(ICONNAME_LIST_ADD, _("Add"));
-	data->BT_add = widget;
-	gtk_container_add (GTK_CONTAINER (bbox), widget);
+		widget = make_image_button(ICONNAME_LIST_ADD, _("Add"));
+		data->BT_add = widget;
+		gtk_container_add (GTK_CONTAINER (bbox), widget);
 
-	widget = make_image_button(ICONNAME_LIST_EDIT, _("Edit"));
-	data->BT_edit = widget;
-	gtk_container_add (GTK_CONTAINER (bbox), widget);
+		widget = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
+		data->BT_del = widget;
+		gtk_container_add (GTK_CONTAINER (bbox), widget);
 
-	widget = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
-	data->BT_del = widget;
-	gtk_container_add (GTK_CONTAINER (bbox), widget);
+	toolitem = gtk_separator_tool_item_new ();
+	//gtk_tool_item_set_expand (toolitem, TRUE);
+	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
 
-	widget = gtk_button_new_with_mnemonic(_("Set as base"));
-	data->BT_base = widget;
-	gtk_container_add (GTK_CONTAINER (bbox), widget);
+	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	toolitem = gtk_tool_item_new();
+	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+
+		widget = make_image_button(ICONNAME_LIST_EDIT, _("Edit"));
+		data->BT_edit = widget;
+		gtk_container_add (GTK_CONTAINER (bbox), widget);
+
+		widget = gtk_button_new_with_mnemonic(_("Set as base"));
+		data->BT_base = widget;
+		gtk_container_add (GTK_CONTAINER (bbox), widget);
 
 
-	//connect all our signals
-	//g_signal_connect (G_OBJECT (data->ST_name), "activate", G_CALLBACK (ui_cur_manage_dialog_add), NULL);
-
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_cur)), "changed", G_CALLBACK (ui_cur_manage_dialog_selection), NULL);
-	g_signal_connect (GTK_TREE_VIEW(data->LV_cur), "row-activated", G_CALLBACK (ui_cur_manage_dialog_onRowActivated), NULL);
-
-	g_signal_connect (G_OBJECT (data->BT_add), "clicked", G_CALLBACK (ui_cur_manage_dialog_add), NULL);
-	g_signal_connect (G_OBJECT (data->BT_del), "clicked", G_CALLBACK (ui_cur_manage_dialog_delete), NULL);
-	g_signal_connect (G_OBJECT (data->BT_edit), "clicked", G_CALLBACK (ui_cur_manage_dialog_modify), NULL);
-	//g_signal_connect (G_OBJECT (data->BT_mov), "clicked", G_CALLBACK (ui_cur_manage_dialog_move), NULL);
-	g_signal_connect (G_OBJECT (data->BT_base), "clicked", G_CALLBACK (ui_cur_manage_dialog_setbase), NULL);
-
-	//setup, init and show window
-	ui_cur_manage_dialog_setup(data);
-
-	ui_cur_manage_dialog_update(data->LV_cur, NULL);
-
-	//gtk_window_resize(GTK_WINDOW(dialog), 256, 414);
+	// connect dialog signals
+	g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
+	g_signal_connect (dialog, "map-event", G_CALLBACK (ui_cur_manage_mapped), &dialog);
 
+	// show & run dialog
+	DB( g_print(" run dialog\n") );
 	gtk_widget_show_all (dialog);
 
 	//wait for the user
-	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
-
-	switch (result)
-    {
-	case GTK_RESPONSE_ACCEPT:
-	   //do_application_specific_something ();
-	   break;
-	default:
-	   //do_nothing_since_dialog_was_cancelled ();
-	   break;
-    }
-
+	gtk_dialog_run (GTK_DIALOG (dialog));
 
 	// cleanup and destroy
 	GLOBALS->changes_count += data->change;
