@@ -1201,12 +1201,12 @@ GtkTreeIter newiter;
 	if( stxn != NULL )
 	{
 		newmodel = gtk_tree_view_get_model(GTK_TREE_VIEW(data->srctreeview));
-		gtk_list_store_clear (GTK_LIST_STORE(newmodel));
+		gtk_tree_store_clear (GTK_TREE_STORE(newmodel));
 	
-		gtk_list_store_append (GTK_LIST_STORE(newmodel), &newiter);
+		gtk_tree_store_append (GTK_TREE_STORE(newmodel), &newiter, NULL);
 
 		//#1830523/#1840393
-		gtk_list_store_set (GTK_LIST_STORE(newmodel), &newiter,
+		gtk_tree_store_set (GTK_TREE_STORE(newmodel), &newiter,
 			MODEL_TXN_POINTER, stxn,
 			MODEL_TXN_SPLITAMT, stxn->amount,
 			-1);
@@ -1216,7 +1216,7 @@ GtkTreeIter newiter;
 
 	/* populate target */
 	newmodel = gtk_tree_view_get_model(GTK_TREE_VIEW(data->treeview));
-	gtk_list_store_clear (GTK_LIST_STORE(newmodel));
+	gtk_tree_store_clear (GTK_TREE_STORE(newmodel));
 
 	GList *tmplist = g_list_first(matchlist);
 	while (tmplist != NULL)
@@ -1224,10 +1224,10 @@ GtkTreeIter newiter;
 	Transaction *tmp = tmplist->data;
 
 		/* append to our treeview */
-			gtk_list_store_append (GTK_LIST_STORE(newmodel), &newiter);
+			gtk_tree_store_append (GTK_TREE_STORE(newmodel), &newiter, NULL);
 
 			//#1830523/#1840393
-			gtk_list_store_set (GTK_LIST_STORE(newmodel), &newiter,
+			gtk_tree_store_set (GTK_TREE_STORE(newmodel), &newiter,
 			MODEL_TXN_POINTER, tmp,
 			MODEL_TXN_SPLITAMT, tmp->amount,
 			-1);
@@ -1282,3 +1282,5 @@ GtkTreeIter newiter;
 	return result;
 }
 
+
+
