@@ -20,21 +20,30 @@
 #ifndef __HB_FILTER_GTK_H__
 #define __HB_FILTER_GTK_H__
 
+
+#define	FLT_PAGE_NAME_DAT		"dat"
+#define	FLT_PAGE_NAME_TYP		"typ"
+#define	FLT_PAGE_NAME_STA		"sta"
+#define	FLT_PAGE_NAME_ACC		"acc"
+#define	FLT_PAGE_NAME_CAT		"cat"
+#define	FLT_PAGE_NAME_PAY		"pay"
+#define	FLT_PAGE_NAME_TAG		"tag"
+#define	FLT_PAGE_NAME_PMT		"pmt"
+#define	FLT_PAGE_NAME_TXT		"txt"
+
+
 enum
 {
-	BUTTON_ALL,
-	BUTTON_NONE,
-	BUTTON_INVERT,
-	MAX_BUTTON
+	LST_DEFFLT_TOGGLE,
+	LST_DEFFLT_DATAS,
+	NUM_LST_DEFFLT
 };
 
 
-struct ui_flt_hub_stuf
+struct ui_flt_list_data
 {
-	GtkWidget	*treeview;
-	GtkWidget   *BT_all;
-	GtkWidget   *BT_none;
-	GtkWidget   *BT_invert;
+	GtkWidget	*gr_criteria;
+	GtkWidget	*tb_bar, *bt_all, *bt_non, *bt_inv;
 };
 
 
@@ -44,15 +53,18 @@ struct ui_flt_manage_data
 
 	GtkWidget	*stack;
 
-	GtkWidget	*CY_option[FLT_GRP_MAX];
+	GtkWidget	*SW_enabled[FLT_GRP_MAX];
+	GtkWidget	*RA_matchmode[FLT_GRP_MAX];
 	GtkWidget	*GR_page[FLT_GRP_MAX];
 
 	GtkWidget	*PO_mindate, *PO_maxdate;
 	GtkWidget	*CY_month, *NB_year;
 
-	GtkWidget	*CY_type;
-	GtkWidget	*CY_status;
-	GtkWidget	*LB_force, *GR_force;
+	GtkWidget	*CM_typexp, *CM_typinc, *CM_typxfr;
+	
+	GtkWidget	*CM_stanon, *CM_staclr, *CM_starec;
+	
+	GtkWidget	*GR_force;
 
 	GtkWidget	*CM_forceadd, *CM_forcechg, *CM_forceremind, *CM_forcevoid;
 
@@ -61,25 +73,24 @@ struct ui_flt_manage_data
 	GtkWidget	*ST_minamount, *ST_maxamount;
 
 	GtkWidget	*CM_exact;
-	GtkWidget	*ST_info, *ST_memo, *ST_tag;
-
-	struct ui_flt_hub_stuf pnl_acc_data;
-	struct ui_flt_hub_stuf pnl_pay_data;
-	struct ui_flt_hub_stuf pnl_cat_data;
-
-	GtkWidget	*LV_acc, *BT_acc[MAX_BUTTON];
-	GtkWidget	*LV_pay, *BT_pay[MAX_BUTTON];
-	GtkWidget	*LV_cat, *BT_cat[MAX_BUTTON];
+	GtkWidget	*ST_info, *ST_memo;
 
+	GtkWidget	*LV_acc;
+	GtkWidget	*LV_pay;
+	GtkWidget	*LV_tag;
+	GtkWidget	*LV_cat;
 	GtkWidget	*BT_expand, *BT_collapse;
 
-
 	gboolean	show_account;
 
 
 };
 
 
+
+
+/* = = = = = = = = = = */
+
 gint ui_flt_manage_dialog_new(GtkWindow *parentwindow, Filter *filter, gboolean show_account, gboolean txnmode);
 
 
