@@ -23,10 +23,14 @@
 struct defhbfile_data
 {
 	GtkWidget	*ST_owner;
+
+	GtkWidget	*RA_postmode;
+	GtkWidget	*GR_payout, *GR_advance;
+	GtkWidget	*NU_weekday, *NU_nbmonths;
+	GtkWidget	*NU_nbdays;
+	GtkWidget	*LB_maxpostdate;
+
 	GtkWidget	*PO_grp;
-	GtkWidget	*radio[2];
-	GtkWidget	*LB_weekday, *NU_weekday;
-	GtkWidget	*LB_nbdays, *NU_nbdays;
 
 	gint		change;
 };
