@@ -236,6 +236,7 @@ static LangName languagenames[] =
 	{ "ca", "Catalan" },
 	{ "ce", "Chechen" },
 	{ "ch", "Chamorro" },
+	{ "ckb", "Kurdish, Central" },
 	{ "co", "Corsican" },
 	{ "cr", "Cree" },
 	{ "cs", "Czech" },
@@ -478,6 +479,10 @@ ui_language_combobox_populate(GtkWidget *combobox)
 {
 GtkTreeModel *model;
 GtkTreeIter  iter;
+GDir *dir;
+const gchar *dirname;
+
+	DB( g_print("\n[ui-pref] lang populate\n") );
 
 	model = gtk_combo_box_get_model(GTK_COMBO_BOX(combobox));
 	gtk_list_store_append (GTK_LIST_STORE(model), &iter);
@@ -486,9 +491,9 @@ GtkTreeIter  iter;
 	                    1, _("System Language"),
 	                    -1);
 
-	GDir *dir = g_dir_open (homebank_app_get_locale_dir (), 0, NULL);
-const gchar *dirname;
+	DB( g_print(" open '%s'\n",homebank_app_get_locale_dir () ) );
 
+	dir = g_dir_open (homebank_app_get_locale_dir (), 0, NULL);
 	if (! dir)
 		return;
 
@@ -499,7 +504,7 @@ const gchar *dirname;
 		                      "LC_MESSAGES",
 		                      GETTEXT_PACKAGE ".mo",
 		                      NULL);
-		//DB( g_print("- seek for '%s'\n", filename) );
+		DB( g_print("- seek for '%s'\n", filename) );
 		if (g_file_test (filename, G_FILE_TEST_EXISTS))
 		{
 		const gchar *lang;
@@ -535,6 +540,8 @@ GtkListStore *store;
 GtkWidget *combobox;
 GtkCellRenderer *renderer;
 
+	DB( g_print("\n[ui-pref] lang combo new\n") );
+
 	store = gtk_list_store_new (2,
 		G_TYPE_STRING,
 		G_TYPE_STRING
@@ -1050,6 +1057,8 @@ GdkRGBA rgba;
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_stat_byamount), PREFS->stat_byamount);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_stat_showrate), PREFS->stat_showrate);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_stat_showdetail), PREFS->stat_showdetail);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_stat_incxfer), PREFS->stat_includexfer);
+	
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_budg_showdetail), PREFS->budg_showdetail);
 
 	/* euro */
@@ -1180,6 +1189,7 @@ const gchar *datfmt;
 	PREFS->stat_byamount   = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_stat_byamount));
 	PREFS->stat_showrate   = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_stat_showrate));
 	PREFS->stat_showdetail = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_stat_showdetail));
+	PREFS->stat_includexfer = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_stat_incxfer));
 	PREFS->budg_showdetail = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_budg_showdetail));
 
 	// euro minor
@@ -1413,6 +1423,11 @@ gint crow, row;
 	data->CM_stat_showdetail = widget;
 	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
 
+	row++;
+	widget = gtk_check_button_new_with_mnemonic (_("Include _transfer"));
+	data->CM_stat_incxfer = widget;
+	gtk_grid_attach (GTK_GRID (group_grid), widget, 1, row, 2, 1);
+
 	// group :: Budget options
     group_grid = gtk_grid_new ();
 	gtk_grid_set_row_spacing (GTK_GRID (group_grid), SPACING_SMALL);
