@@ -265,6 +265,40 @@ GtkTreeViewColumn	*column;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
+
+/*static gboolean ui_split_dialog_cb_output_amount(GtkSpinButton *spin, gpointer data)
+{
+GtkAdjustment *adjustment;
+gchar *text;
+gdouble value;
+//gpointer position;
+
+	DB( g_print("\n[ui_split_dialog] amount output\n") );
+
+
+	adjustment = gtk_spin_button_get_adjustment (spin);
+	value = gtk_adjustment_get_value (adjustment);
+
+	if( value == 0.0 )
+	{
+		gtk_entry_set_text (GTK_ENTRY (spin), "");
+	}
+	else
+	{
+		text = g_strdup_printf ("%+.*f", gtk_spin_button_get_digits(spin), value);
+		
+		DB( g_print(" output '%s'\n", text) );
+		
+		gtk_entry_set_text (GTK_ENTRY (spin), text);
+		//gtk_editable_delete_text (GTK_EDITABLE(spin), 0, -1);
+		//gtk_editable_insert_text (GTK_EDITABLE(spin), text, -1, &position);
+		
+		g_free (text);
+	}
+	return TRUE;
+}*/
+
+
 static void ui_split_dialog_filter_text_handler (GtkEntry    *entry,
                           const gchar *text,
                           gint         length,
@@ -584,6 +618,20 @@ gdouble amount;
 			split->kcat = ui_cat_entry_popover_get_key_add_new(GTK_BOX(data->PO_cat));
 			split->memo = g_strdup((gchar *)gtk_entry_get_text(GTK_ENTRY(data->ST_memo)));
 
+			//#1977686 add into memo autocomplete
+			if( da_transaction_insert_memo(split->memo, data->date) )
+			{
+			GtkEntryCompletion *completion;
+			GtkTreeModel *model;
+			GtkTreeIter  iter;
+
+				completion = gtk_entry_get_completion (GTK_ENTRY(data->ST_memo));
+				model = gtk_entry_completion_get_model (completion);
+				gtk_list_store_insert_with_values(GTK_LIST_STORE(model), &iter, -1,
+					0, split->memo, 
+					-1);
+			}
+
 			DB( g_print(" append split : %d, %.2f, %s\n", split->kcat, split->amount, split->memo) );
 
 			da_splits_append (data->tmp_splits, split);
@@ -836,7 +884,7 @@ Currency *cur;
 }
 
 
-GtkWidget *ui_split_dialog (GtkWidget *parent, GPtrArray **src_splits, gint txntype, gdouble amount, guint32 kcur, void (update_callbackFunction(GtkWidget*, gdouble)))
+GtkWidget *ui_split_dialog (GtkWidget *parent, GPtrArray **src_splits, gint txntype, guint32 date, gdouble amount, guint32 kcur, void (update_callbackFunction(GtkWidget*, gdouble)))
 {
 struct ui_split_dialog_data *data;
 GtkWidget *dialog, *content, *table, *box, *scrollwin, *bar;
@@ -866,7 +914,8 @@ gint row;
 
 	gtk_dialog_add_button(GTK_DIALOG(dialog), _("_OK"), GTK_RESPONSE_ACCEPT);
 
-	data->cur = da_cur_get (kcur);
+	data->date = date;
+	data->cur  = da_cur_get (kcur);
 
 	DB( g_print(" kcur: %d %d %s\n", data->cur->key, data->cur->frac_digits, data->cur->format) );
 
@@ -945,7 +994,9 @@ gint row;
 	data->PO_cat = widget;
 	gtk_grid_attach (GTK_GRID (table), widget, 0, row, 1, 1);
 
-	widget = make_string(NULL);
+	//1977686
+	//widget = make_string(NULL);
+	widget = make_memo_entry(NULL);
 	data->ST_memo= widget;
 	gtk_grid_attach (GTK_GRID (table), widget, 1, row, 1, 1);
 
