@@ -53,6 +53,7 @@ struct ui_split_dialog_data
 
 	gint		mode;
 	gint		txntype;
+	guint32		date;
 	Currency	*cur;
 	 
 	gdouble		amount;
@@ -78,7 +79,7 @@ void ui_split_dialog_activeline(GtkWidget *widget, gpointer user_data);
 void ui_split_dialog_get(struct ui_split_dialog_data *data);
 void ui_split_dialog_set(struct ui_split_dialog_data *data);
 
-GtkWidget *ui_split_dialog (GtkWidget *parent, GPtrArray **src_splits,  gint txntype, gdouble amount, guint32 kcur, void (update_callbackFunction(GtkWidget*, gdouble)));
+GtkWidget *ui_split_dialog (GtkWidget *parent, GPtrArray **src_splits, gint txntype, guint32 date, gdouble amount, guint32 kcur, void (update_callbackFunction(GtkWidget*, gdouble)));
 
 GtkWidget *ui_split_view_dialog (GtkWidget *parent, Transaction *ope);
 
