@@ -19,6 +19,7 @@
 
 #include "homebank.h"
 
+#include "hb-tag.h"
 #include "ui-tag.h"
 
 
@@ -56,8 +57,8 @@ ui_tag_combobox_populate_except(GtkComboBoxText *combobox, guint except_key)
 GList *ltag, *list;
 	
 	//populate template
-	hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combobox), 0, "----");
-	gtk_combo_box_set_active(GTK_COMBO_BOX(combobox), 0);
+	//hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combobox), 0, "----");
+	//gtk_combo_box_set_active(GTK_COMBO_BOX(combobox), 0);
 
 	ltag = list = tag_glist_sorted(1);
 	while (list != NULL)
@@ -74,6 +75,8 @@ GList *ltag, *list;
 
 		list = g_list_next(list);
 	}
+	
+	gtk_combo_box_set_active(GTK_COMBO_BOX(combobox), 0);
 
 	g_list_free(ltag);
 }
@@ -196,6 +199,37 @@ GtkWidget *box, *menubutton, *image, *scrollwin, *treeview;
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
+void ui_tag_listview_toggle_to_filter(GtkTreeView *treeview, Filter *filter)
+{
+GtkTreeModel *model;
+GtkTreeIter	iter;
+gboolean valid;
+gboolean toggled;
+
+	DB( g_print("(ui_tag_listview) toggle_to_filter\n") );
+
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
+	//selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_tag));
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+	while (valid)
+	{
+	Tag *tagitem;
+
+		gtk_tree_model_get (model, &iter,
+			LST_DEFTAG_TOGGLE, &toggled,
+			LST_DEFTAG_DATAS, &tagitem,
+			-1);
+
+		DB( g_print(" get tag k:%3d = %d (%s)\n", tagitem->key, toggled, tagitem->name) );
+		da_flt_status_tag_set(filter, tagitem->key, toggled);
+		
+		//tagitem->flt_select = toggled;
+
+		/* Make iter point to the next row in the list store */
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+	}
+}
+
 
 static void
 ui_tag_listview_toggled_cb (GtkCellRendererToggle *cell,
@@ -221,6 +255,43 @@ ui_tag_listview_toggled_cb (GtkCellRendererToggle *cell,
   gtk_tree_path_free (path);
 }
 
+void
+ui_tag_listview_quick_select(GtkTreeView *treeview, const gchar *uri)
+{
+GtkTreeModel *model;
+GtkTreeIter	iter;
+gboolean valid;
+gboolean toggle;
+gint qselect = hb_clicklabel_to_int(uri);
+
+	DB( g_print("(ui_acc_listview) quick select\n") );
+
+
+	DB( g_print(" comboboxlink '%s' %d\n", uri, qselect) );
+
+	model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
+	valid = gtk_tree_model_get_iter_first(GTK_TREE_MODEL(model), &iter);
+	while (valid)
+	{
+		switch(qselect)
+		{
+			case HB_LIST_QUICK_SELECT_ALL:
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, LST_DEFTAG_TOGGLE, TRUE, -1);
+				break;
+			case HB_LIST_QUICK_SELECT_NONE:
+				gtk_list_store_set (GTK_LIST_STORE (model), &iter, LST_DEFTAG_TOGGLE, FALSE, -1);
+				break;
+			case HB_LIST_QUICK_SELECT_INVERT:
+					gtk_tree_model_get (model, &iter, LST_DEFTAG_TOGGLE, &toggle, -1);
+					toggle ^= 1;
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, LST_DEFTAG_TOGGLE, toggle, -1);
+				break;
+		}
+		valid = gtk_tree_model_iter_next(GTK_TREE_MODEL(model), &iter);
+	}
+}
+
+
 static gint
 ui_tag_listview_compare_func (GtkTreeModel *model, GtkTreeIter *a, GtkTreeIter *b, gpointer userdata)
 {
@@ -246,27 +317,32 @@ ui_tag_listview_name_cell_data_function (GtkTreeViewColumn *col,
 {
 Tag *entry;
 gchar *name;
-#if MYDEBUG
-gchar *string;
-#endif
 
 	gtk_tree_model_get(model, iter, LST_DEFTAG_DATAS, &entry, -1);
-	if(entry->name == NULL)
-		name = _("(none)");		// can never occurs !
+	if(entry->key == 0)
+		name = _("(no tag)");
 	else
 		name = entry->name;
 
-	#if MYDEBUG
-		string = g_strdup_printf ("[%d] %s", entry->key, name );
-		g_object_set(renderer, "text", string, NULL);
-		g_free(string);
-	#else
-		g_object_set(renderer, "text", name, NULL);
-	#endif
-
+	g_object_set(renderer, "text", name, NULL);
 }
 
 
+#if MYDEBUG == 1
+static void
+ui_tag_listview_cell_data_function_debugkey (GtkTreeViewColumn *col, GtkCellRenderer *renderer, GtkTreeModel *model, GtkTreeIter *iter, gpointer user_data)
+{
+Tag *item;
+gchar *string;
+
+	gtk_tree_model_get(model, iter, LST_DEFTAG_DATAS, &item, -1);
+	string = g_strdup_printf ("[%d]", item->key );
+	g_object_set(renderer, "text", string, NULL);
+	g_free(string);
+}
+#endif	
+
+
 
 /* = = = = = = = = = = = = = = = = */
 
@@ -391,6 +467,16 @@ GtkTreeViewColumn	*column;
 
 	gtk_tree_view_set_grid_lines (GTK_TREE_VIEW (treeview), PREFS->grid_lines);
 
+
+	#if MYDEBUG == 1
+	column = gtk_tree_view_column_new();
+	renderer = gtk_cell_renderer_text_new ();
+	gtk_tree_view_column_pack_start(column, renderer, TRUE);
+	gtk_tree_view_column_set_cell_data_func(column, renderer, ui_tag_listview_cell_data_function_debugkey, NULL, NULL);
+	gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
+	#endif
+
+
 	// column 1: toggle
 	if( withtoggle == TRUE )
 	{
@@ -401,9 +487,12 @@ GtkTreeViewColumn	*column;
 							     NULL);
 		gtk_tree_view_append_column (GTK_TREE_VIEW(treeview), column);
 
+		gtk_tree_selection_set_mode(gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview)), GTK_SELECTION_NONE);
+
 		g_signal_connect (renderer, "toggled",
 			    G_CALLBACK (ui_tag_listview_toggled_cb), store);
 
+		g_object_set_data(G_OBJECT(treeview), "togrdr_data", renderer);
 	}
 
 	// column 2: name
@@ -469,6 +558,55 @@ gchar *result = g_new0 (gchar, length+1);
 }
 
 
+static void
+ui_tag_manage_dialog_load_csv( GtkWidget *widget, gpointer user_data)
+{
+struct ui_tag_manage_dialog_data *data = user_data;
+gchar *filename = NULL;
+gchar *error;
+
+	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(GTK_WIDGET(widget), GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("(ui_tag_manage_dialog) load csv - data %p\n", data) );
+
+	if( ui_file_chooser_csv(GTK_WINDOW(data->dialog), GTK_FILE_CHOOSER_ACTION_OPEN, &filename, NULL) == TRUE )
+	{
+		DB( g_print(" + filename is %s\n", filename) );
+
+		if( !tag_load_csv(filename, &error) )
+		{
+			ui_dialog_msg_infoerror(GTK_WINDOW(data->dialog), GTK_MESSAGE_ERROR,
+					_("File format error"),
+					_("The CSV file must contains the exact numbers of column,\nseparated by a semi-colon, please see the help for more details.")
+					);
+		}
+
+		g_free( filename );
+		ui_tag_listview_populate(data->LV_tag, 0);
+	}
+}
+
+
+static void
+ui_tag_manage_dialog_save_csv( GtkWidget *widget, gpointer user_data)
+{
+struct ui_tag_manage_dialog_data *data = user_data;
+gchar *filename = NULL;
+
+	DB( g_print("(ui_tag_manage_dialog) save csv\n") );
+
+	//data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	if( ui_file_chooser_csv(GTK_WINDOW(data->dialog), GTK_FILE_CHOOSER_ACTION_SAVE, &filename, NULL) == TRUE )
+	{
+		DB( g_print(" + filename is %s\n", filename) );
+
+		tag_save_csv(filename);
+		g_free( filename );
+	}
+}
+
+
 
 /**
  * ui_tag_manage_dialog_add:
@@ -535,7 +673,7 @@ guint32 key;
 
 		item = da_tag_get( key );
 
-		dialog = gtk_dialog_new_with_buttons (_("Edit..."),
+		dialog = gtk_dialog_new_with_buttons (_("Edit Tag"),
 						    GTK_WINDOW (data->dialog),
 						    0,
 						    _("_Cancel"),
@@ -703,42 +841,46 @@ GtkTreeIter iter;
 		Tag *newtag;
 		guint dsttagkey;
 
-			model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_tag));
-			gtk_list_store_clear (GTK_LIST_STORE(model));
-
 			dsttagkey = ui_tag_combobox_get_key(GTK_COMBO_BOX_TEXT(getwidget));
 
-			tag_move(srctag->key, dsttagkey);
-
-			newtag = da_tag_get(dsttagkey);
-
-			//#1771720: update count
-			newtag->usage_count += srctag->usage_count;
-			srctag->usage_count = 0;
-
-			// add the new tagee to listview
-			if(newtag)
-				ui_tag_listview_add(GTK_TREE_VIEW(data->LV_tag), newtag);
-
-			// delete the old tagee
-			if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton)) )
+			//do nothing if src = dst...
+			if( srctag->key != dsttagkey )
 			{
-				DB( g_print(" -> delete %d '%s'\n", srctag->key, srctag->name ) );
+				model = gtk_tree_view_get_model(GTK_TREE_VIEW(data->LV_tag));
+				gtk_list_store_clear (GTK_LIST_STORE(model));
 
-				ui_tag_listview_remove_selected(GTK_TREE_VIEW(data->LV_tag));
-				da_tag_delete(srctag->key);
+				DB( g_print(" -> move cat to %d (subcat=%d)\n", dstcatkey, dosubcat) );
+
+				tag_move(srctag->key, dsttagkey);
+
+				newtag = da_tag_get(dsttagkey);
+
+				//#1771720: update count
+				newtag->usage_count += srctag->usage_count;
+				srctag->usage_count = 0;
+
+				// add the new tag to listview
+				if(newtag)
+					ui_tag_listview_add(GTK_TREE_VIEW(data->LV_tag), newtag);
+
+				// delete the old tag
+				if( gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(togglebutton)) )
+				{
+					DB( g_print(" -> delete %d '%s'\n", srctag->key, srctag->name ) );
+
+					ui_tag_listview_remove_selected(GTK_TREE_VIEW(data->LV_tag));
+					da_tag_delete(srctag->key);
+				}
+
+				data->change++;
+
+				ui_tag_listview_populate(data->LV_tag, 0);
 			}
-
-
-			data->change++;
-
-			ui_tag_listview_populate(data->LV_tag, 0);
 		}
 
 		// cleanup and destroy
 		gtk_widget_destroy (dialog);
 	}
-
 }
 
 
@@ -844,10 +986,59 @@ GtkTreeIter			 iter;
 }
 
 
+static void ui_tag_manage_setup(struct ui_tag_manage_dialog_data *data)
+{
+
+	DB( g_print("\n[ui-tag] setup\n") );
+
+	DB( g_print(" init data\n") );
+	data->change = 0;
+
+	DB( g_print(" populate\n") );
+	//tag_fill_usage();
+	ui_tag_listview_populate(data->LV_tag, 0);
+
+
+	//DB( g_print(" set widgets default\n") );
+
+	DB( g_print(" connect widgets signals\n") );
+
+	g_object_bind_property (data->BT_add, "active", data->RE_addreveal, "reveal-child", G_BINDING_BIDIRECTIONAL);
+
+	g_signal_connect (G_OBJECT (data->ST_name), "activate", G_CALLBACK (ui_tag_manage_dialog_add), NULL);
+	g_signal_connect(G_OBJECT(data->ST_name), "insert-text", G_CALLBACK(ui_tag_manage_filter_text_handler), NULL);
+	
+	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_tag)), "changed", G_CALLBACK (ui_tag_manage_dialog_selection), NULL);
+	g_signal_connect (GTK_TREE_VIEW(data->LV_tag), "row-activated", G_CALLBACK (ui_tag_manage_dialog_onRowActivated), NULL);
+
+	g_signal_connect (G_OBJECT (data->BT_edit), "clicked", G_CALLBACK (ui_tag_manage_dialog_edit), NULL);
+	g_signal_connect (G_OBJECT (data->BT_merge), "clicked", G_CALLBACK (ui_tag_manage_dialog_merge), NULL);
+	g_signal_connect (G_OBJECT (data->BT_delete), "clicked", G_CALLBACK (ui_tag_manage_dialog_delete), NULL);
+
+}
+
+
+static gboolean
+ui_tag_manage_mapped (GtkWidget *widget, GdkEvent *event, gpointer user_data)
+{
+struct ui_tag_manage_dialog_data *data;
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	DB( g_print("\n(ui_tag_manage_mapped)\n") );
+
+	ui_tag_manage_setup(data);
+	ui_tag_manage_dialog_update(data->LV_tag, NULL);
+
+	return FALSE;
+}
+
+
 GtkWidget *ui_tag_manage_dialog (void)
 {
 struct ui_tag_manage_dialog_data *data;
 GtkWidget *dialog, *content, *mainvbox, *box, *bbox, *tbar, *treeview, *scrollwin, *table, *addreveal;
+GtkWidget *menu, *menuitem, *widget, *image;
 GtkToolItem *toolitem;
 gint w, h, dw, dh, row;
 
@@ -868,7 +1059,6 @@ gint w, h, dw, dh, row;
 	//gtk_window_set_destroy_with_parent (GTK_WINDOW (dialog), TRUE);
 	
 	data->dialog = dialog;
-	data->change = 0;
 
 	//set a nice dialog size
 	gtk_window_get_size(GTK_WINDOW(GLOBALS->mainwindow), &w, &h);
@@ -883,8 +1073,6 @@ gint w, h, dw, dh, row;
 	g_object_set_data(G_OBJECT(dialog), "inst_data", (gpointer)data);
 	DB( g_print("(ui_tag_manage_dialog) dialog=%p, inst_data=%p\n", dialog, data) );
 
-    g_signal_connect (dialog, "destroy",
-			G_CALLBACK (gtk_widget_destroyed), &dialog);
 
 	//dialog contents
 	content = gtk_dialog_get_content_area(GTK_DIALOG (dialog));
@@ -904,6 +1092,33 @@ gint w, h, dw, dh, row;
 	//test headerbar
 	//content = gtk_dialog_get_header_bar(GTK_DIALOG (dialog));
 
+	menu = gtk_menu_new ();
+	gtk_widget_set_halign (menu, GTK_ALIGN_END);
+
+	menuitem = gtk_menu_item_new_with_mnemonic (_("_Import CSV"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_tag_manage_dialog_load_csv), data);
+
+	menuitem = gtk_menu_item_new_with_mnemonic (_("E_xport CSV"));
+	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_tag_manage_dialog_save_csv), data);
+	
+	//menuitem = gtk_separator_menu_item_new();
+	//gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	
+	//menuitem = gtk_menu_item_new_with_mnemonic (_("_Delete unused"));
+	//gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+	//g_signal_connect (G_OBJECT (menuitem), "activate", G_CALLBACK (ui_pay_manage_dialog_delete_unused), data);
+	
+	gtk_widget_show_all (menu);
+
+	widget = gtk_menu_button_new();
+	image = gtk_image_new_from_icon_name (ICONNAME_HB_BUTTON_MENU, GTK_ICON_SIZE_MENU);
+	g_object_set (widget, "image", image, "popup", GTK_MENU(menu),  NULL);
+	gtk_widget_set_halign (widget, GTK_ALIGN_END);
+	gtk_box_pack_end(GTK_BOX (bbox), widget, FALSE, FALSE, 0);
+	//gtk_header_bar_pack_end(GTK_HEADER_BAR (content), widget);
+	
 	// list
 	row++;
 	box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
@@ -931,61 +1146,48 @@ gint w, h, dw, dh, row;
 	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
 	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
 
-	data->BT_add = make_image_toggle_button(ICONNAME_LIST_ADD, _("Add"));
-	gtk_container_add (GTK_CONTAINER (bbox), data->BT_add);
+		data->BT_add = make_image_toggle_button(ICONNAME_LIST_ADD, _("Add"));
+		gtk_container_add (GTK_CONTAINER (bbox), data->BT_add);
 
-	//todo: useless ?
-	data->BT_edit = make_image_button(ICONNAME_LIST_EDIT, _("Edit"));
-	gtk_container_add (GTK_CONTAINER (bbox), data->BT_edit);
+		data->BT_delete = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
+		gtk_container_add (GTK_CONTAINER (bbox), data->BT_delete);
 
-	data->BT_merge = make_image_button(ICONNAME_HB_LIST_MERGE, _("Move/Merge"));
-	gtk_container_add (GTK_CONTAINER (bbox), data->BT_merge);
+	toolitem = gtk_separator_tool_item_new ();
+	//gtk_tool_item_set_expand (toolitem, TRUE);
+	gtk_separator_tool_item_set_draw(GTK_SEPARATOR_TOOL_ITEM(toolitem), FALSE);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
 
-	data->BT_delete = make_image_button(ICONNAME_LIST_DELETE, _("Delete"));
-	gtk_container_add (GTK_CONTAINER (bbox), data->BT_delete);
+	bbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+	toolitem = gtk_tool_item_new();
+	gtk_container_add (GTK_CONTAINER(toolitem), bbox);
+	gtk_toolbar_insert(GTK_TOOLBAR(tbar), GTK_TOOL_ITEM(toolitem), -1);
+
+		data->BT_edit = make_image_button(ICONNAME_LIST_EDIT, _("Edit"));
+		gtk_container_add (GTK_CONTAINER (bbox), data->BT_edit);
+
+		data->BT_merge = make_image_button(ICONNAME_HB_LIST_MERGE, _("Move/Merge"));
+		gtk_container_add (GTK_CONTAINER (bbox), data->BT_merge);
 
 	row++;
 	addreveal = gtk_revealer_new ();
+	data->RE_addreveal = addreveal;
 	gtk_grid_attach (GTK_GRID (table), addreveal, 0, row, 2, 1);
 	data->ST_name = gtk_entry_new ();
 	gtk_entry_set_placeholder_text(GTK_ENTRY(data->ST_name), _("new tag") );
 	gtk_widget_set_hexpand (data->ST_name, TRUE);
 	gtk_container_add(GTK_CONTAINER(addreveal), data->ST_name);
-
 	
 	
-	//connect all our signals
-	g_object_bind_property (data->BT_add, "active", addreveal, "reveal-child", G_BINDING_BIDIRECTIONAL);
-
-	g_signal_connect (G_OBJECT (data->ST_name), "activate", G_CALLBACK (ui_tag_manage_dialog_add), NULL);
-	g_signal_connect(G_OBJECT(data->ST_name), "insert-text", G_CALLBACK(ui_tag_manage_filter_text_handler), NULL);
-	
-	g_signal_connect (gtk_tree_view_get_selection(GTK_TREE_VIEW(data->LV_tag)), "changed", G_CALLBACK (ui_tag_manage_dialog_selection), NULL);
-	g_signal_connect (GTK_TREE_VIEW(data->LV_tag), "row-activated", G_CALLBACK (ui_tag_manage_dialog_onRowActivated), NULL);
-
-	g_signal_connect (G_OBJECT (data->BT_edit), "clicked", G_CALLBACK (ui_tag_manage_dialog_edit), NULL);
-	g_signal_connect (G_OBJECT (data->BT_merge), "clicked", G_CALLBACK (ui_tag_manage_dialog_merge), NULL);
-	g_signal_connect (G_OBJECT (data->BT_delete), "clicked", G_CALLBACK (ui_tag_manage_dialog_delete), NULL);
-
-	//setup, init and show dialog
-	//tag_fill_usage();
-	ui_tag_listview_populate(data->LV_tag, 0);
-	ui_tag_manage_dialog_update(data->LV_tag, NULL);
+	// connect dialog signals
+	g_signal_connect (dialog, "destroy", G_CALLBACK (gtk_widget_destroyed), &dialog);
+	g_signal_connect (dialog, "map-event", G_CALLBACK (ui_tag_manage_mapped), &dialog);
 
+	// show & run dialog
+	DB( g_print(" run dialog\n") );
 	gtk_widget_show_all (dialog);
 
-	//wait for the user
-	gint result = gtk_dialog_run (GTK_DIALOG (dialog));
-
-	switch (result)
-    {
-	case GTK_RESPONSE_ACCEPT:
-	   //do_application_specific_something ();
-	   break;
-	default:
-	   //do_nothing_since_dialog_was_cancelled ();
-	   break;
-    }
+	// wait for the user
+	gtk_dialog_run (GTK_DIALOG (dialog));
 
 	// cleanup and destroy
 	GLOBALS->changes_count += data->change;
