@@ -33,6 +33,7 @@ struct ui_tag_manage_dialog_data
 {
 	GtkWidget	*dialog;
 	
+	GtkWidget	*RE_addreveal;
 	GtkWidget	*ST_name;
 	GtkWidget	*LV_tag;
 
@@ -63,6 +64,9 @@ ui_tag_popover_list(GtkWidget *entry);
 
 /* = = = = = = = = = = */
 
+void ui_tag_listview_toggle_to_filter(GtkTreeView *treeview, Filter *filter);
+void ui_tag_listview_quick_select(GtkTreeView *treeview, const gchar *uri);
+
 void ui_tag_listview_add(GtkTreeView *treeview, Tag *item);
 guint32 ui_tag_listview_get_selected_key(GtkTreeView *treeview);
 void ui_tag_listview_remove_selected(GtkTreeView *treeview);
