@@ -60,20 +60,77 @@ gchar *CYA_TXN_TYPE[] = {
 extern gchar *CYA_WEEKDAY[];
 
 
-static void deftransaction_cb_type_toggled(GtkWidget *widget, gpointer user_data);
 static void ui_popover_tpl_populate(struct deftransaction_data *data, GList *srclist);
-static gboolean deftransaction_cb_amount_focusout(GtkWidget *widget, GdkEventFocus *event, gpointer user_data);
 
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
+static void	deftransaction_set_amount_currency(Account *acc, GtkWidget *stamount, GtkWidget *lbcurr)
+{
+guint curdigits = 2;
+gchar *curlabel = "";
+
+	if( acc != NULL )
+	{
+	Currency *cur =	da_cur_get(acc->kcur);
+		
+		curdigits = (cur != NULL) ? cur->frac_digits : 2;
+		curlabel  = strlen(cur->iso_code) == 3 ? cur->iso_code : cur->symbol;
+	}
+
+	gtk_spin_button_set_digits (GTK_SPIN_BUTTON(stamount), curdigits);
+	gtk_label_set_label(GTK_LABEL(lbcurr), curlabel);
+}
+
+
+static void	deftransaction_set_amount_xfer(struct deftransaction_data *data)
+{
+Account *srcacc, *dstacc;
+Currency *dstcur;
+gdouble srcamt, dstamt;
+gboolean srcisbasecurr;
+gboolean haswarn = FALSE;
+
+	if( data->action != TXN_DLG_ACTION_ADD )
+		goto end;
+
+	DB( g_print("\n[ui-transaction] set xfer amount\n") );
+
+	srcacc = ui_acc_entry_popover_get(GTK_BOX(data->PO_acc));
+	dstacc = ui_acc_entry_popover_get(GTK_BOX(data->PO_accto));
+	if( srcacc != NULL && dstacc != NULL )
+	{
+		srcisbasecurr = (srcacc->kcur == GLOBALS->kcur) ? TRUE : FALSE;
+		dstcur = da_cur_get(dstacc->kcur);
+		if( (srcacc->kcur != dstacc->kcur) && ((srcisbasecurr == FALSE) || (dstcur->rate == 0.0)) )
+			haswarn = TRUE;
+
+		if( (srcisbasecurr == TRUE) && (srcacc->kcur != dstacc->kcur) )
+		{
+			dstamt = ABS(gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_xferamt)));
+			if( (dstcur->rate != 0.0) && (dstamt == 0.0) )
+			{
+				srcamt = ABS(gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount)));
+				dstamt = hb_amount_round((srcamt * dstcur->rate), dstcur->frac_digits);
+				gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_xferamt), dstamt);
+			}
+		}
+	}
+
+end:
+
+	hb_widget_visible(data->IM_xfernorate, haswarn);
+}
+
+
 static void deftransaction_update(GtkWidget *widget, gpointer user_data)
 {
 struct deftransaction_data *data;
 gint type, paymode;
-gboolean sensitive, visible;
+gboolean sensitive, visible, xferamtvisible;
 Account *srcacc, *dstacc;
+gchar *lbfrom, *lbto;
 
 	DB( g_print("\n[ui-transaction] update\n") );
 
@@ -82,10 +139,12 @@ Account *srcacc, *dstacc;
 	type    = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
 	paymode = paymode_combo_box_get_active(GTK_COMBO_BOX(data->NU_mode));
 
+	//template: hide date
 	visible = (data->type == TXN_DLG_TYPE_TPL) ? FALSE : TRUE;
 	hb_widget_visible(data->LB_date, visible);
 	hb_widget_visible(data->GR_date, visible);
 	
+	//xfer: hide split+paymode / show accto
 	visible = (type == TXN_TYPE_INTXFER) ? FALSE : TRUE;
 	hb_widget_visible(data->BT_split, visible);
 	hb_widget_visible(data->LB_mode , visible);
@@ -107,40 +166,41 @@ Account *srcacc, *dstacc;
 	DB( g_print(" action:%d type:%d\n", data->action, data->type) );
 
 	//srcacc = ui_acc_comboboxentry_get(GTK_COMBO_BOX(data->PO_acc));
+	//dstacc = ui_acc_comboboxentry_get(GTK_COMBO_BOX(data->PO_accto));
 	srcacc = ui_acc_entry_popover_get(GTK_BOX(data->PO_acc));
+	dstacc = ui_acc_entry_popover_get(GTK_BOX(data->PO_accto));
 
+	//#1676162 update the nb digits of amount
+	//set digits and currency label	
+	deftransaction_set_amount_currency(srcacc, data->ST_amount, data->LB_curr);
+
+	lbfrom = _("A_ccount:");
+	lbto   = _("_To:");
+	xferamtvisible = FALSE;
 	if( type == TXN_TYPE_INTXFER )
 	{
 	gdouble amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
+
+		lbfrom = ( amount <= 0.0 ) ? _("_From:") : _("_To:");
+		lbto   = ( amount <= 0.0 ) ? _("_To:")   : _("_From:");
 		
-		if( amount <= 0.0 )
+		//#1673260 show target amount if != kcur
+		if(srcacc != NULL && dstacc != NULL)
 		{
-			gtk_label_set_text_with_mnemonic (GTK_LABEL(data->LB_accfrom), _("_From:"));
-			gtk_label_set_text_with_mnemonic (GTK_LABEL(data->LB_accto), _("_To:"));
-		}
-		else
-		{
-			gtk_label_set_text_with_mnemonic (GTK_LABEL(data->LB_accto), _("_From:"));
-			gtk_label_set_text_with_mnemonic (GTK_LABEL(data->LB_accfrom), _("_To:"));
+			xferamtvisible = (srcacc->kcur == dstacc->kcur) ? FALSE : TRUE;
 		}
+
+		//set digits and currency label
+		deftransaction_set_amount_currency(dstacc, data->ST_xferamt, data->LB_xfercurr);
+		deftransaction_set_amount_xfer(data);
 	}
 	else
-		gtk_label_set_text_with_mnemonic (GTK_LABEL(data->LB_accfrom), _("A_ccount:"));
-
+		hb_widget_visible(data->IM_xfernorate, FALSE);
 	
-	//#1676162 update the nb digits of amount
-	if( srcacc != NULL )
-	{
-	Currency *cur = da_cur_get(srcacc->kcur);
-
-		gtk_spin_button_set_digits (GTK_SPIN_BUTTON(data->ST_amount), (cur != NULL) ? cur->frac_digits : 2);
-		gtk_label_set_label(GTK_LABEL(data->LB_curr), strlen(cur->iso_code) == 3 ? cur->iso_code : cur->symbol );
-	}
-	else
-	{
-		gtk_spin_button_set_digits (GTK_SPIN_BUTTON(data->ST_amount), 2);
-		gtk_label_set_label(GTK_LABEL(data->LB_curr), "");
-	}
+	gtk_label_set_text_with_mnemonic (GTK_LABEL(data->LB_accfrom), lbfrom);
+	gtk_label_set_text_with_mnemonic (GTK_LABEL(data->LB_accto)  , lbto);
+	hb_widget_visible(data->ST_xferamt , xferamtvisible);
+	hb_widget_visible(data->LB_xfercurr, xferamtvisible);
 
 	// item validation
 	if( (data->type == TXN_DLG_TYPE_TPL) )
@@ -157,21 +217,20 @@ Account *srcacc, *dstacc;
 		{
 			sensitive = FALSE;
 			//#1858682 still disabled > faulty test a copy/paste acc instead of accto...
-			//dstacc = ui_acc_comboboxentry_get(GTK_COMBO_BOX(data->PO_accto));
-			dstacc = ui_acc_entry_popover_get(GTK_BOX(data->PO_accto));
 			//todo
 			if( (srcacc != NULL) && (dstacc != NULL) )
 			{
 				if( (dstacc->key != 0)
 				 && (dstacc->key != srcacc->key)   
-				 && (dstacc->kcur == srcacc->kcur)
+				 //#1673260 xfer
+				 //&& (dstacc->kcur == srcacc->kcur)
 				) { sensitive = TRUE; }
 			}
 		}
 	}
 
 	gtk_dialog_set_response_sensitive(GTK_DIALOG (data->dialog), GTK_RESPONSE_ACCEPT, sensitive);
-	gtk_dialog_set_response_sensitive(GTK_DIALOG (data->dialog), HB_RESPONSE_ADD, sensitive);
+	gtk_dialog_set_response_sensitive(GTK_DIALOG (data->dialog), HB_RESPONSE_ADD    , sensitive);
 	gtk_dialog_set_response_sensitive(GTK_DIALOG (data->dialog), HB_RESPONSE_ADDKEEP, sensitive);
 
 }
@@ -345,6 +404,111 @@ Account *srcacc;
 }
 
 
+//#1673260
+static gboolean deftransaction_cb_dstamount_focusout(GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
+{
+struct deftransaction_data *data;
+gint type;
+gdouble amount;
+	
+	DB( g_print("\n[ui-transaction] dst amount focus-out-event %d\n", gtk_widget_is_focus(widget)) );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	type = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
+
+	// when add xfer, dst amount must be positive
+	if( (type == TXN_TYPE_INTXFER) && (data->action == TXN_DLG_ACTION_ADD) )
+	{
+		amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_xferamt));
+		if( amount < 0 )
+		{
+			g_signal_handlers_block_by_func(G_OBJECT(data->ST_xferamt), G_CALLBACK(deftransaction_cb_dstamount_focusout), NULL);
+			gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_xferamt), ABS(amount));
+			g_signal_handlers_unblock_by_func(G_OBJECT(data->ST_xferamt), G_CALLBACK(deftransaction_cb_dstamount_focusout), NULL);
+		}
+	}
+	return FALSE;
+}
+
+
+static gboolean deftransaction_cb_amount_focusout(GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
+{
+struct deftransaction_data *data;
+gint type;
+gdouble amount;
+gboolean change;
+
+	DB( g_print("\n[ui-transaction] amount focus-out-event %d\n", gtk_widget_is_focus(widget)) );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	type = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
+	amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
+
+	change = FALSE;
+	if( hb_amount_type_match(amount, type) == FALSE )
+		change = TRUE;
+	
+	// for internal transfer add, amount must be expense by default
+	if( type == TXN_TYPE_INTXFER && data->action == TXN_DLG_ACTION_ADD && amount > 0)
+		change = TRUE;
+
+	if( change == TRUE )
+	{
+		g_signal_handlers_block_by_func(G_OBJECT(data->ST_amount), G_CALLBACK(deftransaction_cb_amount_focusout), NULL);
+		DB( g_print(" - change value to %.2f\n", amount * -1) );
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), amount * -1);
+		g_signal_handlers_unblock_by_func(G_OBJECT(data->ST_amount), G_CALLBACK(deftransaction_cb_amount_focusout), NULL);
+	}
+
+	deftransaction_set_amount_xfer(data);
+	
+	//#1872329 fill-in cheque if condition match
+	deftransaction_set_cheque(widget, NULL);
+
+	DB( g_print(" - call warnsign\n") );
+	deftransaction_update_warnsign(widget, NULL);
+
+	return FALSE;
+}
+
+
+static void deftransaction_cb_type_toggled(GtkWidget *widget, gpointer user_data)
+{
+struct deftransaction_data *data;
+gint type;
+
+	//ignore event triggered from inactive radiobutton
+	if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget)) == FALSE )
+		return;
+
+	DB( g_print("\n[ui-transaction] type change\n") );
+
+	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
+
+	type = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
+
+	DB( g_print(" type:%d emit from '%s'\n", type, gtk_button_get_label(GTK_BUTTON(widget))) );
+
+	if( type == TXN_TYPE_INTXFER )
+	{
+		if( !(data->action == TXN_DLG_ACTION_EDIT) )
+			deftransaction_cb_accfrom_changed(widget, user_data);
+	}
+
+	//#1882456
+	ui_cat_entry_popover_sort_type(GTK_BOX(data->PO_cat), type);
+
+	deftransaction_cb_amount_focusout(widget, NULL, user_data);
+	
+	DB( g_print("[ui-transaction] end type change\n") );
+
+	deftransaction_update(widget, user_data);
+	
+}
+
+
 static void deftransaction_set(GtkWidget *widget, gpointer user_data)
 {
 struct deftransaction_data *data;
@@ -384,6 +548,14 @@ gchar *tagstr;
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), entry->amount);
 	g_signal_handlers_unblock_by_func(G_OBJECT(data->ST_amount), G_CALLBACK(deftransaction_cb_amount_focusout), NULL);
 
+	//#1673260
+	if( type == TXN_TYPE_INTXFER )
+	{
+		g_signal_handlers_block_by_func(G_OBJECT(data->ST_xferamt), G_CALLBACK(deftransaction_cb_dstamount_focusout), NULL);
+		gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_xferamt), entry->xferamount);
+		g_signal_handlers_unblock_by_func(G_OBJECT(data->ST_xferamt), G_CALLBACK(deftransaction_cb_dstamount_focusout), NULL);
+	}
+
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(data->CM_cheque), (entry->flags & OF_CHEQ2) ? 1 : 0);
 
 	hbtk_entry_set_text(GTK_ENTRY(data->ST_info), entry->info);
@@ -431,47 +603,6 @@ gchar *tagstr;
 }
 
 
-static gboolean deftransaction_cb_amount_focusout(GtkWidget *widget, GdkEventFocus *event, gpointer user_data)
-{
-struct deftransaction_data *data;
-gint type;
-gdouble amount;
-gboolean change;
-	
-	DB( g_print("\n[ui-transaction] amount focus-out-event %d\n", gtk_widget_is_focus(widget)) );
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
-	//#1681532 not reproduced, but prevent
-	if( GTK_IS_COMBO_BOX(data->NU_mode) )
-	{
-		type = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
-		amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
-
-		change = FALSE;
-		if( hb_amount_type_match(amount, type) == FALSE )
-			change = TRUE;
-		
-		// for internal transfer add, amount must be expense by default
-		if( type == TXN_TYPE_INTXFER && data->action == TXN_DLG_ACTION_ADD && amount > 0)
-			change = TRUE;
-
-		if( change == TRUE )
-		{
-			g_signal_handlers_block_by_func(G_OBJECT(data->ST_amount), G_CALLBACK(deftransaction_cb_amount_focusout), NULL);
-			gtk_spin_button_set_value(GTK_SPIN_BUTTON(data->ST_amount), amount *= -1);
-			g_signal_handlers_unblock_by_func(G_OBJECT(data->ST_amount), G_CALLBACK(deftransaction_cb_amount_focusout), NULL);
-		}
-		
-		//#1872329 fill-in cheque if condition match
-		deftransaction_set_cheque(widget, NULL);
-
-		DB( g_print(" - call warnsign\n") );
-		deftransaction_update_warnsign(widget, NULL);
-	}
-	return FALSE;
-}
-
 
 static void deftransaction_cb_split_clicked(GtkWidget *widget, gpointer user_data)
 {
@@ -480,7 +611,7 @@ Transaction *ope;
 gdouble amount;
 Account *srcacc;
 gint type, nbsplit;
-guint32 kcur;
+guint32 kcur, date;
 
 	DB( g_print("\n[ui-transaction] cb split clicked\n") );
 
@@ -489,12 +620,13 @@ guint32 kcur;
 	ope = data->ope;
 
 	type   = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
+	date   = gtk_date_entry_get_date(GTK_DATE_ENTRY(data->PO_date));
 	amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
 	srcacc = ui_acc_entry_popover_get(GTK_BOX(data->PO_acc));
 	kcur   = (srcacc != NULL) ? srcacc->kcur : GLOBALS->kcur;
 
 
-	ui_split_dialog(data->dialog, &ope->splits, type, amount, kcur, &deftransaction_set_amount_from_split);
+	ui_split_dialog(data->dialog, &ope->splits, type, date, amount, kcur, &deftransaction_set_amount_from_split);
 
 	DB( g_print(" - after closed dialog\n") );
 	/* old stuffs */
@@ -541,41 +673,6 @@ gboolean visible;
 }
 
 
-static void deftransaction_cb_type_toggled(GtkWidget *widget, gpointer user_data)
-{
-struct deftransaction_data *data;
-gint type;
-
-	//ignore event triggered from inactive radiobutton
-	if( gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget)) == FALSE )
-		return;
-
-	DB( g_print("\n[ui-transaction] type change\n") );
-
-	data = g_object_get_data(G_OBJECT(gtk_widget_get_ancestor(widget, GTK_TYPE_WINDOW)), "inst_data");
-
-	type = hbtk_radio_button_get_active(GTK_CONTAINER(data->RA_type));
-
-	DB( g_print(" type:%d emit from '%s'\n", type, gtk_button_get_label(GTK_BUTTON(widget))) );
-
-	if( type == TXN_TYPE_INTXFER )
-	{
-		if( !(data->action == TXN_DLG_ACTION_EDIT) )
-			deftransaction_cb_accfrom_changed(widget, user_data);
-	}
-
-	//#1882456
-	ui_cat_entry_popover_sort_type(GTK_BOX(data->PO_cat), type);
-
-	deftransaction_cb_amount_focusout(widget, NULL, user_data);
-	
-	DB( g_print("[ui-transaction] end type change\n") );
-
-	deftransaction_update(widget, user_data);
-	
-}
-
-
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
@@ -633,10 +730,14 @@ gint type, active;
 
 	//#1988594 ensure amount are updated
 	gtk_spin_button_update(GTK_SPIN_BUTTON(data->ST_amount));
+	gtk_spin_button_update(GTK_SPIN_BUTTON(data->ST_xferamt));
 	
 	entry->amount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_amount));
 	DB( g_print(" amount: %f '%s'\n", entry->amount, gtk_entry_get_text(GTK_ENTRY(data->ST_amount))) );
 
+	entry->xferamount = gtk_spin_button_get_value(GTK_SPIN_BUTTON(data->ST_xferamt));
+	DB( g_print(" xferamount %f '%s'\n", entry->xferamount, gtk_entry_get_text(GTK_ENTRY(data->ST_xferamt))) );
+
 	//entry->kacc     = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_acc));
 	entry->kacc     = ui_acc_entry_popover_get_key(GTK_BOX(data->PO_acc));
 	//entry->kxferacc = ui_acc_comboboxentry_get_key(GTK_COMBO_BOX(data->PO_accto));
@@ -657,7 +758,7 @@ gint type, active;
 		entry->memo = g_strdup(txt);
 		
 		//#1716182 add into memo autocomplete
-		if( da_transaction_insert_memo(entry) )
+		if( da_transaction_insert_memo(entry->memo, entry->date) )
 		{
 		GtkEntryCompletion *completion;
 		GtkTreeModel *model;
@@ -709,6 +810,7 @@ gint type, active;
 	if( data->action == TXN_DLG_ACTION_ADD )
 	{
 		entry->amount = ABS(entry->amount);
+		entry->xferamount = ABS(entry->xferamount);
 		if( (type == TXN_TYPE_EXPENSE) || (type == TXN_TYPE_INTXFER) )
 		{
 			entry->amount = -entry->amount;
@@ -727,20 +829,40 @@ gint type, active;
 
 	/* flags */
 	//entry->flags = 0;
-	entry->flags &= ~(OF_SPLIT|OF_CHEQ2);	//remove existing flags
+	entry->flags &= ~(OF_SPLIT|OF_ADVXFER|OF_CHEQ2);	//remove existing flags
 
 	//1859117: keep the split flag
 	if( da_splits_length (entry->splits) > 0 )
 		entry->flags |= OF_SPLIT; //Flag that Splits are active
 	
 	if(	data->action == TXN_DLG_ACTION_ADD || data->action == TXN_DLG_ACTION_INHERIT)
-	entry->flags |= OF_ADDED;
+		entry->flags |= OF_ADDED;
 
 	if(	data->action == TXN_DLG_ACTION_EDIT)
-	entry->flags |= OF_CHANGED;
+		entry->flags |= OF_CHANGED;
 
 	active = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(data->CM_cheque));
-	if(active == 1) entry->flags |= OF_CHEQ2;
+	if(active == 1) 
+		entry->flags |= OF_CHEQ2;
+
+	//#1673260
+	if( type == TXN_TYPE_INTXFER )
+	{
+	Account *srcacc, *dstacc;
+
+		srcacc = da_acc_get(entry->kacc);
+		dstacc = da_acc_get(entry->kxferacc);
+		if( srcacc && dstacc )
+		{
+			if( srcacc->kcur != dstacc->kcur )
+			{
+				DB( g_print(" get OF_ADVXFER\n") );
+				entry->flags |= OF_ADVXFER;
+			}
+		}
+	}
+	else
+		entry->xferamount = 0;
 
 	//active = gtk_combo_box_get_active(GTK_COMBO_BOX(data->CY_amount));
 	//we keep this in case the user want to force the type
@@ -799,7 +921,12 @@ Account *acc;
 	dialog = create_deftransaction_window(GTK_WINDOW(parent), TXN_DLG_ACTION_EDIT, TXN_DLG_TYPE_TXN, 0);
 	deftransaction_set_transaction(dialog, new_txn);
 
+	DB( g_print(" ** dialog run **\n") );
+	
 	result = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	DB( g_print(" ** dialog ended :: result=%d**\n", result) );
+
 	if(result == GTK_RESPONSE_ACCEPT)
 	{
 		deftransaction_get(dialog, NULL);
@@ -874,8 +1001,7 @@ Account *acc;
 					//we must use old_txn to ensure get the child
 					//#1663789 but we must clean new as well
 					transaction_xfer_remove_child(old_txn);
-					new_txn->kxfer = 0;
-					new_txn->kxferacc = 0;
+					transaction_xfer_change_to_normal(new_txn);
 				}
 				else	//force paymode to internal xfer
 				{
@@ -952,6 +1078,11 @@ static void deftransaction_setup(struct deftransaction_data *data)
 
 	DB( g_print("\n[ui-transaction] setup\n") );
 
+	//DB( g_print(" init data\n") );
+	
+
+	DB( g_print(" populate\n") );	
+
 	if( data->showtemplate )
 	{
 		ui_popover_tpl_populate (data, GLOBALS->arc_list);
@@ -971,6 +1102,11 @@ static void deftransaction_setup(struct deftransaction_data *data)
 	//ui_pay_comboboxentry_populate(GTK_COMBO_BOX(data->PO_pay), GLOBALS->h_pay);
 	//ui_tag_combobox_populate(GTK_COMBO_BOX_TEXT(data->CY_tags));
 
+	//DB( g_print(" set widgets default\n") );
+
+	//DB( g_print(" connect widgets signals\n") );
+
+
 	DB( g_print("[ui-transaction] end setup\n") );
 }
 
@@ -1045,37 +1181,7 @@ GString *tpltitle;
 	Archive *item = list->data;
 
 		//#1968249 build a non empty label, when memo/payee/category are empty
-		g_string_truncate(tpltitle, 0);
-		if(item->memo != NULL)
-		{
-			g_string_append(tpltitle, item->memo);
-		}
-		else
-		{
-			g_string_append(tpltitle, _("(no memo)") );
-			if(item->kpay > 0)
-			{
-			Payee *pay = da_pay_get(item->kpay);
-
-				if(pay != NULL)
-				{
-					g_string_append_c(tpltitle, ' ');
-					g_string_append(tpltitle, pay->name);
-				}
-			}
-
-			if(item->kcat > 0)
-			{
-			Category *cat = da_cat_get(item->kcat);
-
-				if(cat != NULL)
-				{
-					g_string_append(tpltitle, " / ");
-					g_string_append(tpltitle, cat->fullname);
-				}
-			}
-
-		}
+		da_archive_get_display_label(tpltitle, item);
 		
 		gtk_list_store_insert_with_values(GTK_LIST_STORE(model), &iter, -1,
 			LST_DSPTPL_DATAS, item,
@@ -1458,6 +1564,26 @@ gint row;
 		gtk_widget_set_margin_start(label, SPACING_SMALL);
 		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
 
+	//#1673260
+	row++;
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, SPACING_SMALL);
+	//gtk_widget_set_hexpand(hbox, FALSE);
+	gtk_grid_attach (GTK_GRID (group_grid), hbox, 1, row, 2, 1);
+
+		widget = make_amount(label);
+		data->ST_xferamt = widget;
+		gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+
+		label = make_label(NULL, 0, 0.5);
+		data->LB_xfercurr = label;
+		//gtk_widget_set_margin_start(label, SPACING_SMALL);
+		gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
+	
+		widget = gtk_image_new_from_icon_name(ICONNAME_WARNING, GTK_ICON_SIZE_SMALL_TOOLBAR);
+		data->IM_xfernorate = widget;
+		gtk_widget_set_tooltip_text (widget, _("No rate available to auto fill"));
+		gtk_box_pack_start (GTK_BOX (hbox), widget, FALSE, FALSE, 0);
+
 	
 	/*row++;
 	label = make_label_widget(_("A_ccount:"));
@@ -1643,10 +1769,11 @@ gint row;
 	wg = &PREFS->txn_wg;
 	gtk_window_set_default_size(GTK_WINDOW(dialog), wg->w, -1);
 
-	//connect all our signals
-	//g_signal_connect (dialog, "configure-event", G_CALLBACK (deftransaction_getgeometry), (gpointer)data);
-	//#1681532
+	// connect dialog signals
 	g_signal_connect (dialog, "destroy", G_CALLBACK (deftransaction_cb_destroy), NULL);
+	
+	//debug signal not to release
+	//g_signal_connect (dialog, "configure-event", G_CALLBACK (deftransaction_getgeometry), (gpointer)data);
 
 	hbtk_radio_button_connect (GTK_CONTAINER(data->RA_type), "toggled", G_CALLBACK (deftransaction_cb_type_toggled), NULL);
 
@@ -1659,9 +1786,14 @@ gint row;
 	
 	g_signal_connect (data->ST_amount, "value-changed", G_CALLBACK (deftransaction_cb_amount_focusout), NULL);
 	g_signal_connect (data->ST_amount, "focus-out-event", G_CALLBACK (deftransaction_cb_amount_focusout), NULL);
-	//g_signal_connect (data->ST_amount, "icon-release", G_CALLBACK (deftransaction_toggleamount), NULL);
+
 	g_signal_connect (data->BT_split, "clicked", G_CALLBACK (deftransaction_cb_split_clicked), NULL);
 
+	//#1673260
+	g_signal_connect (data->ST_xferamt, "value-changed", G_CALLBACK (deftransaction_cb_dstamount_focusout), NULL);
+	g_signal_connect (data->ST_xferamt, "focus-out-event", G_CALLBACK (deftransaction_cb_dstamount_focusout), NULL);
+
+
 	g_signal_connect (data->NU_mode  , "changed", G_CALLBACK (deftransaction_paymode), NULL);
 	g_signal_connect (data->CM_cheque, "toggled", G_CALLBACK (deftransaction_paymode), NULL);
 
@@ -1673,4 +1805,3 @@ gint row;
 	return dialog;
 }
 
-
