@@ -61,10 +61,8 @@ gchar *RA_REPORT_TIME_MODE[] = {
 };
 
 
-gchar *nainex_label_names[] =
+gchar *RA_FILTER_MODE[] =
 {
-//	N_("Inactive"),
-	N_("Off"),
 	N_("Include"),
 	N_("Exclude"),
 	NULL
@@ -95,22 +93,42 @@ HbKvData CYA_ACC_TYPE[] =
 
 
 HbKvData CYA_FLT_RANGE[] = {
-	{ FLT_RANGE_THISMONTH,		N_("This month") },
-	{ FLT_RANGE_LASTMONTH,		N_("Last month") },
-	{ FLT_RANGE_THISQUARTER,	N_("This quarter") },
-	{ FLT_RANGE_LASTQUARTER,	N_("Last quarter") },
-	{ FLT_RANGE_THISYEAR,		N_("This year") },
-	{ FLT_RANGE_LASTYEAR,		N_("Last year") },
+	{  FLT_RANGE_LAST_DAY       , "Yesterday" },
+	{  FLT_RANGE_THIS_DAY       , "Today" },
+	{  FLT_RANGE_NEXT_DAY       , "Tomorrow" },
+
+	{  FLT_RANGE_LAST_WEEK      , "Last Week" },
+	{  FLT_RANGE_THIS_WEEK      , "This Week" },
+	{  FLT_RANGE_NEXT_WEEK      , "Next Week" },
+
+	{  FLT_RANGE_LAST_FORTNIGHT , "This Fortnight" },
+	{  FLT_RANGE_THIS_FORTNIGHT , "This Fortnight" },
+	{  FLT_RANGE_NEXT_FORTNIGHT , "Next Fortnight" },
+
+	{  FLT_RANGE_LAST_MONTH     , "Last Month" },
+	{  FLT_RANGE_THIS_MONTH     , "This Month" },
+	{  FLT_RANGE_NEXT_MONTH     , "Next Month" },
+
+	{  FLT_RANGE_LAST_QUARTER   , "Last Quarter" },
+	{  FLT_RANGE_THIS_QUARTER   , "This Quarter" },
+	{  FLT_RANGE_NEXT_QUARTER   , "Next Quarter" },
+
+	{  FLT_RANGE_LAST_YEAR      , "Last Year" },
+	{  FLT_RANGE_THIS_YEAR      , "This Year" },
+	{  FLT_RANGE_NEXT_YEAR      , "Next Year" },
+
 	{ HBTK_IS_SEPARATOR, "" },
-	{ FLT_RANGE_LAST30DAYS,		N_("Last 30 days") },
-	{ FLT_RANGE_LAST60DAYS,		N_("Last 60 days") },
-	{ FLT_RANGE_LAST90DAYS,		N_("Last 90 days") },
-	{ FLT_RANGE_LAST12MONTHS,	N_("Last 12 months") },
 	{ HBTK_IS_SEPARATOR, "" },
-//	{ FLT_RANGE_OTHER,			N_("Other...") },
-	{ FLT_RANGE_OTHER,			N_("custom") },
 	{ HBTK_IS_SEPARATOR, "" },
-	{ FLT_RANGE_ALLDATE,		N_("All date") },
+
+	{  FLT_RANGE_LAST_30DAYS    , "Last 30 Days" },
+	{  FLT_RANGE_LAST_60DAYS    , "Last 60 Days" },
+	{  FLT_RANGE_LAST_90DAYS    , "Last 90 Days" },
+
+	{  FLT_RANGE_LAST_12MONTHS  , "Last 12 Months" },
+	{  FLT_RANGE_MISC_30DAYS    , "30 Days Around" },
+	{  FLT_RANGE_MISC_ALLDATE   , "All Date" },
+
 	{ 0, NULL }
 };
 
@@ -164,6 +182,8 @@ gchar *RA_ARC_WEEKEND[] = {
 	N_("Possible"), 
 	N_("Before"), 
 	N_("After"), 
+	//added 5.6
+	N_("Skip"), 
 	NULL
 };
 
