@@ -162,6 +162,29 @@ gimp_label_set_attributes (GtkLabel *label,
 }
 
 
+gint hb_clicklabel_to_int(const gchar *uri)
+{
+gint retval = HB_LIST_QUICK_SELECT_UNSET;
+
+	if (g_strcmp0 (uri, "all") == 0)	
+	{
+		retval = HB_LIST_QUICK_SELECT_ALL;
+	}
+	else
+	if (g_strcmp0 (uri, "non") == 0)	
+	{
+		retval = HB_LIST_QUICK_SELECT_NONE;
+	}
+	else
+	if (g_strcmp0 (uri, "inv") == 0)	
+	{
+		retval = HB_LIST_QUICK_SELECT_INVERT;
+	}
+
+	return retval;
+}
+
+
 void hb_widget_set_margin(GtkWidget *widget, gint margin)
 {
 	gtk_widget_set_margin_start (widget, margin);
@@ -260,7 +283,32 @@ GtkTreePath *path;
 		path = gtk_tree_model_get_path(model, &iter);
 		gtk_tree_model_row_changed(model, path, &iter);
 		gtk_tree_path_free (path);
-	}	
+	}
+}
+
+
+GtkTreeViewColumn *
+hbtk_treeview_get_column_by_id(GtkTreeView *treeview, gint search_id)
+{
+GtkTreeViewColumn *column = NULL;
+GList *list, *tmp;
+gint id;
+
+	list = gtk_tree_view_get_columns( treeview );
+	tmp = g_list_first(list);
+	while (tmp != NULL)
+	{
+		id = gtk_tree_view_column_get_sort_column_id(tmp->data);
+		if( search_id == id )
+		{
+			column = tmp->data;
+			break;
+		}
+		tmp = g_list_next(tmp);
+	}
+	g_list_free(list);
+
+	return column;
 }
 
 
@@ -1046,7 +1094,7 @@ guint i;
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
 
 
-#define HB_KV_BUFFER_MAX_LEN	16
+#define HB_KV_BUFFER_MAX_LEN	8
 #define HB_KV_ITEMS_MAX_LEN		32
 
 gchar *hbtk_get_label(HbKvData *kvdata, guint32 key)
@@ -1175,7 +1223,7 @@ gboolean sensitive;
 
 	path = gtk_tree_model_get_path (tree_model, iter);
 	indices = gtk_tree_path_get_indices (path);
-	sensitive = indices[0] != FLT_RANGE_OTHER;  
+	sensitive = indices[0] != FLT_RANGE_MISC_CUSTOM;  
 	gtk_tree_path_free (path);
 
 	g_object_set (cell, "sensitive", sensitive, NULL);
@@ -1196,7 +1244,7 @@ guint32 i;
 		if( tmp->name == NULL )
 			break;
 
-		if( (tmp->key == FLT_RANGE_OTHER) )
+		if( (tmp->key == FLT_RANGE_MISC_CUSTOM) )
 		{
 			if( dspmode == DATE_RANGE_CUSTOM_DISABLE )
 			{
@@ -1223,6 +1271,9 @@ guint32 i;
 		hbtk_combo_box_text_append(GTK_COMBO_BOX_TEXT(combobox), tmp->key, (*tmp->name != 0) ? (gchar *)_(tmp->name) : (gchar *)"");
 	}
 
+	//TODO: option removed into GTK4 ??
+	gtk_combo_box_set_wrap_width (GTK_COMBO_BOX(combobox), 3);
+
 	gtk_combo_box_set_active(GTK_COMBO_BOX(combobox), 0);
 	gtk_combo_box_set_row_separator_func (GTK_COMBO_BOX (combobox), hbtk_combo_box_is_separator, NULL, NULL);
 
@@ -1431,72 +1482,3 @@ GtkWidget *make_paymode_nointxfer(GtkWidget *label)
 }
 
 
-/* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
-
-#define NUM_NAINEX_MAX 3
-
-enum
-{
-	LST_NAINEX_ICONNAME,
-	LST_NAINEX_LABEL,
-	NUM_LST_NAINEX
-};
-
-char *nainex_iconnames[NUM_NAINEX_MAX] =
-{
-	"flt-inactive",
-	"flt-include",
-	"flt-exclude",
-};
-
-extern gchar *nainex_label_names[];
-
-/*
-** Make a nainex combobox widget
-*/
-GtkWidget *make_nainex(GtkWidget *label)
-{
-GtkListStore  *store;
-GtkTreeIter    iter;
-GtkWidget *combobox;
-GtkCellRenderer    *renderer;
-guint i;
-
-	//store
-	store = gtk_list_store_new (
-		NUM_LST_NAINEX,
-		G_TYPE_STRING,
-		G_TYPE_STRING
-		);
-
-	//combobox
-	combobox = gtk_combo_box_new_with_model(GTK_TREE_MODEL(store));
-
-	//column 1
-	renderer = gtk_cell_renderer_pixbuf_new();
-	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combobox), renderer, FALSE);
-	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT(combobox), renderer, "icon-name", LST_NAINEX_ICONNAME);
-
-	renderer = gtk_cell_renderer_text_new();
-	gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(combobox), renderer, FALSE);
-	gtk_cell_layout_add_attribute (GTK_CELL_LAYOUT(combobox), renderer, "text", LST_NAINEX_LABEL);
-
-	gtk_combo_box_set_active(GTK_COMBO_BOX(combobox), 0);
-
-	//populate our combobox model
-	for(i=0;i<NUM_NAINEX_MAX;i++)
-	{
-		gtk_list_store_append(store, &iter);
-		gtk_list_store_set(store, &iter,
-			LST_NAINEX_ICONNAME, nainex_iconnames[i],
-			LST_NAINEX_LABEL, _(nainex_label_names[i]),
-			-1);
-	}
-	gtk_combo_box_set_active(GTK_COMBO_BOX(combobox), 0);
-
-	if(label)
-		gtk_label_set_mnemonic_widget (GTK_LABEL(label), combobox);
-
-	return combobox;
-}
-
